/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:22:15-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define TAG_1_6 1
#define LABEL_1_11 7
#define LABEL_1_12 9
#define LABEL_1_7 11
#define TAG_1_8 4
#define LABEL_1_13 13
#define LABEL_1_14 15
#define LABEL_1_9 17
#define LABEL_1_15 19
#define LABEL_1_17 21
#define LABEL_1_18 23
#define LABEL_1_19 25
#define LABEL_1_20 27
#define LABEL_1_21 29
#define LABEL_1_23 31
#define LABEL_1_25 33
#define LABEL_1_28 35
#define LABEL_1_29 37
#define LABEL_1_30 39
#define LABEL_1_27 41
#define LABEL_1_31 43
#define LABEL_1_33 45
#define LABEL_1_34 47
#define LABEL_1_35 49
#define LABEL_1_32 51
#define LABEL_1_36 53
#define LABEL_1_38 55
#define LABEL_1_39 57
#define LABEL_1_40 59
#define LABEL_1_37 61
#define LABEL_1_41 63
#define LABEL_1_43 65
#define LABEL_1_44 67
#define LABEL_1_45 69
#define LABEL_1_42 71
#define LABEL_1_46 73
#define LABEL_1_47 75
#define LABEL_1_48 77
#define LABEL_1_51 79
#define LABEL_1_49 81
#define LABEL_1_52 83
#define ENVIRONMENT_LABEL_1_3 119
#define DEBUGGING_LABEL_1_2 118
#define OBJECT_1_14 117
#define OBJECT_1_13 116
#define OBJECT_1_12 115
#define OBJECT_1_11 114
#define OBJECT_1_10 113
#define OBJECT_1_9 112
#define OBJECT_1_8 111
#define OBJECT_1_7 110
#define OBJECT_1_6 109
#define OBJECT_1_5 108
#define OBJECT_1_4 107
#define OBJECT_1_3 106
#define OBJECT_1_2 105
#define OBJECT_1_1 104
#define OBJECT_1_0 103
#define EXECUTE_CACHE_1_53 85
#define EXECUTE_CACHE_1_50 87
#define EXECUTE_CACHE_1_26 89
#define EXECUTE_CACHE_1_24 91
#define EXECUTE_CACHE_1_22 93
#define EXECUTE_CACHE_1_16 95
#define EXECUTE_CACHE_1_10 97
#define FREE_REFERENCE_1_0 100
#define FREE_ASSIGNMENT_1_0 102
#define FREE_REFERENCES_LABEL_1_0 84
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rdebug_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd26;
  machine_word Wrd38;
  machine_word Wrd15;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd53;
  machine_word Wrd54;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd27;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd37;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd5;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto dump_register_info_45;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto lambda_72;

    case 2:
      current_block = (Rpc - LABEL_1_11);
      goto label_47;

    case 3:
      current_block = (Rpc - LABEL_1_12);
      goto label_48;

    case 4:
      current_block = (Rpc - LABEL_1_7);
      goto lambda_73;

    case 5:
      current_block = (Rpc - LABEL_1_13);
      goto label_49;

    case 6:
      current_block = (Rpc - LABEL_1_14);
      goto label_50;

    case 7:
      current_block = (Rpc - LABEL_1_9);
      goto lambda_36;

    case 8:
      current_block = (Rpc - LABEL_1_15);
      goto lambda_35;

    case 9:
      current_block = (Rpc - LABEL_1_17);
      goto label_51;

    case 10:
      current_block = (Rpc - LABEL_1_18);
      goto label_52;

    case 11:
      current_block = (Rpc - LABEL_1_19);
      goto label_53;

    case 12:
      current_block = (Rpc - LABEL_1_20);
      goto label_54;

    case 13:
      current_block = (Rpc - LABEL_1_21);
      goto continuation_10;

    case 14:
      current_block = (Rpc - LABEL_1_23);
      goto continuation_11;

    case 15:
      current_block = (Rpc - LABEL_1_25);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_1_28);
      goto label_55;

    case 17:
      current_block = (Rpc - LABEL_1_29);
      goto label_56;

    case 18:
      current_block = (Rpc - LABEL_1_30);
      goto label_57;

    case 19:
      current_block = (Rpc - LABEL_1_27);
      goto continuation_15;

    case 20:
      current_block = (Rpc - LABEL_1_31);
      goto continuation_16;

    case 21:
      current_block = (Rpc - LABEL_1_33);
      goto label_58;

    case 22:
      current_block = (Rpc - LABEL_1_34);
      goto label_59;

    case 23:
      current_block = (Rpc - LABEL_1_35);
      goto label_60;

    case 24:
      current_block = (Rpc - LABEL_1_32);
      goto continuation_19;

    case 25:
      current_block = (Rpc - LABEL_1_36);
      goto continuation_20;

    case 26:
      current_block = (Rpc - LABEL_1_38);
      goto label_61;

    case 27:
      current_block = (Rpc - LABEL_1_39);
      goto label_62;

    case 28:
      current_block = (Rpc - LABEL_1_40);
      goto label_63;

    case 29:
      current_block = (Rpc - LABEL_1_37);
      goto continuation_23;

    case 30:
      current_block = (Rpc - LABEL_1_41);
      goto continuation_24;

    case 31:
      current_block = (Rpc - LABEL_1_43);
      goto label_64;

    case 32:
      current_block = (Rpc - LABEL_1_44);
      goto label_65;

    case 33:
      current_block = (Rpc - LABEL_1_45);
      goto label_66;

    case 34:
      current_block = (Rpc - LABEL_1_42);
      goto continuation_27;

    case 35:
      current_block = (Rpc - LABEL_1_46);
      goto label_67;

    case 36:
      current_block = (Rpc - LABEL_1_47);
      goto label_68;

    case 37:
      current_block = (Rpc - LABEL_1_48);
      goto label_69;

    case 38:
      current_block = (Rpc - LABEL_1_51);
      goto continuation_31;

    case 39:
      current_block = (Rpc - LABEL_1_49);
      goto continuation_33;

    case 40:
      current_block = (Rpc - LABEL_1_52);
      goto continuation_32;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dump_register_info_71)
DEFLABEL (dump_register_info_45)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd8.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd28.pObj) = (& (Rhp [-1]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd28.pObj)));
  (Rsp [1]) = (Wrd29.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_5])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  ((Wrd16.pObj) [2]) = (Wrd29.Obj);
  ((Wrd16.pObj) [3]) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_7])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd23 = Wrd20;
  ((Wrd23.pObj) [2]) = (Wrd29.Obj);
  ((Wrd23.pObj) [3]) = (Wrd7.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_9]))));
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_10]));

DEFLABEL (lambda_72)
  CLOSURE_HEADER (LABEL_1_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_81;

DEFLABEL (label_80)
  Wrd19 = Wrd23;

DEFLABEL (label_79)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_78;

DEFLABEL (label_77)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_76)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_78)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_77;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_12])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_48)
  goto label_76;

DEFLABEL (label_81)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_80;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_11])), (Wrd20.pObj));

DEFLABEL (label_47)
  (Wrd19.Obj) = Rvl;
  goto label_79;

DEFLABEL (lambda_73)
  CLOSURE_HEADER (LABEL_1_7);

DEFLABEL (lambda_43)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_87;

DEFLABEL (label_86)
  Wrd19 = Wrd23;

DEFLABEL (label_85)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_84;

DEFLABEL (label_83)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_82)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_84)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_83;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_14])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_50)
  goto label_82;

DEFLABEL (label_87)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_86;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_13])), (Wrd20.pObj));

DEFLABEL (label_49)
  (Wrd19.Obj) = Rvl;
  goto label_85;

DEFLABEL (lambda_74)
DEFLABEL (lambda_36)
  INTERRUPT_CHECK (26, LABEL_1_9);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_15]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (lambda_75)
DEFLABEL (lambda_35)
  INTERRUPT_CHECK (26, LABEL_1_15);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_131;
  Wrd6 = Wrd10;

DEFLABEL (label_130)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_129;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_129;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);

DEFLABEL (label_128)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_127;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_127;
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd33.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_127;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd29.pObj) = (& ((Wrd34.pObj) [(Wrd27.Lng)]));
  (Wrd25.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_126)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd43.uLng) == 26))
    goto label_125;
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if ((Wrd54.Lng) > 0)
    goto label_89;

DEFLABEL (label_88)
  Rvl = (current_block [OBJECT_1_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_89)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_21]))));
  (* (--Rsp)) = (Wrd53.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_22]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_1_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_1_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_1_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_124;
  Wrd9 = Wrd13;

DEFLABEL (label_123)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_122;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_122;
  (Wrd15.Obj) = ((Wrd19.pObj) [4]);

DEFLABEL (label_121)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_120;
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 26))
    goto label_120;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) (Wrd36.Lng)) < ((unsigned long) (Wrd39.Lng))))
    goto label_120;
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd31.pObj) = (& ((Wrd37.pObj) [(Wrd29.Lng)]));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_119)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_1_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_1_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_118;
  Wrd9 = Wrd13;

DEFLABEL (label_117)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_116;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_116;
  (Wrd15.Obj) = ((Wrd19.pObj) [5]);

DEFLABEL (label_115)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_114;
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 26))
    goto label_114;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) (Wrd36.Lng)) < ((unsigned long) (Wrd39.Lng))))
    goto label_114;
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd31.pObj) = (& ((Wrd37.pObj) [(Wrd29.Lng)]));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_113)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_1_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_6]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_1_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_112;
  Wrd9 = Wrd13;

DEFLABEL (label_111)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_110;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd21.Lng))))
    goto label_110;
  (Wrd15.Obj) = ((Wrd19.pObj) [7]);

DEFLABEL (label_109)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_108;
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 26))
    goto label_108;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) (Wrd36.Lng)) < ((unsigned long) (Wrd39.Lng))))
    goto label_108;
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd31.pObj) = (& ((Wrd37.pObj) [(Wrd29.Lng)]));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_107)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_1_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_1_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_106;
  Wrd9 = Wrd13;

DEFLABEL (label_105)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_104;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd21.Lng))))
    goto label_104;
  (Wrd15.Obj) = ((Wrd19.pObj) [6]);

DEFLABEL (label_103)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_102;
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 26))
    goto label_102;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) (Wrd36.Lng)) < ((unsigned long) (Wrd39.Lng))))
    goto label_102;
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd31.pObj) = (& ((Wrd37.pObj) [(Wrd29.Lng)]));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_101)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_1_42);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_100;
  Wrd6 = Wrd10;

DEFLABEL (label_99)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_98;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_98;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);

DEFLABEL (label_97)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_96;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_96;
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd33.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_96;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd28.pObj) = (& ((Wrd34.pObj) [(Wrd26.Lng)]));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_95)
  (Wrd43.Obj) = (Rsp [0]);
  if (! ((Wrd43.Obj) == (current_block [OBJECT_1_10])))
    goto label_93;
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_49]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd56.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_50]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_1_49);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_91;
  (Wrd7.Obj) = (current_block [OBJECT_1_14]);
  (Rsp [1]) = (Wrd7.Obj);
  goto label_90;

DEFLABEL (label_91)
  (Wrd9.Obj) = (current_block [OBJECT_1_13]);
  (Rsp [1]) = (Wrd9.Obj);

DEFLABEL (label_90)
DEFLABEL (label_92)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (label_93)
  if (! ((Wrd43.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_94;
  (Wrd51.Obj) = (current_block [OBJECT_1_11]);
  (Rsp [1]) = (Wrd51.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (label_94)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_51]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_1_12]);
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_1_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_52]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_53]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_1_52);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (label_96)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_48]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_69)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  (Wrd21.Obj) = (current_block [OBJECT_1_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_47]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_68)
  (Wrd12.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_46])), (Wrd7.pObj));

DEFLABEL (label_67)
  (Wrd6.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_45]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_66)
  (* (--Rsp)) = Rvl;
  goto label_101;

DEFLABEL (label_104)
  (Wrd24.Obj) = (current_block [OBJECT_1_9]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_44]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_65)
  (Wrd15.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_106)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_43])), (Wrd10.pObj));

DEFLABEL (label_64)
  (Wrd9.Obj) = Rvl;
  goto label_105;

DEFLABEL (label_108)
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_40]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_63)
  (* (--Rsp)) = Rvl;
  goto label_107;

DEFLABEL (label_110)
  (Wrd24.Obj) = (current_block [OBJECT_1_7]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_39]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_62)
  (Wrd15.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_38])), (Wrd10.pObj));

DEFLABEL (label_61)
  (Wrd9.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_35]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_60)
  (* (--Rsp)) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  (Wrd24.Obj) = (current_block [OBJECT_1_1]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_34]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_59)
  (Wrd15.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_118)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_33])), (Wrd10.pObj));

DEFLABEL (label_58)
  (Wrd9.Obj) = Rvl;
  goto label_117;

DEFLABEL (label_120)
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_57)
  (* (--Rsp)) = Rvl;
  goto label_119;

DEFLABEL (label_122)
  (Wrd24.Obj) = (current_block [OBJECT_1_4]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_29]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_56)
  (Wrd15.Obj) = Rvl;
  goto label_121;

DEFLABEL (label_124)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_28])), (Wrd10.pObj));

DEFLABEL (label_55)
  (Wrd9.Obj) = Rvl;
  goto label_123;

DEFLABEL (label_125)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_20]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_INTERFACE_0 (44);

DEFLABEL (label_54)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_88;
  goto label_89;

DEFLABEL (label_127)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_19]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_53)
  (Wrd25.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  (Wrd21.Obj) = (current_block [OBJECT_1_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_18]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_52)
  (Wrd12.Obj) = Rvl;
  goto label_128;

DEFLABEL (label_131)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_17])), (Wrd7.pObj));

DEFLABEL (label_51)
  (Wrd6.Obj) = Rvl;
  goto label_130;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define TAG_2_6 1
#define LABEL_2_12 7
#define LABEL_2_13 9
#define LABEL_2_7 11
#define TAG_2_8 4
#define LABEL_2_15 13
#define LABEL_2_9 15
#define TAG_2_10 6
#define LABEL_2_16 17
#define LABEL_2_17 19
#define LABEL_2_14 21
#define LABEL_2_18 23
#define LABEL_2_24 25
#define LABEL_2_19 27
#define TAG_2_20 12
#define LABEL_2_22 29
#define TAG_2_23 13
#define LABEL_2_26 31
#define LABEL_2_28 33
#define LABEL_2_30 35
#define LABEL_2_31 37
#define LABEL_2_34 39
#define LABEL_2_32 41
#define LABEL_2_36 43
#define LABEL_2_35 45
#define LABEL_2_38 47
#define LABEL_2_39 49
#define LABEL_2_40 51
#define LABEL_2_42 53
#define LABEL_2_44 55
#define ENVIRONMENT_LABEL_2_3 91
#define DEBUGGING_LABEL_2_2 90
#define OBJECT_2_10 89
#define OBJECT_2_9 88
#define OBJECT_2_8 87
#define OBJECT_2_7 86
#define OBJECT_2_6 85
#define OBJECT_2_5 84
#define OBJECT_2_4 83
#define OBJECT_2_3 82
#define OBJECT_2_2 81
#define OBJECT_2_1 80
#define OBJECT_2_0 79
#define EXECUTE_CACHE_2_43 57
#define EXECUTE_CACHE_2_41 59
#define EXECUTE_CACHE_2_37 61
#define EXECUTE_CACHE_2_33 63
#define EXECUTE_CACHE_2_29 65
#define EXECUTE_CACHE_2_27 67
#define EXECUTE_CACHE_2_25 69
#define EXECUTE_CACHE_2_21 71
#define EXECUTE_CACHE_2_11 73
#define FREE_REFERENCE_2_0 76
#define FREE_ASSIGNMENT_2_0 78
#define FREE_REFERENCES_LABEL_2_0 56
#define NUMBER_OF_LINKER_SECTIONS_2_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rdebug_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto dump_block_info_37;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto lambda_49;

    case 2:
      current_block = (Rpc - LABEL_2_12);
      goto label_39;

    case 3:
      current_block = (Rpc - LABEL_2_13);
      goto label_40;

    case 4:
      current_block = (Rpc - LABEL_2_7);
      goto lambda_50;

    case 5:
      current_block = (Rpc - LABEL_2_15);
      goto label_41;

    case 6:
      current_block = (Rpc - LABEL_2_9);
      goto lambda_51;

    case 7:
      current_block = (Rpc - LABEL_2_16);
      goto label_42;

    case 8:
      current_block = (Rpc - LABEL_2_17);
      goto label_43;

    case 9:
      current_block = (Rpc - LABEL_2_14);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_2_18);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_2_24);
      goto label_44;

    case 12:
      current_block = (Rpc - LABEL_2_19);
      goto lambda_52;

    case 13:
      current_block = (Rpc - LABEL_2_22);
      goto lambda_53;

    case 14:
      current_block = (Rpc - LABEL_2_26);
      goto continuation_11;

    case 15:
      current_block = (Rpc - LABEL_2_28);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_2_30);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_2_31);
      goto continuation_16;

    case 18:
      current_block = (Rpc - LABEL_2_34);
      goto label_45;

    case 19:
      current_block = (Rpc - LABEL_2_32);
      goto lambda_15;

    case 20:
      current_block = (Rpc - LABEL_2_36);
      goto label_46;

    case 21:
      current_block = (Rpc - LABEL_2_35);
      goto continuation_18;

    case 22:
      current_block = (Rpc - LABEL_2_38);
      goto continuation_19;

    case 23:
      current_block = (Rpc - LABEL_2_39);
      goto continuation_20;

    case 24:
      current_block = (Rpc - LABEL_2_40);
      goto continuation_21;

    case 25:
      current_block = (Rpc - LABEL_2_42);
      goto lambda_23;

    case 26:
      current_block = (Rpc - LABEL_2_44);
      goto continuation_22;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dump_block_info_48)
DEFLABEL (dump_block_info_37)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_5])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  ((Wrd20.pObj) [2]) = (Wrd7.Obj);
  ((Wrd20.pObj) [3]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_7])));
  Rhp += 1;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  ((Wrd24.pObj) [2]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_9])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  ((Wrd32.pObj) [2]) = (Wrd7.Obj);
  ((Wrd32.pObj) [3]) = (Wrd13.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  (Rsp [1]) = (Wrd23.Obj);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_11]));

DEFLABEL (lambda_49)
  CLOSURE_HEADER (LABEL_2_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_61;

DEFLABEL (label_60)
  Wrd19 = Wrd23;

DEFLABEL (label_59)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_58;

DEFLABEL (label_57)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_56)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_58)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_57;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_13])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_40)
  goto label_56;

DEFLABEL (label_61)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_60;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_12])), (Wrd20.pObj));

DEFLABEL (label_39)
  (Wrd19.Obj) = Rvl;
  goto label_59;

DEFLABEL (lambda_50)
  CLOSURE_HEADER (LABEL_2_7);

DEFLABEL (lambda_28)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_65;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_65;
  (Wrd13.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_64)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_2_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_19])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_21]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_2_18);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_22])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_63;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd22.Lng))))
    goto label_63;
  (Wrd10.Obj) = ((Wrd20.pObj) [3]);

DEFLABEL (label_62)
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_25]));

DEFLABEL (label_63)
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Wrd30.Obj) = (current_block [OBJECT_2_4]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 2);

DEFLABEL (label_44)
  (Wrd10.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Wrd29.Obj) = (current_block [OBJECT_2_1]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (lambda_51)
  CLOSURE_HEADER (LABEL_2_9);

DEFLABEL (lambda_35)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_71;

DEFLABEL (label_70)
  Wrd19 = Wrd23;

DEFLABEL (label_69)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_68;

DEFLABEL (label_67)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_66)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_68)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_67;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_17])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_43)
  goto label_66;

DEFLABEL (label_71)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_70;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_16])), (Wrd20.pObj));

DEFLABEL (label_42)
  (Wrd19.Obj) = Rvl;
  goto label_69;

DEFLABEL (lambda_52)
  CLOSURE_HEADER (LABEL_2_19);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);

DEFLABEL (lambda_53)
  CLOSURE_HEADER (LABEL_2_22);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_2_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_2_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_2_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_32]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_2_31);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_74;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd13.Lng))))
    goto label_74;
  (Wrd7.Obj) = ((Wrd11.pObj) [9]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_73)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_35]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_7]), 2);

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_2_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_8]), 1);

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_2_38);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;
  Rvl = (current_block [OBJECT_2_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_72)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_39]))));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_2_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_2_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_41]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_2_40);
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_42]))));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_43]));

DEFLABEL (label_74)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_2_6]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 2);

DEFLABEL (label_45)
  (* (--Rsp)) = Rvl;
  goto label_73;

DEFLABEL (lambda_54)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_2_32);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_76;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_76;
  (Wrd5.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_75)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_37]));

DEFLABEL (label_76)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_2_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_36]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 2);

DEFLABEL (label_46)
  (Wrd5.Obj) = Rvl;
  goto label_75;

DEFLABEL (lambda_55)
DEFLABEL (lambda_23)
  INTERRUPT_CHECK (26, LABEL_2_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_2_10]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_41]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_2_44);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5 3
#define LABEL_6 5
#define LABEL_7 7
#define ENVIRONMENT_LABEL_3 16
#define DEBUGGING_LABEL_2 15
#define PURIFICATION_ROOT 14
#define OBJECT_2 13
#define OBJECT_1 12
#define OBJECT_0 11
#define GLOBAL_EXECUTE_CACHE_4 9
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
rdebug_so_19f281053f22db10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_5)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_4)
  {
    static const short sections [] =
      {
	0,
	3,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 2)
      goto label_3;
    blocks = (current_block [OBJECT_2]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_3)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

static const struct liarc_code_S arr_decl_rdebug_so_19f281053f22db10 [2] =
  {
    { "rdebug_so_code_1", 41, rdebug_so_code_1 },
    { "rdebug_so_code_2", 27, rdebug_so_code_2 }
  };

int
decl_rdebug_so_19f281053f22db10 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_rdebug_so_19f281053f22db10);
  return (0);
}

DECLARE_COMPILED_CODE ("rdebug.so", 3, decl_rdebug_so_19f281053f22db10, rdebug_so_19f281053f22db10)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_rdebug_so_data_19f281053f22db10 [1203] =
  "\x7b\x09\xfe\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0c\x0c"
  "\x0d\x85\x0c\x86\x0c\x0c\x83\x0c\xc2\xb9\x84\x1d\x0d\xba\x25\xb2"
  "\x24\x28\x0d\xbb\x28\x0d\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbf\x1d\xb0\x82\x88\x0c\x0c"
  "\xc1\xc2\x02\xc2\x82\xc2\xb1\x80\x1d\xb2\x25\xb2\x24\x28\xb3\x28"
  "\x0d\x28\x0d\x28\xb4\x28\xb5\x28\x0d\x28\x0d\x28\xb6\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x99\xbd\x88\xb5\xb6\x2a"
  "\xb7\x2a\x99\x0d\x0d\x99\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x02\x4f\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f"
  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30"
  "\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
  "\x72\x74\x6c\x6f\x70\x74\x2f\x72\x64\x65\x62\x75\x67\x2e\x69\x6e"
  "\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
  "\x2d\x72\x6f\x6f\x74\x5d\x02\x10\x3b\x20\x63\x72\x6f\x73\x73\x65"
  "\x73\x20\x63\x61\x6c\x6c\x73\x12\x3b\x20\x6d\x75\x6c\x74\x69\x70"
  "\x6c\x65\x20\x62\x6c\x6f\x63\x6b\x73\x09\x3b\x20\x62\x6c\x6f\x63"
  "\x6b\x20\x0c\x3b\x20\x6e\x6f\x20\x62\x6c\x6f\x63\x6b\x21\x0a\x6e"
  "\x6f\x6e\x2d\x6c\x6f\x63\x61\x6c\x0b\x3b\x20\x6e\x64\x65\x61\x74"
  "\x68\x73\x20\x0a\x3b\x20\x6c\x65\x6e\x67\x74\x68\x20\x09\x3b\x20"
  "\x6e\x72\x65\x66\x73\x20\x0c\x3a\x20\x72\x65\x6e\x75\x6d\x62\x65"
  "\x72\x20\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x02\x11\x2a"
  "\x63\x75\x72\x72\x65\x6e\x74\x2d\x72\x67\x72\x61\x70\x68\x2a\x02"
  "\x02\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64"
  "\x2d\x62\x69\x6e\x64\x03\x19\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d"
  "\x70\x73\x65\x75\x64\x6f\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x02"
  "\x08\x6e\x65\x77\x6c\x69\x6e\x65\x03\x06\x77\x72\x69\x74\x65\x03"
  "\x0d\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x03\x17\x72"
  "\x65\x67\x69\x73\x74\x65\x72\x2d\x63\x72\x6f\x73\x73\x65\x73\x2d"
  "\x63\x61\x6c\x6c\x3f\x03\x07\x75\x6e\x68\x61\x73\x68\x08\x2c\x54"
  "\x81\x85\x02\x2b\x52\x81\x85\x02\x2a\x50\x81\x85\x02\x29\x4e\x81"
  "\x83\x02\x28\x4c\x81\x83\x02\x27\x4a\x81\x83\x02\x26\x48\x81\x83"
  "\x02\x25\x46\x81\x85\x02\x24\x44\x81\x85\x02\x23\x42\x81\x85\x02"
  "\x22\x40\x81\x83\x02\x21\x3e\x81\x83\x02\x20\x3c\x81\x85\x02\x1f"
  "\x3a\x81\x85\x02\x1e\x38\x81\x85\x02\x1d\x36\x81\x83\x02\x1c\x34"
  "\x81\x83\x02\x1b\x32\x81\x85\x02\x1a\x30\x81\x85\x02\x19\x2e\x81"
  "\x85\x02\x18\x2c\x81\x83\x02\x17\x2a\x81\x83\x02\x16\x28\x81\x85"
  "\x02\x15\x26\x81\x85\x02\x14\x24\x81\x85\x02\x13\x22\x81\x83\x02"
  "\x12\x20\x81\x83\x02\x11\x1e\x81\x83\x02\x10\x1c\x81\x83\x02\x0f"
  "\x1a\x81\x83\x02\x0e\x18\x81\x83\x02\x0d\x16\x81\x83\x02\x0c\x14"
  "\x83\x04\x0b\x12\x82\x02\x0a\x10\x81\x87\x02\x09\x0e\x81\x85\x02"
  "\x08\x0c\x81\x83\x02\x07\x0a\x81\x87\x02\x06\x08\x81\x85\x02\x05"
  "\x06\x81\x83\x02\x04\x04\x83\x04\x53\x78\x02\x02\x20\x17\x52\x65"
  "\x67\x69\x73\x74\x65\x72\x73\x20\x6c\x69\x76\x65\x20\x61\x74\x20"
  "\x65\x6e\x64\x3a\x11\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d"
  "\x7a\x65\x72\x6f\x3f\x11\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67"
  "\x2d\x61\x6e\x64\x63\x21\x09\x10\x62\x69\x74\x2d\x73\x74\x72\x69"
  "\x6e\x67\x2d\x73\x65\x74\x21\x10\x6d\x61\x6b\x65\x2d\x62\x69\x74"
  "\x2d\x73\x74\x72\x69\x6e\x67\x02\x02\x02\x05\x03\x1a\x66\x6f\x72"
  "\x2d\x65\x61\x63\x68\x2d\x6d\x61\x63\x68\x69\x6e\x65\x2d\x72\x65"
  "\x67\x69\x73\x74\x65\x72\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68"
  "\x02\x03\x04\x14\x62\x62\x6c\x6f\x63\x6b\x2d\x77\x61\x6c\x6b\x2d"
  "\x66\x6f\x72\x77\x61\x72\x64\x03\x03\x70\x70\x03\x04\x17\x66\x6f"
  "\x72\x2d\x65\x61\x63\x68\x2d\x72\x65\x67\x73\x65\x74\x2d\x6d\x65"
  "\x6d\x62\x65\x72\x0a\x47\x38\x81\x83\x02\x46\x36\x83\x04\x45\x34"
  "\x81\x87\x02\x44\x32\x81\x87\x02\x43\x30\x81\x87\x02\x42\x2e\x81"
  "\x87\x02\x41\x2c\x81\x83\x02\x40\x2a\x83\x04\x3f\x28\x81\x85\x02"
  "\x3e\x26\x81\x85\x02\x3d\x24\x81\x85\x02\x3c\x22\x81\x85\x02\x3b"
  "\x20\x81\x85\x02\x3a\x1e\x81\x85\x02\x39\x1c\x81\x85\x02\x38\x1a"
  "\x81\x85\x02\x37\x18\x81\x85\x02\x36\x16\x81\x83\x02\x35\x14\x81"
  "\x87\x02\x34\x12\x81\x85\x02\x33\x10\x81\x83\x02\x32\x0e\x81\x87"
  "\x02\x31\x0c\x81\x83\x02\x30\x0a\x81\x87\x02\x2f\x08\x81\x85\x02"
  "\x2e\x06\x81\x83\x02\x2d\x04\x83\x04\x37\x5c\x04\x04\x10\x64\x75"
  "\x6d\x70\x2d\x62\x6c\x6f\x63\x6b\x2d\x69\x6e\x66\x6f\x13\x64\x75"
  "\x6d\x70\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x69\x6e\x66\x6f"
  "\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c"
  "\x65\x02\x03\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81"
  "\x02\x07\x11";

SCHEME_OBJECT *
rdebug_so_data_19f281053f22db10 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_rdebug_so_data_19f281053f22db10 [0]))), (sizeof (prog_rdebug_so_data_19f281053f22db10)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_7]));
}

DECLARE_COMPILED_DATA_NS ("rdebug.so", rdebug_so_data_19f281053f22db10)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("rdebug.so", "170a62c2d1649c48")
