/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:06-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define LABEL_1_8 7
#define LABEL_1_9 9
#define LABEL_1_10 11
#define LABEL_1_11 13
#define LABEL_1_12 15
#define LABEL_1_13 17
#define LABEL_1_14 19
#define LABEL_1_15 21
#define LABEL_1_16 23
#define LABEL_1_17 25
#define LABEL_1_18 27
#define LABEL_1_19 29
#define LABEL_1_20 31
#define LABEL_1_21 33
#define LABEL_1_6 35
#define LABEL_1_24 37
#define LABEL_1_22 39
#define LABEL_1_26 41
#define LABEL_1_27 43
#define LABEL_1_28 45
#define LABEL_1_29 47
#define LABEL_1_31 49
#define LABEL_1_32 51
#define LABEL_1_30 53
#define LABEL_1_33 55
#define LABEL_1_35 57
#define LABEL_1_36 59
#define LABEL_1_34 61
#define LABEL_1_37 63
#define ENVIRONMENT_LABEL_1_3 105
#define DEBUGGING_LABEL_1_2 104
#define OBJECT_1_5 103
#define OBJECT_1_4 102
#define OBJECT_1_3 101
#define OBJECT_1_2 100
#define OBJECT_1_1 99
#define OBJECT_1_0 98
#define EXECUTE_CACHE_1_25 65
#define EXECUTE_CACHE_1_23 67
#define EXECUTE_CACHE_1_7 69
#define FREE_REFERENCE_1_6 72
#define FREE_REFERENCE_1_5 73
#define FREE_REFERENCE_1_4 74
#define FREE_REFERENCE_1_3 75
#define FREE_REFERENCE_1_2 76
#define FREE_REFERENCE_1_1 77
#define FREE_REFERENCE_1_0 78
#define FREE_ASSIGNMENT_1_17 80
#define FREE_ASSIGNMENT_1_16 81
#define FREE_ASSIGNMENT_1_15 82
#define FREE_ASSIGNMENT_1_14 83
#define FREE_ASSIGNMENT_1_13 84
#define FREE_ASSIGNMENT_1_12 85
#define FREE_ASSIGNMENT_1_11 86
#define FREE_ASSIGNMENT_1_10 87
#define FREE_ASSIGNMENT_1_9 88
#define FREE_ASSIGNMENT_1_8 89
#define FREE_ASSIGNMENT_1_7 90
#define FREE_ASSIGNMENT_1_6 91
#define FREE_ASSIGNMENT_1_5 92
#define FREE_ASSIGNMENT_1_4 93
#define FREE_ASSIGNMENT_1_3 94
#define FREE_ASSIGNMENT_1_2 95
#define FREE_ASSIGNMENT_1_1 96
#define FREE_ASSIGNMENT_1_0 97
#define FREE_REFERENCES_LABEL_1_0 64
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd62;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd170;
  machine_word Wrd165;
  machine_word Wrd164;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto initialize_packageB_5;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_1_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_1_11);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_1_12);
      goto label_11;

    case 7:
      current_block = (Rpc - LABEL_1_13);
      goto label_12;

    case 8:
      current_block = (Rpc - LABEL_1_14);
      goto label_13;

    case 9:
      current_block = (Rpc - LABEL_1_15);
      goto label_14;

    case 10:
      current_block = (Rpc - LABEL_1_16);
      goto label_15;

    case 11:
      current_block = (Rpc - LABEL_1_17);
      goto label_16;

    case 12:
      current_block = (Rpc - LABEL_1_18);
      goto label_17;

    case 13:
      current_block = (Rpc - LABEL_1_19);
      goto label_18;

    case 14:
      current_block = (Rpc - LABEL_1_20);
      goto label_19;

    case 15:
      current_block = (Rpc - LABEL_1_21);
      goto label_20;

    case 16:
      current_block = (Rpc - LABEL_1_6);
      goto continuation_0;

    case 17:
      current_block = (Rpc - LABEL_1_24);
      goto label_21;

    case 18:
      current_block = (Rpc - LABEL_1_22);
      goto continuation_2;

    case 19:
      current_block = (Rpc - LABEL_1_26);
      goto label_22;

    case 20:
      current_block = (Rpc - LABEL_1_27);
      goto label_23;

    case 21:
      current_block = (Rpc - LABEL_1_28);
      goto label_24;

    case 22:
      current_block = (Rpc - LABEL_1_29);
      goto label_25;

    case 23:
      current_block = (Rpc - LABEL_1_31);
      goto label_26;

    case 24:
      current_block = (Rpc - LABEL_1_32);
      goto label_27;

    case 25:
      current_block = (Rpc - LABEL_1_30);
      goto continuation_3;

    case 26:
      current_block = (Rpc - LABEL_1_33);
      goto label_28;

    case 27:
      current_block = (Rpc - LABEL_1_35);
      goto label_29;

    case 28:
      current_block = (Rpc - LABEL_1_36);
      goto label_30;

    case 29:
      current_block = (Rpc - LABEL_1_34);
      goto continuation_4;

    case 30:
      current_block = (Rpc - LABEL_1_37);
      goto label_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_33)
DEFLABEL (initialize_packageB_5)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_1_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_1_6);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_101;
  Wrd5 = Wrd9;

DEFLABEL (label_100)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_25]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_99;

DEFLABEL (label_98)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_97)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_96;
  Wrd18 = Wrd22;

DEFLABEL (label_95)
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_1]));
  (Wrd32.Obj) = ((Wrd24.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_94;

DEFLABEL (label_93)
  ((Wrd24.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_92)
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_2]));
  (Wrd37.Obj) = (current_block [OBJECT_1_2]);
  (Wrd44.Obj) = ((Wrd36.pObj) [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 50)
    goto label_91;

DEFLABEL (label_90)
  ((Wrd36.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_89)
  (Wrd48.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_3]));
  (Wrd49.Obj) = (current_block [OBJECT_1_3]);
  (Wrd56.Obj) = ((Wrd48.pObj) [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if ((Wrd57.uLng) == 50)
    goto label_88;

DEFLABEL (label_87)
  ((Wrd48.pObj) [0]) = (Wrd49.Obj);

DEFLABEL (label_86)
  (Wrd60.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_4]));
  (Wrd61.Obj) = (current_block [OBJECT_1_2]);
  (Wrd68.Obj) = ((Wrd60.pObj) [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if ((Wrd69.uLng) == 50)
    goto label_85;

DEFLABEL (label_84)
  ((Wrd60.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_83)
  (Wrd72.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_5]));
  (Wrd73.Obj) = (current_block [OBJECT_1_2]);
  (Wrd80.Obj) = ((Wrd72.pObj) [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 50)
    goto label_82;

DEFLABEL (label_81)
  ((Wrd72.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_80)
  (Wrd84.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_6]));
  (Wrd85.Obj) = (current_block [OBJECT_1_2]);
  (Wrd92.Obj) = ((Wrd84.pObj) [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd93.uLng) == 50)
    goto label_79;

DEFLABEL (label_78)
  ((Wrd84.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_77)
  (Wrd96.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_7]));
  (Wrd97.Obj) = (current_block [OBJECT_1_2]);
  (Wrd104.Obj) = ((Wrd96.pObj) [0]);
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if ((Wrd105.uLng) == 50)
    goto label_76;

DEFLABEL (label_75)
  ((Wrd96.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_74)
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_8]));
  (Wrd109.Obj) = (current_block [OBJECT_1_2]);
  (Wrd116.Obj) = ((Wrd108.pObj) [0]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if ((Wrd117.uLng) == 50)
    goto label_73;

DEFLABEL (label_72)
  ((Wrd108.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_71)
  (Wrd120.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_9]));
  (Wrd121.Obj) = (current_block [OBJECT_1_2]);
  (Wrd128.Obj) = ((Wrd120.pObj) [0]);
  (Wrd129.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if ((Wrd129.uLng) == 50)
    goto label_70;

DEFLABEL (label_69)
  ((Wrd120.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_68)
  (Wrd132.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_10]));
  (Wrd133.Obj) = (current_block [OBJECT_1_4]);
  (Wrd140.Obj) = ((Wrd132.pObj) [0]);
  (Wrd141.uLng) = (OBJECT_TYPE (Wrd140.Obj));
  if ((Wrd141.uLng) == 50)
    goto label_67;

DEFLABEL (label_66)
  ((Wrd132.pObj) [0]) = (Wrd133.Obj);

DEFLABEL (label_65)
  (Wrd144.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_11]));
  (Wrd145.Obj) = (current_block [OBJECT_1_2]);
  (Wrd152.Obj) = ((Wrd144.pObj) [0]);
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd152.Obj));
  if ((Wrd153.uLng) == 50)
    goto label_64;

DEFLABEL (label_63)
  ((Wrd144.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_62)
  (Wrd156.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_12]));
  (Wrd157.Obj) = (current_block [OBJECT_1_2]);
  (Wrd164.Obj) = ((Wrd156.pObj) [0]);
  (Wrd165.uLng) = (OBJECT_TYPE (Wrd164.Obj));
  if ((Wrd165.uLng) == 50)
    goto label_61;

DEFLABEL (label_60)
  ((Wrd156.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_59)
  (Wrd170.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_22]))));
  (* (--Rsp)) = (Wrd170.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_23]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_1_22);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_13]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_58;

DEFLABEL (label_57)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_56)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_55;
  Wrd18 = Wrd22;

DEFLABEL (label_54)
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_14]));
  (Wrd32.Obj) = ((Wrd24.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_53;

DEFLABEL (label_52)
  ((Wrd24.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_51)
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_15]));
  (Wrd37.Obj) = (current_block [OBJECT_1_2]);
  (Wrd44.Obj) = ((Wrd36.pObj) [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 50)
    goto label_50;

DEFLABEL (label_49)
  ((Wrd36.pObj) [0]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_48)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_47;
  Wrd51 = Wrd55;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_4]));
  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 50)
    goto label_45;
  Wrd57 = Wrd61;

DEFLABEL (label_44)
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_25]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_1_30);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_16]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_43;

DEFLABEL (label_42)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_41)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_5]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_40;
  Wrd21 = Wrd25;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_6]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_38;
  Wrd27 = Wrd31;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_25]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_1_34);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_17]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_36;

DEFLABEL (label_35)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_34)
  Rvl = (current_block [OBJECT_1_5]);
  goto pop_return;

DEFLABEL (label_36)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_35;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_37])), (Wrd6.pObj), Rvl);

DEFLABEL (label_31)
  goto label_34;

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_36])), (Wrd28.pObj));

DEFLABEL (label_30)
  (Wrd27.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_35])), (Wrd22.pObj));

DEFLABEL (label_29)
  (Wrd21.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_43)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_42;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_33])), (Wrd6.pObj), Rvl);

DEFLABEL (label_28)
  goto label_41;

DEFLABEL (label_45)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_32])), (Wrd58.pObj));

DEFLABEL (label_27)
  (Wrd57.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_31])), (Wrd52.pObj));

DEFLABEL (label_26)
  (Wrd51.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_50)
  if ((Wrd44.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_49;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_29])), (Wrd36.pObj), (Wrd37.Obj));

DEFLABEL (label_25)
  goto label_48;

DEFLABEL (label_53)
  if ((Wrd32.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_52;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_28])), (Wrd24.pObj), (Wrd18.Obj));

DEFLABEL (label_24)
  goto label_51;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_27])), (Wrd19.pObj));

DEFLABEL (label_23)
  (Wrd18.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_57;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_26])), (Wrd6.pObj), Rvl);

DEFLABEL (label_22)
  goto label_56;

DEFLABEL (label_61)
  if ((Wrd164.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_60;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_21])), (Wrd156.pObj), (Wrd157.Obj));

DEFLABEL (label_20)
  goto label_59;

DEFLABEL (label_64)
  if ((Wrd152.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_63;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_20])), (Wrd144.pObj), (Wrd145.Obj));

DEFLABEL (label_19)
  goto label_62;

DEFLABEL (label_67)
  if ((Wrd140.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_66;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_19])), (Wrd132.pObj), (Wrd133.Obj));

DEFLABEL (label_18)
  goto label_65;

DEFLABEL (label_70)
  if ((Wrd128.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_69;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_18])), (Wrd120.pObj), (Wrd121.Obj));

DEFLABEL (label_17)
  goto label_68;

DEFLABEL (label_73)
  if ((Wrd116.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_72;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_17])), (Wrd108.pObj), (Wrd109.Obj));

DEFLABEL (label_16)
  goto label_71;

DEFLABEL (label_76)
  if ((Wrd104.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_75;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_16])), (Wrd96.pObj), (Wrd97.Obj));

DEFLABEL (label_15)
  goto label_74;

DEFLABEL (label_79)
  if ((Wrd92.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_78;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_15])), (Wrd84.pObj), (Wrd85.Obj));

DEFLABEL (label_14)
  goto label_77;

DEFLABEL (label_82)
  if ((Wrd80.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_81;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_14])), (Wrd72.pObj), (Wrd73.Obj));

DEFLABEL (label_13)
  goto label_80;

DEFLABEL (label_85)
  if ((Wrd68.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_84;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_13])), (Wrd60.pObj), (Wrd61.Obj));

DEFLABEL (label_12)
  goto label_83;

DEFLABEL (label_88)
  if ((Wrd56.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_87;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_12])), (Wrd48.pObj), (Wrd49.Obj));

DEFLABEL (label_11)
  goto label_86;

DEFLABEL (label_91)
  if ((Wrd44.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_90;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_11])), (Wrd36.pObj), (Wrd37.Obj));

DEFLABEL (label_10)
  goto label_89;

DEFLABEL (label_94)
  if ((Wrd32.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_93;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_10])), (Wrd24.pObj), (Wrd18.Obj));

DEFLABEL (label_9)
  goto label_92;

DEFLABEL (label_96)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_9])), (Wrd19.pObj));

DEFLABEL (label_8)
  (Wrd18.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_99)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_98;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_7)
  goto label_97;

DEFLABEL (label_101)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_24])), (Wrd6.pObj));

DEFLABEL (label_21)
  (Wrd5.Obj) = Rvl;
  goto label_100;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_6 5
#define LABEL_2_5 7
#define LABEL_2_10 9
#define LABEL_2_11 11
#define LABEL_2_12 13
#define LABEL_2_13 15
#define LABEL_2_14 17
#define LABEL_2_15 19
#define LABEL_2_16 21
#define LABEL_2_17 23
#define LABEL_2_18 25
#define LABEL_2_19 27
#define LABEL_2_20 29
#define LABEL_2_21 31
#define LABEL_2_22 33
#define LABEL_2_23 35
#define LABEL_2_24 37
#define LABEL_2_25 39
#define LABEL_2_26 41
#define LABEL_2_27 43
#define LABEL_2_28 45
#define LABEL_2_29 47
#define LABEL_2_30 49
#define LABEL_2_31 51
#define LABEL_2_32 53
#define LABEL_2_8 55
#define LABEL_2_9 57
#define LABEL_2_34 59
#define TAG_2_35 28
#define LABEL_2_37 61
#define LABEL_2_38 63
#define LABEL_2_39 65
#define ENVIRONMENT_LABEL_2_3 122
#define DEBUGGING_LABEL_2_2 121
#define OBJECT_2_25 120
#define OBJECT_2_24 119
#define OBJECT_2_23 118
#define OBJECT_2_22 117
#define OBJECT_2_21 116
#define OBJECT_2_20 115
#define OBJECT_2_19 114
#define OBJECT_2_18 113
#define OBJECT_2_17 112
#define OBJECT_2_16 111
#define OBJECT_2_15 110
#define OBJECT_2_14 109
#define OBJECT_2_13 108
#define OBJECT_2_12 107
#define OBJECT_2_11 106
#define OBJECT_2_10 105
#define OBJECT_2_9 104
#define OBJECT_2_8 103
#define OBJECT_2_7 102
#define OBJECT_2_6 101
#define OBJECT_2_5 100
#define OBJECT_2_4 99
#define OBJECT_2_3 98
#define OBJECT_2_2 97
#define OBJECT_2_1 96
#define OBJECT_2_0 95
#define EXECUTE_CACHE_2_40 67
#define EXECUTE_CACHE_2_36 69
#define EXECUTE_CACHE_2_33 71
#define EXECUTE_CACHE_2_7 73
#define FREE_REFERENCE_2_18 76
#define FREE_REFERENCE_2_17 77
#define FREE_REFERENCE_2_16 78
#define FREE_REFERENCE_2_15 79
#define FREE_REFERENCE_2_14 80
#define FREE_REFERENCE_2_13 81
#define FREE_REFERENCE_2_12 82
#define FREE_REFERENCE_2_11 83
#define FREE_REFERENCE_2_10 84
#define FREE_REFERENCE_2_9 85
#define FREE_REFERENCE_2_8 86
#define FREE_REFERENCE_2_7 87
#define FREE_REFERENCE_2_6 88
#define FREE_REFERENCE_2_5 89
#define FREE_REFERENCE_2_4 90
#define FREE_REFERENCE_2_3 91
#define FREE_REFERENCE_2_2 92
#define FREE_REFERENCE_2_1 93
#define FREE_REFERENCE_2_0 94
#define FREE_REFERENCES_LABEL_2_0 66
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd354;
  machine_word Wrd353;
  machine_word Wrd355;
  machine_word Wrd348;
  machine_word Wrd350;
  machine_word Wrd351;
  machine_word Wrd342;
  machine_word Wrd347;
  machine_word Wrd346;
  machine_word Wrd343;
  machine_word Wrd339;
  machine_word Wrd338;
  machine_word Wrd340;
  machine_word Wrd333;
  machine_word Wrd335;
  machine_word Wrd336;
  machine_word Wrd327;
  machine_word Wrd332;
  machine_word Wrd331;
  machine_word Wrd328;
  machine_word Wrd324;
  machine_word Wrd323;
  machine_word Wrd325;
  machine_word Wrd318;
  machine_word Wrd320;
  machine_word Wrd321;
  machine_word Wrd312;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd313;
  machine_word Wrd309;
  machine_word Wrd308;
  machine_word Wrd310;
  machine_word Wrd303;
  machine_word Wrd305;
  machine_word Wrd306;
  machine_word Wrd297;
  machine_word Wrd302;
  machine_word Wrd301;
  machine_word Wrd298;
  machine_word Wrd294;
  machine_word Wrd293;
  machine_word Wrd295;
  machine_word Wrd288;
  machine_word Wrd290;
  machine_word Wrd291;
  machine_word Wrd282;
  machine_word Wrd287;
  machine_word Wrd286;
  machine_word Wrd283;
  machine_word Wrd279;
  machine_word Wrd278;
  machine_word Wrd280;
  machine_word Wrd273;
  machine_word Wrd275;
  machine_word Wrd276;
  machine_word Wrd267;
  machine_word Wrd272;
  machine_word Wrd271;
  machine_word Wrd268;
  machine_word Wrd264;
  machine_word Wrd263;
  machine_word Wrd265;
  machine_word Wrd258;
  machine_word Wrd260;
  machine_word Wrd261;
  machine_word Wrd252;
  machine_word Wrd257;
  machine_word Wrd256;
  machine_word Wrd253;
  machine_word Wrd249;
  machine_word Wrd248;
  machine_word Wrd250;
  machine_word Wrd243;
  machine_word Wrd245;
  machine_word Wrd246;
  machine_word Wrd237;
  machine_word Wrd242;
  machine_word Wrd241;
  machine_word Wrd238;
  machine_word Wrd234;
  machine_word Wrd233;
  machine_word Wrd235;
  machine_word Wrd228;
  machine_word Wrd230;
  machine_word Wrd231;
  machine_word Wrd222;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd223;
  machine_word Wrd219;
  machine_word Wrd218;
  machine_word Wrd220;
  machine_word Wrd213;
  machine_word Wrd215;
  machine_word Wrd216;
  machine_word Wrd207;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd208;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd205;
  machine_word Wrd198;
  machine_word Wrd200;
  machine_word Wrd201;
  machine_word Wrd192;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd193;
  machine_word Wrd189;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd183;
  machine_word Wrd185;
  machine_word Wrd186;
  machine_word Wrd177;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd178;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd175;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd162;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd160;
  machine_word Wrd153;
  machine_word Wrd155;
  machine_word Wrd156;
  machine_word Wrd147;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd145;
  machine_word Wrd138;
  machine_word Wrd140;
  machine_word Wrd141;
  machine_word Wrd132;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd130;
  machine_word Wrd123;
  machine_word Wrd125;
  machine_word Wrd126;
  machine_word Wrd117;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd118;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd111;
  machine_word Wrd102;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd93;
  machine_word Wrd95;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd72;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd70;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto make_system_global_unparser_table_54;

    case 1:
      current_block = (Rpc - LABEL_2_6);
      goto label_56;

    case 2:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_2_10);
      goto label_57;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto label_58;

    case 5:
      current_block = (Rpc - LABEL_2_12);
      goto label_59;

    case 6:
      current_block = (Rpc - LABEL_2_13);
      goto label_60;

    case 7:
      current_block = (Rpc - LABEL_2_14);
      goto label_61;

    case 8:
      current_block = (Rpc - LABEL_2_15);
      goto label_62;

    case 9:
      current_block = (Rpc - LABEL_2_16);
      goto label_63;

    case 10:
      current_block = (Rpc - LABEL_2_17);
      goto label_64;

    case 11:
      current_block = (Rpc - LABEL_2_18);
      goto label_65;

    case 12:
      current_block = (Rpc - LABEL_2_19);
      goto label_66;

    case 13:
      current_block = (Rpc - LABEL_2_20);
      goto label_67;

    case 14:
      current_block = (Rpc - LABEL_2_21);
      goto label_68;

    case 15:
      current_block = (Rpc - LABEL_2_22);
      goto label_69;

    case 16:
      current_block = (Rpc - LABEL_2_23);
      goto label_70;

    case 17:
      current_block = (Rpc - LABEL_2_24);
      goto label_71;

    case 18:
      current_block = (Rpc - LABEL_2_25);
      goto label_72;

    case 19:
      current_block = (Rpc - LABEL_2_26);
      goto label_73;

    case 20:
      current_block = (Rpc - LABEL_2_27);
      goto label_74;

    case 21:
      current_block = (Rpc - LABEL_2_28);
      goto label_75;

    case 22:
      current_block = (Rpc - LABEL_2_29);
      goto label_76;

    case 23:
      current_block = (Rpc - LABEL_2_30);
      goto label_77;

    case 24:
      current_block = (Rpc - LABEL_2_31);
      goto label_78;

    case 25:
      current_block = (Rpc - LABEL_2_32);
      goto label_79;

    case 26:
      current_block = (Rpc - LABEL_2_8);
      goto continuation_52;

    case 27:
      current_block = (Rpc - LABEL_2_9);
      goto continuation_51;

    case 28:
      current_block = (Rpc - LABEL_2_34);
      goto lambda_85;

    case 29:
      current_block = (Rpc - LABEL_2_37);
      goto label_80;

    case 30:
      current_block = (Rpc - LABEL_2_38);
      goto label_81;

    case 31:
      current_block = (Rpc - LABEL_2_39);
      goto label_82;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_system_global_unparser_table_84)
DEFLABEL (make_system_global_unparser_table_54)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_133;
  Wrd8 = Wrd12;

DEFLABEL (label_132)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_131;
  Wrd12 = Wrd16;

DEFLABEL (label_130)
  (Wrd21.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_2_1]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_2]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_129;
  Wrd27 = Wrd31;

DEFLABEL (label_128)
  (Wrd36.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd40.Obj) = (current_block [OBJECT_2_2]);
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_3]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_127;
  Wrd42 = Wrd46;

DEFLABEL (label_126)
  (Wrd51.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd51.Obj);
  (Wrd50.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd50.pObj)));
  (Wrd55.Obj) = (current_block [OBJECT_2_3]);
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_4]));
  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 50)
    goto label_125;
  Wrd57 = Wrd61;

DEFLABEL (label_124)
  (Wrd66.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd65.pObj) = (& (Rhp [-2]));
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd65.pObj)));
  (Wrd70.Obj) = (current_block [OBJECT_2_4]);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd63.Obj);
  (Wrd68.pObj) = (& (Rhp [-2]));
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd68.pObj)));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_5]));
  (Wrd76.Obj) = ((Wrd73.pObj) [0]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if ((Wrd77.uLng) == 50)
    goto label_123;
  Wrd72 = Wrd76;

DEFLABEL (label_122)
  (Wrd81.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd72.Obj);
  (* (Rhp++)) = (Wrd81.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (Wrd85.Obj) = (current_block [OBJECT_2_5]);
  (* (Rhp++)) = (Wrd85.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd83.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd83.pObj)));
  (* (--Rsp)) = (Wrd84.Obj);
  (Wrd88.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_6]));
  (Wrd91.Obj) = ((Wrd88.pObj) [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd92.uLng) == 50)
    goto label_121;
  Wrd87 = Wrd91;

DEFLABEL (label_120)
  (Wrd96.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd87.Obj);
  (* (Rhp++)) = (Wrd96.Obj);
  (Wrd95.pObj) = (& (Rhp [-2]));
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd95.pObj)));
  (Wrd100.Obj) = (current_block [OBJECT_2_6]);
  (* (Rhp++)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd93.Obj);
  (Wrd98.pObj) = (& (Rhp [-2]));
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd98.pObj)));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd103.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_7]));
  (Wrd106.Obj) = ((Wrd103.pObj) [0]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if ((Wrd107.uLng) == 50)
    goto label_119;
  Wrd102 = Wrd106;

DEFLABEL (label_118)
  (Wrd111.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd102.Obj);
  (* (Rhp++)) = (Wrd111.Obj);
  (Wrd110.pObj) = (& (Rhp [-2]));
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd110.pObj)));
  (Wrd115.Obj) = (current_block [OBJECT_2_7]);
  (* (Rhp++)) = (Wrd115.Obj);
  (* (Rhp++)) = (Wrd108.Obj);
  (Wrd113.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd113.pObj)));
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd118.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd121.Obj) = ((Wrd118.pObj) [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if ((Wrd122.uLng) == 50)
    goto label_117;
  Wrd117 = Wrd121;

DEFLABEL (label_116)
  (Wrd126.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd117.Obj);
  (* (Rhp++)) = (Wrd126.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (Wrd130.Obj) = (current_block [OBJECT_2_8]);
  (* (Rhp++)) = (Wrd130.Obj);
  (* (Rhp++)) = (Wrd123.Obj);
  (Wrd128.pObj) = (& (Rhp [-2]));
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd128.pObj)));
  (* (--Rsp)) = (Wrd129.Obj);
  (Wrd133.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_9]));
  (Wrd136.Obj) = ((Wrd133.pObj) [0]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if ((Wrd137.uLng) == 50)
    goto label_115;
  Wrd132 = Wrd136;

DEFLABEL (label_114)
  (Wrd141.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd132.Obj);
  (* (Rhp++)) = (Wrd141.Obj);
  (Wrd140.pObj) = (& (Rhp [-2]));
  (Wrd138.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd140.pObj)));
  (Wrd145.Obj) = (current_block [OBJECT_2_9]);
  (* (Rhp++)) = (Wrd145.Obj);
  (* (Rhp++)) = (Wrd138.Obj);
  (Wrd143.pObj) = (& (Rhp [-2]));
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd143.pObj)));
  (* (--Rsp)) = (Wrd144.Obj);
  (Wrd148.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_10]));
  (Wrd151.Obj) = ((Wrd148.pObj) [0]);
  (Wrd152.uLng) = (OBJECT_TYPE (Wrd151.Obj));
  if ((Wrd152.uLng) == 50)
    goto label_113;
  Wrd147 = Wrd151;

DEFLABEL (label_112)
  (Wrd156.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd147.Obj);
  (* (Rhp++)) = (Wrd156.Obj);
  (Wrd155.pObj) = (& (Rhp [-2]));
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd155.pObj)));
  (Wrd160.Obj) = (current_block [OBJECT_2_10]);
  (* (Rhp++)) = (Wrd160.Obj);
  (* (Rhp++)) = (Wrd153.Obj);
  (Wrd158.pObj) = (& (Rhp [-2]));
  (Wrd159.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd158.pObj)));
  (* (--Rsp)) = (Wrd159.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd166.Obj) = ((Wrd163.pObj) [0]);
  (Wrd167.uLng) = (OBJECT_TYPE (Wrd166.Obj));
  if ((Wrd167.uLng) == 50)
    goto label_111;
  Wrd162 = Wrd166;

DEFLABEL (label_110)
  (Wrd171.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd162.Obj);
  (* (Rhp++)) = (Wrd171.Obj);
  (Wrd170.pObj) = (& (Rhp [-2]));
  (Wrd168.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd170.pObj)));
  (Wrd175.Obj) = (current_block [OBJECT_2_11]);
  (* (Rhp++)) = (Wrd175.Obj);
  (* (Rhp++)) = (Wrd168.Obj);
  (Wrd173.pObj) = (& (Rhp [-2]));
  (Wrd174.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd173.pObj)));
  (* (--Rsp)) = (Wrd174.Obj);
  (Wrd178.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_11]));
  (Wrd181.Obj) = ((Wrd178.pObj) [0]);
  (Wrd182.uLng) = (OBJECT_TYPE (Wrd181.Obj));
  if ((Wrd182.uLng) == 50)
    goto label_109;
  Wrd177 = Wrd181;

DEFLABEL (label_108)
  (Wrd186.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd177.Obj);
  (* (Rhp++)) = (Wrd186.Obj);
  (Wrd185.pObj) = (& (Rhp [-2]));
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd185.pObj)));
  (Wrd190.Obj) = (current_block [OBJECT_2_12]);
  (* (Rhp++)) = (Wrd190.Obj);
  (* (Rhp++)) = (Wrd183.Obj);
  (Wrd188.pObj) = (& (Rhp [-2]));
  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd188.pObj)));
  (* (--Rsp)) = (Wrd189.Obj);
  (Wrd193.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd196.Obj) = ((Wrd193.pObj) [0]);
  (Wrd197.uLng) = (OBJECT_TYPE (Wrd196.Obj));
  if ((Wrd197.uLng) == 50)
    goto label_107;
  Wrd192 = Wrd196;

DEFLABEL (label_106)
  (Wrd201.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd192.Obj);
  (* (Rhp++)) = (Wrd201.Obj);
  (Wrd200.pObj) = (& (Rhp [-2]));
  (Wrd198.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd200.pObj)));
  (Wrd205.Obj) = (current_block [OBJECT_2_13]);
  (* (Rhp++)) = (Wrd205.Obj);
  (* (Rhp++)) = (Wrd198.Obj);
  (Wrd203.pObj) = (& (Rhp [-2]));
  (Wrd204.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd203.pObj)));
  (* (--Rsp)) = (Wrd204.Obj);
  (Wrd208.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_12]));
  (Wrd211.Obj) = ((Wrd208.pObj) [0]);
  (Wrd212.uLng) = (OBJECT_TYPE (Wrd211.Obj));
  if ((Wrd212.uLng) == 50)
    goto label_105;
  Wrd207 = Wrd211;

DEFLABEL (label_104)
  (Wrd216.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd207.Obj);
  (* (Rhp++)) = (Wrd216.Obj);
  (Wrd215.pObj) = (& (Rhp [-2]));
  (Wrd213.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd215.pObj)));
  (Wrd220.Obj) = (current_block [OBJECT_2_14]);
  (* (Rhp++)) = (Wrd220.Obj);
  (* (Rhp++)) = (Wrd213.Obj);
  (Wrd218.pObj) = (& (Rhp [-2]));
  (Wrd219.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd218.pObj)));
  (* (--Rsp)) = (Wrd219.Obj);
  (Wrd223.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_13]));
  (Wrd226.Obj) = ((Wrd223.pObj) [0]);
  (Wrd227.uLng) = (OBJECT_TYPE (Wrd226.Obj));
  if ((Wrd227.uLng) == 50)
    goto label_103;
  Wrd222 = Wrd226;

DEFLABEL (label_102)
  (Wrd231.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd222.Obj);
  (* (Rhp++)) = (Wrd231.Obj);
  (Wrd230.pObj) = (& (Rhp [-2]));
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd230.pObj)));
  (Wrd235.Obj) = (current_block [OBJECT_2_15]);
  (* (Rhp++)) = (Wrd235.Obj);
  (* (Rhp++)) = (Wrd228.Obj);
  (Wrd233.pObj) = (& (Rhp [-2]));
  (Wrd234.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd233.pObj)));
  (* (--Rsp)) = (Wrd234.Obj);
  (Wrd238.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_14]));
  (Wrd241.Obj) = ((Wrd238.pObj) [0]);
  (Wrd242.uLng) = (OBJECT_TYPE (Wrd241.Obj));
  if ((Wrd242.uLng) == 50)
    goto label_101;
  Wrd237 = Wrd241;

DEFLABEL (label_100)
  (Wrd246.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd237.Obj);
  (* (Rhp++)) = (Wrd246.Obj);
  (Wrd245.pObj) = (& (Rhp [-2]));
  (Wrd243.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd245.pObj)));
  (Wrd250.Obj) = (current_block [OBJECT_2_16]);
  (* (Rhp++)) = (Wrd250.Obj);
  (* (Rhp++)) = (Wrd243.Obj);
  (Wrd248.pObj) = (& (Rhp [-2]));
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd248.pObj)));
  (* (--Rsp)) = (Wrd249.Obj);
  (Wrd253.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_9]));
  (Wrd256.Obj) = ((Wrd253.pObj) [0]);
  (Wrd257.uLng) = (OBJECT_TYPE (Wrd256.Obj));
  if ((Wrd257.uLng) == 50)
    goto label_99;
  Wrd252 = Wrd256;

DEFLABEL (label_98)
  (Wrd261.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd252.Obj);
  (* (Rhp++)) = (Wrd261.Obj);
  (Wrd260.pObj) = (& (Rhp [-2]));
  (Wrd258.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd260.pObj)));
  (Wrd265.Obj) = (current_block [OBJECT_2_17]);
  (* (Rhp++)) = (Wrd265.Obj);
  (* (Rhp++)) = (Wrd258.Obj);
  (Wrd263.pObj) = (& (Rhp [-2]));
  (Wrd264.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd263.pObj)));
  (* (--Rsp)) = (Wrd264.Obj);
  (Wrd268.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_15]));
  (Wrd271.Obj) = ((Wrd268.pObj) [0]);
  (Wrd272.uLng) = (OBJECT_TYPE (Wrd271.Obj));
  if ((Wrd272.uLng) == 50)
    goto label_97;
  Wrd267 = Wrd271;

DEFLABEL (label_96)
  (Wrd276.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd267.Obj);
  (* (Rhp++)) = (Wrd276.Obj);
  (Wrd275.pObj) = (& (Rhp [-2]));
  (Wrd273.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd275.pObj)));
  (Wrd280.Obj) = (current_block [OBJECT_2_18]);
  (* (Rhp++)) = (Wrd280.Obj);
  (* (Rhp++)) = (Wrd273.Obj);
  (Wrd278.pObj) = (& (Rhp [-2]));
  (Wrd279.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd278.pObj)));
  (* (--Rsp)) = (Wrd279.Obj);
  (Wrd283.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_16]));
  (Wrd286.Obj) = ((Wrd283.pObj) [0]);
  (Wrd287.uLng) = (OBJECT_TYPE (Wrd286.Obj));
  if ((Wrd287.uLng) == 50)
    goto label_95;
  Wrd282 = Wrd286;

DEFLABEL (label_94)
  (Wrd291.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd282.Obj);
  (* (Rhp++)) = (Wrd291.Obj);
  (Wrd290.pObj) = (& (Rhp [-2]));
  (Wrd288.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd290.pObj)));
  (Wrd295.Obj) = (current_block [OBJECT_2_19]);
  (* (Rhp++)) = (Wrd295.Obj);
  (* (Rhp++)) = (Wrd288.Obj);
  (Wrd293.pObj) = (& (Rhp [-2]));
  (Wrd294.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd293.pObj)));
  (* (--Rsp)) = (Wrd294.Obj);
  (Wrd298.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd301.Obj) = ((Wrd298.pObj) [0]);
  (Wrd302.uLng) = (OBJECT_TYPE (Wrd301.Obj));
  if ((Wrd302.uLng) == 50)
    goto label_93;
  Wrd297 = Wrd301;

DEFLABEL (label_92)
  (Wrd306.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd297.Obj);
  (* (Rhp++)) = (Wrd306.Obj);
  (Wrd305.pObj) = (& (Rhp [-2]));
  (Wrd303.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd305.pObj)));
  (Wrd310.Obj) = (current_block [OBJECT_2_20]);
  (* (Rhp++)) = (Wrd310.Obj);
  (* (Rhp++)) = (Wrd303.Obj);
  (Wrd308.pObj) = (& (Rhp [-2]));
  (Wrd309.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd308.pObj)));
  (* (--Rsp)) = (Wrd309.Obj);
  (Wrd313.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_17]));
  (Wrd316.Obj) = ((Wrd313.pObj) [0]);
  (Wrd317.uLng) = (OBJECT_TYPE (Wrd316.Obj));
  if ((Wrd317.uLng) == 50)
    goto label_91;
  Wrd312 = Wrd316;

DEFLABEL (label_90)
  (Wrd321.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd312.Obj);
  (* (Rhp++)) = (Wrd321.Obj);
  (Wrd320.pObj) = (& (Rhp [-2]));
  (Wrd318.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd320.pObj)));
  (Wrd325.Obj) = (current_block [OBJECT_2_21]);
  (* (Rhp++)) = (Wrd325.Obj);
  (* (Rhp++)) = (Wrd318.Obj);
  (Wrd323.pObj) = (& (Rhp [-2]));
  (Wrd324.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd323.pObj)));
  (* (--Rsp)) = (Wrd324.Obj);
  (Wrd328.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_18]));
  (Wrd331.Obj) = ((Wrd328.pObj) [0]);
  (Wrd332.uLng) = (OBJECT_TYPE (Wrd331.Obj));
  if ((Wrd332.uLng) == 50)
    goto label_89;
  Wrd327 = Wrd331;

DEFLABEL (label_88)
  (Wrd336.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd327.Obj);
  (* (Rhp++)) = (Wrd336.Obj);
  (Wrd335.pObj) = (& (Rhp [-2]));
  (Wrd333.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd335.pObj)));
  (Wrd340.Obj) = (current_block [OBJECT_2_22]);
  (* (Rhp++)) = (Wrd340.Obj);
  (* (Rhp++)) = (Wrd333.Obj);
  (Wrd338.pObj) = (& (Rhp [-2]));
  (Wrd339.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd338.pObj)));
  (* (--Rsp)) = (Wrd339.Obj);
  (Wrd343.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_8]));
  (Wrd346.Obj) = ((Wrd343.pObj) [0]);
  (Wrd347.uLng) = (OBJECT_TYPE (Wrd346.Obj));
  if ((Wrd347.uLng) == 50)
    goto label_87;
  Wrd342 = Wrd346;

DEFLABEL (label_86)
  (Wrd351.Obj) = (current_block [OBJECT_2_0]);
  (* (Rhp++)) = (Wrd342.Obj);
  (* (Rhp++)) = (Wrd351.Obj);
  (Wrd350.pObj) = (& (Rhp [-2]));
  (Wrd348.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd350.pObj)));
  (Wrd355.Obj) = (current_block [OBJECT_2_23]);
  (* (Rhp++)) = (Wrd355.Obj);
  (* (Rhp++)) = (Wrd348.Obj);
  (Wrd353.pObj) = (& (Rhp [-2]));
  (Wrd354.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd353.pObj)));
  (* (--Rsp)) = (Wrd354.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_33]));

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_2_9);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_34])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_2_8);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_87)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_32])), (Wrd343.pObj));

DEFLABEL (label_79)
  (Wrd342.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_31])), (Wrd328.pObj));

DEFLABEL (label_78)
  (Wrd327.Obj) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_30])), (Wrd313.pObj));

DEFLABEL (label_77)
  (Wrd312.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_29])), (Wrd298.pObj));

DEFLABEL (label_76)
  (Wrd297.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_28])), (Wrd283.pObj));

DEFLABEL (label_75)
  (Wrd282.Obj) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_27])), (Wrd268.pObj));

DEFLABEL (label_74)
  (Wrd267.Obj) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_26])), (Wrd253.pObj));

DEFLABEL (label_73)
  (Wrd252.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_25])), (Wrd238.pObj));

DEFLABEL (label_72)
  (Wrd237.Obj) = Rvl;
  goto label_100;

DEFLABEL (label_103)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_24])), (Wrd223.pObj));

DEFLABEL (label_71)
  (Wrd222.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_23])), (Wrd208.pObj));

DEFLABEL (label_70)
  (Wrd207.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_22])), (Wrd193.pObj));

DEFLABEL (label_69)
  (Wrd192.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_21])), (Wrd178.pObj));

DEFLABEL (label_68)
  (Wrd177.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_20])), (Wrd163.pObj));

DEFLABEL (label_67)
  (Wrd162.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_19])), (Wrd148.pObj));

DEFLABEL (label_66)
  (Wrd147.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_18])), (Wrd133.pObj));

DEFLABEL (label_65)
  (Wrd132.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_17])), (Wrd118.pObj));

DEFLABEL (label_64)
  (Wrd117.Obj) = Rvl;
  goto label_116;

DEFLABEL (label_119)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_16])), (Wrd103.pObj));

DEFLABEL (label_63)
  (Wrd102.Obj) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_15])), (Wrd88.pObj));

DEFLABEL (label_62)
  (Wrd87.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_14])), (Wrd73.pObj));

DEFLABEL (label_61)
  (Wrd72.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_13])), (Wrd58.pObj));

DEFLABEL (label_60)
  (Wrd57.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_12])), (Wrd43.pObj));

DEFLABEL (label_59)
  (Wrd42.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_11])), (Wrd28.pObj));

DEFLABEL (label_58)
  (Wrd27.Obj) = Rvl;
  goto label_128;

DEFLABEL (label_131)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_10])), (Wrd13.pObj));

DEFLABEL (label_57)
  (Wrd12.Obj) = Rvl;
  goto label_130;

DEFLABEL (label_133)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_6])), (Wrd9.pObj));

DEFLABEL (label_56)
  (Wrd8.Obj) = Rvl;
  goto label_132;

DEFLABEL (lambda_85)
  CLOSURE_HEADER (LABEL_2_34);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_139;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_138)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_137;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_136)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_135;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_134)
  (Rsp [2]) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_40]));

DEFLABEL (label_135)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_39]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_24]), 1);

DEFLABEL (label_82)
  (Wrd26.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_38]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_25]), 1);

DEFLABEL (label_81)
  (Wrd17.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_37]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_24]), 1);

DEFLABEL (label_80)
  (Wrd8.Obj) = Rvl;
  goto label_138;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 7
#define DEBUGGING_LABEL_4_2 6
#define OBJECT_4_1 5
#define OBJECT_4_0 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto unparser_table_dispatch_vector_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_table_dispatch_vector_3)
DEFLABEL (unparser_table_dispatch_vector_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_4_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define ENVIRONMENT_LABEL_5_3 13
#define DEBUGGING_LABEL_5_2 12
#define OBJECT_5_0 11
#define EXECUTE_CACHE_5_7 7
#define EXECUTE_CACHE_5_6 9
#define FREE_REFERENCES_LABEL_5_0 6
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto guarantee_unparser_table_1;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_unparser_table_4)
DEFLABEL (guarantee_unparser_table_1)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_5_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 11
#define DEBUGGING_LABEL_6_2 10
#define OBJECT_6_2 9
#define OBJECT_6_1 8
#define OBJECT_6_0 7
#define EXECUTE_CACHE_6_5 5
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto error_not_unparser_table_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_unparser_table_5)
DEFLABEL (error_not_unparser_table_2)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_6_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_6_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_6_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_6 7
#define ENVIRONMENT_LABEL_7_3 16
#define DEBUGGING_LABEL_7_2 15
#define EXECUTE_CACHE_7_9 9
#define EXECUTE_CACHE_7_8 11
#define EXECUTE_CACHE_7_7 13
#define FREE_REFERENCES_LABEL_7_0 8
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto make_unparser_table_2;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_7_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_unparser_table_5)
DEFLABEL (make_unparser_table_2)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_8]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define ENVIRONMENT_LABEL_8_3 12
#define DEBUGGING_LABEL_8_2 11
#define OBJECT_8_1 10
#define OBJECT_8_0 9
#define EXECUTE_CACHE_8_6 7
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto unparser_table_copy_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_table_copy_5)
DEFLABEL (unparser_table_copy_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_8_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_6 7
#define ENVIRONMENT_LABEL_9_3 15
#define DEBUGGING_LABEL_9_2 14
#define OBJECT_9_2 13
#define OBJECT_9_1 12
#define OBJECT_9_0 11
#define EXECUTE_CACHE_9_7 9
#define FREE_REFERENCES_LABEL_9_0 8
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto unparser_table_entry_2;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_9_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_table_entry_6)
DEFLABEL (unparser_table_entry_2)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_10;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_10;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_6);
  (Rsp [1]) = Rvl;
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 10)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 2);

DEFLABEL (label_8)
  (Wrd14.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd14.uLng) == 26))
    goto label_7;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd20.Lng))))
    goto label_7;
  (Wrd8.uLng) = (OBJECT_DATUM (Rvl));
  (Wrd11.pObj) = (& ((Wrd18.pObj) [(Wrd8.Lng)]));
  Rvl = ((Wrd11.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_9_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_6 7
#define ENVIRONMENT_LABEL_10_3 16
#define DEBUGGING_LABEL_10_2 15
#define OBJECT_10_3 14
#define OBJECT_10_2 13
#define OBJECT_10_1 12
#define OBJECT_10_0 11
#define EXECUTE_CACHE_10_7 9
#define FREE_REFERENCES_LABEL_10_0 8
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto unparser_table_set_entryB_2;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_10_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_table_set_entryB_6)
DEFLABEL (unparser_table_set_entryB_2)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_10;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_10;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_10_6);
  (Rsp [1]) = Rvl;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 10)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_3]), 3);

DEFLABEL (label_8)
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 26))
    goto label_7;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) (Wrd17.Lng)) < ((unsigned long) (Wrd21.Lng))))
    goto label_7;
  (Wrd8.uLng) = (OBJECT_DATUM (Rvl));
  (Wrd11.pObj) = (& ((Wrd19.pObj) [(Wrd8.Lng)]));
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [1]) = (Wrd12.Obj);
  Rvl = (current_block [OBJECT_10_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_10_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 5
#define DEBUGGING_LABEL_11_2 4
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 5
#define DEBUGGING_LABEL_12_2 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define ENVIRONMENT_LABEL_13_3 5
#define DEBUGGING_LABEL_13_2 4
#define FREE_REFERENCES_LABEL_13_0 4
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_13_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 5
#define DEBUGGING_LABEL_14_2 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 7
#define DEBUGGING_LABEL_15_2 6
#define OBJECT_15_1 5
#define OBJECT_15_0 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto unparser_state_port_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_state_port_3)
DEFLABEL (unparser_state_port_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_15_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 7
#define DEBUGGING_LABEL_16_2 6
#define OBJECT_16_1 5
#define OBJECT_16_0 4
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto unparser_state_list_depth_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_state_list_depth_3)
DEFLABEL (unparser_state_list_depth_0)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_16_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define ENVIRONMENT_LABEL_17_3 7
#define DEBUGGING_LABEL_17_2 6
#define OBJECT_17_1 5
#define OBJECT_17_0 4
#define FREE_REFERENCES_LABEL_17_0 4
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto unparser_state_slashifyP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_state_slashifyP_3)
DEFLABEL (unparser_state_slashifyP_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_17_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define ENVIRONMENT_LABEL_18_3 7
#define DEBUGGING_LABEL_18_2 6
#define OBJECT_18_1 5
#define OBJECT_18_0 4
#define FREE_REFERENCES_LABEL_18_0 4
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto unparser_state_environment_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparser_state_environment_3)
DEFLABEL (unparser_state_environment_0)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_18_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define ENVIRONMENT_LABEL_19_3 13
#define DEBUGGING_LABEL_19_2 12
#define OBJECT_19_0 11
#define EXECUTE_CACHE_19_7 7
#define EXECUTE_CACHE_19_6 9
#define FREE_REFERENCES_LABEL_19_0 6
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto guarantee_unparser_state_1;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_unparser_state_4)
DEFLABEL (guarantee_unparser_state_1)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_19_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define ENVIRONMENT_LABEL_20_3 11
#define DEBUGGING_LABEL_20_2 10
#define OBJECT_20_2 9
#define OBJECT_20_1 8
#define OBJECT_20_0 7
#define EXECUTE_CACHE_20_5 5
#define FREE_REFERENCES_LABEL_20_0 4
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto error_not_unparser_state_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_unparser_state_5)
DEFLABEL (error_not_unparser_state_2)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_20_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_20_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_20_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_7 7
#define TAG_21_8 2
#define LABEL_21_14 9
#define LABEL_21_9 11
#define TAG_21_10 4
#define LABEL_21_15 13
#define LABEL_21_16 15
#define LABEL_21_11 17
#define TAG_21_12 7
#define LABEL_21_17 19
#define LABEL_21_18 21
#define ENVIRONMENT_LABEL_21_3 36
#define DEBUGGING_LABEL_21_2 35
#define OBJECT_21_3 34
#define OBJECT_21_2 33
#define OBJECT_21_1 32
#define OBJECT_21_0 31
#define EXECUTE_CACHE_21_13 23
#define EXECUTE_CACHE_21_6 25
#define FREE_REFERENCE_21_0 28
#define FREE_ASSIGNMENT_21_0 30
#define FREE_REFERENCES_LABEL_21_0 22
#define NUMBER_OF_LINKER_SECTIONS_21_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto with_current_unparser_state_18;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_21_7);
      goto lambda_27;

    case 3:
      current_block = (Rpc - LABEL_21_14);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_21_9);
      goto lambda_28;

    case 5:
      current_block = (Rpc - LABEL_21_15);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_21_16);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_21_11);
      goto lambda_29;

    case 8:
      current_block = (Rpc - LABEL_21_17);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_21_18);
      goto label_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (with_current_unparser_state_26)
DEFLABEL (with_current_unparser_state_18)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_5);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_7])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  (Wrd21.Obj) = (Rsp [3]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  ((Wrd20.pObj) [3]) = (Wrd14.Obj);
  (Rsp [2]) = (Wrd16.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_9])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd27 = Wrd24;
  ((Wrd27.pObj) [2]) = (Wrd7.Obj);
  ((Wrd27.pObj) [3]) = (Wrd13.Obj);
  (Rsp [3]) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_11])));
  Rhp += 2;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd34 = Wrd31;
  ((Wrd34.pObj) [2]) = (Wrd7.Obj);
  ((Wrd34.pObj) [3]) = (Wrd13.Obj);
  (Rsp [1]) = (Wrd30.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_13]));

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_21_7);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd23.Obj) = ((Wrd6.pObj) [3]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 62))
    goto label_31;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd20.Lng))))
    goto label_31;
  (Wrd8.Obj) = ((Wrd18.pObj) [2]);

DEFLABEL (label_30)
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_31)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [3]);
  (Wrd28.Obj) = (current_block [OBJECT_21_1]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_14]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_2]), 2);

DEFLABEL (label_20)
  (Wrd8.Obj) = Rvl;
  goto label_30;

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_21_9);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_37;

DEFLABEL (label_36)
  Wrd19 = Wrd23;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_21_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_34;

DEFLABEL (label_33)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_32)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_21_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_33;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_21_16])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_22)
  goto label_32;

DEFLABEL (label_37)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_36;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_21_15])), (Wrd20.pObj));

DEFLABEL (label_21)
  (Wrd19.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_21_11);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_43;

DEFLABEL (label_42)
  Wrd19 = Wrd23;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_21_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_40;

DEFLABEL (label_39)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_38)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_21_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_40)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_39;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_21_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_24)
  goto label_38;

DEFLABEL (label_43)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_42;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_21_17])), (Wrd20.pObj));

DEFLABEL (label_23)
  (Wrd19.Obj) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define LABEL_22_7 7
#define ENVIRONMENT_LABEL_22_3 17
#define DEBUGGING_LABEL_22_2 16
#define OBJECT_22_2 15
#define OBJECT_22_1 14
#define OBJECT_22_0 13
#define EXECUTE_CACHE_22_8 9
#define EXECUTE_CACHE_22_6 11
#define FREE_REFERENCES_LABEL_22_0 8
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto unparse_char_2;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_22_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_char_6)
DEFLABEL (unparse_char_2)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_22_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_7)
  (Wrd21.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_22_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_7 7
#define ENVIRONMENT_LABEL_23_3 17
#define DEBUGGING_LABEL_23_2 16
#define OBJECT_23_2 15
#define OBJECT_23_1 14
#define OBJECT_23_0 13
#define EXECUTE_CACHE_23_8 9
#define EXECUTE_CACHE_23_6 11
#define FREE_REFERENCES_LABEL_23_0 8
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto unparse_string_2;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_23_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_string_6)
DEFLABEL (unparse_string_2)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_7)
  (Wrd21.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_23_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_7 7
#define LABEL_24_8 9
#define LABEL_24_9 11
#define LABEL_24_10 13
#define ENVIRONMENT_LABEL_24_3 26
#define DEBUGGING_LABEL_24_2 25
#define OBJECT_24_5 24
#define OBJECT_24_4 23
#define OBJECT_24_3 22
#define OBJECT_24_2 21
#define OBJECT_24_1 20
#define OBJECT_24_0 19
#define EXECUTE_CACHE_24_11 15
#define EXECUTE_CACHE_24_6 17
#define FREE_REFERENCES_LABEL_24_0 14
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto unparse_object_5;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_24_7);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_24_8);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_24_9);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_24_10);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_object_12)
DEFLABEL (unparse_object_5)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_20;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_20;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_19)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_18;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_18;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_17)
  (Wrd37.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 62))
    goto label_16;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd46.Lng))))
    goto label_16;
  (Wrd38.Obj) = ((Wrd44.pObj) [5]);

DEFLABEL (label_15)
  (Rsp [4]) = (Wrd38.Obj);
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 62))
    goto label_14;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd62.Lng))))
    goto label_14;
  (Wrd54.Obj) = ((Wrd60.pObj) [4]);

DEFLABEL (label_13)
  (Rsp [3]) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (label_14)
  (Wrd65.Obj) = (Rsp [3]);
  (Wrd66.Obj) = (current_block [OBJECT_24_5]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_10]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_2]), 2);

DEFLABEL (label_10)
  (Wrd54.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.Obj) = (current_block [OBJECT_24_4]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_9]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_2]), 2);

DEFLABEL (label_9)
  (Wrd38.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_24_3]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_2]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_24_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_5 3
#define LABEL_25_6 5
#define LABEL_25_7 7
#define LABEL_25_9 9
#define LABEL_25_10 11
#define LABEL_25_11 13
#define LABEL_25_12 15
#define LABEL_25_4 17
#define LABEL_25_13 19
#define LABEL_25_15 21
#define LABEL_25_16 23
#define LABEL_25_17 25
#define LABEL_25_18 27
#define LABEL_25_19 29
#define ENVIRONMENT_LABEL_25_3 47
#define DEBUGGING_LABEL_25_2 46
#define OBJECT_25_4 45
#define OBJECT_25_3 44
#define OBJECT_25_2 43
#define OBJECT_25_1 42
#define OBJECT_25_0 41
#define EXECUTE_CACHE_25_21 31
#define EXECUTE_CACHE_25_20 33
#define EXECUTE_CACHE_25_14 35
#define EXECUTE_CACHE_25_8 37
#define FREE_REFERENCE_25_0 40
#define FREE_REFERENCES_LABEL_25_0 30
#define NUMBER_OF_LINKER_SECTIONS_25_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd69;
  machine_word Wrd54;
  machine_word Wrd55;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd47;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd104;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd99;
  machine_word Wrd85;
  machine_word Wrd86;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd78;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd109;
  machine_word Wrd107;
  machine_word Wrd62;
  machine_word Wrd31;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_4;

    case 1:
      current_block = (Rpc - LABEL_25_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_25_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_25_9);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_25_10);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_25_11);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_25_12);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_25_4);
      goto unparse_object_top_level_5;

    case 8:
      current_block = (Rpc - LABEL_25_13);
      goto label_7;

    case 9:
      current_block = (Rpc - LABEL_25_15);
      goto label_8;

    case 10:
      current_block = (Rpc - LABEL_25_16);
      goto label_9;

    case 11:
      current_block = (Rpc - LABEL_25_17);
      goto label_10;

    case 12:
      current_block = (Rpc - LABEL_25_18);
      goto label_11;

    case 13:
      current_block = (Rpc - LABEL_25_19);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_object_top_level_17)
DEFLABEL (unparse_object_top_level_5)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  if ((Wrd10.Obj) == (current_block [OBJECT_25_2]))
    goto label_37;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_21]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_25_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_28;
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd107.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd109.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd109.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_25_5);
  (Wrd31.Obj) = (Rsp [5]);

DEFLABEL (label_27)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_26)
  (Rsp [4]) = (Wrd31.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_6]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd48.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd51.Obj) = ((Wrd48.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_25;
  Wrd47 = Wrd51;

DEFLABEL (label_24)
  if ((Wrd47.Obj) == ((SCHEME_OBJECT) 0))
    goto label_23;
  (Wrd56.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd59.Obj) = ((Wrd56.pObj) [0]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if ((Wrd60.uLng) == 50)
    goto label_22;
  Wrd55 = Wrd59;

DEFLABEL (label_21)
  Wrd54 = Wrd55;
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd69.uLng) == 62))
    goto label_20;
  (Wrd66.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd67.Obj) = ((Wrd66.pObj) [0]);
  (Wrd68.Lng) = (FIXNUM_TO_LONG (Wrd67.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd68.Lng))))
    goto label_20;
  (Wrd62.Obj) = ((Wrd66.pObj) [3]);

DEFLABEL (label_19)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_18)
  (Rsp [2]) = (Wrd62.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_20]));

DEFLABEL (label_20)
  (Wrd71.Obj) = (current_block [OBJECT_25_4]);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_19]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_12)
  (Wrd62.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_18])), (Wrd56.pObj));

DEFLABEL (label_11)
  (Wrd55.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  (Wrd62.Obj) = (current_block [OBJECT_25_3]);
  goto label_19;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_17])), (Wrd48.pObj));

DEFLABEL (label_10)
  (Wrd47.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_28)
  (Wrd79.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd82.Obj) = ((Wrd79.pObj) [0]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if ((Wrd83.uLng) == 50)
    goto label_36;
  Wrd78 = Wrd82;

DEFLABEL (label_35)
  if (! ((Wrd78.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_30;

DEFLABEL (label_29)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_25_12);
  (Wrd31.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_30)
  (Wrd87.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd90.Obj) = ((Wrd87.pObj) [0]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if ((Wrd91.uLng) == 50)
    goto label_34;
  Wrd86 = Wrd90;

DEFLABEL (label_33)
  Wrd85 = Wrd86;
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if (! ((Wrd99.uLng) == 62))
    goto label_31;
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (Wrd98.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd98.Lng))))
    goto label_31;
  (Wrd31.Obj) = ((Wrd96.pObj) [5]);
  goto label_27;

DEFLABEL (label_31)
  (Wrd101.Obj) = (current_block [OBJECT_25_0]);
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_11]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_15)
DEFLABEL (label_32)
  (Wrd31.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_10])), (Wrd87.pObj));

DEFLABEL (label_14)
  (Wrd86.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_9])), (Wrd79.pObj));

DEFLABEL (label_13)
  (Wrd78.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_37)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_42;
  Wrd16 = Wrd20;

DEFLABEL (label_41)
  if ((Wrd16.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_40;
  Wrd24 = Wrd28;

DEFLABEL (label_39)
  Wrd23 = Wrd24;
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd38.uLng) == 62))
    goto label_38;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd37.Lng))))
    goto label_38;
  (Wrd31.Obj) = ((Wrd35.pObj) [5]);
  goto label_27;

DEFLABEL (label_38)
  (Wrd40.Obj) = (current_block [OBJECT_25_0]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_16]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_9)
  goto label_32;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_15])), (Wrd25.pObj));

DEFLABEL (label_8)
  (Wrd24.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_13])), (Wrd17.pObj));

DEFLABEL (label_7)
  (Wrd16.Obj) = Rvl;
  goto label_41;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_6);
  (Wrd62.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_5 5
#define LABEL_26_7 7
#define LABEL_26_9 9
#define LABEL_26_10 11
#define TAG_26_11 4
#define LABEL_26_17 13
#define LABEL_26_18 15
#define LABEL_26_19 17
#define LABEL_26_20 19
#define LABEL_26_21 21
#define LABEL_26_22 23
#define LABEL_26_23 25
#define LABEL_26_24 27
#define LABEL_26_25 29
#define LABEL_26_26 31
#define LABEL_26_12 33
#define TAG_26_13 15
#define LABEL_26_14 35
#define TAG_26_15 16
#define LABEL_26_28 37
#define LABEL_26_29 39
#define LABEL_26_30 41
#define LABEL_26_31 43
#define LABEL_26_32 45
#define LABEL_26_33 47
#define LABEL_26_34 49
#define LABEL_26_35 51
#define LABEL_26_36 53
#define LABEL_26_37 55
#define ENVIRONMENT_LABEL_26_3 82
#define DEBUGGING_LABEL_26_2 81
#define OBJECT_26_3 80
#define OBJECT_26_2 79
#define OBJECT_26_1 78
#define OBJECT_26_0 77
#define EXECUTE_CACHE_26_27 57
#define EXECUTE_CACHE_26_16 59
#define EXECUTE_CACHE_26_8 61
#define EXECUTE_CACHE_26_6 63
#define FREE_REFERENCE_26_4 66
#define FREE_REFERENCE_26_3 67
#define FREE_REFERENCE_26_2 68
#define FREE_REFERENCE_26_1 69
#define FREE_REFERENCE_26_0 70
#define FREE_ASSIGNMENT_26_4 72
#define FREE_ASSIGNMENT_26_3 73
#define FREE_ASSIGNMENT_26_2 74
#define FREE_ASSIGNMENT_26_1 75
#define FREE_ASSIGNMENT_26_0 76
#define FREE_REFERENCES_LABEL_26_0 56
#define NUMBER_OF_LINKER_SECTIONS_26_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd224;
  machine_word Wrd223;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd220;
  machine_word Wrd216;
  machine_word Wrd215;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd195;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd196;
  machine_word Wrd192;
  machine_word Wrd185;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd151;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd85;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd91;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto unparse_object_internal_69;

    case 1:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_26_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_26_9);
      goto label_71;

    case 4:
      current_block = (Rpc - LABEL_26_10);
      goto lambda_94;

    case 5:
      current_block = (Rpc - LABEL_26_17);
      goto label_72;

    case 6:
      current_block = (Rpc - LABEL_26_18);
      goto label_73;

    case 7:
      current_block = (Rpc - LABEL_26_19);
      goto label_74;

    case 8:
      current_block = (Rpc - LABEL_26_20);
      goto label_75;

    case 9:
      current_block = (Rpc - LABEL_26_21);
      goto label_76;

    case 10:
      current_block = (Rpc - LABEL_26_22);
      goto label_77;

    case 11:
      current_block = (Rpc - LABEL_26_23);
      goto label_78;

    case 12:
      current_block = (Rpc - LABEL_26_24);
      goto label_79;

    case 13:
      current_block = (Rpc - LABEL_26_25);
      goto label_80;

    case 14:
      current_block = (Rpc - LABEL_26_26);
      goto label_81;

    case 15:
      current_block = (Rpc - LABEL_26_12);
      goto lambda_95;

    case 16:
      current_block = (Rpc - LABEL_26_14);
      goto lambda_96;

    case 17:
      current_block = (Rpc - LABEL_26_28);
      goto label_82;

    case 18:
      current_block = (Rpc - LABEL_26_29);
      goto label_83;

    case 19:
      current_block = (Rpc - LABEL_26_30);
      goto label_84;

    case 20:
      current_block = (Rpc - LABEL_26_31);
      goto label_85;

    case 21:
      current_block = (Rpc - LABEL_26_32);
      goto label_86;

    case 22:
      current_block = (Rpc - LABEL_26_33);
      goto label_87;

    case 23:
      current_block = (Rpc - LABEL_26_34);
      goto label_88;

    case 24:
      current_block = (Rpc - LABEL_26_35);
      goto label_89;

    case 25:
      current_block = (Rpc - LABEL_26_36);
      goto label_90;

    case 26:
      current_block = (Rpc - LABEL_26_37);
      goto label_91;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_object_internal_93)
DEFLABEL (unparse_object_internal_69)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd30.pObj) = (& (Rhp [-1]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_26_0]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_26_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_26_7);
  (Wrd6.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd14.uLng) == 62))
    goto label_98;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_98;
  (Wrd8.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_97)
  (Wrd23.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd21.pObj) = (& (Rhp [-1]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd21.pObj)));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd27.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd25.pObj) = (& (Rhp [-1]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd31.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd31.Obj);
  (Wrd29.pObj) = (& (Rhp [-1]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd35.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd35.Obj);
  (Wrd33.pObj) = (& (Rhp [-1]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd33.pObj)));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd91.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd91.Obj);
  (Wrd89.pObj) = (& (Rhp [-1]));
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd89.pObj)));
  (Rsp [4]) = (Wrd90.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 13));
  (Wrd38.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_26_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_26_10])));
  Rhp += 10;
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd38.pObj)));
  Wrd57 = Wrd38;
  (Wrd58.Obj) = (Rsp [9]);
  ((Wrd57.pObj) [2]) = (Wrd58.Obj);
  (Wrd56.Obj) = (Rsp [8]);
  ((Wrd57.pObj) [3]) = (Wrd56.Obj);
  (Wrd54.Obj) = (Rsp [7]);
  ((Wrd57.pObj) [4]) = (Wrd54.Obj);
  (Wrd52.Obj) = (Rsp [6]);
  ((Wrd57.pObj) [5]) = (Wrd52.Obj);
  (Wrd50.Obj) = (Rsp [5]);
  ((Wrd57.pObj) [6]) = (Wrd50.Obj);
  ((Wrd57.pObj) [7]) = (Wrd90.Obj);
  ((Wrd57.pObj) [8]) = (Wrd22.Obj);
  ((Wrd57.pObj) [9]) = (Wrd26.Obj);
  ((Wrd57.pObj) [10]) = (Wrd30.Obj);
  ((Wrd57.pObj) [11]) = (Wrd34.Obj);
  (Rsp [12]) = (Wrd37.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd61.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_26_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_26_12])));
  Rhp += 1;
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd61.pObj)));
  Wrd62 = Wrd61;
  (Wrd63.Obj) = (Rsp [10]);
  ((Wrd62.pObj) [2]) = (Wrd63.Obj);
  (Rsp [13]) = (Wrd60.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 13));
  (Wrd66.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_26_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_26_14])));
  Rhp += 10;
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd66.pObj)));
  Wrd85 = Wrd66;
  ((Wrd85.pObj) [2]) = (Wrd58.Obj);
  ((Wrd85.pObj) [3]) = (Wrd56.Obj);
  ((Wrd85.pObj) [4]) = (Wrd54.Obj);
  ((Wrd85.pObj) [5]) = (Wrd52.Obj);
  ((Wrd85.pObj) [6]) = (Wrd50.Obj);
  ((Wrd85.pObj) [7]) = (Wrd90.Obj);
  ((Wrd85.pObj) [8]) = (Wrd22.Obj);
  ((Wrd85.pObj) [9]) = (Wrd26.Obj);
  ((Wrd85.pObj) [10]) = (Wrd30.Obj);
  ((Wrd85.pObj) [11]) = (Wrd34.Obj);
  (Rsp [14]) = (Wrd65.Obj);
  Rsp = (& (Rsp [12]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_16]));

DEFLABEL (label_98)
  (Wrd16.Obj) = (current_block [OBJECT_26_1]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_2]), 2);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_97;

DEFLABEL (lambda_94)
  CLOSURE_HEADER (LABEL_26_10);

DEFLABEL (lambda_35)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [11]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_128;

DEFLABEL (label_127)
  Wrd19 = Wrd23;

DEFLABEL (label_126)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_125;

DEFLABEL (label_124)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_123)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [6]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [10]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_122;

DEFLABEL (label_121)
  Wrd63 = Wrd67;

DEFLABEL (label_120)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_119;

DEFLABEL (label_118)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_117)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [5]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [9]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_116;

DEFLABEL (label_115)
  Wrd107 = Wrd111;

DEFLABEL (label_114)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_113;

DEFLABEL (label_112)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_111)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [4]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [8]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_110;

DEFLABEL (label_109)
  Wrd151 = Wrd155;

DEFLABEL (label_108)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_107;

DEFLABEL (label_106)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_105)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [3]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  (Wrd183.Obj) = ((Wrd178.pObj) [7]);
  (Wrd184.pObj) = (OBJECT_ADDRESS (Wrd183.Obj));
  (Wrd185.Obj) = ((Wrd184.pObj) [0]);
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd192.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd184.pObj) [0]) = (Wrd192.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd196.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_4]));
  (Wrd199.Obj) = ((Wrd196.pObj) [0]);
  (Wrd200.uLng) = (OBJECT_TYPE (Wrd199.Obj));
  if ((Wrd200.uLng) == 50)
    goto label_104;

DEFLABEL (label_103)
  Wrd195 = Wrd199;

DEFLABEL (label_102)
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd207.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_4]));
  (Wrd208.Obj) = (Rsp [1]);
  (Wrd215.Obj) = ((Wrd207.pObj) [0]);
  (Wrd216.uLng) = (OBJECT_TYPE (Wrd215.Obj));
  if ((Wrd216.uLng) == 50)
    goto label_101;

DEFLABEL (label_100)
  ((Wrd207.pObj) [0]) = (Wrd208.Obj);

DEFLABEL (label_99)
  (Wrd220.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd221.Obj) = (Rsp [0]);
  (Wrd222.pObj) = (OBJECT_ADDRESS (Wrd221.Obj));
  (Wrd223.Obj) = ((Wrd222.pObj) [2]);
  (Wrd224.pObj) = (OBJECT_ADDRESS (Wrd223.Obj));
  ((Wrd224.pObj) [0]) = (Wrd220.Obj);
  Rvl = (current_block [OBJECT_26_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_101)
  if ((Wrd215.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_100;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_26])), (Wrd207.pObj), (Wrd208.Obj));

DEFLABEL (label_81)
  goto label_99;

DEFLABEL (label_104)
  if ((Wrd199.Obj) == (Wrd192.Obj))
    goto label_103;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_25])), (Wrd196.pObj));

DEFLABEL (label_80)
  (Wrd195.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_107)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_106;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_24])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_79)
  goto label_105;

DEFLABEL (label_110)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_109;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_23])), (Wrd152.pObj));

DEFLABEL (label_78)
  (Wrd151.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_113)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_112;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_22])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_77)
  goto label_111;

DEFLABEL (label_116)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_115;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_21])), (Wrd108.pObj));

DEFLABEL (label_76)
  (Wrd107.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_119)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_118;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_20])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_75)
  goto label_117;

DEFLABEL (label_122)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_121;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_19])), (Wrd64.pObj));

DEFLABEL (label_74)
  (Wrd63.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_125)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_124;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_73)
  goto label_123;

DEFLABEL (label_128)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_127;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_17])), (Wrd20.pObj));

DEFLABEL (label_72)
  (Wrd19.Obj) = Rvl;
  goto label_126;

DEFLABEL (lambda_95)
  CLOSURE_HEADER (LABEL_26_12);

DEFLABEL (lambda_36)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_27]));

DEFLABEL (lambda_96)
  CLOSURE_HEADER (LABEL_26_14);

DEFLABEL (lambda_67)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [6]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_158;

DEFLABEL (label_157)
  Wrd19 = Wrd23;

DEFLABEL (label_156)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_155;

DEFLABEL (label_154)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_153)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [11]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [5]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_152;

DEFLABEL (label_151)
  Wrd63 = Wrd67;

DEFLABEL (label_150)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_149;

DEFLABEL (label_148)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_147)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [10]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [4]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_146;

DEFLABEL (label_145)
  Wrd107 = Wrd111;

DEFLABEL (label_144)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_143;

DEFLABEL (label_142)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_141)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [9]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [3]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_140;

DEFLABEL (label_139)
  Wrd151 = Wrd155;

DEFLABEL (label_138)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_137;

DEFLABEL (label_136)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_135)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [8]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  (Wrd183.Obj) = ((Wrd178.pObj) [2]);
  (Wrd184.pObj) = (OBJECT_ADDRESS (Wrd183.Obj));
  (Wrd185.Obj) = ((Wrd184.pObj) [0]);
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd192.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd184.pObj) [0]) = (Wrd192.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd196.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_4]));
  (Wrd199.Obj) = ((Wrd196.pObj) [0]);
  (Wrd200.uLng) = (OBJECT_TYPE (Wrd199.Obj));
  if ((Wrd200.uLng) == 50)
    goto label_134;

DEFLABEL (label_133)
  Wrd195 = Wrd199;

DEFLABEL (label_132)
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd207.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_26_4]));
  (Wrd208.Obj) = (Rsp [1]);
  (Wrd215.Obj) = ((Wrd207.pObj) [0]);
  (Wrd216.uLng) = (OBJECT_TYPE (Wrd215.Obj));
  if ((Wrd216.uLng) == 50)
    goto label_131;

DEFLABEL (label_130)
  ((Wrd207.pObj) [0]) = (Wrd208.Obj);

DEFLABEL (label_129)
  (Wrd220.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd221.Obj) = (Rsp [0]);
  (Wrd222.pObj) = (OBJECT_ADDRESS (Wrd221.Obj));
  (Wrd223.Obj) = ((Wrd222.pObj) [7]);
  (Wrd224.pObj) = (OBJECT_ADDRESS (Wrd223.Obj));
  ((Wrd224.pObj) [0]) = (Wrd220.Obj);
  Rvl = (current_block [OBJECT_26_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_131)
  if ((Wrd215.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_130;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_37])), (Wrd207.pObj), (Wrd208.Obj));

DEFLABEL (label_91)
  goto label_129;

DEFLABEL (label_134)
  if ((Wrd199.Obj) == (Wrd192.Obj))
    goto label_133;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_36])), (Wrd196.pObj));

DEFLABEL (label_90)
  (Wrd195.Obj) = Rvl;
  goto label_132;

DEFLABEL (label_137)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_136;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_35])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_89)
  goto label_135;

DEFLABEL (label_140)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_139;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_34])), (Wrd152.pObj));

DEFLABEL (label_88)
  (Wrd151.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_143)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_142;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_33])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_87)
  goto label_141;

DEFLABEL (label_146)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_145;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_32])), (Wrd108.pObj));

DEFLABEL (label_86)
  (Wrd107.Obj) = Rvl;
  goto label_144;

DEFLABEL (label_149)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_148;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_31])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_85)
  goto label_147;

DEFLABEL (label_152)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_151;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_30])), (Wrd64.pObj));

DEFLABEL (label_84)
  (Wrd63.Obj) = Rvl;
  goto label_150;

DEFLABEL (label_155)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_154;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_26_29])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_83)
  goto label_153;

DEFLABEL (label_158)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_157;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_26_28])), (Wrd20.pObj));

DEFLABEL (label_82)
  (Wrd19.Obj) = Rvl;
  goto label_156;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_6 5
#define LABEL_27_7 7
#define LABEL_27_8 9
#define LABEL_27_9 11
#define LABEL_27_5 13
#define ENVIRONMENT_LABEL_27_3 23
#define DEBUGGING_LABEL_27_2 22
#define EXECUTE_CACHE_27_10 15
#define FREE_REFERENCE_27_3 18
#define FREE_REFERENCE_27_2 19
#define FREE_REFERENCE_27_1 20
#define FREE_REFERENCE_27_0 21
#define FREE_REFERENCES_LABEL_27_0 14
#define NUMBER_OF_LINKER_SECTIONS_27_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto invoke_user_method_1;

    case 1:
      current_block = (Rpc - LABEL_27_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_27_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_27_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_27_9);
      goto label_6;

    case 5:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (invoke_user_method_8)
DEFLABEL (invoke_user_method_1)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_16;
  Wrd9 = Wrd13;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_14;
  Wrd15 = Wrd19;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_12;
  Wrd21 = Wrd25;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_3]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_10;
  Wrd27 = Wrd31;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_9])), (Wrd28.pObj));

DEFLABEL (label_6)
  (Wrd27.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_8])), (Wrd22.pObj));

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_7])), (Wrd16.pObj));

DEFLABEL (label_4)
  (Wrd15.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_6])), (Wrd10.pObj));

DEFLABEL (label_3)
  (Wrd9.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_6 7
#define ENVIRONMENT_LABEL_28_3 12
#define DEBUGGING_LABEL_28_2 11
#define OBJECT_28_0 10
#define FREE_REFERENCE_28_0 9
#define FREE_REFERENCES_LABEL_28_0 8
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto Z__unparse_object_2;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_28_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_object_7)
DEFLABEL (Z__unparse_object_2)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_11;
  Wrd6 = Wrd10;

DEFLABEL (label_10)
  Wrd5 = Wrd6;
  (Wrd13.Obj) = ((SCHEME_OBJECT) 26);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  (Wrd12.Obj) = (MAKE_OBJECT (26, (Wrd15.uLng)));
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_9;
  if (! ((Wrd13.uLng) == 26))
    goto label_9;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd24.Lng))))
    goto label_9;
  (Wrd18.pObj) = (& ((Wrd22.pObj) [(Wrd15.Lng)]));
  (Wrd19.Obj) = ((Wrd18.pObj) [1]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_8)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_9)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_6]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_5])), (Wrd7.pObj));

DEFLABEL (label_4)
  (Wrd6.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define ENVIRONMENT_LABEL_29_3 12
#define DEBUGGING_LABEL_29_2 11
#define EXECUTE_CACHE_29_6 7
#define FREE_REFERENCE_29_0 10
#define FREE_REFERENCES_LABEL_29_0 6
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto Z__unparse_char_0;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_char_4)
DEFLABEL (Z__unparse_char_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define ENVIRONMENT_LABEL_30_3 12
#define DEBUGGING_LABEL_30_2 11
#define EXECUTE_CACHE_30_6 7
#define FREE_REFERENCE_30_0 10
#define FREE_REFERENCES_LABEL_30_0 6
#define NUMBER_OF_LINKER_SECTIONS_30_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto Z__unparse_string_0;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_string_4)
DEFLABEL (Z__unparse_string_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define ENVIRONMENT_LABEL_31_3 12
#define DEBUGGING_LABEL_31_2 11
#define EXECUTE_CACHE_31_6 7
#define FREE_REFERENCE_31_0 10
#define FREE_REFERENCES_LABEL_31_0 6
#define NUMBER_OF_LINKER_SECTIONS_31_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto Z__unparse_substring_0;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_substring_4)
DEFLABEL (Z__unparse_substring_0)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define ENVIRONMENT_LABEL_32_3 11
#define DEBUGGING_LABEL_32_2 10
#define OBJECT_32_0 9
#define EXECUTE_CACHE_32_6 7
#define FREE_REFERENCES_LABEL_32_0 6
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto Z__unparse_datum_1;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_datum_4)
DEFLABEL (Z__unparse_datum_1)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_6 5
#define LABEL_33_5 7
#define LABEL_33_8 9
#define LABEL_33_9 11
#define ENVIRONMENT_LABEL_33_3 22
#define DEBUGGING_LABEL_33_2 21
#define OBJECT_33_1 20
#define OBJECT_33_0 19
#define EXECUTE_CACHE_33_10 13
#define EXECUTE_CACHE_33_7 15
#define FREE_REFERENCE_33_0 18
#define FREE_REFERENCES_LABEL_33_0 12
#define NUMBER_OF_LINKER_SECTIONS_33_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto Z__unparse_hex_2;

    case 1:
      current_block = (Rpc - LABEL_33_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_33_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_33_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_hex_7)
DEFLABEL (Z__unparse_hex_2)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_11;
  Wrd9 = Wrd13;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_33_1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_33_9);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_7]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_8])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_6])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_5 5
#define LABEL_34_6 7
#define LABEL_34_7 9
#define ENVIRONMENT_LABEL_34_3 20
#define DEBUGGING_LABEL_34_2 19
#define EXECUTE_CACHE_34_10 11
#define EXECUTE_CACHE_34_9 13
#define EXECUTE_CACHE_34_8 15
#define FREE_REFERENCE_34_0 18
#define FREE_REFERENCES_LABEL_34_0 10
#define NUMBER_OF_LINKER_SECTIONS_34_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto Z__unparse_hash_2;

    case 1:
      current_block = (Rpc - LABEL_34_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_34_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_34_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_hash_6)
DEFLABEL (Z__unparse_hash_2)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_8;
  Wrd5 = Wrd9;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_34_7);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_34_6);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_5])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_6 5
#define LABEL_35_5 7
#define LABEL_35_8 9
#define LABEL_35_9 11
#define LABEL_35_10 13
#define ENVIRONMENT_LABEL_35_3 25
#define DEBUGGING_LABEL_35_2 24
#define OBJECT_35_0 23
#define EXECUTE_CACHE_35_12 15
#define EXECUTE_CACHE_35_11 17
#define EXECUTE_CACHE_35_7 19
#define FREE_REFERENCE_35_0 22
#define FREE_REFERENCES_LABEL_35_0 14
#define NUMBER_OF_LINKER_SECTIONS_35_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto Z__unparse_readable_hash_3;

    case 1:
      current_block = (Rpc - LABEL_35_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_35_8);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_35_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_readable_hash_8)
DEFLABEL (Z__unparse_readable_hash_3)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_12;
  Wrd9 = Wrd13;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_10;
  Wrd5 = Wrd9;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_35_9);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_8])), (Wrd6.pObj));

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_6])), (Wrd10.pObj));

DEFLABEL (label_5)
  (Wrd9.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define LABEL_36_7 7
#define LABEL_36_6 9
#define LABEL_36_11 11
#define LABEL_36_13 13
#define LABEL_36_14 15
#define LABEL_36_10 17
#define LABEL_36_15 19
#define LABEL_36_16 21
#define LABEL_36_19 23
#define LABEL_36_21 25
#define LABEL_36_23 27
#define LABEL_36_22 29
#define LABEL_36_20 31
#define LABEL_36_18 33
#define LABEL_36_24 35
#define LABEL_36_28 37
#define LABEL_36_25 39
#define LABEL_36_27 41
#define ENVIRONMENT_LABEL_36_3 66
#define DEBUGGING_LABEL_36_2 65
#define OBJECT_36_3 64
#define OBJECT_36_2 63
#define OBJECT_36_1 62
#define OBJECT_36_0 61
#define EXECUTE_CACHE_36_30 43
#define EXECUTE_CACHE_36_29 45
#define EXECUTE_CACHE_36_26 47
#define EXECUTE_CACHE_36_17 49
#define EXECUTE_CACHE_36_12 51
#define EXECUTE_CACHE_36_9 53
#define EXECUTE_CACHE_36_8 55
#define FREE_REFERENCE_36_2 58
#define FREE_REFERENCE_36_1 59
#define FREE_REFERENCE_36_0 60
#define FREE_REFERENCES_LABEL_36_0 42
#define NUMBER_OF_LINKER_SECTIONS_36_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd53;
  machine_word Wrd47;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto Z__unparse_with_brackets_11;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_36_7);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_36_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_36_11);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_36_13);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_36_14);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_36_10);
      goto continuation_2;

    case 8:
      current_block = (Rpc - LABEL_36_15);
      goto label_18;

    case 9:
      current_block = (Rpc - LABEL_36_16);
      goto label_20;

    case 10:
      current_block = (Rpc - LABEL_36_19);
      goto label_19;

    case 11:
      current_block = (Rpc - LABEL_36_21);
      goto label_17;

    case 12:
      current_block = (Rpc - LABEL_36_23);
      goto label_16;

    case 13:
      current_block = (Rpc - LABEL_36_22);
      goto continuation_3;

    case 14:
      current_block = (Rpc - LABEL_36_20);
      goto continuation_10;

    case 15:
      current_block = (Rpc - LABEL_36_18);
      goto continuation_7;

    case 16:
      current_block = (Rpc - LABEL_36_24);
      goto continuation_5;

    case 17:
      current_block = (Rpc - LABEL_36_28);
      goto label_21;

    case 18:
      current_block = (Rpc - LABEL_36_25);
      goto continuation_4;

    case 19:
      current_block = (Rpc - LABEL_36_27);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparse_with_brackets_23)
DEFLABEL (Z__unparse_with_brackets_11)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_46;
  Wrd5 = Wrd9;

DEFLABEL (label_45)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd12.Obj) = (Rsp [1]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_9]));

DEFLABEL (label_24)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_6]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_36_0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_44;
  Wrd20 = Wrd24;

DEFLABEL (label_43)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_36_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 30)
    goto label_40;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_36_10);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_36_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_39;
  Wrd11 = Wrd15;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_36_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_24]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_25]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_26]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_36_25);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_29]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_36_24);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_37;
  Wrd5 = Wrd9;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_36_14);

DEFLABEL (label_35)
  (Wrd17.Obj) = (Rsp [2]);
  if ((Wrd17.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_20]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_36_2]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_29;
  Wrd23 = Wrd27;

DEFLABEL (label_28)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_36_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_36_13);

DEFLABEL (label_27)
  (Wrd48.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd51.Obj) = ((Wrd48.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_26;
  Wrd47 = Wrd51;

DEFLABEL (label_25)
  (Rsp [1]) = (Wrd47.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_36_1]);
  (Rsp [2]) = (Wrd53.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_16])), (Wrd48.pObj));

DEFLABEL (label_20)
  (Wrd47.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_29)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_21])), (Wrd24.pObj));

DEFLABEL (label_17)
  (Wrd23.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_2]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_34;
  Wrd29 = Wrd33;

DEFLABEL (label_33)
  if ((Wrd29.Obj) == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_18]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_36_2]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd44.Obj) = ((Wrd41.pObj) [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 50)
    goto label_32;
  Wrd40 = Wrd44;

DEFLABEL (label_31)
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_36_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_27]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_3]), 1);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_36_27);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_30]));

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_19])), (Wrd41.pObj));

DEFLABEL (label_19)
  (Wrd40.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_15])), (Wrd30.pObj));

DEFLABEL (label_18)
  (Wrd29.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_28])), (Wrd6.pObj));

DEFLABEL (label_21)
  (Wrd5.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_23])), (Wrd12.pObj));

DEFLABEL (label_16)
  (Wrd11.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_40)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_42;
  Wrd15 = Wrd19;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_11])), (Wrd16.pObj));

DEFLABEL (label_15)
  (Wrd15.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_7])), (Wrd21.pObj));

DEFLABEL (label_14)
  (Wrd20.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_5])), (Wrd6.pObj));

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_45;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define LABEL_37_7 7
#define LABEL_37_9 9
#define LABEL_37_14 11
#define TAG_37_15 4
#define LABEL_37_11 13
#define TAG_37_12 5
#define LABEL_37_16 15
#define LABEL_37_17 17
#define ENVIRONMENT_LABEL_37_3 33
#define DEBUGGING_LABEL_37_2 32
#define OBJECT_37_2 31
#define OBJECT_37_1 30
#define OBJECT_37_0 29
#define EXECUTE_CACHE_37_18 19
#define EXECUTE_CACHE_37_13 21
#define EXECUTE_CACHE_37_10 23
#define EXECUTE_CACHE_37_8 25
#define EXECUTE_CACHE_37_6 27
#define FREE_REFERENCES_LABEL_37_0 18
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto unparse_default_10;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_37_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_37_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_37_14);
      goto lambda_15;

    case 5:
      current_block = (Rpc - LABEL_37_11);
      goto lambda_14;

    case 6:
      current_block = (Rpc - LABEL_37_16);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_37_17);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_default_13)
DEFLABEL (unparse_default_10)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_37_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_37_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_13]));

DEFLABEL (label_16)
  (Wrd10.Obj) = (Rsp [0]);
  if ((Wrd10.Obj) == (current_block [OBJECT_37_1]))
    goto label_17;
  (Wrd12.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_14])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  Wrd16 = Wrd15;
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd14.Obj);
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_13]));

DEFLABEL (label_17)
  (Wrd19.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd20.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_11])));
  Rhp += 1;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  ((Wrd23.pObj) [2]) = (Wrd20.Obj);
  (Rsp [2]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_13]));

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_37_14);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_37_16);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_18]));

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_37_11);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_37_17);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_18]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_7 7
#define LABEL_38_8 9
#define ENVIRONMENT_LABEL_38_3 23
#define DEBUGGING_LABEL_38_2 22
#define OBJECT_38_0 21
#define EXECUTE_CACHE_38_12 11
#define EXECUTE_CACHE_38_11 13
#define EXECUTE_CACHE_38_10 15
#define EXECUTE_CACHE_38_9 17
#define EXECUTE_CACHE_38_6 19
#define FREE_REFERENCES_LABEL_38_0 10
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto user_object_type_6;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_38_8);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (user_object_type_9)
DEFLABEL (user_object_type_6)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  (Wrd5.Obj) = (MAKE_OBJECT (26, (Wrd8.uLng)));
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_38_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (label_10)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_38_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_38_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_38_7);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_6 5
#define LABEL_39_5 7
#define ENVIRONMENT_LABEL_39_3 15
#define DEBUGGING_LABEL_39_2 14
#define OBJECT_39_0 13
#define EXECUTE_CACHE_39_7 9
#define FREE_REFERENCE_39_0 12
#define FREE_REFERENCES_LABEL_39_0 8
#define NUMBER_OF_LINKER_SECTIONS_39_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto rename_user_object_type_2;

    case 1:
      current_block = (Rpc - LABEL_39_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (rename_user_object_type_6)
DEFLABEL (rename_user_object_type_2)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_39_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_10;
  Wrd8 = Wrd12;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_7;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_7)
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_8;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_0]), 1);

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_39_6])), (Wrd9.pObj));

DEFLABEL (label_4)
  (Wrd8.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define ENVIRONMENT_LABEL_40_3 15
#define DEBUGGING_LABEL_40_2 14
#define OBJECT_40_0 13
#define EXECUTE_CACHE_40_7 7
#define EXECUTE_CACHE_40_6 9
#define FREE_REFERENCE_40_0 12
#define FREE_REFERENCES_LABEL_40_0 6
#define NUMBER_OF_LINKER_SECTIONS_40_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto unparse_false_0;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_false_4)
DEFLABEL (unparse_false_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_5;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_7]));

DEFLABEL (label_5)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_7;
  Wrd7 = Wrd11;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_40_0]);
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_8 9
#define LABEL_41_9 11
#define LABEL_41_11 13
#define LABEL_41_12 15
#define LABEL_41_13 17
#define LABEL_41_14 19
#define LABEL_41_15 21
#define LABEL_41_16 23
#define LABEL_41_17 25
#define LABEL_41_18 27
#define LABEL_41_19 29
#define LABEL_41_21 31
#define ENVIRONMENT_LABEL_41_3 59
#define DEBUGGING_LABEL_41_2 58
#define OBJECT_41_12 57
#define OBJECT_41_11 56
#define OBJECT_41_10 55
#define OBJECT_41_9 54
#define OBJECT_41_8 53
#define OBJECT_41_7 52
#define OBJECT_41_6 51
#define OBJECT_41_5 50
#define OBJECT_41_4 49
#define OBJECT_41_3 48
#define OBJECT_41_2 47
#define OBJECT_41_1 46
#define OBJECT_41_0 45
#define EXECUTE_CACHE_41_20 33
#define EXECUTE_CACHE_41_10 35
#define EXECUTE_CACHE_41_6 37
#define FREE_REFERENCE_41_4 40
#define FREE_REFERENCE_41_3 41
#define FREE_REFERENCE_41_2 42
#define FREE_REFERENCE_41_1 43
#define FREE_REFERENCE_41_0 44
#define FREE_REFERENCES_LABEL_41_0 32
#define NUMBER_OF_LINKER_SECTIONS_41_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd68;
  machine_word Wrd62;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd32;
  machine_word Wrd75;
  machine_word Wrd69;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd24;
  machine_word Wrd82;
  machine_word Wrd76;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd77;
  machine_word Wrd13;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto unparse_constant_9;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_41_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_41_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_41_11);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_41_12);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_41_13);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_41_14);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_41_15);
      goto label_17;

    case 10:
      current_block = (Rpc - LABEL_41_16);
      goto label_21;

    case 11:
      current_block = (Rpc - LABEL_41_17);
      goto label_18;

    case 12:
      current_block = (Rpc - LABEL_41_18);
      goto label_20;

    case 13:
      current_block = (Rpc - LABEL_41_19);
      goto label_19;

    case 14:
      current_block = (Rpc - LABEL_41_21);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_constant_25)
DEFLABEL (unparse_constant_9)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_41_0]))
    goto label_58;
  if ((Wrd5.Obj) == (current_block [OBJECT_41_2]))
    goto label_55;
  if ((Wrd5.Obj) == (current_block [OBJECT_41_4]))
    goto label_52;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_41_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_27;
  Wrd7 = Wrd11;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_41_12]);
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_21])), (Wrd8.pObj));

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_51;
  Wrd15 = Wrd19;

DEFLABEL (label_50)
  (Wrd21.Obj) = (Rsp [0]);
  if ((Wrd21.Obj) == (Wrd15.Obj))
    goto label_47;
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_2]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_46;
  Wrd23 = Wrd27;

DEFLABEL (label_45)
  (Wrd29.Obj) = (Rsp [0]);
  if ((Wrd29.Obj) == (Wrd23.Obj))
    goto label_42;
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_3]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_41;
  Wrd31 = Wrd35;

DEFLABEL (label_40)
  (Wrd37.Obj) = (Rsp [0]);
  if ((Wrd37.Obj) == (Wrd31.Obj))
    goto label_37;
  (Wrd40.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_4]));
  (Wrd43.Obj) = ((Wrd40.pObj) [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 50)
    goto label_36;
  Wrd39 = Wrd43;

DEFLABEL (label_35)
  (Wrd45.Obj) = (Rsp [0]);
  if ((Wrd45.Obj) == (Wrd39.Obj))
    goto label_32;
  if ((Wrd45.Obj) == (current_block [OBJECT_41_10]))
    goto label_29;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_20]));

DEFLABEL (label_29)
  (Wrd49.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd52.Obj) = ((Wrd49.pObj) [0]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if ((Wrd53.uLng) == 50)
    goto label_31;
  Wrd48 = Wrd52;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd54.Obj) = (current_block [OBJECT_41_11]);
  (Rsp [1]) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_19])), (Wrd49.pObj));

DEFLABEL (label_19)
  (Wrd48.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_32)
  (Wrd56.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd59.Obj) = ((Wrd56.pObj) [0]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if ((Wrd60.uLng) == 50)
    goto label_34;
  Wrd55 = Wrd59;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_41_9]);
  (Rsp [1]) = (Wrd61.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_18])), (Wrd56.pObj));

DEFLABEL (label_20)
  (Wrd55.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_17])), (Wrd40.pObj));

DEFLABEL (label_18)
  (Wrd39.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_37)
  (Wrd63.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd66.Obj) = ((Wrd63.pObj) [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd67.uLng) == 50)
    goto label_39;
  Wrd62 = Wrd66;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd68.Obj) = (current_block [OBJECT_41_8]);
  (Rsp [1]) = (Wrd68.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_16])), (Wrd63.pObj));

DEFLABEL (label_21)
  (Wrd62.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_15])), (Wrd32.pObj));

DEFLABEL (label_17)
  (Wrd31.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_42)
  (Wrd70.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd73.Obj) = ((Wrd70.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_44;
  Wrd69 = Wrd73;

DEFLABEL (label_43)
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd75.Obj) = (current_block [OBJECT_41_7]);
  (Rsp [1]) = (Wrd75.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_14])), (Wrd70.pObj));

DEFLABEL (label_22)
  (Wrd69.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_13])), (Wrd24.pObj));

DEFLABEL (label_16)
  (Wrd23.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd77.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd80.Obj) = ((Wrd77.pObj) [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 50)
    goto label_49;
  Wrd76 = Wrd80;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd82.Obj) = (current_block [OBJECT_41_6]);
  (Rsp [1]) = (Wrd82.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_12])), (Wrd77.pObj));

DEFLABEL (label_23)
  (Wrd76.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_11])), (Wrd16.pObj));

DEFLABEL (label_15)
  (Wrd15.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_52)
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_54;
  Wrd15 = Wrd19;

DEFLABEL (label_53)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_41_5]);
  (Rsp [1]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_8])), (Wrd16.pObj));

DEFLABEL (label_11)
  (Wrd15.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_57;
  Wrd22 = Wrd26;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_41_3]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_7])), (Wrd23.pObj));

DEFLABEL (label_12)
  (Wrd22.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_58)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_60;
  Wrd29 = Wrd33;

DEFLABEL (label_59)
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_41_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_5])), (Wrd30.pObj));

DEFLABEL (label_13)
  (Wrd29.Obj) = Rvl;
  goto label_59;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define TAG_42_6 1
#define LABEL_42_8 7
#define ENVIRONMENT_LABEL_42_3 17
#define DEBUGGING_LABEL_42_2 16
#define OBJECT_42_0 15
#define EXECUTE_CACHE_42_10 9
#define EXECUTE_CACHE_42_9 11
#define EXECUTE_CACHE_42_7 13
#define FREE_REFERENCES_LABEL_42_0 8
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto unparse_return_address_2;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_42_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_return_address_5)
DEFLABEL (unparse_return_address_2)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_42_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_42_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_42_5])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_42_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_8);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_10]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define ENVIRONMENT_LABEL_43_3 8
#define DEBUGGING_LABEL_43_2 7
#define EXECUTE_CACHE_43_5 5
#define FREE_REFERENCES_LABEL_43_0 4
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto unparse_interned_symbol_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_interned_symbol_3)
DEFLABEL (unparse_interned_symbol_0)
  INTERRUPT_CHECK (26, LABEL_43_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_6 7
#define TAG_44_7 2
#define ENVIRONMENT_LABEL_44_3 17
#define DEBUGGING_LABEL_44_2 16
#define OBJECT_44_0 15
#define EXECUTE_CACHE_44_9 9
#define EXECUTE_CACHE_44_8 11
#define FREE_REFERENCE_44_0 14
#define FREE_REFERENCES_LABEL_44_0 8
#define NUMBER_OF_LINKER_SECTIONS_44_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto unparse_uninterned_symbol_1;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_44_6);
      goto lambda_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_uninterned_symbol_5)
DEFLABEL (unparse_uninterned_symbol_1)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_44_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_7;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

DEFLABEL (label_7)
  (Wrd12.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_44_0]);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_44_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_44_6])));
  Rhp += 1;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  ((Wrd16.pObj) [2]) = (Wrd12.Obj);
  (Rsp [2]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_8]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_44_5])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_8;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_44_6);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define LABEL_45_9 7
#define LABEL_45_11 9
#define LABEL_45_12 11
#define LABEL_45_13 13
#define LABEL_45_7 15
#define LABEL_45_16 17
#define LABEL_45_17 19
#define LABEL_45_18 21
#define LABEL_45_21 23
#define LABEL_45_8 25
#define LABEL_45_23 27
#define LABEL_45_24 29
#define LABEL_45_20 31
#define LABEL_45_27 33
#define LABEL_45_28 35
#define LABEL_45_30 37
#define LABEL_45_26 39
#define LABEL_45_32 41
#define LABEL_45_29 43
#define LABEL_45_33 45
#define LABEL_45_36 47
#define LABEL_45_35 49
#define LABEL_45_38 51
#define LABEL_45_37 53
#define LABEL_45_40 55
#define LABEL_45_41 57
#define LABEL_45_39 59
#define ENVIRONMENT_LABEL_45_3 93
#define DEBUGGING_LABEL_45_2 92
#define OBJECT_45_5 91
#define OBJECT_45_4 90
#define OBJECT_45_3 89
#define OBJECT_45_2 88
#define OBJECT_45_1 87
#define OBJECT_45_0 86
#define EXECUTE_CACHE_45_34 61
#define EXECUTE_CACHE_45_31 63
#define EXECUTE_CACHE_45_25 65
#define EXECUTE_CACHE_45_22 67
#define EXECUTE_CACHE_45_19 69
#define EXECUTE_CACHE_45_15 71
#define EXECUTE_CACHE_45_14 73
#define EXECUTE_CACHE_45_10 75
#define EXECUTE_CACHE_45_6 77
#define FREE_REFERENCE_45_5 80
#define FREE_REFERENCE_45_4 81
#define FREE_REFERENCE_45_3 82
#define FREE_REFERENCE_45_2 83
#define FREE_REFERENCE_45_1 84
#define FREE_REFERENCE_45_0 85
#define FREE_REFERENCES_LABEL_45_0 60
#define NUMBER_OF_LINKER_SECTIONS_45_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd50;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto unparse_symbol_25;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_45_9);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_45_11);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_45_12);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_45_13);
      goto label_35;

    case 6:
      current_block = (Rpc - LABEL_45_7);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_45_16);
      goto label_29;

    case 8:
      current_block = (Rpc - LABEL_45_17);
      goto label_30;

    case 9:
      current_block = (Rpc - LABEL_45_18);
      goto label_31;

    case 10:
      current_block = (Rpc - LABEL_45_21);
      goto label_28;

    case 11:
      current_block = (Rpc - LABEL_45_8);
      goto continuation_1;

    case 12:
      current_block = (Rpc - LABEL_45_23);
      goto label_33;

    case 13:
      current_block = (Rpc - LABEL_45_24);
      goto label_32;

    case 14:
      current_block = (Rpc - LABEL_45_20);
      goto continuation_9;

    case 15:
      current_block = (Rpc - LABEL_45_27);
      goto label_34;

    case 16:
      current_block = (Rpc - LABEL_45_28);
      goto loop_21;

    case 17:
      current_block = (Rpc - LABEL_45_30);
      goto label_37;

    case 18:
      current_block = (Rpc - LABEL_45_26);
      goto continuation_11;

    case 19:
      current_block = (Rpc - LABEL_45_32);
      goto label_36;

    case 20:
      current_block = (Rpc - LABEL_45_29);
      goto continuation_14;

    case 21:
      current_block = (Rpc - LABEL_45_33);
      goto label_39;

    case 22:
      current_block = (Rpc - LABEL_45_36);
      goto label_38;

    case 23:
      current_block = (Rpc - LABEL_45_35);
      goto continuation_15;

    case 24:
      current_block = (Rpc - LABEL_45_38);
      goto label_40;

    case 25:
      current_block = (Rpc - LABEL_45_37);
      goto continuation_16;

    case 26:
      current_block = (Rpc - LABEL_45_40);
      goto label_41;

    case 27:
      current_block = (Rpc - LABEL_45_41);
      goto label_42;

    case 28:
      current_block = (Rpc - LABEL_45_39);
      goto continuation_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_symbol_44)
DEFLABEL (unparse_symbol_25)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_45_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_45_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_68;
  Wrd13 = Wrd17;

DEFLABEL (label_67)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_45_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_4]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_63;
  Wrd7 = Wrd11;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_61)
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_25]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_45_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;

DEFLABEL (label_50)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_45_4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_49;
  Wrd11 = Wrd15;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_22]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_45_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 30))
    goto label_47;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [1]);
  (Wrd12.Obj) = (MAKE_OBJECT (26, (Wrd11.uLng)));
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_46)
  (Wrd19.Obj) = (current_block [OBJECT_45_2]);
  (* (--Rsp)) = (Wrd19.Obj);
  goto loop_21;

DEFLABEL (label_47)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_27]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_21])), (Wrd12.pObj));

DEFLABEL (label_28)
  (Wrd11.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 30))
    goto label_60;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (Wrd17.Obj) = (MAKE_OBJECT (26, (Wrd21.uLng)));

DEFLABEL (label_59)
  if ((Wrd17.Obj) == (current_block [OBJECT_45_2]))
    goto label_50;
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_12]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 30))
    goto label_58;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [1]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd42.Lng))))
    goto label_58;
  (Wrd35.uLng) = ((unsigned long) (((unsigned char *) (Wrd40.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd36.Obj) = (MAKE_OBJECT (2, (Wrd35.uLng)));
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_57)
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_2]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_56;
  Wrd50 = Wrd54;

DEFLABEL (label_55)
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_45_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_11]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd61.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd61.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_45_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_50;

DEFLABEL (label_54)
  (Wrd63.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd66.Obj) = ((Wrd63.pObj) [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd67.uLng) == 50)
    goto label_53;
  Wrd62 = Wrd66;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd62.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_14]));

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_13])), (Wrd63.pObj));

DEFLABEL (label_35)
  (Wrd62.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_18])), (Wrd51.pObj));

DEFLABEL (label_31)
  (Wrd50.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.Obj) = (current_block [OBJECT_45_2]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_17]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_3]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_16]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 1);

DEFLABEL (label_29)
  (Wrd17.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_24])), (Wrd8.pObj));

DEFLABEL (label_32)
  (Wrd7.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_64)
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_3]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_66;
  Wrd14 = Wrd18;

DEFLABEL (label_65)
  (* (--Rsp)) = (Wrd14.Obj);
  goto label_61;

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_23])), (Wrd15.pObj));

DEFLABEL (label_33)
  (Wrd14.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_9])), (Wrd14.pObj));

DEFLABEL (label_27)
  (Wrd13.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_45_26);

DEFLABEL (label_71)
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_70;
  Wrd5 = Wrd9;

DEFLABEL (label_69)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_45_4]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_22]));

DEFLABEL (label_70)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_32])), (Wrd6.pObj));

DEFLABEL (label_36)
  (Wrd5.Obj) = Rvl;
  goto label_69;

DEFLABEL (loop_45)
DEFLABEL (loop_21)
  INTERRUPT_CHECK (26, LABEL_45_28);
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if ((Wrd13.Lng) < (Wrd15.Lng))
    goto label_72;
  Rsp = (& (Rsp [3]));
  goto label_71;

DEFLABEL (label_72)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_29]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_5]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_85;
  Wrd20 = Wrd24;

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_31]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_45_29);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_81;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_35]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_80;
  Wrd13 = Wrd17;

DEFLABEL (label_79)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_34]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_45_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_45_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_78;
  Wrd9 = Wrd13;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_22]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_45_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd24.Obj) = (Rsp [5]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 30))
    goto label_76;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_76;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [1]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) (Wrd19.Lng)) < ((unsigned long) (Wrd23.Lng))))
    goto label_76;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd16.Obj));
  (Wrd13.pChr) = (& ((Wrd21.pChr) [(Wrd10.Lng)]));
  (Wrd14.uLng) = ((unsigned long) (((unsigned char *) (Wrd13.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd15.Obj) = (MAKE_OBJECT (2, (Wrd14.uLng)));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_75)
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_74;
  Wrd31 = Wrd35;

DEFLABEL (label_73)
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_22]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_45_39);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_21;

DEFLABEL (label_74)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_41])), (Wrd32.pObj));

DEFLABEL (label_42)
  (Wrd31.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd26.Obj) = (Rsp [5]);
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_40]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_3]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_38])), (Wrd10.pObj));

DEFLABEL (label_40)
  (Wrd9.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_36])), (Wrd14.pObj));

DEFLABEL (label_38)
  (Wrd13.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_81)
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_83;
  Wrd19 = Wrd23;

DEFLABEL (label_82)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_34]));

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_33])), (Wrd20.pObj));

DEFLABEL (label_39)
  (Wrd19.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_30])), (Wrd21.pObj));

DEFLABEL (label_37)
  (Wrd20.Obj) = Rvl;
  goto label_84;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_9 7
#define LABEL_46_8 9
#define LABEL_46_11 11
#define LABEL_46_6 13
#define LABEL_46_15 15
#define LABEL_46_16 17
#define LABEL_46_12 19
#define LABEL_46_14 21
#define LABEL_46_18 23
#define LABEL_46_19 25
#define ENVIRONMENT_LABEL_46_3 41
#define DEBUGGING_LABEL_46_2 40
#define OBJECT_46_1 39
#define OBJECT_46_0 38
#define EXECUTE_CACHE_46_17 27
#define EXECUTE_CACHE_46_13 29
#define EXECUTE_CACHE_46_10 31
#define EXECUTE_CACHE_46_7 33
#define FREE_REFERENCE_46_1 36
#define FREE_REFERENCE_46_0 37
#define FREE_REFERENCES_LABEL_46_0 26
#define NUMBER_OF_LINKER_SECTIONS_46_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto unparse_character_5;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_46_9);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_46_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_46_11);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_46_6);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_46_15);
      goto label_11;

    case 7:
      current_block = (Rpc - LABEL_46_16);
      goto label_10;

    case 8:
      current_block = (Rpc - LABEL_46_12);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_46_14);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_46_18);
      goto label_12;

    case 11:
      current_block = (Rpc - LABEL_46_19);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_character_14)
DEFLABEL (unparse_character_5)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_28;
  Wrd5 = Wrd9;

DEFLABEL (label_27)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_46_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_16;
  Wrd7 = Wrd11;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_17]));

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_16])), (Wrd8.pObj));

DEFLABEL (label_10)
  (Wrd7.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_17)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_14]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_21;
  Wrd17 = Wrd21;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_46_14);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_19;
  Wrd5 = Wrd9;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_46_1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_46_19);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_10]));

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_18])), (Wrd6.pObj));

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_15])), (Wrd18.pObj));

DEFLABEL (label_11)
  (Wrd17.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_22)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_26;
  Wrd16 = Wrd20;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_46_8);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_24;
  Wrd5 = Wrd9;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_46_1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_13]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_46_12);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_10]));

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_11])), (Wrd6.pObj));

DEFLABEL (label_9)
  (Wrd5.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_9])), (Wrd17.pObj));

DEFLABEL (label_8)
  (Wrd16.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_5])), (Wrd6.pObj));

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_5 3
#define LABEL_47_4 5
#define LABEL_47_6 7
#define LABEL_47_7 9
#define LABEL_47_9 11
#define LABEL_47_10 13
#define LABEL_47_12 15
#define LABEL_47_14 17
#define LABEL_47_11 19
#define LABEL_47_17 21
#define LABEL_47_16 23
#define LABEL_47_20 25
#define LABEL_47_22 27
#define LABEL_47_19 29
#define LABEL_47_23 31
#define LABEL_47_24 33
#define LABEL_47_25 35
#define LABEL_47_26 37
#define LABEL_47_28 39
#define LABEL_47_27 41
#define LABEL_47_29 43
#define LABEL_47_31 45
#define LABEL_47_30 47
#define LABEL_47_33 49
#define LABEL_47_32 51
#define LABEL_47_35 53
#define LABEL_47_36 55
#define LABEL_47_37 57
#define LABEL_47_38 59
#define LABEL_47_39 61
#define LABEL_47_40 63
#define LABEL_47_41 65
#define LABEL_47_42 67
#define LABEL_47_43 69
#define LABEL_47_44 71
#define LABEL_47_45 73
#define LABEL_47_34 75
#define LABEL_47_48 77
#define LABEL_47_46 79
#define ENVIRONMENT_LABEL_47_3 119
#define DEBUGGING_LABEL_47_2 118
#define OBJECT_47_19 117
#define OBJECT_47_18 116
#define OBJECT_47_17 115
#define OBJECT_47_16 114
#define OBJECT_47_15 113
#define OBJECT_47_14 112
#define OBJECT_47_13 111
#define OBJECT_47_12 110
#define OBJECT_47_11 109
#define OBJECT_47_10 108
#define OBJECT_47_9 107
#define OBJECT_47_8 106
#define OBJECT_47_7 105
#define OBJECT_47_6 104
#define OBJECT_47_5 103
#define OBJECT_47_4 102
#define OBJECT_47_3 101
#define OBJECT_47_2 100
#define OBJECT_47_1 99
#define OBJECT_47_0 98
#define EXECUTE_CACHE_47_47 81
#define EXECUTE_CACHE_47_21 83
#define EXECUTE_CACHE_47_18 85
#define EXECUTE_CACHE_47_15 87
#define EXECUTE_CACHE_47_13 89
#define EXECUTE_CACHE_47_8 91
#define FREE_REFERENCE_47_3 94
#define FREE_REFERENCE_47_2 95
#define FREE_REFERENCE_47_1 96
#define FREE_REFERENCE_47_0 97
#define FREE_REFERENCES_LABEL_47_0 80
#define NUMBER_OF_LINKER_SECTIONS_47_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd58;
  machine_word Wrd49;
  machine_word Wrd54;
  machine_word Wrd59;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd65;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd84;
  machine_word Wrd78;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd91;
  machine_word Wrd85;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd86;
  machine_word Wrd98;
  machine_word Wrd92;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd105;
  machine_word Wrd99;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd100;
  machine_word Wrd112;
  machine_word Wrd106;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd107;
  machine_word Wrd119;
  machine_word Wrd113;
  machine_word Wrd118;
  machine_word Wrd117;
  machine_word Wrd114;
  machine_word Wrd23;
  machine_word Wrd11;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd28;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd37;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd46;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd52;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_47_4);
      goto unparse_string_30;

    case 2:
      current_block = (Rpc - LABEL_47_6);
      goto label_32;

    case 3:
      current_block = (Rpc - LABEL_47_7);
      goto label_37;

    case 4:
      current_block = (Rpc - LABEL_47_9);
      goto label_33;

    case 5:
      current_block = (Rpc - LABEL_47_10);
      goto label_34;

    case 6:
      current_block = (Rpc - LABEL_47_12);
      goto label_36;

    case 7:
      current_block = (Rpc - LABEL_47_14);
      goto label_35;

    case 8:
      current_block = (Rpc - LABEL_47_11);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_47_17);
      goto label_38;

    case 10:
      current_block = (Rpc - LABEL_47_16);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_47_20);
      goto label_39;

    case 12:
      current_block = (Rpc - LABEL_47_22);
      goto continuation_27;

    case 13:
      current_block = (Rpc - LABEL_47_19);
      goto continuation_4;

    case 14:
      current_block = (Rpc - LABEL_47_23);
      goto label_40;

    case 15:
      current_block = (Rpc - LABEL_47_24);
      goto label_41;

    case 16:
      current_block = (Rpc - LABEL_47_25);
      goto label_42;

    case 17:
      current_block = (Rpc - LABEL_47_26);
      goto loop_24;

    case 18:
      current_block = (Rpc - LABEL_47_28);
      goto label_43;

    case 19:
      current_block = (Rpc - LABEL_47_27);
      goto continuation_6;

    case 20:
      current_block = (Rpc - LABEL_47_29);
      goto label_45;

    case 21:
      current_block = (Rpc - LABEL_47_31);
      goto label_44;

    case 22:
      current_block = (Rpc - LABEL_47_30);
      goto continuation_7;

    case 23:
      current_block = (Rpc - LABEL_47_33);
      goto label_46;

    case 24:
      current_block = (Rpc - LABEL_47_32);
      goto continuation_8;

    case 25:
      current_block = (Rpc - LABEL_47_35);
      goto label_47;

    case 26:
      current_block = (Rpc - LABEL_47_36);
      goto label_57;

    case 27:
      current_block = (Rpc - LABEL_47_37);
      goto label_56;

    case 28:
      current_block = (Rpc - LABEL_47_38);
      goto label_55;

    case 29:
      current_block = (Rpc - LABEL_47_39);
      goto label_54;

    case 30:
      current_block = (Rpc - LABEL_47_40);
      goto label_53;

    case 31:
      current_block = (Rpc - LABEL_47_41);
      goto label_52;

    case 32:
      current_block = (Rpc - LABEL_47_42);
      goto label_51;

    case 33:
      current_block = (Rpc - LABEL_47_43);
      goto label_50;

    case 34:
      current_block = (Rpc - LABEL_47_44);
      goto label_49;

    case 35:
      current_block = (Rpc - LABEL_47_45);
      goto label_48;

    case 36:
      current_block = (Rpc - LABEL_47_34);
      goto continuation_10;

    case 37:
      current_block = (Rpc - LABEL_47_48);
      goto label_58;

    case 38:
      current_block = (Rpc - LABEL_47_46);
      goto continuation_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_string_60)
DEFLABEL (unparse_string_30)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_88;
  Wrd5 = Wrd9;

DEFLABEL (label_87)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_84;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 30))
    goto label_83;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (Wrd16.Obj) = (MAKE_OBJECT (26, (Wrd15.uLng)));
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_82)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_2]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_81;
  Wrd26 = Wrd30;

DEFLABEL (label_80)
  if ((Wrd26.Obj) == ((SCHEME_OBJECT) 0))
    goto label_79;
  (Wrd33.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd35.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_2]));
  (Wrd38.Obj) = ((Wrd35.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_78;
  Wrd34 = Wrd38;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_15]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_76)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_11]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_47_1]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd47.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd50.Obj) = ((Wrd47.pObj) [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 50)
    goto label_75;
  Wrd46 = Wrd50;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_47_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_73;
  Wrd8 = Wrd12;

DEFLABEL (label_72)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_47_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto loop_24;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_47_19);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_68;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_68;
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd35.Lng) < (Wrd37.Lng))
    goto label_65;

DEFLABEL (label_64)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_63;
  Wrd16 = Wrd20;

DEFLABEL (label_62)
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_47_1]);
  (Rsp [2]) = (Wrd22.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_24])), (Wrd17.pObj));

DEFLABEL (label_41)
  (Wrd16.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_22]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_47_3]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_67;
  Wrd28 = Wrd32;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_47_22);
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_25])), (Wrd29.pObj));

DEFLABEL (label_42)
  (Wrd28.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_68)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_23]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_40)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  goto label_65;

DEFLABEL (label_69)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_71;
  Wrd17 = Wrd21;

DEFLABEL (label_70)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_21]));

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_20])), (Wrd18.pObj));

DEFLABEL (label_39)
  (Wrd17.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_17])), (Wrd9.pObj));

DEFLABEL (label_38)
  (Wrd8.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_12])), (Wrd47.pObj));

DEFLABEL (label_36)
  (Wrd46.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_14])), (Wrd35.pObj));

DEFLABEL (label_35)
  (Wrd34.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_79)
  (Wrd41.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd41.Obj);
  goto label_76;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_10])), (Wrd27.pObj));

DEFLABEL (label_34)
  (Wrd26.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_0]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (label_84)
  (Wrd53.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd56.Obj) = ((Wrd53.pObj) [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if ((Wrd57.uLng) == 50)
    goto label_86;
  Wrd52 = Wrd56;

DEFLABEL (label_85)
  (* (--Rsp)) = (Wrd52.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (label_86)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_7])), (Wrd53.pObj));

DEFLABEL (label_37)
  (Wrd52.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_6])), (Wrd6.pObj));

DEFLABEL (label_32)
  (Wrd5.Obj) = Rvl;
  goto label_87;

DEFLABEL (loop_61)
DEFLABEL (loop_24)
  INTERRUPT_CHECK (26, LABEL_47_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_128;
  Wrd8 = Wrd12;

DEFLABEL (label_127)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_18]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_47_27);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_124;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_30]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_123;
  Wrd13 = Wrd17;

DEFLABEL (label_122)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_47_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_121;
  Wrd9 = Wrd13;

DEFLABEL (label_120)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_47_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd24.Obj) = (Rsp [6]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 30))
    goto label_119;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_119;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [1]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) (Wrd19.Lng)) < ((unsigned long) (Wrd23.Lng))))
    goto label_119;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd16.Obj));
  (Wrd13.pChr) = (& ((Wrd21.pChr) [(Wrd10.Lng)]));
  (Wrd14.uLng) = ((unsigned long) (((unsigned char *) (Wrd13.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd15.Obj) = (MAKE_OBJECT (2, (Wrd14.uLng)));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_118)
  (Wrd31.Obj) = (Rsp [0]);
  if ((Wrd31.Obj) == (current_block [OBJECT_47_6]))
    goto label_115;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_8]))
    goto label_112;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_10]))
    goto label_109;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_12]))
    goto label_106;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_14]))
    goto label_103;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_16]))
    goto label_100;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_18]))
    goto label_97;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_4]))
    goto label_94;
  if ((Wrd31.Obj) == (current_block [OBJECT_47_1]))
    goto label_91;
  (Wrd50.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd53.Obj) = ((Wrd50.pObj) [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd54.uLng) == 50)
    goto label_90;
  Wrd49 = Wrd53;

DEFLABEL (label_89)
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_46]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd58.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_47]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_47_46);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (label_90)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_45])), (Wrd50.pObj));

DEFLABEL (label_48)
  (Wrd49.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_91)
  (Wrd60.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd63.Obj) = ((Wrd60.pObj) [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 50)
    goto label_93;
  Wrd59 = Wrd63;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_44])), (Wrd60.pObj));

DEFLABEL (label_49)
  (Wrd59.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_94)
  (Wrd66.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd69.Obj) = ((Wrd66.pObj) [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if ((Wrd70.uLng) == 50)
    goto label_96;
  Wrd65 = Wrd69;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd65.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_96)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_43])), (Wrd66.pObj));

DEFLABEL (label_50)
  (Wrd65.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_97)
  (Wrd72.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd75.Obj) = ((Wrd72.pObj) [0]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if ((Wrd76.uLng) == 50)
    goto label_99;
  Wrd71 = Wrd75;

DEFLABEL (label_98)
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd77.Obj) = (current_block [OBJECT_47_19]);
  (Rsp [1]) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_99)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_42])), (Wrd72.pObj));

DEFLABEL (label_51)
  (Wrd71.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_100)
  (Wrd79.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd82.Obj) = ((Wrd79.pObj) [0]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if ((Wrd83.uLng) == 50)
    goto label_102;
  Wrd78 = Wrd82;

DEFLABEL (label_101)
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd84.Obj) = (current_block [OBJECT_47_17]);
  (Rsp [1]) = (Wrd84.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_102)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_41])), (Wrd79.pObj));

DEFLABEL (label_52)
  (Wrd78.Obj) = Rvl;
  goto label_101;

DEFLABEL (label_103)
  (Wrd86.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd89.Obj) = ((Wrd86.pObj) [0]);
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if ((Wrd90.uLng) == 50)
    goto label_105;
  Wrd85 = Wrd89;

DEFLABEL (label_104)
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd91.Obj) = (current_block [OBJECT_47_15]);
  (Rsp [1]) = (Wrd91.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_105)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_40])), (Wrd86.pObj));

DEFLABEL (label_53)
  (Wrd85.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_106)
  (Wrd93.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd96.Obj) = ((Wrd93.pObj) [0]);
  (Wrd97.uLng) = (OBJECT_TYPE (Wrd96.Obj));
  if ((Wrd97.uLng) == 50)
    goto label_108;
  Wrd92 = Wrd96;

DEFLABEL (label_107)
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd98.Obj) = (current_block [OBJECT_47_13]);
  (Rsp [1]) = (Wrd98.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_108)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_39])), (Wrd93.pObj));

DEFLABEL (label_54)
  (Wrd92.Obj) = Rvl;
  goto label_107;

DEFLABEL (label_109)
  (Wrd100.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd103.Obj) = ((Wrd100.pObj) [0]);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if ((Wrd104.uLng) == 50)
    goto label_111;
  Wrd99 = Wrd103;

DEFLABEL (label_110)
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd105.Obj) = (current_block [OBJECT_47_11]);
  (Rsp [1]) = (Wrd105.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_111)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_38])), (Wrd100.pObj));

DEFLABEL (label_55)
  (Wrd99.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_112)
  (Wrd107.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd110.Obj) = ((Wrd107.pObj) [0]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if ((Wrd111.uLng) == 50)
    goto label_114;
  Wrd106 = Wrd110;

DEFLABEL (label_113)
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd112.Obj) = (current_block [OBJECT_47_9]);
  (Rsp [1]) = (Wrd112.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_114)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_37])), (Wrd107.pObj));

DEFLABEL (label_56)
  (Wrd106.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_115)
  (Wrd114.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd117.Obj) = ((Wrd114.pObj) [0]);
  (Wrd118.uLng) = (OBJECT_TYPE (Wrd117.Obj));
  if ((Wrd118.uLng) == 50)
    goto label_117;
  Wrd113 = Wrd117;

DEFLABEL (label_116)
  (* (--Rsp)) = (Wrd113.Obj);
  (Wrd119.Obj) = (current_block [OBJECT_47_7]);
  (Rsp [1]) = (Wrd119.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_117)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_36])), (Wrd114.pObj));

DEFLABEL (label_57)
  (Wrd113.Obj) = Rvl;
  goto label_116;

DEFLABEL (label_119)
  (Wrd26.Obj) = (Rsp [6]);
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_35]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_5]), 2);

DEFLABEL (label_47)
  (* (--Rsp)) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_33])), (Wrd10.pObj));

DEFLABEL (label_46)
  (Wrd9.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_31])), (Wrd14.pObj));

DEFLABEL (label_44)
  (Wrd13.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_124)
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_126;
  Wrd20 = Wrd24;

DEFLABEL (label_125)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  (Rsp [3]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_21]));

DEFLABEL (label_126)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_29])), (Wrd21.pObj));

DEFLABEL (label_45)
  (Wrd20.Obj) = Rvl;
  goto label_125;

DEFLABEL (label_128)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_28])), (Wrd9.pObj));

DEFLABEL (label_43)
  (Wrd8.Obj) = Rvl;
  goto label_127;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_47_34);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 26))
    goto label_130;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd14.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_130;
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_129)
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_24;

DEFLABEL (label_130)
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_48]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_58)
  (Wrd9.Obj) = Rvl;
  goto label_129;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define LABEL_48_6 7
#define LABEL_48_8 9
#define LABEL_48_9 11
#define LABEL_48_12 13
#define LABEL_48_13 15
#define LABEL_48_14 17
#define LABEL_48_15 19
#define LABEL_48_18 21
#define LABEL_48_19 23
#define ENVIRONMENT_LABEL_48_3 39
#define DEBUGGING_LABEL_48_2 38
#define OBJECT_48_0 37
#define EXECUTE_CACHE_48_20 25
#define EXECUTE_CACHE_48_17 27
#define EXECUTE_CACHE_48_16 29
#define EXECUTE_CACHE_48_11 31
#define EXECUTE_CACHE_48_10 33
#define EXECUTE_CACHE_48_7 35
#define FREE_REFERENCES_LABEL_48_0 24
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto char__octal_12;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_48_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_48_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_48_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_48_12);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_48_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_48_14);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_48_15);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_48_18);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_48_19);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (char__octal_15)
DEFLABEL (char__octal_12)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_48_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_48_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_48_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_48_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_13]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_48_13);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_48_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_48_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_17]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_48_14);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_18]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_19]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_48_19);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_17]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_48_18);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_20]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_6 5
#define LABEL_49_5 7
#define LABEL_49_8 9
#define LABEL_49_9 11
#define LABEL_49_10 13
#define LABEL_49_11 15
#define LABEL_49_12 17
#define ENVIRONMENT_LABEL_49_3 32
#define DEBUGGING_LABEL_49_2 31
#define OBJECT_49_5 30
#define OBJECT_49_4 29
#define OBJECT_49_3 28
#define OBJECT_49_2 27
#define OBJECT_49_1 26
#define OBJECT_49_0 25
#define EXECUTE_CACHE_49_13 19
#define EXECUTE_CACHE_49_7 21
#define FREE_REFERENCE_49_0 24
#define FREE_REFERENCES_LABEL_49_0 18
#define NUMBER_OF_LINKER_SECTIONS_49_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto unparse_bit_string_11;

    case 1:
      current_block = (Rpc - LABEL_49_6);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_49_8);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_49_9);
      goto loop_9;

    case 5:
      current_block = (Rpc - LABEL_49_10);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_49_11);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_49_12);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_bit_string_17)
DEFLABEL (unparse_bit_string_11)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_22;
  Wrd9 = Wrd13;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 47))
    goto label_20;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (Wrd5.Obj) = (MAKE_OBJECT (26, (Wrd9.uLng)));

DEFLABEL (label_19)
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd17.Lng) = ((Wrd16.Lng) - 1L);
  (Wrd18.Obj) = (LONG_TO_FIXNUM (Wrd17.Lng));
  (* (--Rsp)) = (Wrd18.Obj);
  goto loop_9;

DEFLABEL (label_20)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 1);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_49_6])), (Wrd10.pObj));

DEFLABEL (label_13)
  (Wrd9.Obj) = Rvl;
  goto label_21;

DEFLABEL (loop_18)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_49_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if (! ((Wrd6.Lng) < 0))
    goto label_23;
  Rvl = (current_block [OBJECT_49_2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_3]), 2);

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_49_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd7.Obj) = (current_block [OBJECT_49_5]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto label_24;

DEFLABEL (label_25)
  (Wrd14.Obj) = (current_block [OBJECT_49_4]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_24)
DEFLABEL (label_28)
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_27;
  Wrd8 = Wrd12;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_49_10);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) - 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [0]) = (Wrd5.Obj);
  goto loop_9;

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_49_12])), (Wrd9.pObj));

DEFLABEL (label_15)
  (Wrd8.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define LABEL_50_9 7
#define LABEL_50_10 9
#define LABEL_50_11 11
#define LABEL_50_12 13
#define LABEL_50_8 15
#define ENVIRONMENT_LABEL_50_3 29
#define DEBUGGING_LABEL_50_2 28
#define EXECUTE_CACHE_50_13 17
#define EXECUTE_CACHE_50_7 19
#define EXECUTE_CACHE_50_6 21
#define FREE_REFERENCE_50_3 24
#define FREE_REFERENCE_50_2 25
#define FREE_REFERENCE_50_1 26
#define FREE_REFERENCE_50_0 27
#define FREE_REFERENCES_LABEL_50_0 16
#define NUMBER_OF_LINKER_SECTIONS_50_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto unparse_vector_3;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_50_9);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_50_10);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_50_11);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_50_12);
      goto label_8;

    case 6:
      current_block = (Rpc - LABEL_50_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_vector_10)
DEFLABEL (unparse_vector_3)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_50_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_7]));

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_19;
  Wrd11 = Wrd15;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_17;
  Wrd17 = Wrd21;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50_2]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_15;
  Wrd23 = Wrd27;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50_3]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_13;
  Wrd29 = Wrd33;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_50_8);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50_12])), (Wrd30.pObj));

DEFLABEL (label_8)
  (Wrd29.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50_11])), (Wrd24.pObj));

DEFLABEL (label_7)
  (Wrd23.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50_10])), (Wrd18.pObj));

DEFLABEL (label_6)
  (Wrd17.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50_9])), (Wrd12.pObj));

DEFLABEL (label_5)
  (Wrd11.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define LABEL_51_6 7
#define LABEL_51_8 9
#define ENVIRONMENT_LABEL_51_3 21
#define DEBUGGING_LABEL_51_2 20
#define OBJECT_51_2 19
#define OBJECT_51_1 18
#define OBJECT_51_0 17
#define EXECUTE_CACHE_51_10 11
#define EXECUTE_CACHE_51_9 13
#define EXECUTE_CACHE_51_7 15
#define FREE_REFERENCES_LABEL_51_0 10
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto unparse_vector_unparser_6;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_51_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_51_8);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_vector_unparser_10)
DEFLABEL (unparse_vector_unparser_6)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 10))
    goto label_14;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (Wrd5.Obj) = (MAKE_OBJECT (26, (Wrd9.uLng)));

DEFLABEL (label_13)
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd16.Lng) > 0)
    goto label_11;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_51_1]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_51_6);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_51_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_51_8);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_10]));

DEFLABEL (label_14)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_0]), 1);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define TAG_52_6 1
#define LABEL_52_8 7
#define LABEL_52_10 9
#define LABEL_52_12 11
#define LABEL_52_9 13
#define LABEL_52_13 15
#define LABEL_52_14 17
#define LABEL_52_17 19
#define LABEL_52_18 21
#define LABEL_52_20 23
#define LABEL_52_22 25
#define LABEL_52_23 27
#define LABEL_52_24 29
#define LABEL_52_25 31
#define LABEL_52_27 33
#define LABEL_52_26 35
#define LABEL_52_21 37
#define LABEL_52_28 39
#define LABEL_52_29 41
#define LABEL_52_30 43
#define LABEL_52_31 45
#define ENVIRONMENT_LABEL_52_3 69
#define DEBUGGING_LABEL_52_2 68
#define OBJECT_52_7 67
#define OBJECT_52_6 66
#define OBJECT_52_5 65
#define OBJECT_52_4 64
#define OBJECT_52_3 63
#define OBJECT_52_2 62
#define OBJECT_52_1 61
#define OBJECT_52_0 60
#define EXECUTE_CACHE_52_19 47
#define EXECUTE_CACHE_52_16 49
#define EXECUTE_CACHE_52_15 51
#define EXECUTE_CACHE_52_11 53
#define EXECUTE_CACHE_52_7 55
#define FREE_REFERENCE_52_1 58
#define FREE_REFERENCE_52_0 59
#define FREE_REFERENCES_LABEL_52_0 46
#define NUMBER_OF_LINKER_SECTIONS_52_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd56;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd69;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd5;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd36;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto unparse_vector_normal_20;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto lambda_34;

    case 2:
      current_block = (Rpc - LABEL_52_8);
      goto label_22;

    case 3:
      current_block = (Rpc - LABEL_52_10);
      goto label_24;

    case 4:
      current_block = (Rpc - LABEL_52_12);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_52_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_52_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_52_14);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_52_17);
      goto loop_16;

    case 9:
      current_block = (Rpc - LABEL_52_18);
      goto label_31;

    case 10:
      current_block = (Rpc - LABEL_52_20);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_52_22);
      goto label_30;

    case 12:
      current_block = (Rpc - LABEL_52_23);
      goto label_26;

    case 13:
      current_block = (Rpc - LABEL_52_24);
      goto label_27;

    case 14:
      current_block = (Rpc - LABEL_52_25);
      goto label_28;

    case 15:
      current_block = (Rpc - LABEL_52_27);
      goto label_29;

    case 16:
      current_block = (Rpc - LABEL_52_26);
      goto continuation_12;

    case 17:
      current_block = (Rpc - LABEL_52_21);
      goto continuation_7;

    case 18:
      current_block = (Rpc - LABEL_52_28);
      goto continuation_14;

    case 19:
      current_block = (Rpc - LABEL_52_29);
      goto continuation_13;

    case 20:
      current_block = (Rpc - LABEL_52_30);
      goto continuation_9;

    case 21:
      current_block = (Rpc - LABEL_52_31);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_vector_normal_33)
DEFLABEL (unparse_vector_normal_20)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_52_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_52_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_7]));

DEFLABEL (lambda_34)
  CLOSURE_HEADER (LABEL_52_5);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_42;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (Wrd11.Obj) = (MAKE_OBJECT (26, (Wrd10.uLng)));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_41)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if ((Wrd23.Lng) > 0)
    goto label_38;
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_37;
  Wrd25 = Wrd29;

DEFLABEL (label_36)
  (Rsp [0]) = (Wrd25.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_52_2]);
  (Rsp [1]) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_11]));

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_12])), (Wrd26.pObj));

DEFLABEL (label_23)
  (Wrd25.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_9]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_52_1]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd37.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd40.Obj) = ((Wrd37.pObj) [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 50)
    goto label_40;
  Wrd36 = Wrd40;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_52_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_52_3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_52_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_16]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_52_13);
  (Wrd5.Obj) = (current_block [OBJECT_52_4]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_16;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_10])), (Wrd37.pObj));

DEFLABEL (label_24)
  (Wrd36.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_8]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_0]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (loop_35)
DEFLABEL (loop_16)
  INTERRUPT_CHECK (26, LABEL_52_17);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_57;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_1]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_56;
  Wrd7 = Wrd11;

DEFLABEL (label_55)
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_52;
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_51;
  Wrd15 = Wrd19;

DEFLABEL (label_50)
  Wrd14 = Wrd15;
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_49;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_49;
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if ((Wrd50.Lng) < (Wrd51.Lng))
    goto label_46;

DEFLABEL (label_45)
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_44;
  Wrd31 = Wrd35;

DEFLABEL (label_43)
  (Rsp [1]) = (Wrd31.Obj);
  (Wrd37.Obj) = (current_block [OBJECT_52_7]);
  (Rsp [2]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_11]));

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_25])), (Wrd32.pObj));

DEFLABEL (label_28)
  (Wrd31.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_26]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (current_block [OBJECT_52_6]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd44.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd47.Obj) = ((Wrd44.pObj) [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if ((Wrd48.uLng) == 50)
    goto label_48;
  Wrd43 = Wrd47;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd43.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_19]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_52_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_29]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_15]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_52_29);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_16]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_52_28);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [0]) = (Wrd5.Obj);
  goto loop_16;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_27])), (Wrd44.pObj));

DEFLABEL (label_29)
  (Wrd43.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_24]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  goto label_46;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_23])), (Wrd16.pObj));

DEFLABEL (label_26)
  (Wrd15.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_52)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_21]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_52_6]);
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd57.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd60.Obj) = ((Wrd57.pObj) [0]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if ((Wrd61.uLng) == 50)
    goto label_54;
  Wrd56 = Wrd60;

DEFLABEL (label_53)
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_52_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_52_31);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_52_30);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [0]) = (Wrd5.Obj);
  goto loop_16;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_22])), (Wrd57.pObj));

DEFLABEL (label_30)
  (Wrd56.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_20])), (Wrd8.pObj));

DEFLABEL (label_25)
  (Wrd7.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_59;
  Wrd63 = Wrd67;

DEFLABEL (label_58)
  (Rsp [1]) = (Wrd63.Obj);
  (Wrd69.Obj) = (current_block [OBJECT_52_5]);
  (Rsp [2]) = (Wrd69.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_19]));

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_18])), (Wrd64.pObj));

DEFLABEL (label_31)
  (Wrd63.Obj) = Rvl;
  goto label_58;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_9 5
#define LABEL_53_5 7
#define LABEL_53_6 9
#define TAG_53_7 3
#define LABEL_53_14 11
#define LABEL_53_10 13
#define TAG_53_11 5
#define ENVIRONMENT_LABEL_53_3 27
#define DEBUGGING_LABEL_53_2 26
#define OBJECT_53_4 25
#define OBJECT_53_3 24
#define OBJECT_53_2 23
#define OBJECT_53_1 22
#define OBJECT_53_0 21
#define EXECUTE_CACHE_53_13 15
#define EXECUTE_CACHE_53_12 17
#define EXECUTE_CACHE_53_8 19
#define FREE_REFERENCES_LABEL_53_0 14
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd6;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto safe_vector_ref_5;

    case 1:
      current_block = (Rpc - LABEL_53_9);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_53_6);
      goto lambda_10;

    case 4:
      current_block = (Rpc - LABEL_53_14);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_53_10);
      goto lambda_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safe_vector_ref_9)
DEFLABEL (safe_vector_ref_5)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_53_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_53_6])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_53_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;

DEFLABEL (label_12)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_53_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_53_10])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  (Wrd17.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [0]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Rsp [1]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_12]));

DEFLABEL (label_13)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_53_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_53_9);
  goto label_12;

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_53_6);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_53_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [3]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_19;
  (Wrd18.Obj) = ((Wrd31.pObj) [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_19;
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd23.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_19;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  (Wrd15.pObj) = (& ((Wrd27.pObj) [(Wrd10.Lng)]));
  (Wrd6.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_18)
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_53_1]);
  (Wrd53.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 39L) < ((unsigned long) (Wrd53.Lng)))
    goto label_14;
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_4]), 2);

DEFLABEL (label_14)
  (Wrd45.uLng) = (OBJECT_DATUM (Wrd50.Obj));
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd45.Obj) == (Wrd47.Obj))
    goto label_16;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_15;

DEFLABEL (label_16)
  Rvl = (current_block [OBJECT_53_3]);

DEFLABEL (label_15)
DEFLABEL (label_17)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [3]);
  (Wrd37.Obj) = ((Wrd36.pObj) [2]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_14]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_7)
  (Wrd6.Obj) = Rvl;
  goto label_18;

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_53_10);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd27.uLng) == 10)
    goto label_21;

DEFLABEL (label_20)
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_21)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_20;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_20;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd8.Obj));
  (Wrd16.pObj) = (& ((Wrd23.pObj) [(Wrd13.Lng)]));
  Rvl = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_7 7
#define LABEL_54_8 9
#define LABEL_54_9 11
#define LABEL_54_10 13
#define LABEL_54_6 15
#define ENVIRONMENT_LABEL_54_3 30
#define DEBUGGING_LABEL_54_2 29
#define EXECUTE_CACHE_54_13 17
#define EXECUTE_CACHE_54_12 19
#define EXECUTE_CACHE_54_11 21
#define FREE_REFERENCE_54_4 24
#define FREE_REFERENCE_54_3 25
#define FREE_REFERENCE_54_2 26
#define FREE_REFERENCE_54_1 27
#define FREE_REFERENCE_54_0 28
#define FREE_REFERENCES_LABEL_54_0 16
#define NUMBER_OF_LINKER_SECTIONS_54_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto unparse_record_1;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_54_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_54_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_54_9);
      goto label_6;

    case 5:
      current_block = (Rpc - LABEL_54_10);
      goto label_7;

    case 6:
      current_block = (Rpc - LABEL_54_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_record_9)
DEFLABEL (unparse_record_1)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_20;
  Wrd5 = Wrd9;

DEFLABEL (label_19)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_10;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_12]));

DEFLABEL (label_10)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_18;
  Wrd15 = Wrd19;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_16;
  Wrd21 = Wrd25;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_3]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_14;
  Wrd27 = Wrd31;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_4]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_12;
  Wrd33 = Wrd37;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_11]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_54_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_13]));

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_10])), (Wrd34.pObj));

DEFLABEL (label_7)
  (Wrd33.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_9])), (Wrd28.pObj));

DEFLABEL (label_6)
  (Wrd27.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_8])), (Wrd22.pObj));

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_7])), (Wrd16.pObj));

DEFLABEL (label_4)
  (Wrd15.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_5])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define LABEL_55_7 7
#define LABEL_55_12 9
#define LABEL_55_13 11
#define LABEL_55_14 13
#define LABEL_55_15 15
#define LABEL_55_11 17
#define ENVIRONMENT_LABEL_55_3 35
#define DEBUGGING_LABEL_55_2 34
#define EXECUTE_CACHE_55_16 19
#define EXECUTE_CACHE_55_10 21
#define EXECUTE_CACHE_55_9 23
#define EXECUTE_CACHE_55_8 25
#define EXECUTE_CACHE_55_6 27
#define FREE_REFERENCE_55_3 30
#define FREE_REFERENCE_55_2 31
#define FREE_REFERENCE_55_1 32
#define FREE_REFERENCE_55_0 33
#define FREE_REFERENCES_LABEL_55_0 18
#define NUMBER_OF_LINKER_SECTIONS_55_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto unparse_pair_7;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_55_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_55_12);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_55_13);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_55_14);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_55_15);
      goto label_12;

    case 7:
      current_block = (Rpc - LABEL_55_11);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_pair_14)
DEFLABEL (unparse_pair_7)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_9]));

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_55_7);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_10]));

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_11]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_24;
  Wrd12 = Wrd16;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_1]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_22;
  Wrd18 = Wrd22;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_2]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_20;
  Wrd24 = Wrd28;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_3]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_18;
  Wrd30 = Wrd34;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_55_11);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_15])), (Wrd31.pObj));

DEFLABEL (label_12)
  (Wrd30.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_14])), (Wrd25.pObj));

DEFLABEL (label_11)
  (Wrd24.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_13])), (Wrd19.pObj));

DEFLABEL (label_10)
  (Wrd18.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_12])), (Wrd13.pObj));

DEFLABEL (label_9)
  (Wrd12.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define TAG_56_6 1
#define LABEL_56_9 7
#define LABEL_56_8 9
#define LABEL_56_11 11
#define LABEL_56_12 13
#define LABEL_56_14 15
#define LABEL_56_18 17
#define LABEL_56_15 19
#define ENVIRONMENT_LABEL_56_3 39
#define DEBUGGING_LABEL_56_2 38
#define OBJECT_56_2 37
#define OBJECT_56_1 36
#define OBJECT_56_0 35
#define EXECUTE_CACHE_56_19 21
#define EXECUTE_CACHE_56_17 23
#define EXECUTE_CACHE_56_16 25
#define EXECUTE_CACHE_56_13 27
#define EXECUTE_CACHE_56_10 29
#define EXECUTE_CACHE_56_7 31
#define FREE_REFERENCE_56_0 34
#define FREE_REFERENCES_LABEL_56_0 20
#define NUMBER_OF_LINKER_SECTIONS_56_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto unparse_list_6;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto lambda_12;

    case 2:
      current_block = (Rpc - LABEL_56_9);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_56_8);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_56_11);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_56_12);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_56_14);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_56_18);
      goto label_9;

    case 8:
      current_block = (Rpc - LABEL_56_15);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_list_11)
DEFLABEL (unparse_list_6)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_56_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_56_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_56_5);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_56_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_56_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_16;
  Wrd9 = Wrd13;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_56_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_56_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_56_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_56_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_56_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_19]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_56_14);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_56_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_14;
  Wrd5 = Wrd9;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_56_2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_10]));

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56_18])), (Wrd6.pObj));

DEFLABEL (label_9)
  (Wrd5.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56_9])), (Wrd10.pObj));

DEFLABEL (label_8)
  (Wrd9.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_5 5
#define LABEL_57_6 7
#define LABEL_57_7 9
#define LABEL_57_8 11
#define TAG_57_9 4
#define LABEL_57_15 13
#define LABEL_57_16 15
#define LABEL_57_10 17
#define TAG_57_11 7
#define LABEL_57_17 19
#define LABEL_57_18 21
#define LABEL_57_19 23
#define LABEL_57_20 25
#define LABEL_57_12 27
#define TAG_57_13 12
#define LABEL_57_22 29
#define LABEL_57_23 31
#define ENVIRONMENT_LABEL_57_3 46
#define DEBUGGING_LABEL_57_2 45
#define OBJECT_57_1 44
#define OBJECT_57_0 43
#define EXECUTE_CACHE_57_21 33
#define EXECUTE_CACHE_57_14 35
#define FREE_REFERENCE_57_2 38
#define FREE_REFERENCE_57_1 39
#define FREE_REFERENCE_57_0 40
#define FREE_ASSIGNMENT_57_0 42
#define FREE_REFERENCES_LABEL_57_0 32
#define NUMBER_OF_LINKER_SECTIONS_57_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd37;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd40;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd28;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto limit_unparse_depth_18;

    case 1:
      current_block = (Rpc - LABEL_57_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_57_6);
      goto label_21;

    case 3:
      current_block = (Rpc - LABEL_57_7);
      goto label_22;

    case 4:
      current_block = (Rpc - LABEL_57_8);
      goto lambda_33;

    case 5:
      current_block = (Rpc - LABEL_57_15);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_57_16);
      goto label_24;

    case 7:
      current_block = (Rpc - LABEL_57_10);
      goto lambda_34;

    case 8:
      current_block = (Rpc - LABEL_57_17);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_57_18);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_57_19);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_57_20);
      goto label_28;

    case 12:
      current_block = (Rpc - LABEL_57_12);
      goto lambda_35;

    case 13:
      current_block = (Rpc - LABEL_57_22);
      goto label_29;

    case 14:
      current_block = (Rpc - LABEL_57_23);
      goto label_30;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (limit_unparse_depth_32)
DEFLABEL (limit_unparse_depth_18)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_42;
  Wrd5 = Wrd9;

DEFLABEL (label_41)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_36;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_36)
  (Wrd17.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd13.pObj) = (& (Rhp [-1]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_40;
  Wrd19 = Wrd23;

DEFLABEL (label_39)
  Wrd18 = Wrd19;
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_38;
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd30.Lng) = ((Wrd31.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd30.Lng)))
    goto label_38;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd30.Lng));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_37)
  (Wrd55.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd55.Obj);
  (Wrd53.pObj) = (& (Rhp [-1]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd53.pObj)));
  (Rsp [0]) = (Wrd54.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_8])));
  Rhp += 2;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd38 = Wrd35;
  (Wrd39.Obj) = (Rsp [1]);
  ((Wrd38.pObj) [2]) = (Wrd39.Obj);
  ((Wrd38.pObj) [3]) = (Wrd54.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_10])));
  Rhp += 1;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  Wrd43 = Wrd42;
  (Wrd44.Obj) = (Rsp [2]);
  ((Wrd43.pObj) [2]) = (Wrd44.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_12])));
  Rhp += 2;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  Wrd50 = Wrd47;
  ((Wrd50.pObj) [2]) = (Wrd39.Obj);
  ((Wrd50.pObj) [3]) = (Wrd54.Obj);
  (Rsp [2]) = (Wrd46.Obj);
  (Rsp [1]) = (Wrd41.Obj);
  (Rsp [0]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_14]));

DEFLABEL (label_38)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_6])), (Wrd20.pObj));

DEFLABEL (label_21)
  (Wrd19.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_5])), (Wrd6.pObj));

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_41;

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_57_8);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_48;

DEFLABEL (label_47)
  Wrd19 = Wrd23;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_57_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_45;

DEFLABEL (label_44)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_43)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_57_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_44;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_57_16])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_24)
  goto label_43;

DEFLABEL (label_48)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_47;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_57_15])), (Wrd20.pObj));

DEFLABEL (label_23)
  (Wrd19.Obj) = Rvl;
  goto label_46;

DEFLABEL (lambda_34)
  CLOSURE_HEADER (LABEL_57_10);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_57;
  Wrd5 = Wrd9;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_55;
  Wrd12 = Wrd16;

DEFLABEL (label_54)
  Wrd11 = Wrd12;
  (Wrd18.Obj) = (* (Rsp++));
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_53;
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_53;
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if ((Wrd37.Lng) > (Wrd38.Lng))
    goto label_50;

DEFLABEL (label_49)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Rsp [0]) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_50)
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_2]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_52;
  Wrd30 = Wrd34;

DEFLABEL (label_51)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_57_1]);
  (Rsp [1]) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_21]));

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_20])), (Wrd31.pObj));

DEFLABEL (label_28)
  (Wrd30.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_53)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_19]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_INTERFACE_0 (37);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  goto label_50;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_18])), (Wrd13.pObj));

DEFLABEL (label_26)
  (Wrd12.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_17])), (Wrd6.pObj));

DEFLABEL (label_25)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (lambda_35)
  CLOSURE_HEADER (LABEL_57_12);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_63;

DEFLABEL (label_62)
  Wrd19 = Wrd23;

DEFLABEL (label_61)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_57_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_60;

DEFLABEL (label_59)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_58)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_57_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_60)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_59;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_57_23])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_30)
  goto label_58;

DEFLABEL (label_63)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_62;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_57_22])), (Wrd20.pObj));

DEFLABEL (label_29)
  (Wrd19.Obj) = Rvl;
  goto label_61;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_8 5
#define LABEL_58_7 7
#define LABEL_58_5 9
#define LABEL_58_12 11
#define LABEL_58_15 13
#define LABEL_58_14 15
#define LABEL_58_17 17
#define LABEL_58_18 19
#define LABEL_58_19 21
#define LABEL_58_20 23
#define LABEL_58_11 25
#define LABEL_58_16 27
#define LABEL_58_22 29
#define LABEL_58_25 31
#define LABEL_58_27 33
#define LABEL_58_28 35
#define LABEL_58_23 37
#define LABEL_58_29 39
#define LABEL_58_32 41
#define LABEL_58_30 43
#define LABEL_58_34 45
#define LABEL_58_26 47
#define LABEL_58_36 49
#define LABEL_58_33 51
#define LABEL_58_37 53
#define ENVIRONMENT_LABEL_58_3 83
#define DEBUGGING_LABEL_58_2 82
#define OBJECT_58_4 81
#define OBJECT_58_3 80
#define OBJECT_58_2 79
#define OBJECT_58_1 78
#define OBJECT_58_0 77
#define EXECUTE_CACHE_58_35 55
#define EXECUTE_CACHE_58_31 57
#define EXECUTE_CACHE_58_24 59
#define EXECUTE_CACHE_58_21 61
#define EXECUTE_CACHE_58_13 63
#define EXECUTE_CACHE_58_10 65
#define EXECUTE_CACHE_58_9 67
#define EXECUTE_CACHE_58_6 69
#define FREE_REFERENCE_58_4 72
#define FREE_REFERENCE_58_3 73
#define FREE_REFERENCE_58_2 74
#define FREE_REFERENCE_58_1 75
#define FREE_REFERENCE_58_0 76
#define FREE_REFERENCES_LABEL_58_0 54
#define NUMBER_OF_LINKER_SECTIONS_58_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd7;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto unparse_tail_19;

    case 1:
      current_block = (Rpc - LABEL_58_8);
      goto label_21;

    case 2:
      current_block = (Rpc - LABEL_58_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_58_5);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_58_12);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_58_15);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_58_14);
      goto continuation_16;

    case 7:
      current_block = (Rpc - LABEL_58_17);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_58_18);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_58_19);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_58_20);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_58_11);
      goto continuation_4;

    case 12:
      current_block = (Rpc - LABEL_58_16);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_58_22);
      goto continuation_6;

    case 14:
      current_block = (Rpc - LABEL_58_25);
      goto label_28;

    case 15:
      current_block = (Rpc - LABEL_58_27);
      goto label_29;

    case 16:
      current_block = (Rpc - LABEL_58_28);
      goto label_30;

    case 17:
      current_block = (Rpc - LABEL_58_23);
      goto continuation_5;

    case 18:
      current_block = (Rpc - LABEL_58_29);
      goto continuation_10;

    case 19:
      current_block = (Rpc - LABEL_58_32);
      goto label_31;

    case 20:
      current_block = (Rpc - LABEL_58_30);
      goto continuation_14;

    case 21:
      current_block = (Rpc - LABEL_58_34);
      goto label_32;

    case 22:
      current_block = (Rpc - LABEL_58_26);
      goto continuation_7;

    case 23:
      current_block = (Rpc - LABEL_58_36);
      goto label_33;

    case 24:
      current_block = (Rpc - LABEL_58_33);
      goto continuation_12;

    case 25:
      current_block = (Rpc - LABEL_58_37);
      goto label_34;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_tail_36)
DEFLABEL (unparse_tail_19)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 1))
    goto label_60;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_58_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_58_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_46;
  Wrd11 = Wrd15;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_9]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_58_14);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_16]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_44;
  Wrd9 = Wrd13;

DEFLABEL (label_43)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_2]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_42;
  Wrd15 = Wrd19;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_3]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_40;
  Wrd21 = Wrd25;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_38;
  Wrd27 = Wrd31;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_21]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_58_16);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_20])), (Wrd28.pObj));

DEFLABEL (label_27)
  (Wrd27.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_19])), (Wrd22.pObj));

DEFLABEL (label_26)
  (Wrd21.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_18])), (Wrd16.pObj));

DEFLABEL (label_25)
  (Wrd15.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_17])), (Wrd10.pObj));

DEFLABEL (label_24)
  (Wrd9.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_15])), (Wrd12.pObj));

DEFLABEL (label_22)
  (Wrd11.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_11]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_58_3]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_0]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_59;
  Wrd21 = Wrd25;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_13]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_58_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_24]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_58_23);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_58_22);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_57;
  Wrd5 = Wrd9;

DEFLABEL (label_56)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_55;
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_4]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_54;
  Wrd13 = Wrd17;

DEFLABEL (label_53)
  Wrd12 = Wrd13;
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_52;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_52;
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if ((Wrd37.Lng) < (Wrd38.Lng))
    goto label_49;

DEFLABEL (label_50)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_29]))));
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_48;

DEFLABEL (label_49)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_30]))));
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_48)
DEFLABEL (label_51)
  (Wrd42.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_31]));

DEFLABEL (label_52)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_28]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_30)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  goto label_49;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_27])), (Wrd14.pObj));

DEFLABEL (label_29)
  (Wrd13.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_26]))));
  (* (--Rsp)) = (Wrd41.Obj);
  goto label_51;

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_25])), (Wrd6.pObj));

DEFLABEL (label_28)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_12])), (Wrd22.pObj));

DEFLABEL (label_23)
  (Wrd21.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_60)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_58_0])))
    goto label_61;
  Rvl = (current_block [OBJECT_58_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_61)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_58_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_63;
  Wrd13 = Wrd17;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_58_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_8])), (Wrd14.pObj));

DEFLABEL (label_21)
  (Wrd13.Obj) = Rvl;
  goto label_62;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_58_29);
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 1)
    goto label_66;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_33]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_31]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_58_33);
  (Rsp [1]) = Rvl;
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_65;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_65;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_64)
  (Rsp [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_35]));

DEFLABEL (label_65)
  (Wrd6.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_37]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_34)
  (Wrd10.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_66)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_68;
  Wrd12 = Wrd16;

DEFLABEL (label_67)
  (Rsp [1]) = (Wrd12.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_58_4]);
  (Rsp [2]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_9]));

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58_32])), (Wrd13.pObj));

DEFLABEL (label_31)
  (Wrd12.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_58_30);
  (Rsp [1]) = Rvl;
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_70;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_70;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_69)
  (Rsp [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_35]));

DEFLABEL (label_70)
  (Wrd6.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_34]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_32)
  (Wrd10.Obj) = Rvl;
  goto label_69;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_58_26);
  (Rsp [1]) = Rvl;
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_72;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_72;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_71)
  (Rsp [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_35]));

DEFLABEL (label_72)
  (Wrd6.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_36]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_33)
  (Wrd10.Obj) = Rvl;
  goto label_71;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_5 5
#define LABEL_59_7 7
#define ENVIRONMENT_LABEL_59_3 17
#define DEBUGGING_LABEL_59_2 16
#define OBJECT_59_0 15
#define EXECUTE_CACHE_59_9 9
#define EXECUTE_CACHE_59_8 11
#define EXECUTE_CACHE_59_6 13
#define FREE_REFERENCES_LABEL_59_0 8
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto unparse_list_unparser_4;

    case 1:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_59_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_list_unparser_7)
DEFLABEL (unparse_list_unparser_4)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_59_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_59_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_59_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_8)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_6 5
#define LABEL_60_5 7
#define LABEL_60_8 9
#define LABEL_60_9 11
#define ENVIRONMENT_LABEL_60_3 24
#define DEBUGGING_LABEL_60_2 23
#define EXECUTE_CACHE_60_12 13
#define EXECUTE_CACHE_60_11 15
#define EXECUTE_CACHE_60_10 17
#define EXECUTE_CACHE_60_7 19
#define FREE_REFERENCE_60_0 22
#define FREE_REFERENCES_LABEL_60_0 12
#define NUMBER_OF_LINKER_SECTIONS_60_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto unparse_list_prefix_pair_3;

    case 1:
      current_block = (Rpc - LABEL_60_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_60_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_60_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_list_prefix_pair_7)
DEFLABEL (unparse_list_prefix_pair_3)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_60_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_9;
  Wrd9 = Wrd13;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_60_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_60_8);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_11]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60_6])), (Wrd10.pObj));

DEFLABEL (label_5)
  (Wrd9.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define LABEL_61_6 7
#define LABEL_61_8 9
#define LABEL_61_9 11
#define LABEL_61_10 13
#define ENVIRONMENT_LABEL_61_3 31
#define DEBUGGING_LABEL_61_2 30
#define OBJECT_61_8 29
#define OBJECT_61_7 28
#define OBJECT_61_6 27
#define OBJECT_61_5 26
#define OBJECT_61_4 25
#define OBJECT_61_3 24
#define OBJECT_61_2 23
#define OBJECT_61_1 22
#define OBJECT_61_0 21
#define EXECUTE_CACHE_61_11 15
#define EXECUTE_CACHE_61_7 17
#define FREE_REFERENCE_61_0 20
#define FREE_REFERENCES_LABEL_61_0 14
#define NUMBER_OF_LINKER_SECTIONS_61_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto unparse_list_prefix_pairP_11;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_61_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_61_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_61_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_61_10);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_list_prefix_pairP_15)
DEFLABEL (unparse_list_prefix_pairP_11)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_61_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_26;
  Wrd5 = Wrd9;

DEFLABEL (label_25)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_16;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_61_6);
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 1)
    goto label_17;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_9]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_61_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_61_8);
  if (Rvl == (current_block [OBJECT_61_0]))
    goto label_18;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_61_10);
  (Rsp [0]) = Rvl;
  if (Rvl == (current_block [OBJECT_61_1]))
    goto label_24;
  if (Rvl == (current_block [OBJECT_61_3]))
    goto label_23;
  if (Rvl == (current_block [OBJECT_61_5]))
    goto label_22;
  if (Rvl == (current_block [OBJECT_61_7]))
    goto label_20;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_19;

DEFLABEL (label_20)
  Rvl = (current_block [OBJECT_61_8]);

DEFLABEL (label_19)
DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  Rvl = (current_block [OBJECT_61_6]);
  goto label_21;

DEFLABEL (label_23)
  Rvl = (current_block [OBJECT_61_4]);
  goto label_21;

DEFLABEL (label_24)
  Rvl = (current_block [OBJECT_61_2]);
  goto label_21;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_61_5])), (Wrd6.pObj));

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_5 5
#define TAG_62_6 1
#define ENVIRONMENT_LABEL_62_3 11
#define DEBUGGING_LABEL_62_2 10
#define OBJECT_62_0 9
#define EXECUTE_CACHE_62_7 7
#define FREE_REFERENCES_LABEL_62_0 6
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto safe_car_1;

    case 1:
      current_block = (Rpc - LABEL_62_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safe_car_4)
DEFLABEL (safe_car_1)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_62_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_6;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd10.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_0]), 1);

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define LABEL_63_5 5
#define TAG_63_6 1
#define ENVIRONMENT_LABEL_63_3 11
#define DEBUGGING_LABEL_63_2 10
#define OBJECT_63_0 9
#define EXECUTE_CACHE_63_7 7
#define FREE_REFERENCES_LABEL_63_0 6
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto safe_cdr_1;

    case 1:
      current_block = (Rpc - LABEL_63_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safe_cdr_4)
DEFLABEL (safe_cdr_1)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_63_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_6;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_0]), 1);

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_5 3
#define LABEL_64_4 5
#define LABEL_64_6 7
#define LABEL_64_10 9
#define LABEL_64_11 11
#define LABEL_64_12 13
#define LABEL_64_13 15
#define LABEL_64_9 17
#define LABEL_64_7 19
#define LABEL_64_16 21
#define LABEL_64_18 23
#define TAG_64_19 10
#define ENVIRONMENT_LABEL_64_3 45
#define DEBUGGING_LABEL_64_2 44
#define OBJECT_64_0 43
#define EXECUTE_CACHE_64_21 25
#define EXECUTE_CACHE_64_20 27
#define EXECUTE_CACHE_64_17 29
#define EXECUTE_CACHE_64_15 31
#define EXECUTE_CACHE_64_14 33
#define EXECUTE_CACHE_64_8 35
#define FREE_REFERENCE_64_4 38
#define FREE_REFERENCE_64_3 39
#define FREE_REFERENCE_64_2 40
#define FREE_REFERENCE_64_1 41
#define FREE_REFERENCE_64_0 42
#define FREE_REFERENCES_LABEL_64_0 24
#define NUMBER_OF_LINKER_SECTIONS_64_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd36;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_64_4);
      goto unparse_procedure_8;

    case 2:
      current_block = (Rpc - LABEL_64_6);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_64_10);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_64_11);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_64_12);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_64_13);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_64_9);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_64_7);
      goto continuation_1;

    case 9:
      current_block = (Rpc - LABEL_64_16);
      goto continuation_2;

    case 10:
      current_block = (Rpc - LABEL_64_18);
      goto lambda_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_procedure_16)
DEFLABEL (unparse_procedure_8)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_34;
  Wrd8 = Wrd12;

DEFLABEL (label_33)
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_15]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_31)
  (Wrd18.Obj) = (Rsp [0]);
  if (! ((Wrd18.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_7]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_64_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_18)
  (Wrd7.Obj) = (current_block [OBJECT_64_0]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_64_16);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_18])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  Wrd12 = Wrd8;
  goto label_19;

DEFLABEL (label_20)
  (Wrd12.Obj) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_19)
DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (label_22)
  (Wrd20.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_1]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_30;
  Wrd24 = Wrd28;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_2]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_28;
  Wrd30 = Wrd34;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd37.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_3]));
  (Wrd40.Obj) = ((Wrd37.pObj) [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 50)
    goto label_26;
  Wrd36 = Wrd40;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_4]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_24;
  Wrd42 = Wrd46;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_64_9);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_13])), (Wrd43.pObj));

DEFLABEL (label_14)
  (Wrd42.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_12])), (Wrd37.pObj));

DEFLABEL (label_13)
  (Wrd36.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_11])), (Wrd31.pObj));

DEFLABEL (label_12)
  (Wrd30.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_10])), (Wrd25.pObj));

DEFLABEL (label_11)
  (Wrd24.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_6])), (Wrd9.pObj));

DEFLABEL (label_10)
  (Wrd8.Obj) = Rvl;
  goto label_33;

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_64_18);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_21]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_8 5
#define LABEL_65_5 7
#define TAG_65_6 2
#define LABEL_65_9 9
#define LABEL_65_11 11
#define LABEL_65_12 13
#define LABEL_65_14 15
#define TAG_65_15 6
#define ENVIRONMENT_LABEL_65_3 32
#define DEBUGGING_LABEL_65_2 31
#define OBJECT_65_1 30
#define OBJECT_65_0 29
#define EXECUTE_CACHE_65_17 17
#define EXECUTE_CACHE_65_16 19
#define EXECUTE_CACHE_65_13 21
#define EXECUTE_CACHE_65_10 23
#define EXECUTE_CACHE_65_7 25
#define FREE_REFERENCE_65_0 28
#define FREE_REFERENCES_LABEL_65_0 16
#define NUMBER_OF_LINKER_SECTIONS_65_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd28;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto unparse_compound_procedure_6;

    case 1:
      current_block = (Rpc - LABEL_65_8);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_65_5);
      goto lambda_11;

    case 3:
      current_block = (Rpc - LABEL_65_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_65_11);
      goto lambda_4;

    case 5:
      current_block = (Rpc - LABEL_65_12);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_65_14);
      goto lambda_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_compound_procedure_10)
DEFLABEL (unparse_compound_procedure_6)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_65_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_65_5])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = (Wrd5.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_7]));

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_65_5);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_65_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_65_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_17;
  Wrd12 = Wrd16;

DEFLABEL (label_16)
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_11]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [5]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_65_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_16]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_8);
  (Wrd28.Obj) = Rvl;

DEFLABEL (label_14)
  (Rsp [2]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_10]));

DEFLABEL (label_15)
  (Wrd28.Obj) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_65_9])), (Wrd13.pObj));

DEFLABEL (label_8)
  (Wrd12.Obj) = Rvl;
  goto label_16;

DEFLABEL (lambda_12)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_65_11);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_65_1]))
    goto label_19;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_65_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_65_14])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = (Wrd5.Obj);
  Rvl = (Wrd8.Obj);
  goto label_18;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_18)
DEFLABEL (label_20)
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_65_14);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_17]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define LABEL_66_5 5
#define TAG_66_6 1
#define LABEL_66_10 7
#define LABEL_66_11 9
#define LABEL_66_8 11
#define TAG_66_9 4
#define LABEL_66_14 13
#define ENVIRONMENT_LABEL_66_3 30
#define DEBUGGING_LABEL_66_2 29
#define OBJECT_66_0 28
#define EXECUTE_CACHE_66_16 15
#define EXECUTE_CACHE_66_15 17
#define EXECUTE_CACHE_66_13 19
#define EXECUTE_CACHE_66_12 21
#define EXECUTE_CACHE_66_7 23
#define FREE_REFERENCE_66_1 26
#define FREE_REFERENCE_66_0 27
#define FREE_REFERENCES_LABEL_66_0 14
#define NUMBER_OF_LINKER_SECTIONS_66_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto unparse_primitive_procedure_4;

    case 1:
      current_block = (Rpc - LABEL_66_5);
      goto lambda_10;

    case 2:
      current_block = (Rpc - LABEL_66_10);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_66_11);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_66_8);
      goto lambda_11;

    case 5:
      current_block = (Rpc - LABEL_66_14);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_primitive_procedure_9)
DEFLABEL (unparse_primitive_procedure_4)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_66_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_66_5])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = (Wrd5.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_7]));

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_66_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_66_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_66_8])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  ((Wrd7.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_17;
  Wrd11 = Wrd15;

DEFLABEL (label_16)
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_12;
  (Wrd18.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_1;

DEFLABEL (label_12)
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_15;
  Wrd20 = Wrd24;

DEFLABEL (label_14)
  if ((Wrd20.Obj) == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Rsp [1]) = (Wrd27.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_13]));

DEFLABEL (label_13)
  (Wrd31.Obj) = (current_block [OBJECT_66_0]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd32.Obj);
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_12]));

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66_11])), (Wrd21.pObj));

DEFLABEL (label_7)
  (Wrd20.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66_10])), (Wrd12.pObj));

DEFLABEL (label_6)
  (Wrd11.Obj) = Rvl;
  goto label_16;

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_66_8);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_15]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_66_14);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_16]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_7 5
#define LABEL_67_5 7
#define LABEL_67_11 9
#define LABEL_67_8 11
#define TAG_67_9 4
#define LABEL_67_16 13
#define LABEL_67_13 15
#define TAG_67_14 6
#define LABEL_67_17 17
#define LABEL_67_22 19
#define LABEL_67_18 21
#define LABEL_67_21 23
#define LABEL_67_24 25
#define TAG_67_25 11
#define LABEL_67_30 27
#define LABEL_67_31 29
#define LABEL_67_26 31
#define LABEL_67_33 33
#define LABEL_67_35 35
#define LABEL_67_27 37
#define LABEL_67_37 39
#define LABEL_67_38 41
#define LABEL_67_40 43
#define LABEL_67_41 45
#define LABEL_67_42 47
#define LABEL_67_29 49
#define LABEL_67_43 51
#define LABEL_67_46 53
#define LABEL_67_47 55
#define LABEL_67_34 57
#define LABEL_67_32 59
#define LABEL_67_44 61
#define LABEL_67_49 63
#define LABEL_67_50 65
#define LABEL_67_52 67
#define LABEL_67_39 69
#define ENVIRONMENT_LABEL_67_3 108
#define DEBUGGING_LABEL_67_2 107
#define OBJECT_67_7 106
#define OBJECT_67_6 105
#define OBJECT_67_5 104
#define OBJECT_67_4 103
#define OBJECT_67_3 102
#define OBJECT_67_2 101
#define OBJECT_67_1 100
#define OBJECT_67_0 99
#define EXECUTE_CACHE_67_53 71
#define EXECUTE_CACHE_67_51 73
#define EXECUTE_CACHE_67_48 75
#define EXECUTE_CACHE_67_45 77
#define EXECUTE_CACHE_67_36 79
#define EXECUTE_CACHE_67_28 81
#define EXECUTE_CACHE_67_23 83
#define EXECUTE_CACHE_67_20 85
#define EXECUTE_CACHE_67_19 87
#define EXECUTE_CACHE_67_15 89
#define EXECUTE_CACHE_67_12 91
#define EXECUTE_CACHE_67_10 93
#define EXECUTE_CACHE_67_6 95
#define FREE_REFERENCE_67_0 98
#define FREE_REFERENCES_LABEL_67_0 70
#define NUMBER_OF_LINKER_SECTIONS_67_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd51;
  machine_word Wrd45;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd59;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto unparse_compiled_entry_32;

    case 1:
      current_block = (Rpc - LABEL_67_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_67_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_67_11);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_67_8);
      goto lambda_44;

    case 5:
      current_block = (Rpc - LABEL_67_16);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_67_13);
      goto lambda_45;

    case 7:
      current_block = (Rpc - LABEL_67_17);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_67_22);
      goto label_34;

    case 9:
      current_block = (Rpc - LABEL_67_18);
      goto continuation_15;

    case 10:
      current_block = (Rpc - LABEL_67_21);
      goto continuation_17;

    case 11:
      current_block = (Rpc - LABEL_67_24);
      goto lambda_46;

    case 12:
      current_block = (Rpc - LABEL_67_30);
      goto label_35;

    case 13:
      current_block = (Rpc - LABEL_67_31);
      goto continuation_23;

    case 14:
      current_block = (Rpc - LABEL_67_26);
      goto continuation_19;

    case 15:
      current_block = (Rpc - LABEL_67_33);
      goto label_37;

    case 16:
      current_block = (Rpc - LABEL_67_35);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_67_27);
      goto continuation_18;

    case 18:
      current_block = (Rpc - LABEL_67_37);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_67_38);
      goto continuation_11;

    case 20:
      current_block = (Rpc - LABEL_67_40);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_67_41);
      goto continuation_9;

    case 22:
      current_block = (Rpc - LABEL_67_42);
      goto continuation_8;

    case 23:
      current_block = (Rpc - LABEL_67_29);
      goto continuation_7;

    case 24:
      current_block = (Rpc - LABEL_67_43);
      goto label_40;

    case 25:
      current_block = (Rpc - LABEL_67_46);
      goto label_39;

    case 26:
      current_block = (Rpc - LABEL_67_47);
      goto label_38;

    case 27:
      current_block = (Rpc - LABEL_67_34);
      goto continuation_20;

    case 28:
      current_block = (Rpc - LABEL_67_32);
      goto continuation_24;

    case 29:
      current_block = (Rpc - LABEL_67_44);
      goto continuation_10;

    case 30:
      current_block = (Rpc - LABEL_67_49);
      goto continuation_22;

    case 31:
      current_block = (Rpc - LABEL_67_50);
      goto continuation_21;

    case 32:
      current_block = (Rpc - LABEL_67_52);
      goto continuation_25;

    case 33:
      current_block = (Rpc - LABEL_67_39);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_compiled_entry_43)
DEFLABEL (unparse_compiled_entry_32)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_67_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == (current_block [OBJECT_67_0]))
    goto label_48;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_47;

DEFLABEL (label_48)
  (Wrd8.Obj) = (current_block [OBJECT_67_1]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_47)
DEFLABEL (label_52)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_11]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_2]), 1);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_67_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_67_7);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_50)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_8])));
  Rhp += 4;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd29 = Wrd22;
  (Wrd30.Obj) = (Rsp [3]);
  ((Wrd29.pObj) [2]) = (Wrd30.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  ((Wrd29.pObj) [3]) = (Wrd28.Obj);
  (Wrd26.Obj) = (Rsp [1]);
  ((Wrd29.pObj) [4]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [0]);
  ((Wrd29.pObj) [5]) = (Wrd24.Obj);
  (Rsp [0]) = (Wrd21.Obj);
  if ((Wrd26.Obj) == ((SCHEME_OBJECT) 0))
    goto label_49;
  (Rsp [2]) = (Wrd30.Obj);
  (Rsp [3]) = (Wrd21.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_10]));

DEFLABEL (label_49)
  (Rsp [3]) = (Wrd21.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_27;

DEFLABEL (label_51)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_50;

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_67_8);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  if ((Wrd10.Obj) == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd12.Obj) = (current_block [OBJECT_67_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_53;

DEFLABEL (label_54)
  (Wrd30.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_53)
DEFLABEL (label_55)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_13])));
  Rhp += 3;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  Wrd24 = Wrd15;
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  ((Wrd24.pObj) [2]) = (Wrd27.Obj);
  (Wrd23.Obj) = ((Wrd26.pObj) [4]);
  ((Wrd24.pObj) [3]) = (Wrd23.Obj);
  (Wrd19.Obj) = ((Wrd26.pObj) [5]);
  ((Wrd24.pObj) [4]) = (Wrd19.Obj);
  (Rsp [2]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_15]));

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_67_13);

DEFLABEL (lambda_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  if ((Wrd13.Obj) == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd17.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_20]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_67_16);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_56)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_19]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_67_18);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_24])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_57)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_56;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_67_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_64;
  Wrd9 = Wrd13;

DEFLABEL (label_63)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_67_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_27]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_28]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_67_27);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_36]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_67_26);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_60;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_34]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_62;
  Wrd13 = Wrd17;

DEFLABEL (label_61)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_67_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_49]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_50]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_51]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_67_50);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_7]), 1);

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_67_49);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_36]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_67_31);

DEFLABEL (label_60)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_32]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_59;
  Wrd23 = Wrd27;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_67_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_52]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_7]), 1);

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_67_52);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_36]));

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_33])), (Wrd24.pObj));

DEFLABEL (label_37)
  (Wrd23.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_62)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_35])), (Wrd14.pObj));

DEFLABEL (label_36)
  (Wrd13.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_22])), (Wrd10.pObj));

DEFLABEL (label_34)
  (Wrd9.Obj) = Rvl;
  goto label_63;

DEFLABEL (lambda_46)
  CLOSURE_HEADER (LABEL_67_24);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_78;
  Wrd9 = Wrd13;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_67_29);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_74;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_42]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_76;
  Wrd15 = Wrd19;

DEFLABEL (label_75)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_48]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_67_42);

DEFLABEL (label_74)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_67;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  if (! ((Wrd25.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_71;

DEFLABEL (label_70)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_38]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_44]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd43.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_45]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_67_44);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_53]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_67_38);
  (Wrd53.Obj) = (Rsp [2]);
  if ((Wrd53.Obj) == ((SCHEME_OBJECT) 0))
    goto label_67;
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_39]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd60.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd63.Obj) = ((Wrd60.pObj) [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 50)
    goto label_69;
  Wrd59 = Wrd63;

DEFLABEL (label_68)
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_67_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_36]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_67_37);

DEFLABEL (label_67)
  (Wrd46.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd49.Obj) = ((Wrd46.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_66;
  Wrd45 = Wrd49;

DEFLABEL (label_65)
  (Rsp [1]) = (Wrd45.Obj);
  (Wrd51.Obj) = (current_block [OBJECT_67_6]);
  (Rsp [2]) = (Wrd51.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_43])), (Wrd46.pObj));

DEFLABEL (label_40)
  (Wrd45.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_40])), (Wrd60.pObj));

DEFLABEL (label_41)
  (Wrd59.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_41]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_73;
  Wrd31 = Wrd35;

DEFLABEL (label_72)
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_67_41);
  goto label_70;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_46])), (Wrd32.pObj));

DEFLABEL (label_39)
  (Wrd31.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_76)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_47])), (Wrd16.pObj));

DEFLABEL (label_38)
  (Wrd15.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_30])), (Wrd10.pObj));

DEFLABEL (label_35)
  (Wrd9.Obj) = Rvl;
  goto label_77;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define LABEL_68_5 5
#define TAG_68_6 1
#define LABEL_68_8 7
#define ENVIRONMENT_LABEL_68_3 17
#define DEBUGGING_LABEL_68_2 16
#define OBJECT_68_0 15
#define EXECUTE_CACHE_68_10 9
#define EXECUTE_CACHE_68_9 11
#define EXECUTE_CACHE_68_7 13
#define FREE_REFERENCES_LABEL_68_0 8
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto unparse_variable_2;

    case 1:
      current_block = (Rpc - LABEL_68_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_68_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_variable_5)
DEFLABEL (unparse_variable_2)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_68_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_5])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_68_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_68_8);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_5 3
#define LABEL_69_6 5
#define LABEL_69_7 7
#define LABEL_69_8 9
#define LABEL_69_9 11
#define LABEL_69_10 13
#define LABEL_69_11 15
#define LABEL_69_12 17
#define LABEL_69_13 19
#define LABEL_69_14 21
#define LABEL_69_4 23
#define LABEL_69_17 25
#define LABEL_69_19 27
#define LABEL_69_18 29
#define ENVIRONMENT_LABEL_69_3 54
#define DEBUGGING_LABEL_69_2 53
#define OBJECT_69_12 52
#define OBJECT_69_11 51
#define OBJECT_69_10 50
#define OBJECT_69_9 49
#define OBJECT_69_8 48
#define OBJECT_69_7 47
#define OBJECT_69_6 46
#define OBJECT_69_5 45
#define OBJECT_69_4 44
#define OBJECT_69_3 43
#define OBJECT_69_2 42
#define OBJECT_69_1 41
#define OBJECT_69_0 40
#define EXECUTE_CACHE_69_20 31
#define EXECUTE_CACHE_69_16 33
#define EXECUTE_CACHE_69_15 35
#define FREE_REFERENCE_69_1 38
#define FREE_REFERENCE_69_0 39
#define FREE_REFERENCES_LABEL_69_0 30
#define NUMBER_OF_LINKER_SECTIONS_69_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd36;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd74;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd82;
  machine_word Wrd72;
  machine_word Wrd107;
  machine_word Wrd71;
  machine_word Wrd69;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd52;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd60;
  machine_word Wrd50;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd128;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd123;
  machine_word Wrd120;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd135;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd148;
  machine_word Wrd146;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd136;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_7;

    case 1:
      current_block = (Rpc - LABEL_69_6);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_69_7);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_69_8);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_69_9);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_69_10);
      goto lambda_10;

    case 6:
      current_block = (Rpc - LABEL_69_11);
      goto label_25;

    case 7:
      current_block = (Rpc - LABEL_69_12);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_69_13);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_69_14);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_69_4);
      goto unparse_number_18;

    case 11:
      current_block = (Rpc - LABEL_69_17);
      goto label_20;

    case 12:
      current_block = (Rpc - LABEL_69_19);
      goto label_21;

    case 13:
      current_block = (Rpc - LABEL_69_18);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_number_29)
DEFLABEL (unparse_number_18)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_37;
  Wrd5 = Wrd9;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_35;
  Wrd14 = Wrd18;

DEFLABEL (label_34)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_69_7]);
  if (! ((Wrd14.Obj) == (Wrd21.Obj)))
    goto label_30;
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_69_8]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Rsp [2]) = (Wrd21.Obj);
  goto lambda_10;

DEFLABEL (label_30)
  (Wrd23.Obj) = (current_block [OBJECT_69_9]);
  if (! ((Wrd14.Obj) == (Wrd23.Obj)))
    goto label_31;
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_69_10]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Rsp [2]) = (Wrd23.Obj);
  goto lambda_10;

DEFLABEL (label_31)
  (Wrd25.Obj) = (current_block [OBJECT_69_11]);
  if (! ((Wrd14.Obj) == (Wrd25.Obj)))
    goto label_32;
  (Wrd29.Obj) = (current_block [OBJECT_69_6]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_69_12]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Rsp [2]) = (Wrd25.Obj);
  goto lambda_10;

DEFLABEL (label_32)
  (Wrd27.Obj) = (current_block [OBJECT_69_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_33)
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_20]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_69_18);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_15]));

DEFLABEL (label_35)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_19])), (Wrd15.pObj));

DEFLABEL (label_21)
  (Wrd14.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_17])), (Wrd6.pObj));

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_36;

DEFLABEL (lambda_28)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_69_10);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_9]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd120.Obj) = (current_block [OBJECT_69_0]);
  (Wrd123.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd123.Lng))))
    goto label_61;
  (Wrd43.uLng) = (OBJECT_DATUM (Wrd120.Obj));
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd43.Obj) == (Wrd45.Obj))
    goto label_58;

DEFLABEL (label_60)
  (Wrd110.Obj) = (current_block [OBJECT_69_2]);
  (Wrd113.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd113.Lng))))
    goto label_59;
  (Wrd47.uLng) = (OBJECT_DATUM (Wrd110.Obj));
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if ((Wrd47.Obj) == (Wrd49.Obj))
    goto label_58;

DEFLABEL (label_57)
  (Wrd50.Obj) = (current_block [OBJECT_69_3]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd60.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 58L) < ((unsigned long) (Wrd60.Lng)))
    goto label_39;

DEFLABEL (label_38)
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_1]), 2);

DEFLABEL (label_39)
  (Wrd54.uLng) = (OBJECT_DATUM (Wrd50.Obj));
  (Wrd55.Obj) = (Rsp [1]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd54.Obj) == (Wrd56.Obj))
    goto label_41;
  (Wrd52.Obj) = (current_block [OBJECT_69_5]);
  goto label_40;

DEFLABEL (label_41)
  (Wrd52.Obj) = (current_block [OBJECT_69_4]);

DEFLABEL (label_40)
DEFLABEL (label_56)
  Rsp = (& (Rsp [3]));
  if ((Wrd52.Obj) == ((SCHEME_OBJECT) 0))
    goto label_55;

DEFLABEL (label_54)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_8]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (Wrd67.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd99.Obj) = (current_block [OBJECT_69_0]);
  (Wrd102.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd102.Lng))))
    goto label_53;
  (Wrd69.uLng) = (OBJECT_DATUM (Wrd99.Obj));
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd69.Obj) == (Wrd71.Obj))
    goto label_52;

DEFLABEL (label_51)
  (Wrd72.Obj) = (current_block [OBJECT_69_2]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd82.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd82.Lng))))
    goto label_38;
  (Wrd76.uLng) = (OBJECT_DATUM (Wrd72.Obj));
  (Wrd77.Obj) = (Rsp [1]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd76.Obj) == (Wrd78.Obj))
    goto label_43;
  (Wrd74.Obj) = (current_block [OBJECT_69_5]);
  goto label_42;

DEFLABEL (label_43)
  (Wrd74.Obj) = (current_block [OBJECT_69_4]);

DEFLABEL (label_42)
DEFLABEL (label_50)
  Rsp = (& (Rsp [3]));
  if ((Wrd74.Obj) == ((SCHEME_OBJECT) 0))
    goto label_47;

DEFLABEL (label_49)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd97.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd97.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_69_5);
  (Wrd136.Obj) = Rvl;
  (Wrd137.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd137.uLng) == 26))
    goto label_48;
  (Wrd138.Obj) = (Rsp [1]);
  (Wrd139.uLng) = (OBJECT_TYPE (Wrd138.Obj));
  if (! ((Wrd139.uLng) == 26))
    goto label_48;
  (Wrd146.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd148.Lng) = (FIXNUM_TO_LONG (Wrd138.Obj));
  if ((Wrd146.Lng) < (Wrd148.Lng))
    goto label_44;

DEFLABEL (label_47)
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_7]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (Wrd87.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd87.Obj);
  (Wrd89.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd92.Obj) = ((Wrd89.pObj) [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd93.uLng) == 50)
    goto label_46;
  Wrd88 = Wrd92;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd88.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_15]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_69_7);

DEFLABEL (label_44)
  (Wrd135.Obj) = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd135.Obj);
  goto label_33;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_14])), (Wrd89.pObj));

DEFLABEL (label_22)
  (Wrd88.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd141.Obj) = (Rsp [1]);
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_6]))));
  (* (--Rsp)) = (Wrd144.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd136.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  goto label_44;

DEFLABEL (label_52)
  Rsp = (& (Rsp [2]));
  goto label_49;

DEFLABEL (label_53)
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_13]))));
  (* (--Rsp)) = (Wrd107.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_1]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  goto label_52;

DEFLABEL (label_55)
  (Wrd63.Obj) = (current_block [OBJECT_69_6]);
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd63.Obj);
  goto label_33;

DEFLABEL (label_58)
  Rsp = (& (Rsp [2]));
  goto label_54;

DEFLABEL (label_59)
  (Wrd115.Obj) = (Rsp [0]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_12]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd110.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_1]), 2);

DEFLABEL (label_24)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  goto label_58;

DEFLABEL (label_61)
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_11]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd120.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_1]), 2);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_60;
  goto label_58;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_69_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  goto label_49;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_69_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  goto label_54;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_5 5
#define ENVIRONMENT_LABEL_70_3 13
#define DEBUGGING_LABEL_70_2 12
#define OBJECT_70_0 11
#define EXECUTE_CACHE_70_7 7
#define EXECUTE_CACHE_70_6 9
#define FREE_REFERENCES_LABEL_70_0 6
#define NUMBER_OF_LINKER_SECTIONS_70_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto unparse_flonum_3;

    case 1:
      current_block = (Rpc - LABEL_70_5);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_flonum_7)
DEFLABEL (unparse_flonum_3)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd9.Obj));
  (Wrd5.Obj) = (MAKE_OBJECT (26, (Wrd10.uLng)));
  (Wrd11.Obj) = ((SCHEME_OBJECT) 26);
  if (! ((Wrd11.uLng) == 26))
    goto label_10;
  if ((Wrd5.Obj) == (current_block [OBJECT_70_0]))
    goto label_9;

DEFLABEL (label_8)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_7]));

DEFLABEL (label_10)
  (Wrd14.Obj) = (current_block [OBJECT_70_0]);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_5]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_5)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  goto label_9;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define LABEL_71_5 5
#define LABEL_71_6 7
#define LABEL_71_10 9
#define LABEL_71_7 11
#define TAG_71_8 4
#define LABEL_71_11 13
#define LABEL_71_13 15
#define LABEL_71_15 17
#define LABEL_71_12 19
#define LABEL_71_17 21
#define LABEL_71_18 23
#define LABEL_71_19 25
#define LABEL_71_20 27
#define LABEL_71_23 29
#define LABEL_71_22 31
#define LABEL_71_26 33
#define LABEL_71_25 35
#define LABEL_71_27 37
#define ENVIRONMENT_LABEL_71_3 62
#define DEBUGGING_LABEL_71_2 61
#define OBJECT_71_8 60
#define OBJECT_71_7 59
#define OBJECT_71_6 58
#define OBJECT_71_5 57
#define OBJECT_71_4 56
#define OBJECT_71_3 55
#define OBJECT_71_2 54
#define OBJECT_71_1 53
#define OBJECT_71_0 52
#define EXECUTE_CACHE_71_24 39
#define EXECUTE_CACHE_71_21 41
#define EXECUTE_CACHE_71_16 43
#define EXECUTE_CACHE_71_14 45
#define EXECUTE_CACHE_71_9 47
#define FREE_REFERENCE_71_1 50
#define FREE_REFERENCE_71_0 51
#define FREE_REFERENCES_LABEL_71_0 38
#define NUMBER_OF_LINKER_SECTIONS_71_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd24;
  machine_word Wrd41;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd59;
  machine_word Wrd57;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd15;
  double Dbl16;
  machine_word Wrd16;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd26;
  machine_word Wrd9;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd25;
  double Dbl36;
  machine_word Wrd36;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd13;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto unparse_floating_vector_19;

    case 1:
      current_block = (Rpc - LABEL_71_5);
      goto label_21;

    case 2:
      current_block = (Rpc - LABEL_71_6);
      goto label_22;

    case 3:
      current_block = (Rpc - LABEL_71_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_71_7);
      goto lambda_34;

    case 5:
      current_block = (Rpc - LABEL_71_11);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_71_13);
      goto label_25;

    case 7:
      current_block = (Rpc - LABEL_71_15);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_71_12);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_71_17);
      goto do_loop_13;

    case 10:
      current_block = (Rpc - LABEL_71_18);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_71_19);
      goto label_27;

    case 12:
      current_block = (Rpc - LABEL_71_20);
      goto label_28;

    case 13:
      current_block = (Rpc - LABEL_71_23);
      goto label_29;

    case 14:
      current_block = (Rpc - LABEL_71_22);
      goto continuation_9;

    case 15:
      current_block = (Rpc - LABEL_71_26);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_71_25);
      goto continuation_11;

    case 17:
      current_block = (Rpc - LABEL_71_27);
      goto label_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_floating_vector_33)
DEFLABEL (unparse_floating_vector_19)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 6))
    goto label_42;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  (Wrd11.Lng) = (FIXNUM_QUOTIENT ((Wrd8.Lng), ((ADDRESS_UNITS_PER_FLOAT + (ADDRESS_UNITS_PER_OBJECT - 1)) / ADDRESS_UNITS_PER_OBJECT)));
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd11.Lng));
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_41)
  (Wrd19.Obj) = (current_block [OBJECT_71_1]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_40;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if ((Wrd36.Lng) == 0)
    goto label_37;

DEFLABEL (label_38)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_71_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_71_7])));
  Rhp += 2;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  Wrd31 = Wrd28;
  (Wrd32.Obj) = (Rsp [2]);
  ((Wrd31.pObj) [2]) = (Wrd32.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  ((Wrd31.pObj) [3]) = (Wrd30.Obj);
  Wrd33 = Wrd27;
  goto label_36;

DEFLABEL (label_37)
  (Wrd33.Obj) = (current_block [OBJECT_71_2]);

DEFLABEL (label_36)
DEFLABEL (label_39)
  (Wrd34.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd34.Obj);
  (Rsp [2]) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_9]));

DEFLABEL (label_40)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;
  goto label_37;

DEFLABEL (label_42)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_5]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_0]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (lambda_34)
  CLOSURE_HEADER (LABEL_71_7);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_50;
  Wrd8 = Wrd12;

DEFLABEL (label_49)
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_47;
  Wrd15 = Wrd19;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_71_10);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_45)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_12]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [2]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 6))
    goto label_44;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_44;
  Dbl36 = (((double *) (& ((Wrd43.pObj) [1]))) [0]);
  INLINE_DOUBLE_TO_FLONUM (Dbl36, (Wrd37.Obj));
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_43)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_71_12);
  (Wrd5.Obj) = (current_block [OBJECT_71_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto do_loop_13;

DEFLABEL (label_44)
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [2]);
  (Wrd53.Obj) = (current_block [OBJECT_71_3]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_13]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_4]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_15])), (Wrd16.pObj));

DEFLABEL (label_24)
  (Wrd15.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_48)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [3]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_45;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_11])), (Wrd9.pObj));

DEFLABEL (label_23)
  (Wrd8.Obj) = Rvl;
  goto label_49;

DEFLABEL (do_loop_35)
DEFLABEL (do_loop_13)
  INTERRUPT_CHECK (26, LABEL_71_17);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_64;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_64;
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd57.Lng) < (Wrd59.Lng))
    goto label_57;

DEFLABEL (label_56)
  Rsp = (& (Rsp [1]));
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_55;
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_55;
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if ((Wrd41.Lng) < (Wrd45.Lng))
    goto label_52;

DEFLABEL (label_51)
  Rvl = (current_block [OBJECT_71_6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_1]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_54;
  Wrd33 = Wrd37;

DEFLABEL (label_53)
  (Rsp [0]) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_71_7]);
  (Rsp [1]) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_21]));

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_20])), (Wrd34.pObj));

DEFLABEL (label_28)
  (Wrd33.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [3]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_19]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  goto label_52;

DEFLABEL (label_57)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_22]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_71_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_1]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_63;
  Wrd50 = Wrd54;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_24]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_71_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 6))
    goto label_61;
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_61;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd27.Lng))))
    goto label_61;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  Dbl16 = (((double *) (& ((Wrd25.pObj) [1]))) [(Wrd9.Lng)]);
  INLINE_DOUBLE_TO_FLONUM (Dbl16, (Wrd17.Obj));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_60)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_14]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_71_25);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 26))
    goto label_59;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd14.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_59;
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_58)
  (Rsp [0]) = (Wrd9.Obj);
  goto do_loop_13;

DEFLABEL (label_59)
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_27]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_31)
  (Wrd9.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [2]);
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_26]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_4]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_23])), (Wrd51.pObj));

DEFLABEL (label_29)
  (Wrd50.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_64)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_56;
  goto label_57;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define LABEL_72_9 7
#define LABEL_72_7 9
#define LABEL_72_11 11
#define LABEL_72_13 13
#define LABEL_72_18 15
#define LABEL_72_16 17
#define LABEL_72_15 19
#define LABEL_72_21 21
#define TAG_72_22 9
#define LABEL_72_23 23
#define ENVIRONMENT_LABEL_72_3 50
#define DEBUGGING_LABEL_72_2 49
#define OBJECT_72_3 48
#define OBJECT_72_2 47
#define OBJECT_72_1 46
#define OBJECT_72_0 45
#define EXECUTE_CACHE_72_24 25
#define EXECUTE_CACHE_72_20 27
#define EXECUTE_CACHE_72_19 29
#define EXECUTE_CACHE_72_17 31
#define EXECUTE_CACHE_72_14 33
#define EXECUTE_CACHE_72_12 35
#define EXECUTE_CACHE_72_10 37
#define EXECUTE_CACHE_72_8 39
#define EXECUTE_CACHE_72_6 41
#define FREE_REFERENCE_72_0 44
#define FREE_REFERENCES_LABEL_72_0 24
#define NUMBER_OF_LINKER_SECTIONS_72_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unpars_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto unparse_entity_12;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_72_9);
      goto plain_9;

    case 3:
      current_block = (Rpc - LABEL_72_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_72_11);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_72_13);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_72_18);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_72_16);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_72_15);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_72_21);
      goto lambda_18;

    case 10:
      current_block = (Rpc - LABEL_72_23);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unparse_entity_16)
DEFLABEL (unparse_entity_12)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd7.Obj) = (current_block [OBJECT_72_0]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto plain_9;

DEFLABEL (label_19)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_72_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd7.Obj) = (current_block [OBJECT_72_1]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto plain_9;

DEFLABEL (label_20)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_72_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_21;
  (Wrd11.Obj) = (current_block [OBJECT_72_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto plain_9;

DEFLABEL (label_21)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_72_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_72_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_18]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_20]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_72_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd25.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_19]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_72_15);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd5.Obj);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_22;
  (Wrd8.Obj) = (current_block [OBJECT_72_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_21])));
  Rhp += 1;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  ((Wrd11.pObj) [2]) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd14.Obj);
  (Rsp [2]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_10]));

DEFLABEL (label_22)
  (Wrd15.Obj) = (current_block [OBJECT_72_3]);
  (Rsp [0]) = (Wrd15.Obj);
  goto plain_9;

DEFLABEL (label_24)
  (Wrd5.Obj) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto label_23;

DEFLABEL (plain_17)
DEFLABEL (plain_9)
  INTERRUPT_CHECK (26, LABEL_72_9);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_10]));

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_72_21);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_72_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_26;
  Wrd5 = Wrd9;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_24]));

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_72_23])), (Wrd6.pObj));

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_11 7
#define LABEL_7 9
#define LABEL_9 11
#define LABEL_10 13
#define LABEL_13 15
#define LABEL_18 17
#define LABEL_14 19
#define TAG_15 8
#define LABEL_16 21
#define LABEL_17 23
#define LABEL_19 25
#define LABEL_20 27
#define TAG_21 12
#define LABEL_24 29
#define LABEL_22 31
#define LABEL_27 33
#define LABEL_23 35
#define LABEL_25 37
#define LABEL_26 39
#define LABEL_28 41
#define LABEL_33 43
#define LABEL_29 45
#define TAG_30 21
#define LABEL_31 47
#define LABEL_32 49
#define LABEL_34 51
#define TAG_35 24
#define LABEL_36 53
#define LABEL_37 55
#define LABEL_38 57
#define LABEL_39 59
#define ENVIRONMENT_LABEL_3 103
#define DEBUGGING_LABEL_2 102
#define PURIFICATION_ROOT 101
#define OBJECT_30 100
#define OBJECT_29 99
#define OBJECT_28 98
#define OBJECT_27 97
#define OBJECT_26 96
#define OBJECT_25 95
#define OBJECT_24 94
#define OBJECT_23 93
#define OBJECT_22 92
#define OBJECT_21 91
#define OBJECT_20 90
#define OBJECT_19 89
#define OBJECT_18 88
#define OBJECT_17 87
#define OBJECT_16 86
#define OBJECT_15 85
#define OBJECT_14 84
#define OBJECT_13 83
#define OBJECT_12 82
#define OBJECT_11 81
#define OBJECT_10 80
#define OBJECT_9 79
#define OBJECT_8 78
#define OBJECT_7 77
#define OBJECT_6 76
#define OBJECT_5 75
#define OBJECT_4 74
#define OBJECT_3 73
#define OBJECT_2 72
#define OBJECT_1 71
#define OBJECT_0 70
#define FREE_REFERENCE_1 61
#define FREE_REFERENCE_0 62
#define GLOBAL_EXECUTE_CACHE_12 64
#define GLOBAL_EXECUTE_CACHE_8 66
#define GLOBAL_EXECUTE_CACHE_5 68
#define FREE_REFERENCES_LABEL_0 60
#define NUMBER_OF_LINKER_SECTIONS_1 2

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
unpars_so_2aaf08d9f878738e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_11);
      goto label_39;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_18);
      goto label_40;

    case 8:
      current_block = (Rpc - LABEL_14);
      goto Z__make_unparser_table_46;

    case 9:
      current_block = (Rpc - LABEL_16);
      goto continuation_16;

    case 10:
      current_block = (Rpc - LABEL_17);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_19);
      goto continuation_17;

    case 12:
      current_block = (Rpc - LABEL_20);
      goto unparser_tableP_47;

    case 13:
      current_block = (Rpc - LABEL_24);
      goto label_41;

    case 14:
      current_block = (Rpc - LABEL_22);
      goto continuation_23;

    case 15:
      current_block = (Rpc - LABEL_27);
      goto label_42;

    case 16:
      current_block = (Rpc - LABEL_23);
      goto continuation_22;

    case 17:
      current_block = (Rpc - LABEL_25);
      goto continuation_28;

    case 18:
      current_block = (Rpc - LABEL_26);
      goto continuation_24;

    case 19:
      current_block = (Rpc - LABEL_28);
      goto continuation_29;

    case 20:
      current_block = (Rpc - LABEL_33);
      goto label_43;

    case 21:
      current_block = (Rpc - LABEL_29);
      goto make_unparser_state_48;

    case 22:
      current_block = (Rpc - LABEL_31);
      goto continuation_36;

    case 23:
      current_block = (Rpc - LABEL_32);
      goto continuation_30;

    case 24:
      current_block = (Rpc - LABEL_34);
      goto unparser_stateP_49;

    case 25:
      current_block = (Rpc - LABEL_36);
      goto label_44;

    case 26:
      current_block = (Rpc - LABEL_37);
      goto label_51;

    case 27:
      current_block = (Rpc - LABEL_38);
      goto label_52;

    case 28:
      current_block = (Rpc - LABEL_39);
      goto expression_38;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_38)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_38])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_52)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_51)
  {
    static const short sections [] =
      {
	0,
	2,
	2,
	1,
	2,
	1,
	2,
	2,
	2,
	2,
	1,
	1,
	2,
	2,
	1,
	2,
	3,
	2,
	2,
	2,
	1,
	2,
	1,
	2,
	2,
	1,
	2,
	2,
	2,
	2,
	1,
	1,
	2,
	2,
	2,
	1,
	1,
	2,
	2,
	2,
	2,
	1,
	2,
	2,
	2,
	1,
	2,
	3,
	2,
	1,
	1,
	1,
	3,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	0,
	2,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 72)
      goto label_50;
    blocks = (current_block [OBJECT_30]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_37])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_50)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (current_block [OBJECT_2]);
  (Wrd16.Obj) = (current_block [OBJECT_3]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_60;
  Wrd11 = Wrd15;

DEFLABEL (label_59)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_10);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_58;
  Wrd11 = Wrd15;

DEFLABEL (label_57)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_17);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_20])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (current_block [OBJECT_14]);
  (Wrd16.Obj) = (current_block [OBJECT_3]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_15]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd24.Obj) = (current_block [OBJECT_16]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Wrd28.Obj) = (current_block [OBJECT_17]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_8]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_23);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_56;
  Wrd11 = Wrd15;

DEFLABEL (label_55)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_26);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_29])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_54;
  Wrd11 = Wrd15;

DEFLABEL (label_53)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_32);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_34])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7]), 3);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_31);
  (Wrd5.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_28]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33])), (Wrd12.pObj));

DEFLABEL (label_43)
  (Wrd11.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27])), (Wrd12.pObj));

DEFLABEL (label_42)
  (Wrd11.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18])), (Wrd12.pObj));

DEFLABEL (label_40)
  (Wrd11.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd12.pObj));

DEFLABEL (label_39)
  (Wrd11.Obj) = Rvl;
  goto label_59;

DEFLABEL (Z__make_unparser_table_46)
  CLOSURE_HEADER (LABEL_14);

DEFLABEL (Z__make_unparser_table_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 2));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (Wrd15.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd7.pObj) = (& (Rhp [-3]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (unparser_tableP_47)
  CLOSURE_HEADER (LABEL_20);

DEFLABEL (unparser_tableP_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_63;

DEFLABEL (label_62)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_61)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_63)
  if (! ((Wrd6.uLng) == 62))
    goto label_65;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_65;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_64)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_62;
  Rvl = (current_block [OBJECT_22]);
  goto label_61;

DEFLABEL (label_65)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_20]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21]), 2);

DEFLABEL (label_41)
  (Wrd9.Obj) = Rvl;
  goto label_64;

DEFLABEL (make_unparser_state_48)
  CLOSURE_HEADER (LABEL_29);

DEFLABEL (make_unparser_state_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (unparser_stateP_49)
  CLOSURE_HEADER (LABEL_34);

DEFLABEL (unparser_stateP_34)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_68;

DEFLABEL (label_67)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_66)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_68)
  if (! ((Wrd6.uLng) == 62))
    goto label_70;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_70;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_69)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_67;
  Rvl = (current_block [OBJECT_22]);
  goto label_66;

DEFLABEL (label_70)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_20]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21]), 2);

DEFLABEL (label_44)
  (Wrd9.Obj) = Rvl;
  goto label_69;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_unpars_so_2aaf08d9f878738e [72] =
  {
    { "unpars_so_code_1", 31, unpars_so_code_1 },
    { "unpars_so_code_2", 32, unpars_so_code_2 },
    { "unpars_so_code_3", 1, unpars_so_code_3 },
    { "unpars_so_code_4", 1, unpars_so_code_4 },
    { "unpars_so_code_5", 2, unpars_so_code_5 },
    { "unpars_so_code_6", 1, unpars_so_code_6 },
    { "unpars_so_code_7", 3, unpars_so_code_7 },
    { "unpars_so_code_8", 2, unpars_so_code_8 },
    { "unpars_so_code_9", 3, unpars_so_code_9 },
    { "unpars_so_code_10", 3, unpars_so_code_10 },
    { "unpars_so_code_11", 1, unpars_so_code_11 },
    { "unpars_so_code_12", 1, unpars_so_code_12 },
    { "unpars_so_code_13", 1, unpars_so_code_13 },
    { "unpars_so_code_14", 1, unpars_so_code_14 },
    { "unpars_so_code_15", 1, unpars_so_code_15 },
    { "unpars_so_code_16", 1, unpars_so_code_16 },
    { "unpars_so_code_17", 1, unpars_so_code_17 },
    { "unpars_so_code_18", 1, unpars_so_code_18 },
    { "unpars_so_code_19", 2, unpars_so_code_19 },
    { "unpars_so_code_20", 1, unpars_so_code_20 },
    { "unpars_so_code_21", 10, unpars_so_code_21 },
    { "unpars_so_code_22", 3, unpars_so_code_22 },
    { "unpars_so_code_23", 3, unpars_so_code_23 },
    { "unpars_so_code_24", 6, unpars_so_code_24 },
    { "unpars_so_code_25", 14, unpars_so_code_25 },
    { "unpars_so_code_26", 27, unpars_so_code_26 },
    { "unpars_so_code_27", 6, unpars_so_code_27 },
    { "unpars_so_code_28", 3, unpars_so_code_28 },
    { "unpars_so_code_29", 2, unpars_so_code_29 },
    { "unpars_so_code_30", 2, unpars_so_code_30 },
    { "unpars_so_code_31", 2, unpars_so_code_31 },
    { "unpars_so_code_32", 2, unpars_so_code_32 },
    { "unpars_so_code_33", 5, unpars_so_code_33 },
    { "unpars_so_code_34", 4, unpars_so_code_34 },
    { "unpars_so_code_35", 6, unpars_so_code_35 },
    { "unpars_so_code_36", 20, unpars_so_code_36 },
    { "unpars_so_code_37", 8, unpars_so_code_37 },
    { "unpars_so_code_38", 4, unpars_so_code_38 },
    { "unpars_so_code_39", 3, unpars_so_code_39 },
    { "unpars_so_code_40", 2, unpars_so_code_40 },
    { "unpars_so_code_41", 15, unpars_so_code_41 },
    { "unpars_so_code_42", 3, unpars_so_code_42 },
    { "unpars_so_code_43", 1, unpars_so_code_43 },
    { "unpars_so_code_44", 3, unpars_so_code_44 },
    { "unpars_so_code_45", 29, unpars_so_code_45 },
    { "unpars_so_code_46", 12, unpars_so_code_46 },
    { "unpars_so_code_47", 39, unpars_so_code_47 },
    { "unpars_so_code_48", 11, unpars_so_code_48 },
    { "unpars_so_code_49", 8, unpars_so_code_49 },
    { "unpars_so_code_50", 7, unpars_so_code_50 },
    { "unpars_so_code_51", 4, unpars_so_code_51 },
    { "unpars_so_code_52", 22, unpars_so_code_52 },
    { "unpars_so_code_53", 6, unpars_so_code_53 },
    { "unpars_so_code_54", 7, unpars_so_code_54 },
    { "unpars_so_code_55", 8, unpars_so_code_55 },
    { "unpars_so_code_56", 9, unpars_so_code_56 },
    { "unpars_so_code_57", 15, unpars_so_code_57 },
    { "unpars_so_code_58", 26, unpars_so_code_58 },
    { "unpars_so_code_59", 3, unpars_so_code_59 },
    { "unpars_so_code_60", 5, unpars_so_code_60 },
    { "unpars_so_code_61", 6, unpars_so_code_61 },
    { "unpars_so_code_62", 2, unpars_so_code_62 },
    { "unpars_so_code_63", 2, unpars_so_code_63 },
    { "unpars_so_code_64", 11, unpars_so_code_64 },
    { "unpars_so_code_65", 7, unpars_so_code_65 },
    { "unpars_so_code_66", 6, unpars_so_code_66 },
    { "unpars_so_code_67", 34, unpars_so_code_67 },
    { "unpars_so_code_68", 3, unpars_so_code_68 },
    { "unpars_so_code_69", 14, unpars_so_code_69 },
    { "unpars_so_code_70", 2, unpars_so_code_70 },
    { "unpars_so_code_71", 18, unpars_so_code_71 },
    { "unpars_so_code_72", 11, unpars_so_code_72 }
  };

int
decl_unpars_so_2aaf08d9f878738e (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_unpars_so_2aaf08d9f878738e);
  return (0);
}

DECLARE_COMPILED_CODE ("unpars.so", 29, decl_unpars_so_2aaf08d9f878738e, unpars_so_2aaf08d9f878738e)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_unpars_so_data_2aaf08d9f878738e [12859] =
  "\xb2\x01\xa9\x01\xcf\x18\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x07"
  "\x02\x06\x0f\x0f\x0d\xb9\x0d\xba\x0d\xbb\x0d\xbc\x0d\xbd\x0d\xbe"
  "\x0d\xbf\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x25\x0d\x1c\x0d\x1b\x0d\x1c\x0d"
  "\x0d\x1b\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x82"
  "\x88\xc1\x1c\xc1\x1c\x0d\x1c\x0d\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x0d\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x08\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x83\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0"
  "\x84\x88\xc2\x1c\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x85\x88\x1d"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x86\x88\x06\x1d\x0c\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x0d\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x28\x1b\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x1b\x81\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xc3\x1d\x1b\x81\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1d\x28"
  "\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1d\x1b\x81\x0d\x1c\x1b\x25\x1b\x24\x28\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x0d\x1c\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\x0d\x1c\x28\x1b\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x84\x81\x1b"
  "\x82\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x80\x1d"
  "\x1b\x84\x1b\x24\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x1b\x81\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x25"
  "\x1b\x1b\x1b\x1b\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x1b\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\xc1\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x02\x0c\x1b\x24\x28\x1b\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1b\x24\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0f\x0f\x0c\x1b\x1b"
  "\x1b\x24\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x08\x8d\x28\x0d\x1c\x28"
  "\x0d\x28\x0d\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x28\x0d\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d"
  "\x1c\x24\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0c\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\x1d\x0c\x0c\x0c\x0c\x0c\x1d"
  "\x0c\x07\x0c\x08\x1b\x0d\x0d\x0d\x0d\x24\x28\x1b\x28\x0d\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x28\x0d\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\xb2\x23"
  "\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0f\x0f\xc2\x1c\x80\xc1\x1c\x0d\x1b\x1b\x0d\x1b\x1b\x1b\x24\x28"
  "\x0d\x28\x1b\x28\x1b\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x07\x0c\x1b\x1b\x24\x28\x0d\x28\x1b\x28\x0d"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f"
  "\x0f\x1b\x0f\x0c\x80\x0f\x1b\x1b\x1b\xb7\xb1\x24\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x02\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f\x0f\xc2"
  "\x1d\xc1\x0c\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x1b\x1b\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\xc1\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0c\x0f\x0f\x81\x80\x0c\x0c\x1b\x1b\xb5\x24\x28\x0d"
  "\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c"
  "\x07\x1b\x02\x0c\x28\x0d\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x1b\x1b\x1b\x24\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x1b\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f"
  "\x82\x0f\x1b\x24\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x1b"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d"
  "\x1b\x25\xb6\x1b\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x0f\x0c\x1d\x08\x1b\x1b\x1b\x1b\xb5\x24\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0d\x0c\x0d"
  "\x0c\x0d\x0c\x0d\x08\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0d\xb3\x1b\x1b\x1b\x1b\x24\x28\x0d\x28\x1b\x28\xb3\x28\x0d\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x0d\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x0d\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x1b\x1b\x24\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0f\x0f\x0f"
  "\x0d\xc1\x07\x0d\x1b\x24\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28\x0d"
  "\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28"
  "\x1b\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x02\x0c\x02\x0c\x82\x02\x06\x07\x02\x02\x1b"
  "\x02\x1b\xb4\x24\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x81"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0f\x0c\x1d\x81\xc2\x80\x06\x0c\xc1\xb5\x1b\x24\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1b\x0d\x0d\x1b\x24\x28\x0d\x28\x0d\x28"
  "\x1b\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x0d\x1c\x88\x1b\x1b\x88\x1b\x1b\x88\x1b\x1b\x88\x1b"
  "\x1b\x88\x1b\x0d\x1c\x88\x1b\x1b\x88\x1b\x1b\x88\x1b\x1b\x88\x0d"
  "\x0d\x1c\x88\x0d\x1b\x88\x0d\x0d\x1c\x88\x0d\x1b\x88\x0d\x1b\x88"
  "\x0d\x1b\x88\x0d\x1b\x88\x0d\x1b\x88\x0d\x0d\x1c\x88\x0d\x1b\x88"
  "\x08\x14\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x1e\x1e\x1e\x1e\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x17\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\xb3\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\xb1\x1b\x1b\x1b\x1b"
  "\x1b\xb2\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x0d\x0d"
  "\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x0d\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x17\x1b\x0d\x0d\x0d\x0d\x9b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x9b\x0d\x1c\x07\x1b\x80\x0c\x0d\x0d\x0d\x0d\x08\x8b\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x1b\x0d\x0d\x1b\x1b\x1b\x9d\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9d\x1b\x0d\x1b\x2a\xc3\x0d"
  "\x1c\x0c\x0d\x08\x88\x08\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\xb7\xb6\xb5\xb4\x0d\x17\x1b\x2a\x1e\x1e\x1e\x1e"
  "\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1b\x2a\x17\x28\x0d"
  "\x28\x0d\x28\x0d\x26\x1b\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x02\x47\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
  "\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30"
  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
  "\x39\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
  "\x65\x2f\x75\x6e\x70\x61\x72\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70"
  "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
  "\x5d\x02\x02\x0b\x01\x23\x01\x5d\x12\x73\x74\x72\x69\x6e\x67\x2d"
  "\x64\x65\x6c\x69\x6d\x69\x74\x65\x72\x73\x15\x68\x6f\x6f\x6b\x2f"
  "\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x18"
  "\x68\x6f\x6f\x6b\x2f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x75"
  "\x6e\x70\x61\x72\x73\x65\x72\x11\x2a\x75\x6e\x70\x61\x72\x73\x65"
  "\x72\x2d\x72\x61\x64\x69\x78\x2a\x1e\x2a\x75\x6e\x70\x61\x72\x73"
  "\x65\x72\x2d\x6c\x69\x73\x74\x2d\x62\x72\x65\x61\x64\x74\x68\x2d"
  "\x6c\x69\x6d\x69\x74\x2a\x1c\x2a\x75\x6e\x70\x61\x72\x73\x65\x72"
  "\x2d\x6c\x69\x73\x74\x2d\x64\x65\x70\x74\x68\x2d\x6c\x69\x6d\x69"
  "\x74\x2a\x1f\x2a\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x72"
  "\x69\x6e\x67\x2d\x6c\x65\x6e\x67\x74\x68\x2d\x6c\x69\x6d\x69\x74"
  "\x2a\x1e\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x70\x72\x69\x6d\x69"
  "\x74\x69\x76\x65\x73\x2d\x62\x79\x2d\x6e\x61\x6d\x65\x3f\x2a\x09"
  "\x26\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x75\x6e\x69\x6e\x74\x65"
  "\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x73\x2d\x62\x79\x2d"
  "\x6e\x61\x6d\x65\x3f\x2a\x0a\x24\x2a\x75\x6e\x70\x61\x72\x73\x65"
  "\x2d\x77\x69\x74\x68\x2d\x6d\x61\x78\x69\x6d\x75\x6d\x2d\x72\x65"
  "\x61\x64\x61\x62\x69\x6c\x69\x74\x79\x3f\x2a\x0b\x24\x2a\x75\x6e"
  "\x70\x61\x72\x73\x65\x2d\x63\x6f\x6d\x70\x6f\x75\x6e\x64\x2d\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x6e\x61\x6d\x65\x73\x3f\x2a"
  "\x0c\x16\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x77\x69\x74\x68\x2d"
  "\x64\x61\x74\x75\x6d\x3f\x2a\x0d\x21\x2a\x75\x6e\x70\x61\x72\x73"
  "\x65\x2d\x61\x62\x62\x72\x65\x76\x69\x61\x74\x65\x2d\x71\x75\x6f"
  "\x74\x61\x74\x69\x6f\x6e\x73\x3f\x2a\x0e\x1d\x73\x79\x73\x74\x65"
  "\x6d\x2d\x67\x6c\x6f\x62\x61\x6c\x2d\x75\x6e\x70\x61\x72\x73\x65"
  "\x72\x2d\x74\x61\x62\x6c\x65\x0f\x11\x2a\x75\x6e\x70\x61\x72\x73"
  "\x65\x72\x2d\x74\x61\x62\x6c\x65\x2a\x10\x19\x2a\x64\x65\x66\x61"
  "\x75\x6c\x74\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61"
  "\x74\x65\x2a\x11\x18\x6e\x6f\x6e\x2d\x63\x61\x6e\x6f\x6e\x2d\x73"
  "\x79\x6d\x62\x6f\x6c\x2d\x71\x75\x6f\x74\x65\x64\x12\x14\x63\x61"
  "\x6e\x6f\x6e\x2d\x73\x79\x6d\x62\x6f\x6c\x2d\x71\x75\x6f\x74\x65"
  "\x64\x13\x13\x0f\x75\x6e\x70\x61\x72\x73\x65\x2d\x73\x79\x6d\x62"
  "\x6f\x6c\x14\x15\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x6e\x6f\x74"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x0f\x17\x63\x68\x61\x72\x2d\x73"
  "\x65\x74\x2f\x73\x79\x6d\x62\x6f\x6c\x2d\x71\x75\x6f\x74\x65\x73"
  "\x15\x19\x63\x68\x61\x72\x2d\x73\x65\x74\x2f\x61\x74\x6f\x6d\x2d"
  "\x64\x65\x6c\x69\x6d\x69\x74\x65\x72\x73\x14\x63\x68\x61\x72\x2d"
  "\x73\x65\x74\x3a\x75\x70\x70\x65\x72\x2d\x63\x61\x73\x65\x12\x08"
  "\x04\x09\x63\x68\x61\x72\x2d\x73\x65\x74\x02\x22\x6d\x61\x6b\x65"
  "\x2d\x73\x79\x73\x74\x65\x6d\x2d\x67\x6c\x6f\x62\x61\x6c\x2d\x75"
  "\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x16\x04\x0f"
  "\x63\x68\x61\x72\x2d\x73\x65\x74\x2d\x75\x6e\x69\x6f\x6e\x04\x3c"
  "\x40\x81\x81\x02\x3b\x3e\x81\x81\x02\x3a\x3c\x81\x85\x02\x39\x3a"
  "\x81\x83\x02\x38\x38\x81\x81\x02\x37\x36\x81\x81\x02\x36\x34\x81"
  "\x85\x02\x35\x32\x81\x83\x02\x34\x30\x81\x81\x02\x33\x2e\x81\x81"
  "\x02\x32\x2c\x81\x81\x02\x31\x2a\x81\x81\x02\x30\x28\x81\x81\x02"
  "\x2f\x26\x81\x85\x02\x2e\x24\x81\x83\x02\x2d\x22\x81\x81\x02\x2c"
  "\x20\x81\x81\x02\x2b\x1e\x81\x81\x02\x2a\x1c\x81\x81\x02\x29\x1a"
  "\x81\x81\x02\x28\x18\x81\x81\x02\x27\x16\x81\x81\x02\x26\x14\x81"
  "\x81\x02\x25\x12\x81\x81\x02\x24\x10\x81\x81\x02\x23\x0e\x81\x81"
  "\x02\x22\x0c\x81\x81\x02\x21\x0a\x81\x81\x02\x20\x08\x81\x81\x02"
  "\x1f\x06\x81\x81\x02\x1e\x04\x82\x02\x3f\x6a\x17\x02\x04\x63\x64"
  "\x72\x18\x04\x63\x61\x72\x19\x07\x62\x69\x67\x6e\x75\x6d\x1a\x0a"
  "\x63\x68\x61\x72\x61\x63\x74\x65\x72\x0f\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x64\x2d\x65\x6e\x74\x72\x79\x1b\x08\x63\x6f\x6d\x70\x6c\x65"
  "\x78\x1c\x09\x63\x6f\x6e\x73\x74\x61\x6e\x74\x07\x65\x6e\x74\x69"
  "\x74\x79\x1d\x13\x65\x78\x74\x65\x6e\x64\x65\x64\x2d\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x1e\x07\x66\x6c\x6f\x6e\x75\x6d\x1f\x10"
  "\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x20"
  "\x05\x6c\x69\x73\x74\x21\x10\x6e\x65\x67\x61\x74\x69\x76\x65\x2d"
  "\x66\x69\x78\x6e\x75\x6d\x22\x06\x66\x61\x6c\x73\x65\x10\x70\x6f"
  "\x73\x69\x74\x69\x76\x65\x2d\x66\x69\x78\x6e\x75\x6d\x23\x0a\x70"
  "\x72\x69\x6d\x69\x74\x69\x76\x65\x24\x0a\x70\x72\x6f\x63\x65\x64"
  "\x75\x72\x65\x25\x07\x72\x61\x74\x6e\x75\x6d\x07\x72\x65\x63\x6f"
  "\x72\x64\x0f\x72\x65\x74\x75\x72\x6e\x2d\x61\x64\x64\x72\x65\x73"
  "\x73\x26\x07\x73\x74\x72\x69\x6e\x67\x27\x12\x75\x6e\x69\x6e\x74"
  "\x65\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x28\x09\x76\x61"
  "\x72\x69\x61\x62\x6c\x65\x29\x07\x76\x65\x63\x74\x6f\x72\x2a\x0a"
  "\x76\x65\x63\x74\x6f\x72\x2d\x31\x62\x10\x75\x6e\x70\x61\x72\x73"
  "\x65\x2f\x64\x65\x66\x61\x75\x6c\x74\x2b\x13\x75\x6e\x70\x61\x72"
  "\x73\x65\x2f\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2c\x0f\x75"
  "\x6e\x70\x61\x72\x73\x65\x2f\x76\x65\x63\x74\x6f\x72\x2d\x11\x75"
  "\x6e\x70\x61\x72\x73\x65\x2f\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
  "\x1a\x75\x6e\x70\x61\x72\x73\x65\x2f\x75\x6e\x69\x6e\x74\x65\x72"
  "\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x2f\x0f\x75\x6e\x70\x61"
  "\x72\x73\x65\x2f\x73\x74\x72\x69\x6e\x67\x30\x17\x75\x6e\x70\x61"
  "\x72\x73\x65\x2f\x72\x65\x74\x75\x72\x6e\x2d\x61\x64\x64\x72\x65"
  "\x73\x73\x31\x0f\x75\x6e\x70\x61\x72\x73\x65\x2f\x72\x65\x63\x6f"
  "\x72\x64\x32\x0f\x75\x6e\x70\x61\x72\x73\x65\x2f\x6e\x75\x6d\x62"
  "\x65\x72\x33\x1b\x75\x6e\x70\x61\x72\x73\x65\x2f\x63\x6f\x6d\x70"
  "\x6f\x75\x6e\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x34\x1c"
  "\x75\x6e\x70\x61\x72\x73\x65\x2f\x70\x72\x69\x6d\x69\x74\x69\x76"
  "\x65\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x35\x0e\x75\x6e\x70"
  "\x61\x72\x73\x65\x2f\x66\x61\x6c\x73\x65\x36\x0d\x75\x6e\x70\x61"
  "\x72\x73\x65\x2f\x70\x61\x69\x72\x37\x18\x75\x6e\x70\x61\x72\x73"
  "\x65\x2f\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f"
  "\x6c\x38\x0f\x75\x6e\x70\x61\x72\x73\x65\x2f\x66\x6c\x6f\x6e\x75"
  "\x6d\x39\x0f\x75\x6e\x70\x61\x72\x73\x65\x2f\x65\x6e\x74\x69\x74"
  "\x79\x3a\x11\x75\x6e\x70\x61\x72\x73\x65\x2f\x63\x6f\x6e\x73\x74"
  "\x61\x6e\x74\x3b\x17\x75\x6e\x70\x61\x72\x73\x65\x2f\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x64\x2d\x65\x6e\x74\x72\x79\x3c\x12\x75\x6e\x70"
  "\x61\x72\x73\x65\x2f\x63\x68\x61\x72\x61\x63\x74\x65\x72\x3d\x14"
  "\x03\x14\x6d\x61\x6b\x65\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d"
  "\x74\x61\x62\x6c\x65\x3e\x19\x21\x04\x09\x66\x6f\x72\x2d\x65\x61"
  "\x63\x68\x05\x1a\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62"
  "\x6c\x65\x2f\x73\x65\x74\x2d\x65\x6e\x74\x72\x79\x21\x3f\x05\x5c"
  "\x42\x81\x87\x02\x5b\x40\x81\x87\x02\x5a\x3e\x81\x87\x02\x59\x3c"
  "\x81\x85\x02\x58\x3a\x81\x85\x02\x57\x38\x81\x83\x02\x56\x36\x81"
  "\xb3\x02\x55\x34\x81\xb1\x02\x54\x32\x81\xaf\x02\x53\x30\x81\xad"
  "\x02\x52\x2e\x81\xab\x02\x51\x2c\x81\xa9\x02\x50\x2a\x81\xa7\x02"
  "\x4f\x28\x81\xa5\x02\x4e\x26\x81\xa3\x02\x4d\x24\x81\xa1\x02\x4c"
  "\x22\x81\x9f\x02\x4b\x20\x81\x9d\x02\x4a\x1e\x81\x9b\x02\x49\x1c"
  "\x81\x99\x02\x48\x1a\x81\x97\x02\x47\x18\x81\x95\x02\x46\x16\x81"
  "\x93\x02\x45\x14\x81\x91\x02\x44\x12\x81\x8f\x02\x43\x10\x81\x8d"
  "\x02\x42\x0e\x81\x8b\x02\x41\x0c\x81\x89\x02\x40\x0a\x81\x87\x02"
  "\x3f\x08\x81\x81\x02\x3e\x06\x81\x83\x02\x3d\x04\x82\x02\x41\x7b"
  "\x40\x02\x5d\x04\x82\x02\x03\x41\x02\x0c\x25\x72\x65\x63\x6f\x72"
  "\x64\x2d\x72\x65\x66\x42\x5e\x04\x83\x04\x03\x43\x02\x02\x03\x10"
  "\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x3f\x44"
  "\x04\x19\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x75\x6e\x70\x61"
  "\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x45\x03\x60\x06\x81\x85"
  "\x02\x5f\x04\x84\x04\x05\x0e\x46\x02\x08\x0f\x75\x6e\x70\x61\x72"
  "\x73\x65\x72\x20\x74\x61\x62\x6c\x65\x05\x1a\x65\x72\x72\x6f\x72"
  "\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61\x72\x67\x75"
  "\x6d\x65\x6e\x74\x47\x02\x61\x04\x84\x04\x03\x0c\x48\x02\x08\x02"
  "\x1a\x6d\x69\x63\x72\x6f\x63\x6f\x64\x65\x2d\x74\x79\x70\x65\x2f"
  "\x63\x6f\x64\x65\x2d\x6c\x69\x6d\x69\x74\x03\x15\x25\x6d\x61\x6b"
  "\x65\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65"
  "\x49\x04\x0c\x6d\x61\x6b\x65\x2d\x76\x65\x63\x74\x6f\x72\x04\x64"
  "\x08\x81\x87\x02\x63\x06\x81\x83\x02\x62\x04\x83\x04\x07\x11\x4a"
  "\x02\x09\x42\x03\x49\x02\x66\x06\x81\x83\x02\x65\x04\x83\x04\x05"
  "\x0d\x4b\x02\x0a\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x4c"
  "\x42\x03\x0f\x6d\x69\x63\x72\x6f\x63\x6f\x64\x65\x2d\x74\x79\x70"
  "\x65\x4d\x02\x69\x08\x81\x85\x02\x68\x06\x81\x85\x02\x67\x04\x84"
  "\x06\x07\x10\x4e\x02\x0b\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65"
  "\x74\x21\x02\x42\x03\x4d\x02\x6c\x08\x81\x87\x02\x6b\x06\x81\x87"
  "\x02\x6a\x04\x85\x08\x07\x11\x4d\x02\x0c\x6d\x04\x82\x02\x03\x4f"
  "\x02\x0d\x6e\x04\x82\x02\x03\x50\x02\x0e\x6f\x04\x82\x02\x03\x51"
  "\x02\x0f\x70\x04\x82\x02\x03\x52\x02\x10\x42\x71\x04\x83\x04\x03"
  "\x53\x02\x11\x42\x72\x04\x83\x04\x03\x54\x02\x12\x42\x73\x04\x83"
  "\x04\x03\x55\x02\x13\x42\x74\x04\x83\x04\x03\x56\x02\x14\x02\x03"
  "\x10\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x3f"
  "\x57\x04\x19\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x75\x6e\x70"
  "\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x58\x03\x76\x06\x81"
  "\x85\x02\x75\x04\x84\x04\x05\x0e\x59\x02\x15\x08\x0f\x75\x6e\x70"
  "\x61\x72\x73\x65\x72\x20\x73\x74\x61\x74\x65\x05\x47\x02\x77\x04"
  "\x84\x04\x03\x0c\x47\x02\x16\x02\x42\x1c\x77\x69\x74\x68\x2d\x63"
  "\x75\x72\x72\x65\x6e\x74\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d"
  "\x73\x74\x61\x74\x65\x5a\x11\x02\x11\x02\x04\x19\x67\x75\x61\x72"
  "\x61\x6e\x74\x65\x65\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73"
  "\x74\x61\x74\x65\x5b\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66"
  "\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x5c\x03\x81\x01\x16\x81\x87"
  "\x02\x80\x01\x14\x81\x85\x02\x7f\x12\x81\x83\x02\x7e\x10\x81\x87"
  "\x02\x7d\x0e\x81\x85\x02\x7c\x0c\x81\x83\x02\x7b\x0a\x81\x85\x02"
  "\x7a\x08\x81\x83\x02\x79\x06\x81\x85\x02\x78\x04\x84\x06\x15\x25"
  "\x5d\x02\x17\x42\x0d\x75\x6e\x70\x61\x72\x73\x65\x2d\x63\x68\x61"
  "\x72\x5e\x04\x5b\x04\x0b\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72"
  "\x03\x84\x01\x08\x81\x85\x02\x83\x01\x06\x81\x85\x02\x82\x01\x04"
  "\x84\x06\x07\x12\x5f\x02\x18\x42\x0f\x75\x6e\x70\x61\x72\x73\x65"
  "\x2d\x73\x74\x72\x69\x6e\x67\x60\x04\x5b\x04\x0d\x77\x72\x69\x74"
  "\x65\x2d\x73\x74\x72\x69\x6e\x67\x03\x87\x01\x08\x81\x85\x02\x86"
  "\x01\x06\x81\x85\x02\x85\x01\x04\x84\x06\x07\x12\x61\x02\x19\x42"
  "\x0f\x75\x6e\x70\x61\x72\x73\x65\x2d\x6f\x62\x6a\x65\x63\x74\x62"
  "\x04\x5b\x07\x18\x75\x6e\x70\x61\x72\x73\x65\x2d\x6f\x62\x6a\x65"
  "\x63\x74\x2f\x69\x6e\x74\x65\x72\x6e\x61\x6c\x63\x03\x8d\x01\x0e"
  "\x81\x8b\x02\x8c\x01\x0c\x81\x8b\x02\x8b\x01\x0a\x81\x87\x02\x8a"
  "\x01\x08\x81\x85\x02\x89\x01\x06\x81\x85\x02\x88\x01\x04\x84\x06"
  "\x0d\x1b\x64\x02\x1a\x08\x42\x11\x02\x04\x16\x67\x75\x61\x72\x61"
  "\x6e\x74\x65\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x02\x19\x6e\x65\x61\x72\x65\x73\x74\x2d\x72\x65\x70\x6c\x2f\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x07\x63\x03\x44\x05\x9b"
  "\x01\x1e\x81\x8d\x02\x9a\x01\x1c\x81\x8d\x02\x99\x01\x1a\x81\x8d"
  "\x02\x98\x01\x18\x81\x8d\x02\x97\x01\x16\x81\x8d\x02\x96\x01\x14"
  "\x81\x8d\x02\x95\x01\x12\x86\x0a\x94\x01\x10\x81\x8b\x02\x93\x01"
  "\x0e\x81\x8d\x02\x92\x01\x0c\x81\x8d\x02\x91\x01\x0a\x81\x8d\x02"
  "\x90\x01\x08\x81\x8d\x02\x8f\x01\x06\x81\x8b\x02\x8e\x01\x04\x81"
  "\x8d\x02\x1d\x30\x65\x02\x1b\x02\x42\x10\x0e\x2a\x6f\x75\x74\x70"
  "\x75\x74\x2d\x70\x6f\x72\x74\x2a\x66\x0d\x2a\x6c\x69\x73\x74\x2d"
  "\x64\x65\x70\x74\x68\x2a\x67\x0c\x2a\x73\x6c\x61\x73\x68\x69\x66"
  "\x79\x3f\x2a\x68\x0e\x2a\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2a\x69\x11\x2a\x64\x69\x73\x70\x61\x74\x63\x68\x2d\x74\x61"
  "\x62\x6c\x65\x2a\x6a\x06\x66\x67\x68\x69\x6a\x06\x04\x13\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x6c\x6f\x6f\x6b\x75\x70"
  "\x6b\x04\x19\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x75\x6e\x70"
  "\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x6c\x05\x5c\x03\x10"
  "\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x6f\x62\x6a\x65\x63\x74\x6d"
  "\x05\xb6\x01\x38\x81\x87\x02\xb5\x01\x36\x81\x85\x02\xb4\x01\x34"
  "\x81\x87\x02\xb3\x01\x32\x81\x85\x02\xb2\x01\x30\x81\x87\x02\xb1"
  "\x01\x2e\x81\x85\x02\xb0\x01\x2c\x81\x87\x02\xaf\x01\x2a\x81\x85"
  "\x02\xae\x01\x28\x81\x87\x02\xad\x01\x26\x81\x85\x02\xac\x01\x24"
  "\x81\x83\x02\xab\x01\x22\x81\x83\x02\xaa\x01\x20\x81\x87\x02\xa9"
  "\x01\x1e\x81\x85\x02\xa8\x01\x1c\x81\x87\x02\xa7\x01\x1a\x81\x85"
  "\x02\xa6\x01\x18\x81\x87\x02\xa5\x01\x16\x81\x85\x02\xa4\x01\x14"
  "\x81\x87\x02\xa3\x01\x12\x81\x85\x02\xa2\x01\x10\x81\x87\x02\xa1"
  "\x01\x0e\x81\x85\x02\xa0\x01\x0c\x81\x83\x02\x9f\x01\x0a\x81\x95"
  "\x02\x9e\x01\x08\x81\x97\x02\x9d\x01\x06\x81\x95\x02\x9c\x01\x04"
  "\x87\x0c\x37\x53\x6e\x02\x1c\x69\x68\x67\x66\x05\x06\x14\x6d\x61"
  "\x6b\x65\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74"
  "\x65\x6f\x02\xbc\x01\x0e\x81\x87\x02\xbb\x01\x0c\x81\x8f\x02\xba"
  "\x01\x0a\x81\x8d\x02\xb9\x01\x08\x81\x8b\x02\xb8\x01\x06\x81\x89"
  "\x02\xb7\x01\x04\x84\x06\x0d\x18\x70\x02\x1d\x4c\x6a\x02\xbf\x01"
  "\x08\x81\x83\x02\xbe\x01\x06\x81\x83\x02\xbd\x01\x04\x83\x04\x07"
  "\x0d\x71\x02\x1e\x66\x02\x04\x17\x6f\x75\x74\x70\x75\x74\x2d\x70"
  "\x6f\x72\x74\x2f\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x72\x02"
  "\xc1\x01\x06\x81\x83\x02\xc0\x01\x04\x83\x04\x05\x0d\x73\x02\x1f"
  "\x66\x02\x04\x19\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x2f"
  "\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x74\x02\xc3\x01"
  "\x06\x81\x83\x02\xc2\x01\x04\x83\x04\x05\x0d\x75\x02\x20\x66\x02"
  "\x06\x1c\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x2f\x77\x72"
  "\x69\x74\x65\x2d\x73\x75\x62\x73\x74\x72\x69\x6e\x67\x76\x02\xc5"
  "\x01\x06\x81\x87\x02\xc4\x01\x04\x85\x08\x05\x0d\x77\x02\x21\x0d"
  "\x6f\x62\x6a\x65\x63\x74\x2d\x64\x61\x74\x75\x6d\x78\x03\x0d\x2a"
  "\x75\x6e\x70\x61\x72\x73\x65\x2d\x68\x65\x78\x79\x02\xc7\x01\x06"
  "\x81\x83\x02\xc6\x01\x04\x83\x04\x05\x0c\x7a\x02\x22\x11\x03\x23"
  "\x78\x66\x02\x04\x74\x04\x0f\x6e\x75\x6d\x62\x65\x72\x2d\x3e\x73"
  "\x74\x72\x69\x6e\x67\x7b\x03\xcc\x01\x0c\x81\x85\x02\xcb\x01\x0a"
  "\x81\x83\x02\xca\x01\x08\x81\x83\x02\xc9\x01\x06\x81\x87\x02\xc8"
  "\x01\x04\x83\x04\x0b\x17\x7c\x02\x23\x66\x02\x03\x05\x68\x61\x73"
  "\x68\x7d\x04\x74\x03\x7b\x04\xd0\x01\x0a\x81\x87\x02\xcf\x01\x08"
  "\x81\x85\x02\xce\x01\x06\x81\x83\x02\xcd\x01\x04\x83\x04\x09\x15"
  "\x7e\x02\x24\x03\x23\x40\x66\x02\x04\x74\x03\x7d\x03\x7b\x04\xd6"
  "\x01\x0e\x81\x87\x02\xd5\x01\x0c\x81\x85\x02\xd4\x01\x0a\x81\x83"
  "\x02\xd3\x01\x08\x81\x83\x02\xd2\x01\x06\x81\x87\x02\xd1\x01\x04"
  "\x83\x04\x0d\x1a\x7f\x02\x25\x78\x01\x21\x01\x5e\x03\x23\x5b\x0b"
  "\x66\x0d\x04\x04\x74\x03\x17\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d"
  "\x72\x65\x61\x64\x61\x62\x6c\x65\x2d\x68\x61\x73\x68\x80\x01\x03"
  "\x6d\x04\x72\x03\x7d\x03\x7b\x03\x79\x08\xea\x01\x2a\x81\x89\x02"
  "\xe9\x01\x28\x81\x8b\x02\xe8\x01\x26\x81\x8b\x02\xe7\x01\x24\x81"
  "\x89\x02\xe6\x01\x22\x81\x87\x02\xe5\x01\x20\x81\x87\x02\xe4\x01"
  "\x1e\x81\x87\x02\xe3\x01\x1c\x81\x8b\x02\xe2\x01\x1a\x81\x8b\x02"
  "\xe1\x01\x18\x81\x8b\x02\xe0\x01\x16\x81\x87\x02\xdf\x01\x14\x81"
  "\x87\x02\xde\x01\x12\x81\x87\x02\xdd\x01\x10\x81\x87\x02\xdc\x01"
  "\x0e\x81\x87\x02\xdb\x01\x0c\x81\x8b\x02\xda\x01\x0a\x81\x87\x02"
  "\xd9\x01\x08\x81\x8b\x02\xd8\x01\x06\x81\x87\x02\xd7\x01\x04\x85"
  "\x08\x29\x43\x7d\x02\x26\x78\x0c\x6e\x6f\x6e\x2d\x70\x6f\x69\x6e"
  "\x74\x65\x72\x05\x63\x65\x6c\x6c\x05\x70\x61\x69\x72\x07\x74\x72"
  "\x69\x70\x6c\x65\x0a\x71\x75\x61\x64\x72\x75\x70\x6c\x65\x2a\x1b"
  "\x03\x11\x75\x73\x65\x72\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79"
  "\x70\x65\x1b\x03\x0f\x6f\x62\x6a\x65\x63\x74\x2d\x67\x63\x2d\x74"
  "\x79\x70\x65\x04\x05\x6d\x65\x6d\x71\x05\x17\x2a\x75\x6e\x70\x61"
  "\x72\x73\x65\x2d\x77\x69\x74\x68\x2d\x62\x72\x61\x63\x6b\x65\x74"
  "\x73\x81\x01\x03\x79\x06\xf2\x01\x12\x81\x83\x02\xf1\x01\x10\x81"
  "\x83\x02\xf0\x01\x0e\x81\x83\x02\xef\x01\x0c\x81\x83\x02\xee\x01"
  "\x0a\x81\x87\x02\xed\x01\x08\x81\x85\x02\xec\x01\x06\x81\x83\x02"
  "\xeb\x01\x04\x83\x04\x11\x22\x82\x01\x02\x27\x10\x75\x6e\x64\x65"
  "\x66\x69\x6e\x65\x64\x2d\x74\x79\x70\x65\x3a\x03\x1a\x6d\x69\x63"
  "\x72\x6f\x63\x6f\x64\x65\x2d\x74\x79\x70\x65\x2f\x63\x6f\x64\x65"
  "\x2d\x3e\x6e\x61\x6d\x65\x03\x7b\x03\x18\x72\x65\x6e\x61\x6d\x65"
  "\x2d\x75\x73\x65\x72\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70"
  "\x65\x83\x01\x03\x07\x69\x6e\x74\x65\x72\x6e\x04\x0e\x73\x74\x72"
  "\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x06\xf6\x01\x0a\x81\x87"
  "\x02\xf5\x01\x08\x81\x85\x02\xf4\x01\x06\x81\x83\x02\xf3\x01\x04"
  "\x83\x04\x09\x18\x84\x01\x02\x28\x18\x1a\x72\x65\x6e\x61\x6d\x65"
  "\x64\x2d\x75\x73\x65\x72\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79"
  "\x70\x65\x73\x85\x01\x02\x04\x05\x61\x73\x73\x71\x02\xf9\x01\x08"
  "\x81\x83\x02\xf8\x01\x06\x81\x85\x02\xf7\x01\x04\x83\x04\x07\x10"
  "\x86\x01\x02\x29\x03\x23\x66\x66\x02\x04\x74\x03\x2b\x03\xfb\x01"
  "\x06\x81\x83\x02\xfa\x01\x04\x83\x04\x05\x10\x87\x01\x02\x2a\x06"
  "\x23\x21\x65\x6f\x66\x0d\x23\x21\x75\x6e\x73\x70\x65\x63\x69\x66"
  "\x69\x63\x02\x07\x23\x21\x72\x65\x73\x74\x0b\x23\x21\x6f\x70\x74"
  "\x69\x6f\x6e\x61\x6c\x06\x23\x21\x6b\x65\x79\x06\x23\x21\x61\x75"
  "\x78\x0a\x23\x21\x64\x65\x66\x61\x75\x6c\x74\x08\x03\x23\x74\x03"
  "\x28\x29\x66\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x61"
  "\x75\x78\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x6b\x65"
  "\x79\x14\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x6f\x70\x74"
  "\x69\x6f\x6e\x61\x6c\x10\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67"
  "\x3a\x72\x65\x73\x74\x06\x04\x74\x03\x0c\x65\x6f\x66\x2d\x6f\x62"
  "\x6a\x65\x63\x74\x3f\x03\x2b\x04\x8a\x02\x20\x81\x83\x02\x89\x02"
  "\x1e\x81\x83\x02\x88\x02\x1c\x81\x83\x02\x87\x02\x1a\x81\x83\x02"
  "\x86\x02\x18\x81\x83\x02\x85\x02\x16\x81\x83\x02\x84\x02\x14\x81"
  "\x83\x02\x83\x02\x12\x81\x83\x02\x82\x02\x10\x81\x83\x02\x81\x02"
  "\x0e\x81\x83\x02\x80\x02\x0c\x81\x83\x02\xff\x01\x0a\x81\x83\x02"
  "\xfe\x01\x08\x81\x83\x02\xfd\x01\x06\x81\x83\x02\xfc\x01\x04\x83"
  "\x04\x1f\x3c\x88\x01\x02\x2b\x26\x05\x81\x01\x03\x14\x72\x65\x74"
  "\x75\x72\x6e\x2d\x61\x64\x64\x72\x65\x73\x73\x2f\x6e\x61\x6d\x65"
  "\x03\x6d\x04\x8d\x02\x08\x81\x83\x02\x8c\x02\x06\x81\x83\x02\x8b"
  "\x02\x04\x83\x04\x07\x12\x26\x02\x2c\x03\x02\x8e\x02\x04\x83\x04"
  "\x03\x89\x01\x02\x2d\x28\x0a\x02\x05\x81\x01\x03\x14\x03\x91\x02"
  "\x08\x81\x83\x02\x90\x02\x06\x81\x83\x02\x8f\x02\x04\x83\x04\x07"
  "\x12\x8a\x01\x02\x2e\x01\x5d\x01\x7d\x0b\x73\x74\x72\x69\x6e\x67"
  "\x2d\x72\x65\x66\x8b\x01\x0e\x73\x74\x72\x69\x6e\x67\x2d\x6c\x65"
  "\x6e\x67\x74\x68\x8c\x01\x1f\x2a\x70\x61\x72\x73\x65\x72\x2d\x63"
  "\x61\x6e\x6f\x6e\x69\x63\x61\x6c\x69\x7a\x65\x2d\x73\x79\x6d\x62"
  "\x6f\x6c\x73\x3f\x2a\x69\x66\x18\x63\x68\x61\x72\x2d\x73\x65\x74"
  "\x2f\x6e\x75\x6d\x62\x65\x72\x2d\x6c\x65\x61\x64\x65\x72\x73\x12"
  "\x13\x15\x07\x03\x0c\x73\x79\x6d\x62\x6f\x6c\x2d\x6e\x61\x6d\x65"
  "\x04\x6b\x04\x74\x03\x0f\x73\x74\x72\x69\x6e\x67\x2d\x3e\x6e\x75"
  "\x6d\x62\x65\x72\x04\x11\x63\x68\x61\x72\x2d\x73\x65\x74\x2d\x6d"
  "\x65\x6d\x62\x65\x72\x3f\x04\x72\x04\x1d\x73\x74\x72\x69\x6e\x67"
  "\x2d\x66\x69\x6e\x64\x2d\x6e\x65\x78\x74\x2d\x63\x68\x61\x72\x2d"
  "\x69\x6e\x2d\x73\x65\x74\x06\x20\x73\x75\x62\x73\x74\x72\x69\x6e"
  "\x67\x2d\x66\x69\x6e\x64\x2d\x6e\x65\x78\x74\x2d\x63\x68\x61\x72"
  "\x2d\x69\x6e\x2d\x73\x65\x74\x6b\x06\x76\x0a\xae\x02\x3c\x81\x87"
  "\x02\xad\x02\x3a\x81\x8b\x02\xac\x02\x38\x81\x89\x02\xab\x02\x36"
  "\x81\x87\x02\xaa\x02\x34\x81\x8b\x02\xa9\x02\x32\x81\x87\x02\xa8"
  "\x02\x30\x81\x8f\x02\xa7\x02\x2e\x81\x87\x02\xa6\x02\x2c\x81\x85"
  "\x02\xa5\x02\x2a\x81\x83\x02\xa4\x02\x28\x81\x83\x02\xa3\x02\x26"
  "\x81\x87\x02\xa2\x02\x24\x81\x85\x02\xa1\x02\x22\x81\x85\x02\xa0"
  "\x02\x20\x81\x83\x02\x9f\x02\x1e\x81\x85\x02\x9e\x02\x1c\x81\x85"
  "\x02\x9d\x02\x1a\x81\x85\x02\x9c\x02\x18\x81\x87\x02\x9b\x02\x16"
  "\x81\x87\x02\x9a\x02\x14\x81\x85\x02\x99\x02\x12\x81\x83\x02\x98"
  "\x02\x10\x81\x83\x02\x97\x02\x0e\x81\x83\x02\x96\x02\x0c\x81\x83"
  "\x02\x95\x02\x0a\x81\x83\x02\x94\x02\x08\x81\x89\x02\x93\x02\x06"
  "\x81\x83\x02\x92\x02\x04\x83\x04\x3b\x5e\x15\x02\x2f\x03\x23\x5c"
  "\x68\x66\x03\x03\x0c\x63\x68\x61\x72\x2d\x61\x73\x63\x69\x69\x3f"
  "\x04\x74\x04\x0b\x63\x68\x61\x72\x2d\x3e\x6e\x61\x6d\x65\x04\x72"
  "\x05\xba\x02\x1a\x81\x85\x02\xb9\x02\x18\x81\x83\x02\xb8\x02\x16"
  "\x81\x83\x02\xb7\x02\x14\x81\x85\x02\xb6\x02\x12\x81\x83\x02\xb5"
  "\x02\x10\x81\x87\x02\xb4\x02\x0e\x81\x83\x02\xb3\x02\x0c\x81\x83"
  "\x02\xb2\x02\x0a\x81\x83\x02\xb1\x02\x08\x81\x87\x02\xb0\x02\x06"
  "\x81\x83\x02\xaf\x02\x04\x83\x04\x19\x2a\x8d\x01\x02\x30\x01\x62"
  "\x01\x08\x01\x67\x01\x0d\x01\x73\x01\x0e\x01\x63\x01\x09\x01\x77"
  "\x01\x0c\x01\x75\x01\x0a\x01\x6f\x01\x0b\x8b\x01\x01\x5d\x04\x2e"
  "\x2e\x2e\x01\x23\x8c\x01\x68\x66\x05\x04\x74\x04\x72\x04\x04\x6d"
  "\x69\x6e\x8c\x01\x06\x6b\x06\x76\x03\x0c\x63\x68\x61\x72\x2d\x3e"
  "\x6f\x63\x74\x61\x6c\x8b\x01\x07\xe1\x02\x50\x81\x85\x02\xe0\x02"
  "\x4e\x81\x85\x02\xdf\x02\x4c\x81\x85\x02\xde\x02\x4a\x81\x83\x02"
  "\xdd\x02\x48\x81\x83\x02\xdc\x02\x46\x81\x83\x02\xdb\x02\x44\x81"
  "\x83\x02\xda\x02\x42\x81\x83\x02\xd9\x02\x40\x81\x83\x02\xd8\x02"
  "\x3e\x81\x83\x02\xd7\x02\x3c\x81\x83\x02\xd6\x02\x3a\x81\x83\x02"
  "\xd5\x02\x38\x81\x83\x02\xd4\x02\x36\x81\x87\x02\xd3\x02\x34\x81"
  "\x85\x02\xd2\x02\x32\x81\x89\x02\xd1\x02\x30\x81\x85\x02\xd0\x02"
  "\x2e\x81\x8d\x02\xcf\x02\x2c\x81\x87\x02\xce\x02\x2a\x81\x83\x02"
  "\xcd\x02\x28\x81\x85\x02\xcc\x02\x26\x81\x83\x02\xcb\x02\x24\x81"
  "\x8b\x02\xca\x02\x22\x81\x87\x02\xc9\x02\x20\x81\x87\x02\xc8\x02"
  "\x1e\x81\x87\x02\xc7\x02\x1c\x81\x87\x02\xc6\x02\x1a\x81\x8f\x02"
  "\xc5\x02\x18\x81\x87\x02\xc4\x02\x16\x81\x89\x02\xc3\x02\x14\x81"
  "\x87\x02\xc2\x02\x12\x81\x89\x02\xc1\x02\x10\x81\x8b\x02\xc0\x02"
  "\x0e\x81\x87\x02\xbf\x02\x0c\x81\x83\x02\xbe\x02\x0a\x81\x83\x02"
  "\xbd\x02\x08\x81\x83\x02\xbc\x02\x06\x83\x04\xbb\x02\x04\x81\x85"
  "\x02\x4f\x78\x76\x02\x31\x09\x03\x0c\x63\x68\x61\x72\x2d\x3e\x61"
  "\x73\x63\x69\x69\x03\x18\x69\x6e\x74\x65\x67\x65\x72\x2d\x64\x69"
  "\x76\x69\x64\x65\x2d\x71\x75\x6f\x74\x69\x65\x6e\x74\x04\x0f\x69"
  "\x6e\x74\x65\x67\x65\x72\x2d\x64\x69\x76\x69\x64\x65\x03\x19\x69"
  "\x6e\x74\x65\x67\x65\x72\x2d\x64\x69\x76\x69\x64\x65\x2d\x72\x65"
  "\x6d\x61\x69\x6e\x64\x65\x72\x04\x0c\x64\x69\x67\x69\x74\x2d\x3e"
  "\x63\x68\x61\x72\x05\x27\x07\xec\x02\x18\x81\x8b\x02\xeb\x02\x16"
  "\x81\x87\x02\xea\x02\x14\x81\x8b\x02\xe9\x02\x12\x81\x87\x02\xe8"
  "\x02\x10\x81\x89\x02\xe7\x02\x0e\x81\x85\x02\xe6\x02\x0c\x81\x87"
  "\x02\xe5\x02\x0a\x81\x83\x02\xe4\x02\x08\x81\x87\x02\xe3\x02\x06"
  "\x81\x83\x02\xe2\x02\x04\x83\x04\x17\x28\x6b\x02\x32\x01\x32\x01"
  "\x31\x0f\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x72\x65\x66"
  "\x02\x12\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x6c\x65\x6e"
  "\x67\x74\x68\x03\x23\x2a\x66\x02\x04\x74\x04\x72\x03\xf4\x02\x12"
  "\x81\x89\x02\xf3\x02\x10\x81\x87\x02\xf2\x02\x0e\x81\x85\x02\xf1"
  "\x02\x0c\x81\x85\x02\xf0\x02\x0a\x81\x83\x02\xef\x02\x08\x81\x83"
  "\x02\xee\x02\x06\x81\x87\x02\xed\x02\x04\x83\x04\x11\x21\x27\x02"
  "\x33\x69\x68\x67\x66\x05\x03\x18\x75\x6e\x70\x61\x72\x73\x65\x2d"
  "\x76\x65\x63\x74\x6f\x72\x2f\x75\x6e\x70\x61\x72\x73\x65\x72\x8e"
  "\x01\x03\x16\x75\x6e\x70\x61\x72\x73\x65\x2d\x76\x65\x63\x74\x6f"
  "\x72\x2f\x6e\x6f\x72\x6d\x61\x6c\x8f\x01\x06\x6f\x04\xfb\x02\x10"
  "\x81\x87\x02\xfa\x02\x0e\x81\x8f\x02\xf9\x02\x0c\x81\x8d\x02\xf8"
  "\x02\x0a\x81\x8b\x02\xf7\x02\x08\x81\x89\x02\xf6\x02\x06\x81\x83"
  "\x02\xf5\x02\x04\x83\x04\x0f\x1e\x90\x01\x02\x34\x2a\x0e\x76\x65"
  "\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x2a\x04\x10\x73\x61"
  "\x66\x65\x2d\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x91\x01\x04"
  "\x1e\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2d\x74\x61\x67\x2f\x75"
  "\x6e\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x92\x01"
  "\x03\x1e\x75\x6e\x70\x61\x72\x73\x65\x72\x2f\x74\x61\x67\x67\x65"
  "\x64\x2d\x76\x65\x63\x74\x6f\x72\x2d\x6d\x65\x74\x68\x6f\x64\x04"
  "\xff\x02\x0a\x81\x83\x02\xfe\x02\x08\x81\x83\x02\xfd\x02\x06\x81"
  "\x83\x02\xfc\x02\x04\x83\x04\x09\x16\x93\x01\x02\x35\x06\x20\x2e"
  "\x2e\x2e\x29\x01\x21\x01\x2a\x04\x23\x28\x29\x03\x23\x28\x2a\x66"
  "\x03\x03\x14\x6c\x69\x6d\x69\x74\x2d\x75\x6e\x70\x61\x72\x73\x65"
  "\x2d\x64\x65\x70\x74\x68\x2a\x04\x74\x04\x91\x01\x03\x6d\x04\x72"
  "\x06\x95\x03\x2e\x81\x89\x02\x94\x03\x2c\x81\x87\x02\x93\x03\x2a"
  "\x81\x89\x02\x92\x03\x28\x81\x87\x02\x91\x03\x26\x81\x87\x02\x90"
  "\x03\x24\x81\x87\x02\x8f\x03\x22\x81\x8b\x02\x8e\x03\x20\x81\x87"
  "\x02\x8d\x03\x1e\x81\x87\x02\x8c\x03\x1c\x81\x87\x02\x8b\x03\x1a"
  "\x81\x8b\x02\x8a\x03\x18\x81\x87\x02\x89\x03\x16\x81\x87\x02\x88"
  "\x03\x14\x81\x87\x02\x87\x03\x12\x81\x87\x02\x86\x03\x10\x81\x85"
  "\x02\x85\x03\x0e\x81\x85\x02\x84\x03\x0c\x81\x85\x02\x83\x03\x0a"
  "\x81\x89\x02\x82\x03\x08\x81\x83\x02\x81\x03\x06\x81\x83\x02\x80"
  "\x03\x04\x83\x04\x2d\x46\x94\x01\x02\x36\x0d\x6f\x62\x6a\x65\x63"
  "\x74\x2d\x74\x79\x70\x65\x3f\x95\x01\x4c\x28\x2c\x41\x74\x74\x65"
  "\x6d\x70\x74\x20\x74\x6f\x20\x75\x6e\x70\x61\x72\x73\x65\x20\x70"
  "\x61\x72\x74\x69\x61\x6c\x6c\x79\x20\x6d\x61\x72\x6b\x65\x64\x20"
  "\x76\x65\x63\x74\x6f\x72\x2e\x03\x1e\x77\x69\x74\x68\x2d\x61\x62"
  "\x73\x6f\x6c\x75\x74\x65\x6c\x79\x2d\x6e\x6f\x2d\x69\x6e\x74\x65"
  "\x72\x72\x75\x70\x74\x73\x03\x13\x6d\x61\x70\x2d\x72\x65\x66\x65"
  "\x72\x65\x6e\x63\x65\x2d\x74\x72\x61\x70\x4c\x03\x06\x65\x72\x72"
  "\x6f\x72\x04\x9b\x03\x0e\x81\x83\x02\x9a\x03\x0c\x81\x85\x02\x99"
  "\x03\x0a\x81\x83\x02\x98\x03\x08\x81\x85\x02\x97\x03\x06\x81\x85"
  "\x02\x96\x03\x04\x84\x06\x0d\x1c\x96\x01\x02\x37\x0b\x69\x68\x67"
  "\x66\x06\x06\x6f\x03\x80\x01\x04\x0f\x75\x6e\x70\x61\x72\x73\x65"
  "\x2d\x72\x65\x63\x6f\x72\x64\x04\xa2\x03\x10\x81\x83\x02\xa1\x03"
  "\x0e\x81\x8b\x02\xa0\x03\x0c\x81\x89\x02\x9f\x03\x0a\x81\x87\x02"
  "\x9e\x03\x08\x81\x85\x02\x9d\x03\x06\x81\x83\x02\x9c\x03\x04\x83"
  "\x04\x0f\x1f\x97\x01\x02\x38\x69\x68\x67\x66\x05\x03\x1a\x75\x6e"
  "\x70\x61\x72\x73\x65\x2d\x6c\x69\x73\x74\x2f\x70\x72\x65\x66\x69"
  "\x78\x2d\x70\x61\x69\x72\x3f\x98\x01\x03\x16\x75\x6e\x70\x61\x72"
  "\x73\x65\x2d\x6c\x69\x73\x74\x2f\x75\x6e\x70\x61\x72\x73\x65\x72"
  "\x99\x01\x04\x19\x75\x6e\x70\x61\x72\x73\x65\x2d\x6c\x69\x73\x74"
  "\x2f\x70\x72\x65\x66\x69\x78\x2d\x70\x61\x69\x72\x9a\x01\x03\x0d"
  "\x75\x6e\x70\x61\x72\x73\x65\x2d\x6c\x69\x73\x74\x9b\x01\x06\x6f"
  "\x06\xaa\x03\x12\x81\x87\x02\xa9\x03\x10\x81\x8f\x02\xa8\x03\x0e"
  "\x81\x8d\x02\xa7\x03\x0c\x81\x8b\x02\xa6\x03\x0a\x81\x89\x02\xa5"
  "\x03\x08\x81\x85\x02\xa4\x03\x06\x81\x83\x02\xa3\x03\x04\x83\x04"
  "\x11\x24\x9c\x01\x02\x39\x01\x2a\x01\x29\x66\x02\x03\x2a\x04\x72"
  "\x03\x09\x73\x61\x66\x65\x2d\x63\x61\x72\x9d\x01\x03\x09\x73\x61"
  "\x66\x65\x2d\x63\x64\x72\x9e\x01\x03\x6d\x04\x0d\x75\x6e\x70\x61"
  "\x72\x73\x65\x2d\x74\x61\x69\x6c\x9f\x01\x07\xb3\x03\x14\x81\x87"
  "\x02\xb2\x03\x12\x81\x83\x02\xb1\x03\x10\x81\x83\x02\xb0\x03\x0e"
  "\x81\x85\x02\xaf\x03\x0c\x81\x83\x02\xae\x03\x0a\x81\x83\x02\xad"
  "\x03\x08\x81\x87\x02\xac\x03\x06\x81\x83\x02\xab\x03\x04\x83\x04"
  "\x13\x28\xa0\x01\x02\x3a\x04\x2e\x2e\x2e\x02\x67\x02\x67\x66\x04"
  "\x05\x5c\x04\x74\x03\xc2\x03\x20\x81\x87\x02\xc1\x03\x1e\x81\x85"
  "\x02\xc0\x03\x1c\x81\x83\x02\xbf\x03\x1a\x81\x83\x02\xbe\x03\x18"
  "\x81\x83\x02\xbd\x03\x16\x81\x85\x02\xbc\x03\x14\x81\x83\x02\xbb"
  "\x03\x12\x81\x83\x02\xba\x03\x10\x81\x87\x02\xb9\x03\x0e\x81\x85"
  "\x02\xb8\x03\x0c\x81\x83\x02\xb7\x03\x0a\x81\x85\x02\xb6\x03\x08"
  "\x81\x85\x02\xb5\x03\x06\x81\x83\x02\xb4\x03\x04\x83\x04\x1f\x2f"
  "\x5c\x02\x3b\x05\x20\x2e\x2e\x2e\x01\x21\x04\x20\x2e\x20\x02\x66"
  "\x69\x68\x67\x06\x03\x99\x01\x04\x74\x03\x6d\x04\x72\x06\x6f\x03"
  "\x9d\x01\x03\x9e\x01\x04\x9f\x01\x09\xdc\x03\x36\x81\x87\x02\xdb"
  "\x03\x34\x81\x87\x02\xda\x03\x32\x81\x87\x02\xd9\x03\x30\x81\x87"
  "\x02\xd8\x03\x2e\x81\x87\x02\xd7\x03\x2c\x81\x87\x02\xd6\x03\x2a"
  "\x81\x87\x02\xd5\x03\x28\x81\x87\x02\xd4\x03\x26\x81\x89\x02\xd3"
  "\x03\x24\x81\x87\x02\xd2\x03\x22\x81\x87\x02\xd1\x03\x20\x81\x87"
  "\x02\xd0\x03\x1e\x81\x87\x02\xcf\x03\x1c\x81\x87\x02\xce\x03\x1a"
  "\x81\x87\x02\xcd\x03\x18\x81\x8f\x02\xcc\x03\x16\x81\x8d\x02\xcb"
  "\x03\x14\x81\x8b\x02\xca\x03\x12\x81\x89\x02\xc9\x03\x10\x81\x87"
  "\x02\xc8\x03\x0e\x81\x8b\x02\xc7\x03\x0c\x81\x8b\x02\xc6\x03\x0a"
  "\x81\x85\x02\xc5\x03\x08\x81\x85\x02\xc4\x03\x06\x81\x89\x02\xc3"
  "\x03\x04\x84\x06\x35\x54\xa1\x01\x02\x3c\x21\x03\x9d\x01\x04\x92"
  "\x01\x03\x1c\x75\x6e\x70\x61\x72\x73\x65\x72\x2f\x74\x61\x67\x67"
  "\x65\x64\x2d\x70\x61\x69\x72\x2d\x6d\x65\x74\x68\x6f\x64\x04\xdf"
  "\x03\x08\x81\x83\x02\xde\x03\x06\x81\x83\x02\xdd\x03\x04\x83\x04"
  "\x07\x12\x92\x01\x02\x3d\x66\x02\x04\x74\x03\x9e\x01\x03\x6d\x03"
  "\x9d\x01\x05\xe4\x03\x0c\x81\x87\x02\xe3\x03\x0a\x81\x85\x02\xe2"
  "\x03\x08\x81\x85\x02\xe1\x03\x06\x81\x89\x02\xe0\x03\x04\x84\x06"
  "\x0b\x19\x21\x02\x3e\x03\x2c\x40\x11\x75\x6e\x71\x75\x6f\x74\x65"
  "\x2d\x73\x70\x6c\x69\x63\x69\x6e\x67\x02\x2c\x08\x75\x6e\x71\x75"
  "\x6f\x74\x65\x02\x60\x0b\x71\x75\x61\x73\x69\x71\x75\x6f\x74\x65"
  "\x02\x27\x06\x71\x75\x6f\x74\x65\x0e\x02\x03\x9e\x01\x03\x9d\x01"
  "\x03\xea\x03\x0e\x81\x83\x02\xe9\x03\x0c\x81\x85\x02\xe8\x03\x0a"
  "\x81\x83\x02\xe7\x03\x08\x81\x83\x02\xe6\x03\x06\x81\x83\x02\xe5"
  "\x03\x04\x83\x04\x0d\x20\xa2\x01\x02\x3f\x19\x03\x4c\x02\xec\x03"
  "\x06\x81\x83\x02\xeb\x03\x04\x83\x04\x05\x0c\x19\x02\x40\x18\x03"
  "\x4c\x02\xee\x03\x06\x81\x83\x02\xed\x03\x04\x83\x04\x05\x0c\x4c"
  "\x02\x41\x12\x67\x65\x6e\x65\x72\x69\x63\x2d\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x69\x68\x67\x66\x06\x03\x13\x67\x65\x6e\x65\x72"
  "\x69\x63\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x3f\x06\x6f\x03"
  "\x03\x17\x67\x65\x6e\x65\x72\x69\x63\x2d\x70\x72\x6f\x63\x65\x64"
  "\x75\x72\x65\x2d\x6e\x61\x6d\x65\x05\x81\x01\x03\x6d\x07\xf9\x03"
  "\x18\x81\x83\x02\xf8\x03\x16\x81\x87\x02\xf7\x03\x14\x81\x87\x02"
  "\xf6\x03\x12\x81\x87\x02\xf5\x03\x10\x81\x8f\x02\xf4\x03\x0e\x81"
  "\x8d\x02\xf3\x03\x0c\x81\x8b\x02\xf2\x03\x0a\x81\x89\x02\xf1\x03"
  "\x08\x81\x87\x02\xf0\x03\x06\x84\x06\xef\x03\x04\x81\x85\x02\x17"
  "\x2e\x18\x02\x42\x15\x23\x5b\x75\x6e\x6e\x61\x6d\x65\x64\x2d\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x5d\x13\x63\x6f\x6d\x70\x6f\x75"
  "\x6e\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x0c\x02\x04\x12"
  "\x75\x6e\x70\x61\x72\x73\x65\x2d\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\xa3\x01\x05\x81\x01\x03\x11\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x6c\x61\x6d\x62\x64\x61\x04\x13\x6c\x61\x6d\x62\x64\x61"
  "\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x2a\x03\x6d\x06\x80"
  "\x04\x10\x81\x83\x02\xff\x03\x0e\x81\x8b\x02\xfe\x03\x0c\x87\x0c"
  "\xfd\x03\x0a\x81\x89\x02\xfc\x03\x08\x81\x83\x02\xfb\x03\x06\x81"
  "\x87\x02\xfa\x03\x04\x83\x04\x0f\x21\xa4\x01\x02\x43\x14\x70\x72"
  "\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\xa5\x01\x09\x0b\x03\x04\xa3\x01\x05\x81\x01\x03\x80\x01\x03"
  "\x19\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x2d\x6e\x61\x6d\x65\x03\x6d\x06\x86\x04\x0e\x81"
  "\x83\x02\x85\x04\x0c\x81\x83\x02\x84\x04\x0a\x81\x85\x02\x83\x04"
  "\x08\x81\x85\x02\x82\x04\x06\x81\x83\x02\x81\x04\x04\x83\x04\x0d"
  "\x1f\xa6\x01\x02\x44\x78\x01\x2a\x01\x29\x01\x21\x11\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x64\x2d\x63\x6c\x6f\x73\x75\x72\x65\x1d\x63\x6f"
  "\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x61\x64\x64\x72"
  "\x65\x73\x73\x2d\x3e\x62\x6c\x6f\x63\x6b\x13\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x66\x02\x03"
  "\x14\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x65\x6e\x74\x72\x79\x2d"
  "\x74\x79\x70\x65\x04\xa3\x01\x03\x26\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x64\x2d\x63\x6f\x64\x65\x2d\x62\x6c\x6f\x63\x6b\x2f\x6d\x61\x6e"
  "\x69\x66\x65\x73\x74\x2d\x63\x6c\x6f\x73\x75\x72\x65\x3f\x05\x81"
  "\x01\x03\x22\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x65\x6e\x74\x72"
  "\x79\x2f\x66\x69\x6c\x65\x6e\x61\x6d\x65\x2d\x61\x6e\x64\x2d\x69"
  "\x6e\x64\x65\x78\x03\x18\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2f\x6e\x61\x6d\x65\x78\x04\x72"
  "\x03\x16\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x65\x6e\x74\x72\x79"
  "\x2f\x6f\x66\x66\x73\x65\x74\x03\x79\x03\x0e\x70\x61\x74\x68\x6e"
  "\x61\x6d\x65\x2d\x6e\x61\x6d\x65\x04\x74\x03\x18\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x64\x2d\x63\x6c\x6f\x73\x75\x72\x65\x2d\x3e\x65\x6e"
  "\x74\x72\x79\x03\x6d\x0e\xa8\x04\x46\x81\x87\x02\xa7\x04\x44\x81"
  "\x83\x02\xa6\x04\x42\x81\x87\x02\xa5\x04\x40\x81\x85\x02\xa4\x04"
  "\x3e\x81\x89\x02\xa3\x04\x3c\x81\x83\x02\xa2\x04\x3a\x81\x83\x02"
  "\xa1\x04\x38\x81\x8b\x02\xa0\x04\x36\x81\x8b\x02\x9f\x04\x34\x81"
  "\x87\x02\x9e\x04\x32\x81\x87\x02\x9d\x04\x30\x81\x87\x02\x9c\x04"
  "\x2e\x81\x87\x02\x9b\x04\x2c\x81\x8b\x02\x9a\x04\x2a\x81\x87\x02"
  "\x99\x04\x28\x81\x87\x02\x98\x04\x26\x81\x85\x02\x97\x04\x24\x81"
  "\x87\x02\x96\x04\x22\x81\x87\x02\x95\x04\x20\x81\x83\x02\x94\x04"
  "\x1e\x81\x83\x02\x93\x04\x1c\x81\x8b\x02\x92\x04\x1a\x81\x87\x02"
  "\x91\x04\x18\x81\x83\x02\x90\x04\x16\x81\x83\x02\x8f\x04\x14\x81"
  "\x87\x02\x8e\x04\x12\x81\x83\x02\x8d\x04\x10\x81\x83\x02\x8c\x04"
  "\x0e\x81\x85\x02\x8b\x04\x0c\x81\x83\x02\x8a\x04\x0a\x81\x89\x02"
  "\x89\x04\x08\x81\x83\x02\x88\x04\x06\x81\x87\x02\x87\x04\x04\x83"
  "\x04\x45\x6d\xa7\x01\x02\x45\x29\x05\x81\x01\x03\x0e\x76\x61\x72"
  "\x69\x61\x62\x6c\x65\x2d\x6e\x61\x6d\x65\x03\x6d\x04\xab\x04\x08"
  "\x81\x83\x02\xaa\x04\x06\x81\x83\x02\xa9\x04\x04\x83\x04\x07\x12"
  "\x29\x02\x46\x03\x23\x78\x11\x03\x23\x6f\x09\x03\x23\x62\x0b\x3b"
  "\x0f\x95\x01\x1b\x66\x03\x04\x74\x03\x04\x61\x62\x73\x04\x7b\x04"
  "\xb9\x04\x1e\x81\x85\x02\xb8\x04\x1c\x81\x87\x02\xb7\x04\x1a\x81"
  "\x83\x02\xb6\x04\x18\x83\x04\xb5\x04\x16\x81\x91\x02\xb4\x04\x14"
  "\x81\x83\x02\xb3\x04\x12\x81\x83\x02\xb2\x04\x10\x81\x83\x02\xb1"
  "\x04\x0e\x81\x8d\x02\xb0\x04\x0c\x81\x8d\x02\xaf\x04\x0a\x81\x8d"
  "\x02\xae\x04\x08\x81\x8d\x02\xad\x04\x06\x81\x8d\x02\xac\x04\x04"
  "\x81\x8d\x02\x1d\x37\x95\x01\x02\x47\x03\x18\x75\x6e\x70\x61\x72"
  "\x73\x65\x2f\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x76\x65\x63\x74"
  "\x6f\x72\x7b\x03\x33\x03\xbb\x04\x06\x81\x83\x02\xba\x04\x04\x83"
  "\x04\x05\x0e\xa8\x01\x02\x48\x01\x21\x05\x20\x2e\x2e\x2e\x02\x14"
  "\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x76\x65\x63\x74\x6f\x72\x2d"
  "\x72\x65\x66\x10\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x76\x65\x63"
  "\x74\x6f\x72\x17\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x76\x65\x63"
  "\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x66\x03\x05\x81\x01\x03"
  "\x39\x04\x8c\x01\x04\x74\x04\x72\x06\xcd\x04\x26\x81\x87\x02\xcc"
  "\x04\x24\x81\x87\x02\xcb\x04\x22\x81\x89\x02\xca\x04\x20\x81\x87"
  "\x02\xc9\x04\x1e\x81\x8b\x02\xc8\x04\x1c\x81\x85\x02\xc7\x04\x1a"
  "\x81\x85\x02\xc6\x04\x18\x81\x87\x02\xc5\x04\x16\x81\x87\x02\xc4"
  "\x04\x14\x81\x85\x02\xc3\x04\x12\x81\x85\x02\xc2\x04\x10\x81\x87"
  "\x02\xc1\x04\x0e\x81\x85\x02\xc0\x04\x0c\x81\x83\x02\xbf\x04\x0a"
  "\x81\x83\x02\xbe\x04\x08\x81\x87\x02\xbd\x04\x06\x81\x83\x02\xbc"
  "\x04\x04\x83\x04\x25\x3f\x8c\x01\x02\x49\x1b\x61\x72\x69\x74\x79"
  "\x2d\x64\x69\x73\x70\x61\x74\x63\x68\x65\x64\x2d\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x1d\x0b\x61\x70\x70\x6c\x79\x2d\x68\x6f\x6f"
  "\x6b\x0d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x66\x02"
  "\x03\x0e\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x3f\x03"
  "\x0c\x61\x70\x70\x6c\x79\x2d\x68\x6f\x6f\x6b\x3f\x05\x81\x01\x03"
  "\x1c\x61\x72\x69\x74\x79\x2d\x64\x69\x73\x70\x61\x74\x63\x68\x65"
  "\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x3f\x03\x11\x65\x6e"
  "\x74\x69\x74\x79\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x03\x17"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x61\x64"
  "\x64\x72\x65\x73\x73\x3f\x03\x78\x03\x14\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x3f\x04\x74\x0a"
  "\xd8\x04\x18\x81\x83\x02\xd7\x04\x16\x81\x83\x02\xd6\x04\x14\x81"
  "\x85\x02\xd5\x04\x12\x81\x87\x02\xd4\x04\x10\x81\x87\x02\xd3\x04"
  "\x0e\x81\x83\x02\xd2\x04\x0c\x81\x83\x02\xd1\x04\x0a\x81\x83\x02"
  "\xd0\x04\x08\x81\x85\x02\xcf\x04\x06\x81\x83\x02\xce\x04\x04\x83"
  "\x04\x17\x33\x78\x49\x74\x74\x57\x78\x04\x8c\x01\x04\xa8\x01\x04"
  "\x95\x01\x18\x29\x04\xa7\x01\x04\xa6\x01\x04\xa4\x01\x04\x18\x06"
  "\x4c\x04\x19\x04\xa2\x01\x04\x21\x04\x92\x01\x04\xa1\x01\x04\x5c"
  "\x04\xa0\x01\x04\x9c\x01\x04\x97\x01\x04\x96\x01\x04\x94\x01\x04"
  "\x93\x01\x04\x90\x01\x04\x27\x04\x6b\x04\x76\x06\x8d\x01\x04\x15"
  "\x04\x8a\x01\x04\x89\x01\x04\x26\x04\x88\x01\x04\x87\x01\x04\x22"
  "\x07\x6e\x75\x6d\x62\x65\x72\xa8\x01\x23\xa8\x01\x1a\xa8\x01\x1f"
  "\xa8\x01\x1c\xa8\x01\x20\x07\x73\x79\x6d\x62\x6f\x6c\xa8\x01\x28"
  "\xa8\x01\x1e\x25\x24\xa5\x01\x06\x6c\x65\x78\x70\x72\x07\x6c\x61"
  "\x6d\x62\x64\x61\xa8\x01\x10\x65\x78\x74\x65\x6e\x64\x65\x64\x2d"
  "\x6c\x61\x6d\x62\x64\x61\xa8\x01\x0e\x63\x6f\x6d\x62\x69\x6e\x61"
  "\x74\x69\x6f\x6e\x2d\x31\x0c\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69"
  "\x6f\x6e\xa8\x01\x0e\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e"
  "\x2d\x32\xa8\x01\x18\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x63"
  "\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x30\xa8\x01\x18\x70"
  "\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x63\x6f\x6d\x62\x69\x6e\x61"
  "\x74\x69\x6f\x6e\x2d\x31\xa8\x01\x18\x70\x72\x69\x6d\x69\x74\x69"
  "\x76\x65\x2d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x32"
  "\xa8\x01\x18\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x63\x6f\x6d"
  "\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x33\xa8\x01\x0b\x73\x65\x71"
  "\x75\x65\x6e\x63\x65\x2d\x32\x09\x73\x65\x71\x75\x65\x6e\x63\x65"
  "\xa8\x01\x0b\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x33\xa8\x01\x13"
  "\x86\x01\x04\x84\x01\x04\x82\x01\x04\x7d\x04\x7f\x04\x7e\x04\x7c"
  "\x04\x7a\x04\x77\x04\x75\x04\x73\x04\x71\x04\x70\x04\x6e\x04\x65"
  "\x12\x64\x04\x61\x04\x5f\x04\x5d\x04\x47\x04\x59\x04\x40\x3a\x7b"
  "\x39\x33\x2e\x3c\x35\x34\xa3\x01\x9e\x01\x9d\x01\x98\x01\x9a\x01"
  "\x99\x01\x9f\x01\x2a\x9b\x01\x37\x32\x91\x01\x8f\x01\x8e\x01\x2d"
  "\x2c\x8b\x01\x30\x3d\x14\x2f\x38\x31\x3b\x36\x85\x01\x83\x01\x1b"
  "\x2b\x81\x01\x80\x01\x0e\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x68"
  "\x61\x73\x68\x79\x0f\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x64\x61"
  "\x74\x75\x6d\x13\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d\x73\x75\x62"
  "\x73\x74\x72\x69\x6e\x67\x10\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d"
  "\x73\x74\x72\x69\x6e\x67\x0e\x2a\x75\x6e\x70\x61\x72\x73\x65\x2d"
  "\x63\x68\x61\x72\x66\x6d\x6a\x69\x68\x67\x13\x69\x6e\x76\x6f\x6b"
  "\x65\x2d\x75\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x63\x19\x75"
  "\x6e\x70\x61\x72\x73\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2f\x74\x6f"
  "\x70\x2d\x6c\x65\x76\x65\x6c\x62\x60\x5e\x5a\x58\x5b\x40\x6f\x1b"
  "\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x2f\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x19\x75\x6e\x70\x61\x72"
  "\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x2f\x73\x6c\x61\x73\x68\x69"
  "\x66\x79\x3f\x1a\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61"
  "\x74\x65\x2f\x6c\x69\x73\x74\x2d\x64\x65\x70\x74\x68\x14\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x2f\x70\x6f\x72"
  "\x74\x56\x04\x55\x04\x54\x04\x53\x04\x13\x72\x74\x64\x3a\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\xa8\x01\x42\x0f"
  "\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x73\x74\x61\x74\x65\x05\x70"
  "\x6f\x72\x74\x0b\x6c\x69\x73\x74\x2d\x64\x65\x70\x74\x68\x0a\x73"
  "\x6c\x61\x73\x68\x69\x66\x79\x3f\x0c\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x4f\x04\x50\x04\x51\x04\x52\x04\x44\x3f\x15\x75"
  "\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x2f\x65\x6e"
  "\x74\x72\x79\x14\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62"
  "\x6c\x65\x2f\x63\x6f\x70\x79\x3e\x45\x6c\x4d\x04\x4e\x04\x4b\x04"
  "\x4a\x04\x48\x04\x46\x04\x49\x1f\x75\x6e\x70\x61\x72\x73\x65\x72"
  "\x2d\x74\x61\x62\x6c\x65\x2f\x64\x69\x73\x70\x61\x74\x63\x68\x2d"
  "\x76\x65\x63\x74\x6f\x72\x43\x04\x11\x6c\x6f\x63\x61\x6c\x2d\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x13\x72\x74\x64\x3a\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\xa7\x01\x0f\x75"
  "\x6e\x70\x61\x72\x73\x65\x72\x2d\x74\x61\x62\x6c\x65\x10\x64\x69"
  "\x73\x70\x61\x74\x63\x68\x2d\x76\x65\x63\x74\x6f\x72\x41\x04\x16"
  "\x13\x12\x11\x10\x0f\x0e\x0d\x0c\x0b\x0a\x09\x14\x69\x6e\x69\x74"
  "\x69\x61\x6c\x69\x7a\x65\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x12"
  "\x40\x04\x17\x04\x12\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75"
  "\x6c\x74\x69\x70\x6c\x65\x06\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63"
  "\x6f\x72\x64\x2d\x74\x79\x70\x65\x03\x19\x72\x65\x63\x6f\x72\x64"
  "\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61\x74\x63\x68\x2d\x74"
  "\x61\x67\x04\xa7\x01\xa8\x01\x03\x1d\x3c\x80\x80\x04\x1c\x3a\x81"
  "\x81\x02\x1b\x38\x81\x81\x02\x1a\x36\x81\x85\x02\x19\x34\x81\x85"
  "\x02\x18\x32\x81\x85\x02\x17\x30\x81\x83\x02\x16\x2e\x81\x8b\x02"
  "\x15\x2c\x81\x87\x02\x14\x2a\x81\x83\x02\x13\x28\x81\x85\x02\x12"
  "\x26\x81\x83\x02\x11\x24\x81\x85\x02\x10\x22\x81\x87\x02\x0f\x20"
  "\x81\x83\x02\x0e\x1e\x81\x85\x02\x0d\x1c\x81\x85\x02\x0c\x1a\x81"
  "\x83\x02\x0b\x18\x81\x85\x02\x0a\x16\x81\x83\x02\x09\x14\x81\x85"
  "\x02\x08\x12\x81\x87\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x85\x02"
  "\x05\x0c\x81\x83\x02\x04\x0a\x81\x85\x02\x03\x08\x81\x87\x02\x02"
  "\x06\x81\x83\x02\x01\x04\x81\x83\x02\x3b\x68";

SCHEME_OBJECT *
unpars_so_data_2aaf08d9f878738e (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_unpars_so_data_2aaf08d9f878738e [0]))), (sizeof (prog_unpars_so_data_2aaf08d9f878738e)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_39]));
}

DECLARE_COMPILED_DATA_NS ("unpars.so", unpars_so_data_2aaf08d9f878738e)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("unpars.so", "ad44a733a6d66348")
