/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:22:14-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 5
#define DEBUGGING_LABEL_1_2 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 5
#define DEBUGGING_LABEL_2_2 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 5
#define DEBUGGING_LABEL_4_2 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define TAG_5_6 1
#define LABEL_5_8 7
#define ENVIRONMENT_LABEL_5_3 16
#define DEBUGGING_LABEL_5_2 15
#define EXECUTE_CACHE_5_9 9
#define EXECUTE_CACHE_5_7 11
#define FREE_REFERENCE_5_0 14
#define FREE_REFERENCES_LABEL_5_0 8
#define NUMBER_OF_LINKER_SECTIONS_5_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto common_subexpression_elimination_1;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_5_8);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (common_subexpression_elimination_5)
DEFLABEL (common_subexpression_elimination_1)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_5_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_5_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_8;
  Wrd5 = Wrd9;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_8])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define LABEL_6_7 7
#define TAG_6_8 2
#define LABEL_6_14 9
#define LABEL_6_15 11
#define LABEL_6_16 13
#define LABEL_6_17 15
#define LABEL_6_18 17
#define LABEL_6_19 19
#define LABEL_6_20 21
#define LABEL_6_21 23
#define LABEL_6_9 25
#define TAG_6_10 11
#define LABEL_6_11 27
#define TAG_6_12 12
#define LABEL_6_25 29
#define LABEL_6_26 31
#define LABEL_6_27 33
#define LABEL_6_28 35
#define LABEL_6_29 37
#define LABEL_6_30 39
#define LABEL_6_31 41
#define LABEL_6_32 43
#define LABEL_6_22 45
#define LABEL_6_34 47
#define LABEL_6_23 49
#define LABEL_6_33 51
#define LABEL_6_36 53
#define LABEL_6_43 55
#define LABEL_6_38 57
#define TAG_6_39 27
#define LABEL_6_46 59
#define LABEL_6_47 61
#define LABEL_6_48 63
#define LABEL_6_49 65
#define LABEL_6_50 67
#define LABEL_6_51 69
#define LABEL_6_52 71
#define LABEL_6_53 73
#define LABEL_6_40 75
#define TAG_6_41 36
#define LABEL_6_54 77
#define LABEL_6_55 79
#define LABEL_6_56 81
#define LABEL_6_57 83
#define LABEL_6_58 85
#define LABEL_6_59 87
#define LABEL_6_60 89
#define LABEL_6_61 91
#define LABEL_6_42 93
#define LABEL_6_44 95
#define ENVIRONMENT_LABEL_6_3 136
#define DEBUGGING_LABEL_6_2 135
#define OBJECT_6_3 134
#define OBJECT_6_2 133
#define OBJECT_6_1 132
#define OBJECT_6_0 131
#define EXECUTE_CACHE_6_63 97
#define EXECUTE_CACHE_6_62 99
#define EXECUTE_CACHE_6_45 101
#define EXECUTE_CACHE_6_37 103
#define EXECUTE_CACHE_6_35 105
#define EXECUTE_CACHE_6_24 107
#define EXECUTE_CACHE_6_13 109
#define EXECUTE_CACHE_6_6 111
#define FREE_REFERENCE_6_7 114
#define FREE_REFERENCE_6_6 115
#define FREE_REFERENCE_6_5 116
#define FREE_REFERENCE_6_4 117
#define FREE_REFERENCE_6_3 118
#define FREE_REFERENCE_6_2 119
#define FREE_REFERENCE_6_1 120
#define FREE_REFERENCE_6_0 121
#define FREE_ASSIGNMENT_6_7 123
#define FREE_ASSIGNMENT_6_6 124
#define FREE_ASSIGNMENT_6_5 125
#define FREE_ASSIGNMENT_6_4 126
#define FREE_ASSIGNMENT_6_3 127
#define FREE_ASSIGNMENT_6_2 128
#define FREE_ASSIGNMENT_6_1 129
#define FREE_ASSIGNMENT_6_0 130
#define FREE_REFERENCES_LABEL_6_0 96
#define NUMBER_OF_LINKER_SECTIONS_6_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd50;
  machine_word Wrd61;
  machine_word Wrd62;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd151;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd54;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto cse_rgraph_111;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_6_7);
      goto lambda_149;

    case 3:
      current_block = (Rpc - LABEL_6_14);
      goto label_113;

    case 4:
      current_block = (Rpc - LABEL_6_15);
      goto label_114;

    case 5:
      current_block = (Rpc - LABEL_6_16);
      goto label_115;

    case 6:
      current_block = (Rpc - LABEL_6_17);
      goto label_116;

    case 7:
      current_block = (Rpc - LABEL_6_18);
      goto label_117;

    case 8:
      current_block = (Rpc - LABEL_6_19);
      goto label_118;

    case 9:
      current_block = (Rpc - LABEL_6_20);
      goto label_119;

    case 10:
      current_block = (Rpc - LABEL_6_21);
      goto label_120;

    case 11:
      current_block = (Rpc - LABEL_6_9);
      goto lambda_150;

    case 12:
      current_block = (Rpc - LABEL_6_11);
      goto lambda_151;

    case 13:
      current_block = (Rpc - LABEL_6_25);
      goto label_121;

    case 14:
      current_block = (Rpc - LABEL_6_26);
      goto label_122;

    case 15:
      current_block = (Rpc - LABEL_6_27);
      goto label_123;

    case 16:
      current_block = (Rpc - LABEL_6_28);
      goto label_124;

    case 17:
      current_block = (Rpc - LABEL_6_29);
      goto label_125;

    case 18:
      current_block = (Rpc - LABEL_6_30);
      goto label_126;

    case 19:
      current_block = (Rpc - LABEL_6_31);
      goto label_127;

    case 20:
      current_block = (Rpc - LABEL_6_32);
      goto label_128;

    case 21:
      current_block = (Rpc - LABEL_6_22);
      goto continuation_29;

    case 22:
      current_block = (Rpc - LABEL_6_34);
      goto label_129;

    case 23:
      current_block = (Rpc - LABEL_6_23);
      goto continuation_28;

    case 24:
      current_block = (Rpc - LABEL_6_33);
      goto continuation_31;

    case 25:
      current_block = (Rpc - LABEL_6_36);
      goto lambda_27;

    case 26:
      current_block = (Rpc - LABEL_6_43);
      goto label_130;

    case 27:
      current_block = (Rpc - LABEL_6_38);
      goto lambda_152;

    case 28:
      current_block = (Rpc - LABEL_6_46);
      goto label_131;

    case 29:
      current_block = (Rpc - LABEL_6_47);
      goto label_132;

    case 30:
      current_block = (Rpc - LABEL_6_48);
      goto label_133;

    case 31:
      current_block = (Rpc - LABEL_6_49);
      goto label_134;

    case 32:
      current_block = (Rpc - LABEL_6_50);
      goto label_135;

    case 33:
      current_block = (Rpc - LABEL_6_51);
      goto label_136;

    case 34:
      current_block = (Rpc - LABEL_6_52);
      goto label_137;

    case 35:
      current_block = (Rpc - LABEL_6_53);
      goto label_138;

    case 36:
      current_block = (Rpc - LABEL_6_40);
      goto lambda_153;

    case 37:
      current_block = (Rpc - LABEL_6_54);
      goto label_139;

    case 38:
      current_block = (Rpc - LABEL_6_55);
      goto label_140;

    case 39:
      current_block = (Rpc - LABEL_6_56);
      goto label_141;

    case 40:
      current_block = (Rpc - LABEL_6_57);
      goto label_142;

    case 41:
      current_block = (Rpc - LABEL_6_58);
      goto label_143;

    case 42:
      current_block = (Rpc - LABEL_6_59);
      goto label_144;

    case 43:
      current_block = (Rpc - LABEL_6_60);
      goto label_145;

    case 44:
      current_block = (Rpc - LABEL_6_61);
      goto label_146;

    case 45:
      current_block = (Rpc - LABEL_6_42);
      goto lambda_57;

    case 46:
      current_block = (Rpc - LABEL_6_44);
      goto continuation_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_rgraph_148)
DEFLABEL (cse_rgraph_111)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_6_0]);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd30.pObj) = (& (Rhp [-1]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_5);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_6_1]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd10.pObj) = (& (Rhp [-1]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd58.pObj) = (& (Rhp [-1]));
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd58.pObj)));
  (Rsp [2]) = (Wrd59.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_7])));
  Rhp += 8;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  Wrd30 = Wrd15;
  (Wrd31.Obj) = (Rsp [7]);
  ((Wrd30.pObj) [2]) = (Wrd31.Obj);
  (Wrd29.Obj) = (Rsp [6]);
  ((Wrd30.pObj) [3]) = (Wrd29.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  ((Wrd30.pObj) [4]) = (Wrd27.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  ((Wrd30.pObj) [5]) = (Wrd25.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  ((Wrd30.pObj) [6]) = (Wrd23.Obj);
  ((Wrd30.pObj) [7]) = (Wrd59.Obj);
  ((Wrd30.pObj) [8]) = (Wrd7.Obj);
  ((Wrd30.pObj) [9]) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd34.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_9])));
  Rhp += 1;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd34.pObj)));
  ((Wrd34.pObj) [2]) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd39.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_11])));
  Rhp += 8;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd39.pObj)));
  Wrd54 = Wrd39;
  ((Wrd54.pObj) [2]) = (Wrd31.Obj);
  ((Wrd54.pObj) [3]) = (Wrd29.Obj);
  ((Wrd54.pObj) [4]) = (Wrd27.Obj);
  ((Wrd54.pObj) [5]) = (Wrd25.Obj);
  ((Wrd54.pObj) [6]) = (Wrd23.Obj);
  ((Wrd54.pObj) [7]) = (Wrd59.Obj);
  ((Wrd54.pObj) [8]) = (Wrd7.Obj);
  ((Wrd54.pObj) [9]) = (Wrd11.Obj);
  (Rsp [8]) = (Wrd38.Obj);
  (Rsp [7]) = (Wrd33.Obj);
  (Rsp [6]) = (Wrd14.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_13]));

DEFLABEL (lambda_149)
  CLOSURE_HEADER (LABEL_6_7);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [9]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_179;

DEFLABEL (label_178)
  Wrd19 = Wrd23;

DEFLABEL (label_177)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_176;

DEFLABEL (label_175)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_174)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [8]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_173;

DEFLABEL (label_172)
  Wrd63 = Wrd67;

DEFLABEL (label_171)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_170;

DEFLABEL (label_169)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_168)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [7]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_167;

DEFLABEL (label_166)
  Wrd107 = Wrd111;

DEFLABEL (label_165)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_164;

DEFLABEL (label_163)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_162)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [3]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [6]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_161;

DEFLABEL (label_160)
  Wrd151 = Wrd155;

DEFLABEL (label_159)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_158;

DEFLABEL (label_157)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_156)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [2]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_6_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_158)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_157;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_21])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_120)
  goto label_156;

DEFLABEL (label_161)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_160;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_20])), (Wrd152.pObj));

DEFLABEL (label_119)
  (Wrd151.Obj) = Rvl;
  goto label_159;

DEFLABEL (label_164)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_163;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_19])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_118)
  goto label_162;

DEFLABEL (label_167)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_166;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_18])), (Wrd108.pObj));

DEFLABEL (label_117)
  (Wrd107.Obj) = Rvl;
  goto label_165;

DEFLABEL (label_170)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_169;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_17])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_116)
  goto label_168;

DEFLABEL (label_173)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_172;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_16])), (Wrd64.pObj));

DEFLABEL (label_115)
  (Wrd63.Obj) = Rvl;
  goto label_171;

DEFLABEL (label_176)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_175;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_15])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_114)
  goto label_174;

DEFLABEL (label_179)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_178;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_14])), (Wrd20.pObj));

DEFLABEL (label_113)
  (Wrd19.Obj) = Rvl;
  goto label_177;

DEFLABEL (lambda_150)
  CLOSURE_HEADER (LABEL_6_9);

DEFLABEL (lambda_84)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_24]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_6_23);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_36]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_37]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_6_22);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd30.pObj) = (& (Rhp [-1]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd36.pObj) = (& (Rhp [-1]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_33]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd57.Obj) = (Rsp [7]);
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [2]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 10))
    goto label_181;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd56.Lng))))
    goto label_181;
  (Wrd48.Obj) = ((Wrd54.pObj) [1]);
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_180)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_6_33);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [7]) = (Wrd5.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd50.pObj) = (& (Rhp [-1]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd50.pObj)));
  (Rsp [0]) = (Wrd51.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd54.pObj) = (& (Rhp [-1]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd54.pObj)));
  (Rsp [7]) = (Wrd55.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_39);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_38])));
  Rhp += 8;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd25 = Wrd10;
  ((Wrd25.pObj) [2]) = (Wrd55.Obj);
  (Wrd24.Obj) = (Rsp [6]);
  ((Wrd25.pObj) [3]) = (Wrd24.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  ((Wrd25.pObj) [4]) = (Wrd22.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  ((Wrd25.pObj) [5]) = (Wrd20.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  ((Wrd25.pObj) [6]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [7]) = (Wrd16.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  ((Wrd25.pObj) [8]) = (Wrd14.Obj);
  ((Wrd25.pObj) [9]) = (Wrd51.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_41);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_40])));
  Rhp += 8;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd44 = Wrd29;
  ((Wrd44.pObj) [2]) = (Wrd55.Obj);
  ((Wrd44.pObj) [3]) = (Wrd24.Obj);
  ((Wrd44.pObj) [4]) = (Wrd22.Obj);
  ((Wrd44.pObj) [5]) = (Wrd20.Obj);
  ((Wrd44.pObj) [6]) = (Wrd18.Obj);
  ((Wrd44.pObj) [7]) = (Wrd16.Obj);
  ((Wrd44.pObj) [8]) = (Wrd14.Obj);
  ((Wrd44.pObj) [9]) = (Wrd51.Obj);
  (Rsp [7]) = (Wrd28.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_42]))));
  (Rsp [6]) = (Wrd46.Obj);
  (Rsp [5]) = (Wrd9.Obj);
  Rsp = (& (Rsp [5]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_13]));

DEFLABEL (label_181)
  (Wrd62.Obj) = (Rsp [7]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd61.Obj) = ((Wrd63.pObj) [2]);
  (Wrd64.Obj) = (current_block [OBJECT_6_1]);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_34]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_3]), 2);

DEFLABEL (label_129)
  (* (--Rsp)) = Rvl;
  goto label_180;

DEFLABEL (lambda_151)
  CLOSURE_HEADER (LABEL_6_11);

DEFLABEL (lambda_109)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_205;

DEFLABEL (label_204)
  Wrd19 = Wrd23;

DEFLABEL (label_203)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_202;

DEFLABEL (label_201)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_200)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [9]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_199;

DEFLABEL (label_198)
  Wrd63 = Wrd67;

DEFLABEL (label_197)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_196;

DEFLABEL (label_195)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_194)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [8]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [3]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_193;

DEFLABEL (label_192)
  Wrd107 = Wrd111;

DEFLABEL (label_191)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_190;

DEFLABEL (label_189)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_188)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [7]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [2]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_187;

DEFLABEL (label_186)
  Wrd151 = Wrd155;

DEFLABEL (label_185)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_184;

DEFLABEL (label_183)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_182)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [6]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_6_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_184)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_183;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_32])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_128)
  goto label_182;

DEFLABEL (label_187)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_186;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_31])), (Wrd152.pObj));

DEFLABEL (label_127)
  (Wrd151.Obj) = Rvl;
  goto label_185;

DEFLABEL (label_190)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_189;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_30])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_126)
  goto label_188;

DEFLABEL (label_193)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_192;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_29])), (Wrd108.pObj));

DEFLABEL (label_125)
  (Wrd107.Obj) = Rvl;
  goto label_191;

DEFLABEL (label_196)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_195;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_28])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_124)
  goto label_194;

DEFLABEL (label_199)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_198;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_27])), (Wrd64.pObj));

DEFLABEL (label_123)
  (Wrd63.Obj) = Rvl;
  goto label_197;

DEFLABEL (label_202)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_201;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_26])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_122)
  goto label_200;

DEFLABEL (label_205)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_204;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_25])), (Wrd20.pObj));

DEFLABEL (label_121)
  (Wrd19.Obj) = Rvl;
  goto label_203;

DEFLABEL (lambda_154)
DEFLABEL (lambda_27)
  INTERRUPT_CHECK (26, LABEL_6_36);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_207;
  Wrd5 = Wrd9;

DEFLABEL (label_206)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_44]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_45]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_6_44);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_63]));

DEFLABEL (label_207)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_6_43])), (Wrd6.pObj));

DEFLABEL (label_130)
  (Wrd5.Obj) = Rvl;
  goto label_206;

DEFLABEL (lambda_152)
  CLOSURE_HEADER (LABEL_6_38);

DEFLABEL (lambda_56)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [9]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_4]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_231;

DEFLABEL (label_230)
  Wrd19 = Wrd23;

DEFLABEL (label_229)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_4]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_228;

DEFLABEL (label_227)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_226)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [8]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_5]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_225;

DEFLABEL (label_224)
  Wrd63 = Wrd67;

DEFLABEL (label_223)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_5]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_222;

DEFLABEL (label_221)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_220)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [7]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_6]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_219;

DEFLABEL (label_218)
  Wrd107 = Wrd111;

DEFLABEL (label_217)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_6]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_216;

DEFLABEL (label_215)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_214)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [3]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [6]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_7]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_213;

DEFLABEL (label_212)
  Wrd151 = Wrd155;

DEFLABEL (label_211)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_7]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_210;

DEFLABEL (label_209)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_208)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [2]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_6_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_210)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_209;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_53])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_138)
  goto label_208;

DEFLABEL (label_213)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_212;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_52])), (Wrd152.pObj));

DEFLABEL (label_137)
  (Wrd151.Obj) = Rvl;
  goto label_211;

DEFLABEL (label_216)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_215;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_51])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_136)
  goto label_214;

DEFLABEL (label_219)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_218;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_50])), (Wrd108.pObj));

DEFLABEL (label_135)
  (Wrd107.Obj) = Rvl;
  goto label_217;

DEFLABEL (label_222)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_221;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_49])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_134)
  goto label_220;

DEFLABEL (label_225)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_224;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_48])), (Wrd64.pObj));

DEFLABEL (label_133)
  (Wrd63.Obj) = Rvl;
  goto label_223;

DEFLABEL (label_228)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_227;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_47])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_132)
  goto label_226;

DEFLABEL (label_231)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_230;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_46])), (Wrd20.pObj));

DEFLABEL (label_131)
  (Wrd19.Obj) = Rvl;
  goto label_229;

DEFLABEL (lambda_153)
  CLOSURE_HEADER (LABEL_6_40);

DEFLABEL (lambda_82)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_4]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_255;

DEFLABEL (label_254)
  Wrd19 = Wrd23;

DEFLABEL (label_253)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_4]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_252;

DEFLABEL (label_251)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_250)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [9]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_5]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_249;

DEFLABEL (label_248)
  Wrd63 = Wrd67;

DEFLABEL (label_247)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_5]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_246;

DEFLABEL (label_245)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_244)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [8]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [3]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_6]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_243;

DEFLABEL (label_242)
  Wrd107 = Wrd111;

DEFLABEL (label_241)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_6]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_240;

DEFLABEL (label_239)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_238)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [7]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [2]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_7]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_237;

DEFLABEL (label_236)
  Wrd151 = Wrd155;

DEFLABEL (label_235)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_7]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_234;

DEFLABEL (label_233)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_232)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [6]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_6_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_234)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_233;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_61])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_146)
  goto label_232;

DEFLABEL (label_237)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_236;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_60])), (Wrd152.pObj));

DEFLABEL (label_145)
  (Wrd151.Obj) = Rvl;
  goto label_235;

DEFLABEL (label_240)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_239;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_59])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_144)
  goto label_238;

DEFLABEL (label_243)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_242;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_58])), (Wrd108.pObj));

DEFLABEL (label_143)
  (Wrd107.Obj) = Rvl;
  goto label_241;

DEFLABEL (label_246)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_245;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_57])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_142)
  goto label_244;

DEFLABEL (label_249)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_248;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_56])), (Wrd64.pObj));

DEFLABEL (label_141)
  (Wrd63.Obj) = Rvl;
  goto label_247;

DEFLABEL (label_252)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_251;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_55])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_140)
  goto label_250;

DEFLABEL (label_255)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_254;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_54])), (Wrd20.pObj));

DEFLABEL (label_139)
  (Wrd19.Obj) = Rvl;
  goto label_253;

DEFLABEL (lambda_155)
DEFLABEL (lambda_57)
  INTERRUPT_CHECK (26, LABEL_6_42);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_62]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_7 7
#define LABEL_7_9 9
#define LABEL_7_10 11
#define LABEL_7_11 13
#define LABEL_7_12 15
#define LABEL_7_13 17
#define LABEL_7_14 19
#define LABEL_7_15 21
#define LABEL_7_16 23
#define LABEL_7_17 25
#define LABEL_7_18 27
#define LABEL_7_19 29
#define LABEL_7_20 31
#define LABEL_7_21 33
#define LABEL_7_22 35
#define LABEL_7_23 37
#define LABEL_7_6 39
#define LABEL_7_25 41
#define LABEL_7_28 43
#define LABEL_7_27 45
#define ENVIRONMENT_LABEL_7_3 74
#define DEBUGGING_LABEL_7_2 73
#define OBJECT_7_8 72
#define OBJECT_7_7 71
#define OBJECT_7_6 70
#define OBJECT_7_5 69
#define OBJECT_7_4 68
#define OBJECT_7_3 67
#define OBJECT_7_2 66
#define OBJECT_7_1 65
#define OBJECT_7_0 64
#define EXECUTE_CACHE_7_29 47
#define EXECUTE_CACHE_7_26 49
#define EXECUTE_CACHE_7_24 51
#define EXECUTE_CACHE_7_8 53
#define FREE_REFERENCE_7_1 56
#define FREE_REFERENCE_7_0 57
#define FREE_ASSIGNMENT_7_4 59
#define FREE_ASSIGNMENT_7_3 60
#define FREE_ASSIGNMENT_7_2 61
#define FREE_ASSIGNMENT_7_1 62
#define FREE_ASSIGNMENT_7_0 63
#define FREE_REFERENCES_LABEL_7_0 46
#define NUMBER_OF_LINKER_SECTIONS_7_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd183;
  machine_word Wrd175;
  machine_word Wrd177;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd171;
  machine_word Wrd170;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd146;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd118;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd90;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd62;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd187;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd188;
  machine_word Wrd186;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto continue_walk_15;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto label_17;

    case 2:
      current_block = (Rpc - LABEL_7_7);
      goto label_33;

    case 3:
      current_block = (Rpc - LABEL_7_9);
      goto label_18;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto label_19;

    case 5:
      current_block = (Rpc - LABEL_7_11);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_7_12);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_7_13);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_7_14);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_7_15);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_7_16);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_7_17);
      goto label_26;

    case 12:
      current_block = (Rpc - LABEL_7_18);
      goto label_27;

    case 13:
      current_block = (Rpc - LABEL_7_19);
      goto label_28;

    case 14:
      current_block = (Rpc - LABEL_7_20);
      goto label_29;

    case 15:
      current_block = (Rpc - LABEL_7_21);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_7_22);
      goto label_31;

    case 17:
      current_block = (Rpc - LABEL_7_23);
      goto label_32;

    case 18:
      current_block = (Rpc - LABEL_7_6);
      goto continuation_12;

    case 19:
      current_block = (Rpc - LABEL_7_25);
      goto continuation_13;

    case 20:
      current_block = (Rpc - LABEL_7_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_7_27);
      goto continuation_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (continue_walk_36)
DEFLABEL (continue_walk_15)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_79;
  Wrd6 = Wrd10;

DEFLABEL (label_78)
  if ((Wrd6.Obj) == (current_block [OBJECT_7_0]))
    goto label_72;
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_71;
  Wrd14 = Wrd18;

DEFLABEL (label_70)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_69;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_68)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_67;
  Wrd28 = Wrd32;

DEFLABEL (label_66)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_65;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd34.Obj) = ((Wrd35.pObj) [1]);

DEFLABEL (label_64)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_0]));
  (Wrd49.Obj) = ((Wrd41.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_63;

DEFLABEL (label_62)
  ((Wrd41.pObj) [0]) = (Wrd34.Obj);

DEFLABEL (label_61)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_60;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_59)
  (Wrd71.Obj) = (Rsp [0]);
  (Wrd72.uLng) = (OBJECT_TYPE (Wrd71.Obj));
  if (! ((Wrd72.uLng) == 10))
    goto label_58;
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [0]);
  (Wrd70.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd70.Lng))))
    goto label_58;
  (Wrd62.Obj) = ((Wrd68.pObj) [1]);

DEFLABEL (label_57)
  (Wrd78.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_1]));
  (Wrd86.Obj) = ((Wrd78.pObj) [0]);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if ((Wrd87.uLng) == 50)
    goto label_56;

DEFLABEL (label_55)
  ((Wrd78.pObj) [0]) = (Wrd62.Obj);

DEFLABEL (label_54)
  (Wrd99.Obj) = (Rsp [0]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd100.uLng) == 10))
    goto label_53;
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd99.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (Wrd98.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd98.Lng))))
    goto label_53;
  (Wrd90.Obj) = ((Wrd96.pObj) [2]);

DEFLABEL (label_52)
  (Wrd106.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_2]));
  (Wrd114.Obj) = ((Wrd106.pObj) [0]);
  (Wrd115.uLng) = (OBJECT_TYPE (Wrd114.Obj));
  if ((Wrd115.uLng) == 50)
    goto label_51;

DEFLABEL (label_50)
  ((Wrd106.pObj) [0]) = (Wrd90.Obj);

DEFLABEL (label_49)
  (Wrd127.Obj) = (Rsp [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd128.uLng) == 10))
    goto label_48;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd125.Obj) = ((Wrd124.pObj) [0]);
  (Wrd126.Lng) = (FIXNUM_TO_LONG (Wrd125.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd126.Lng))))
    goto label_48;
  (Wrd118.Obj) = ((Wrd124.pObj) [3]);

DEFLABEL (label_47)
  (Wrd134.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_3]));
  (Wrd142.Obj) = ((Wrd134.pObj) [0]);
  (Wrd143.uLng) = (OBJECT_TYPE (Wrd142.Obj));
  if ((Wrd143.uLng) == 50)
    goto label_46;

DEFLABEL (label_45)
  ((Wrd134.pObj) [0]) = (Wrd118.Obj);

DEFLABEL (label_44)
  (Wrd155.Obj) = (Rsp [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if (! ((Wrd156.uLng) == 10))
    goto label_43;
  (Wrd152.pObj) = (OBJECT_ADDRESS (Wrd155.Obj));
  (Wrd153.Obj) = ((Wrd152.pObj) [0]);
  (Wrd154.Lng) = (FIXNUM_TO_LONG (Wrd153.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd154.Lng))))
    goto label_43;
  (Wrd146.Obj) = ((Wrd152.pObj) [4]);

DEFLABEL (label_42)
  (Wrd162.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_4]));
  (Wrd170.Obj) = ((Wrd162.pObj) [0]);
  (Wrd171.uLng) = (OBJECT_TYPE (Wrd170.Obj));
  if ((Wrd171.uLng) == 50)
    goto label_41;

DEFLABEL (label_40)
  ((Wrd162.pObj) [0]) = (Wrd146.Obj);

DEFLABEL (label_39)
  Rsp = (& (Rsp [1]));
  (Wrd178.Obj) = (Rsp [0]);
  (Wrd179.uLng) = (OBJECT_TYPE (Wrd178.Obj));
  if (! ((Wrd179.uLng) == 1))
    goto label_38;
  (Wrd177.pObj) = (OBJECT_ADDRESS (Wrd178.Obj));
  (Wrd175.Obj) = ((Wrd177.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [0]) = (Wrd175.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_24]));

DEFLABEL (label_38)
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_23]))));
  (* (--Rsp)) = (Wrd183.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_32)
  (Wrd175.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_41)
  if ((Wrd170.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_40;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_22])), (Wrd162.pObj), (Wrd146.Obj));

DEFLABEL (label_31)
  goto label_39;

DEFLABEL (label_43)
  (Wrd157.Obj) = (Rsp [0]);
  (Wrd158.Obj) = (current_block [OBJECT_7_7]);
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_21]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_4]), 2);

DEFLABEL (label_30)
  (Wrd146.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  if ((Wrd142.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_45;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_20])), (Wrd134.pObj), (Wrd118.Obj));

DEFLABEL (label_29)
  goto label_44;

DEFLABEL (label_48)
  (Wrd129.Obj) = (Rsp [0]);
  (Wrd130.Obj) = (current_block [OBJECT_7_6]);
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_19]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_4]), 2);

DEFLABEL (label_28)
  (Wrd118.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_51)
  if ((Wrd114.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_50;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_18])), (Wrd106.pObj), (Wrd90.Obj));

DEFLABEL (label_27)
  goto label_49;

DEFLABEL (label_53)
  (Wrd101.Obj) = (Rsp [0]);
  (Wrd102.Obj) = (current_block [OBJECT_7_5]);
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_17]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_4]), 2);

DEFLABEL (label_26)
  (Wrd90.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_56)
  if ((Wrd86.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_55;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_16])), (Wrd78.pObj), (Wrd62.Obj));

DEFLABEL (label_25)
  goto label_54;

DEFLABEL (label_58)
  (Wrd73.Obj) = (Rsp [0]);
  (Wrd74.Obj) = (current_block [OBJECT_7_3]);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_15]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_4]), 2);

DEFLABEL (label_24)
  (Wrd62.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 1);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  if ((Wrd49.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_62;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_13])), (Wrd41.pObj), (Wrd34.Obj));

DEFLABEL (label_22)
  goto label_61;

DEFLABEL (label_65)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_21)
  (Wrd34.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_11])), (Wrd29.pObj));

DEFLABEL (label_20)
  (Wrd28.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_9])), (Wrd15.pObj));

DEFLABEL (label_18)
  (Wrd14.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_72)
  (Wrd186.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd186.Obj);
  (Wrd188.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd191.Obj) = ((Wrd188.pObj) [0]);
  (Wrd192.uLng) = (OBJECT_TYPE (Wrd191.Obj));
  if ((Wrd192.uLng) == 50)
    goto label_77;
  Wrd187 = Wrd191;

DEFLABEL (label_76)
  (* (--Rsp)) = (Wrd187.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_8]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_7_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_73;
  Rvl = (current_block [OBJECT_7_8]);
  goto pop_return;

DEFLABEL (label_73)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_26]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_7_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_75;
  Wrd8 = Wrd12;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_29]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_7_27);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_24]));

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_28])), (Wrd9.pObj));

DEFLABEL (label_34)
  (Wrd8.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_7])), (Wrd188.pObj));

DEFLABEL (label_33)
  (Wrd187.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_5])), (Wrd7.pObj));

DEFLABEL (label_17)
  (Wrd6.Obj) = Rvl;
  goto label_78;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 5
#define DEBUGGING_LABEL_8_2 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto make_state_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_state_3)
DEFLABEL (make_state_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 4));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-5]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 7
#define DEBUGGING_LABEL_9_2 6
#define OBJECT_9_1 5
#define OBJECT_9_0 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto state_register_tables_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_register_tables_3)
DEFLABEL (state_register_tables_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_9_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define ENVIRONMENT_LABEL_10_3 7
#define DEBUGGING_LABEL_10_2 6
#define OBJECT_10_1 5
#define OBJECT_10_0 4
#define FREE_REFERENCES_LABEL_10_0 4
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto state_hash_table_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_hash_table_3)
DEFLABEL (state_hash_table_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_10_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 7
#define DEBUGGING_LABEL_11_2 6
#define OBJECT_11_1 5
#define OBJECT_11_0 4
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto state_stack_offset_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_stack_offset_3)
DEFLABEL (state_stack_offset_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_11_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 7
#define DEBUGGING_LABEL_12_2 6
#define OBJECT_12_1 5
#define OBJECT_12_0 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto state_stack_reference_quantities_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_stack_reference_quantities_3)
DEFLABEL (state_stack_reference_quantities_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_12_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_6 5
#define LABEL_13_5 7
#define LABEL_13_8 9
#define LABEL_13_10 11
#define LABEL_13_11 13
#define LABEL_13_12 15
#define ENVIRONMENT_LABEL_13_3 31
#define DEBUGGING_LABEL_13_2 30
#define OBJECT_13_2 29
#define OBJECT_13_1 28
#define OBJECT_13_0 27
#define EXECUTE_CACHE_13_9 17
#define EXECUTE_CACHE_13_7 19
#define FREE_REFERENCE_13_0 22
#define FREE_ASSIGNMENT_13_2 24
#define FREE_ASSIGNMENT_13_1 25
#define FREE_ASSIGNMENT_13_0 26
#define FREE_REFERENCES_LABEL_13_0 16
#define NUMBER_OF_LINKER_SECTIONS_13_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto state_resetB_2;

    case 1:
      current_block = (Rpc - LABEL_13_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_13_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_13_10);
      goto label_5;

    case 5:
      current_block = (Rpc - LABEL_13_11);
      goto label_6;

    case 6:
      current_block = (Rpc - LABEL_13_12);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_resetB_9)
DEFLABEL (state_resetB_2)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_20;
  Wrd8 = Wrd12;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_8);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_18;

DEFLABEL (label_17)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_16)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_1]));
  (Wrd19.Obj) = (current_block [OBJECT_13_0]);
  (Wrd26.Obj) = ((Wrd18.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_15;

DEFLABEL (label_14)
  ((Wrd18.pObj) [0]) = (Wrd19.Obj);

DEFLABEL (label_13)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_2]));
  (Wrd31.Obj) = (current_block [OBJECT_13_1]);
  (Wrd38.Obj) = ((Wrd30.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_12;

DEFLABEL (label_11)
  ((Wrd30.pObj) [0]) = (Wrd31.Obj);

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_13_2]);
  goto pop_return;

DEFLABEL (label_12)
  if ((Wrd38.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_11;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_12])), (Wrd30.pObj), (Wrd31.Obj));

DEFLABEL (label_7)
  goto label_10;

DEFLABEL (label_15)
  if ((Wrd26.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_14;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_11])), (Wrd18.pObj), (Wrd19.Obj));

DEFLABEL (label_6)
  goto label_13;

DEFLABEL (label_18)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_17;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_10])), (Wrd6.pObj), Rvl);

DEFLABEL (label_5)
  goto label_16;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_6])), (Wrd9.pObj));

DEFLABEL (label_4)
  (Wrd8.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_6 5
#define LABEL_14_5 7
#define LABEL_14_9 9
#define LABEL_14_11 11
#define LABEL_14_7 13
#define LABEL_14_14 15
#define LABEL_14_10 17
#define LABEL_14_17 19
#define LABEL_14_13 21
#define LABEL_14_19 23
#define LABEL_14_16 25
#define ENVIRONMENT_LABEL_14_3 45
#define DEBUGGING_LABEL_14_2 44
#define OBJECT_14_1 43
#define OBJECT_14_0 42
#define EXECUTE_CACHE_14_20 27
#define EXECUTE_CACHE_14_18 29
#define EXECUTE_CACHE_14_15 31
#define EXECUTE_CACHE_14_12 33
#define EXECUTE_CACHE_14_8 35
#define FREE_REFERENCE_14_3 38
#define FREE_REFERENCE_14_2 39
#define FREE_REFERENCE_14_1 40
#define FREE_REFERENCE_14_0 41
#define FREE_REFERENCES_LABEL_14_0 26
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto state_get_7;

    case 1:
      current_block = (Rpc - LABEL_14_6);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_14_9);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_14_11);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_14_7);
      goto lambda_5;

    case 6:
      current_block = (Rpc - LABEL_14_14);
      goto label_12;

    case 7:
      current_block = (Rpc - LABEL_14_10);
      goto continuation_1;

    case 8:
      current_block = (Rpc - LABEL_14_17);
      goto label_13;

    case 9:
      current_block = (Rpc - LABEL_14_13);
      goto continuation_4;

    case 10:
      current_block = (Rpc - LABEL_14_19);
      goto label_14;

    case 11:
      current_block = (Rpc - LABEL_14_16);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (state_get_16)
DEFLABEL (state_get_7)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_25;
  Wrd8 = Wrd12;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_14_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_23;
  Wrd5 = Wrd9;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_2]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_21;
  Wrd14 = Wrd18;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_14_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_19;
  Wrd8 = Wrd12;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_18]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_20]));

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_17])), (Wrd9.pObj));

DEFLABEL (label_13)
  (Wrd8.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_11])), (Wrd15.pObj));

DEFLABEL (label_11)
  (Wrd14.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_9])), (Wrd6.pObj));

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_6])), (Wrd9.pObj));

DEFLABEL (label_9)
  (Wrd8.Obj) = Rvl;
  goto label_24;

DEFLABEL (lambda_17)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_14_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_29;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_14_13);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_27;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_26)
  (Wrd14.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_28;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define LABEL_15_6 7
#define LABEL_15_7 9
#define LABEL_15_8 11
#define LABEL_15_10 13
#define LABEL_15_11 15
#define LABEL_15_13 17
#define LABEL_15_14 19
#define LABEL_15_15 21
#define LABEL_15_16 23
#define LABEL_15_17 25
#define LABEL_15_12 27
#define LABEL_15_19 29
#define LABEL_15_22 31
#define LABEL_15_20 33
#define LABEL_15_23 35
#define LABEL_15_27 37
#define LABEL_15_25 39
#define LABEL_15_30 41
#define LABEL_15_36 43
#define LABEL_15_32 45
#define LABEL_15_40 47
#define LABEL_15_34 49
#define LABEL_15_39 51
#define LABEL_15_38 53
#define LABEL_15_46 55
#define LABEL_15_37 57
#define LABEL_15_47 59
#define LABEL_15_43 61
#define LABEL_15_48 63
#define LABEL_15_45 65
#define LABEL_15_44 67
#define LABEL_15_51 69
#define LABEL_15_50 71
#define LABEL_15_49 73
#define LABEL_15_54 75
#define LABEL_15_58 77
#define LABEL_15_59 79
#define LABEL_15_53 81
#define LABEL_15_55 83
#define LABEL_15_60 85
#define LABEL_15_57 87
#define ENVIRONMENT_LABEL_15_3 133
#define DEBUGGING_LABEL_15_2 132
#define OBJECT_15_7 131
#define OBJECT_15_6 130
#define OBJECT_15_5 129
#define OBJECT_15_4 128
#define OBJECT_15_3 127
#define OBJECT_15_2 126
#define OBJECT_15_1 125
#define OBJECT_15_0 124
#define EXECUTE_CACHE_15_56 89
#define EXECUTE_CACHE_15_52 91
#define EXECUTE_CACHE_15_42 93
#define EXECUTE_CACHE_15_41 95
#define EXECUTE_CACHE_15_35 97
#define EXECUTE_CACHE_15_33 99
#define EXECUTE_CACHE_15_31 101
#define EXECUTE_CACHE_15_29 103
#define EXECUTE_CACHE_15_28 105
#define EXECUTE_CACHE_15_26 107
#define EXECUTE_CACHE_15_24 109
#define EXECUTE_CACHE_15_21 111
#define EXECUTE_CACHE_15_18 113
#define EXECUTE_CACHE_15_9 115
#define FREE_REFERENCE_15_3 118
#define FREE_REFERENCE_15_2 119
#define FREE_REFERENCE_15_1 120
#define FREE_REFERENCE_15_0 121
#define FREE_ASSIGNMENT_15_0 123
#define FREE_REFERENCES_LABEL_15_0 88
#define NUMBER_OF_LINKER_SECTIONS_15_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd57;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd35;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd66;
  machine_word Wrd68;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd73;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto walk_bblock_46;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto label_48;

    case 2:
      current_block = (Rpc - LABEL_15_6);
      goto continuation_11;

    case 3:
      current_block = (Rpc - LABEL_15_7);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_15_8);
      goto label_56;

    case 5:
      current_block = (Rpc - LABEL_15_10);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_15_11);
      goto loop_16;

    case 7:
      current_block = (Rpc - LABEL_15_13);
      goto label_49;

    case 8:
      current_block = (Rpc - LABEL_15_14);
      goto label_50;

    case 9:
      current_block = (Rpc - LABEL_15_15);
      goto label_53;

    case 10:
      current_block = (Rpc - LABEL_15_16);
      goto label_51;

    case 11:
      current_block = (Rpc - LABEL_15_17);
      goto label_52;

    case 12:
      current_block = (Rpc - LABEL_15_12);
      goto continuation_4;

    case 13:
      current_block = (Rpc - LABEL_15_19);
      goto label_55;

    case 14:
      current_block = (Rpc - LABEL_15_22);
      goto label_54;

    case 15:
      current_block = (Rpc - LABEL_15_20);
      goto continuation_18;

    case 16:
      current_block = (Rpc - LABEL_15_23);
      goto continuation_19;

    case 17:
      current_block = (Rpc - LABEL_15_27);
      goto continuation_41;

    case 18:
      current_block = (Rpc - LABEL_15_25);
      goto continuation_20;

    case 19:
      current_block = (Rpc - LABEL_15_30);
      goto continuation_42;

    case 20:
      current_block = (Rpc - LABEL_15_36);
      goto continuation_22;

    case 21:
      current_block = (Rpc - LABEL_15_32);
      goto continuation_21;

    case 22:
      current_block = (Rpc - LABEL_15_40);
      goto continuation_44;

    case 23:
      current_block = (Rpc - LABEL_15_34);
      goto continuation_43;

    case 24:
      current_block = (Rpc - LABEL_15_39);
      goto continuation_23;

    case 25:
      current_block = (Rpc - LABEL_15_38);
      goto continuation_28;

    case 26:
      current_block = (Rpc - LABEL_15_46);
      goto continuation_27;

    case 27:
      current_block = (Rpc - LABEL_15_37);
      goto continuation_26;

    case 28:
      current_block = (Rpc - LABEL_15_47);
      goto continuation_25;

    case 29:
      current_block = (Rpc - LABEL_15_43);
      goto continuation_24;

    case 30:
      current_block = (Rpc - LABEL_15_48);
      goto continuation_39;

    case 31:
      current_block = (Rpc - LABEL_15_45);
      goto continuation_38;

    case 32:
      current_block = (Rpc - LABEL_15_44);
      goto continuation_29;

    case 33:
      current_block = (Rpc - LABEL_15_51);
      goto label_57;

    case 34:
      current_block = (Rpc - LABEL_15_50);
      goto continuation_35;

    case 35:
      current_block = (Rpc - LABEL_15_49);
      goto continuation_30;

    case 36:
      current_block = (Rpc - LABEL_15_54);
      goto label_59;

    case 37:
      current_block = (Rpc - LABEL_15_58);
      goto label_58;

    case 38:
      current_block = (Rpc - LABEL_15_59);
      goto continuation_37;

    case 39:
      current_block = (Rpc - LABEL_15_53);
      goto continuation_36;

    case 40:
      current_block = (Rpc - LABEL_15_55);
      goto continuation_31;

    case 41:
      current_block = (Rpc - LABEL_15_60);
      goto label_60;

    case 42:
      current_block = (Rpc - LABEL_15_57);
      goto continuation_34;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_bblock_62)
DEFLABEL (walk_bblock_46)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_65;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_65;
  (Wrd7.Obj) = ((Wrd11.pObj) [7]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_64)
  goto loop_16;

DEFLABEL (label_65)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_15_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (loop_63)
DEFLABEL (loop_16)
  INTERRUPT_CHECK (26, LABEL_15_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_82;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_82;
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_81)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_80;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);

DEFLABEL (label_79)
  if ((Wrd27.Obj) == (current_block [OBJECT_15_6]))
    goto label_76;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_1]));
  (Wrd44.Obj) = ((Wrd41.pObj) [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 50)
    goto label_75;
  Wrd40 = Wrd44;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_73;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_72)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_18]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_15_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;

DEFLABEL (label_68)
  (Wrd69.Obj) = (Rsp [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if ((Wrd70.uLng) == 1)
    goto label_66;
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_4]), 1);

DEFLABEL (label_66)
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd66.Obj) = ((Wrd68.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_67)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_69)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_6]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd77.Obj) = (Rsp [3]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_71;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_70)
  (Wrd83.Obj) = (current_block [OBJECT_15_3]);
  (* (--Rsp)) = (Wrd83.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_9]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_15_6);
  goto label_68;

DEFLABEL (label_71)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_8]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_2]), 1);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_17]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_2]), 1);

DEFLABEL (label_52)
  (* (--Rsp)) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_16])), (Wrd41.pObj));

DEFLABEL (label_51)
  (Wrd40.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_76)
  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_0]));
  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 50)
    goto label_78;
  Wrd57 = Wrd61;

DEFLABEL (label_77)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd57.Obj);
  goto label_67;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_15])), (Wrd58.pObj));

DEFLABEL (label_53)
  (Wrd57.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_14]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_2]), 1);

DEFLABEL (label_50)
  (Wrd27.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_15_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_13]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_15_10);
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_15_12);
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_104;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd35.Lng))))
    goto label_104;
  (Wrd7.Obj) = ((Wrd33.pObj) [3]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_101;

DEFLABEL (label_100)
  Rsp = (& (Rsp [1]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_20]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_21]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_15_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_24]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_15_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_27]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_28]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_15_27);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_83;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_29]));

DEFLABEL (label_83)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_30]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_31]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_15_30);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_84;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_29]));

DEFLABEL (label_84)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_34]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_15_34);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_86;

DEFLABEL (label_85)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_86)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_42]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_15_40);
  goto label_85;

DEFLABEL (label_87)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_25]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_26]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_15_25);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_33]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_15_32);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_92;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_36]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_31]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_15_36);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_93;

DEFLABEL (label_92)
  (Wrd12.Obj) = (Rsp [1]);
  if (! ((Wrd12.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_88;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_29]));

DEFLABEL (label_88)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_39]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_31]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_15_39);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_89;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_29]));

DEFLABEL (label_89)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_43]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_15_43);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_91;

DEFLABEL (label_90)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_91)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_47]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_42]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_15_47);
  goto label_90;

DEFLABEL (label_93)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_97;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_38]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_31]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_15_38);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_95;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_45]))));
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_94;

DEFLABEL (label_95)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_44]))));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_94)
DEFLABEL (label_96)
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (label_97)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_37]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_15_37);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_99;

DEFLABEL (label_98)
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_99)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_46]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_42]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_15_46);
  goto label_98;

DEFLABEL (label_101)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_103;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd22.Lng))))
    goto label_103;
  (Wrd14.Obj) = ((Wrd20.pObj) [3]);

DEFLABEL (label_102)
  (Rsp [0]) = (Wrd14.Obj);
  goto loop_16;

DEFLABEL (label_103)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.Obj) = (current_block [OBJECT_15_7]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_22]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_54)
  (Wrd14.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_104)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.Obj) = (current_block [OBJECT_15_7]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_19]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_55)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_100;
  goto label_101;

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_15_45);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_106;

DEFLABEL (label_105)
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_106)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_48]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_42]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_15_48);
  goto label_105;

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_15_44);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_115;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_49]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_15_49);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_110;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_57]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_109;
  Wrd11 = Wrd15;

DEFLABEL (label_108)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_52]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_15_57);

DEFLABEL (label_107)
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_109)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_58])), (Wrd12.pObj));

DEFLABEL (label_58)
  (Wrd11.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_110)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_3]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_114;
  Wrd17 = Wrd21;

DEFLABEL (label_113)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_55]))));
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_56]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_15_55);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Wrd12.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_15_0]));
  (Wrd24.Obj) = ((Wrd16.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_112;

DEFLABEL (label_111)
  ((Wrd16.pObj) [0]) = (Wrd13.Obj);
  goto label_107;

DEFLABEL (label_112)
  if ((Wrd24.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_111;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_15_60])), (Wrd16.pObj), (Wrd13.Obj));

DEFLABEL (label_60)
  goto label_107;

DEFLABEL (label_114)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_54])), (Wrd18.pObj));

DEFLABEL (label_59)
  (Wrd17.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_115)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_50]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_119;
  Wrd11 = Wrd15;

DEFLABEL (label_118)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_52]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_15_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_53]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_35]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_15_53);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_117;

DEFLABEL (label_116)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_41]));

DEFLABEL (label_117)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_59]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_42]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_15_59);
  goto label_116;

DEFLABEL (label_119)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_51])), (Wrd12.pObj));

DEFLABEL (label_57)
  (Wrd11.Obj) = Rvl;
  goto label_118;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define ENVIRONMENT_LABEL_16_3 11
#define DEBUGGING_LABEL_16_2 10
#define OBJECT_16_0 9
#define EXECUTE_CACHE_16_6 7
#define FREE_REFERENCES_LABEL_16_0 6
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto walk_nextP_1;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_nextP_4)
DEFLABEL (walk_nextP_1)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_6;

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_16_0]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_7 5
#define LABEL_17_5 7
#define ENVIRONMENT_LABEL_17_3 16
#define DEBUGGING_LABEL_17_2 15
#define EXECUTE_CACHE_17_9 9
#define EXECUTE_CACHE_17_8 11
#define EXECUTE_CACHE_17_6 13
#define FREE_REFERENCES_LABEL_17_0 8
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto walk_next_2;

    case 1:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_17_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_next_5)
DEFLABEL (walk_next_2)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_7;

DEFLABEL (label_6)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_8]));

DEFLABEL (label_7)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_17_7);
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_7 5
#define LABEL_18_6 7
#define LABEL_18_9 9
#define LABEL_18_10 11
#define LABEL_18_5 13
#define ENVIRONMENT_LABEL_18_3 23
#define DEBUGGING_LABEL_18_2 22
#define OBJECT_18_0 21
#define EXECUTE_CACHE_18_8 15
#define FREE_REFERENCE_18_0 18
#define FREE_ASSIGNMENT_18_0 20
#define FREE_REFERENCES_LABEL_18_0 14
#define NUMBER_OF_LINKER_SECTIONS_18_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto define_cse_method_5;

    case 1:
      current_block = (Rpc - LABEL_18_7);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_18_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_18_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_18_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_cse_method_11)
DEFLABEL (define_cse_method_5)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_21;
  Wrd11 = Wrd15;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_6);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [4]);
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd16.uLng) == 1)
    goto label_12;
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_0]), 2);

DEFLABEL (label_12)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  ((Wrd13.pObj) [1]) = (Wrd10.Obj);
  Rsp = (& (Rsp [3]));

DEFLABEL (label_13)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_0]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_19;
  Wrd18 = Wrd22;

DEFLABEL (label_18)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd31.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd31.pObj)));
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_18_0]));
  (Wrd40.Obj) = ((Wrd32.pObj) [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 50)
    goto label_17;

DEFLABEL (label_16)
  ((Wrd32.pObj) [0]) = (Wrd29.Obj);

DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  goto label_13;

DEFLABEL (label_17)
  if ((Wrd40.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_16;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_18_10])), (Wrd32.pObj), (Wrd29.Obj));

DEFLABEL (label_9)
  goto label_15;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_9])), (Wrd19.pObj));

DEFLABEL (label_8)
  (Wrd18.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_7])), (Wrd12.pObj));

DEFLABEL (label_7)
  (Wrd11.Obj) = Rvl;
  goto label_20;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_5);
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_6 7
#define LABEL_19_7 9
#define TAG_19_8 3
#define LABEL_19_10 11
#define LABEL_19_13 13
#define LABEL_19_14 15
#define LABEL_19_15 17
#define LABEL_19_16 19
#define LABEL_19_17 21
#define LABEL_19_18 23
#define LABEL_19_21 25
#define LABEL_19_22 27
#define LABEL_19_23 29
#define LABEL_19_24 31
#define LABEL_19_25 33
#define LABEL_19_28 35
#define LABEL_19_29 37
#define LABEL_19_12 39
#define LABEL_19_30 41
#define LABEL_19_31 43
#define LABEL_19_34 45
#define LABEL_19_32 47
#define LABEL_19_19 49
#define ENVIRONMENT_LABEL_19_3 82
#define DEBUGGING_LABEL_19_2 81
#define OBJECT_19_7 80
#define OBJECT_19_6 79
#define OBJECT_19_5 78
#define OBJECT_19_4 77
#define OBJECT_19_3 76
#define OBJECT_19_2 75
#define OBJECT_19_1 74
#define OBJECT_19_0 73
#define EXECUTE_CACHE_19_35 51
#define EXECUTE_CACHE_19_33 53
#define EXECUTE_CACHE_19_27 55
#define EXECUTE_CACHE_19_26 57
#define EXECUTE_CACHE_19_20 59
#define EXECUTE_CACHE_19_11 61
#define EXECUTE_CACHE_19_9 63
#define FREE_REFERENCE_19_6 66
#define FREE_REFERENCE_19_5 67
#define FREE_REFERENCE_19_4 68
#define FREE_REFERENCE_19_3 69
#define FREE_REFERENCE_19_2 70
#define FREE_REFERENCE_19_1 71
#define FREE_REFERENCE_19_0 72
#define FREE_REFERENCES_LABEL_19_0 50
#define NUMBER_OF_LINKER_SECTIONS_19_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd50;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd88;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd73;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd72;
  machine_word Wrd64;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd93;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd116;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd129;
  machine_word Wrd126;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd124;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto cse_assign_21;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto label_23;

    case 2:
      current_block = (Rpc - LABEL_19_6);
      goto label_24;

    case 3:
      current_block = (Rpc - LABEL_19_7);
      goto lambda_37;

    case 4:
      current_block = (Rpc - LABEL_19_10);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_19_13);
      goto continuation_16;

    case 6:
      current_block = (Rpc - LABEL_19_14);
      goto label_34;

    case 7:
      current_block = (Rpc - LABEL_19_15);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_19_16);
      goto continuation_13;

    case 9:
      current_block = (Rpc - LABEL_19_17);
      goto label_32;

    case 10:
      current_block = (Rpc - LABEL_19_18);
      goto continuation_14;

    case 11:
      current_block = (Rpc - LABEL_19_21);
      goto label_31;

    case 12:
      current_block = (Rpc - LABEL_19_22);
      goto continuation_8;

    case 13:
      current_block = (Rpc - LABEL_19_23);
      goto label_28;

    case 14:
      current_block = (Rpc - LABEL_19_24);
      goto label_29;

    case 15:
      current_block = (Rpc - LABEL_19_25);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_19_28);
      goto label_27;

    case 17:
      current_block = (Rpc - LABEL_19_29);
      goto continuation_5;

    case 18:
      current_block = (Rpc - LABEL_19_12);
      goto continuation_2;

    case 19:
      current_block = (Rpc - LABEL_19_30);
      goto label_25;

    case 20:
      current_block = (Rpc - LABEL_19_31);
      goto label_26;

    case 21:
      current_block = (Rpc - LABEL_19_34);
      goto continuation_4;

    case 22:
      current_block = (Rpc - LABEL_19_32);
      goto continuation_1;

    case 23:
      current_block = (Rpc - LABEL_19_19);
      goto continuation_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_36)
DEFLABEL (cse_assign_21)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_41;
  Wrd6 = Wrd10;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_39;
  Wrd12 = Wrd16;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_7])));
  Rhp += 1;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd21 = Wrd20;
  (Wrd22.Obj) = (Rsp [3]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_6])), (Wrd13.pObj));

DEFLABEL (label_24)
  (Wrd12.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_5])), (Wrd7.pObj));

DEFLABEL (label_23)
  (Wrd6.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_37)
  CLOSURE_HEADER (LABEL_19_7);

DEFLABEL (lambda_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_12);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_68;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_34]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_19_6]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_19_34);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_35]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_19_29);

DEFLABEL (label_68)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_67;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_66)
  if ((Wrd17.Obj) == (current_block [OBJECT_19_5]))
    goto label_63;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_22]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_33]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_19_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_5]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_44;
  Wrd50 = Wrd54;

DEFLABEL (label_43)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd50.Obj);

DEFLABEL (label_42)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_32]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (current_block [OBJECT_19_6]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [4]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [2]);
  (* (--Rsp)) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_19_32);
  (Rsp [2]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_28])), (Wrd51.pObj));

DEFLABEL (label_27)
  (Wrd50.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  (Wrd59.Obj) = (Rsp [0]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_62;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd56.Obj) = ((Wrd58.pObj) [0]);

DEFLABEL (label_61)
  if ((Wrd56.Obj) == (current_block [OBJECT_19_3]))
    goto label_54;

DEFLABEL (label_53)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_18]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd69.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd69.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_27]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_19_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_50;
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_19]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (Wrd102.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd102.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_20]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_19_19);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_19_7]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_19_13);
  (Wrd124.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd124.uLng) == 1))
    goto label_49;
  (Wrd122.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd123.Obj) = (Rsp [0]);
  ((Wrd122.pObj) [0]) = (Wrd123.Obj);

DEFLABEL (label_48)
  (Wrd117.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_2]));
  (Wrd120.Obj) = ((Wrd117.pObj) [0]);
  (Wrd121.uLng) = (OBJECT_TYPE (Wrd120.Obj));
  if ((Wrd121.uLng) == 50)
    goto label_47;
  Wrd116 = Wrd120;

DEFLABEL (label_46)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd116.Obj);
  goto label_42;

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_15])), (Wrd117.pObj));

DEFLABEL (label_33)
  (Wrd116.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd126.Obj) = (Rsp [0]);
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_14]))));
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_34)
  goto label_48;

DEFLABEL (label_50)
  (Wrd94.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_4]));
  (Wrd97.Obj) = ((Wrd94.pObj) [0]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if ((Wrd98.uLng) == 50)
    goto label_52;
  Wrd93 = Wrd97;

DEFLABEL (label_51)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd93.Obj);
  goto label_42;

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_21])), (Wrd94.pObj));

DEFLABEL (label_31)
  (Wrd93.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_16]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_60;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd73.Obj) = ((Wrd75.pObj) [1]);

DEFLABEL (label_59)
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd84.uLng) == 1))
    goto label_58;
  (Wrd82.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd83.Obj) = ((Wrd82.pObj) [0]);
  (* (--Rsp)) = (Wrd83.Obj);

DEFLABEL (label_57)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_26]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_19_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_53;
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_3]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_56;
  Wrd107 = Wrd111;

DEFLABEL (label_55)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd107.Obj);
  goto label_42;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_17])), (Wrd108.pObj));

DEFLABEL (label_32)
  (Wrd107.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_25]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_24]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_4]), 1);

DEFLABEL (label_29)
  (Wrd73.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_23]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_28)
  (Wrd56.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_63)
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_6]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_65;
  Wrd33 = Wrd37;

DEFLABEL (label_64)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd33.Obj);
  goto label_42;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_31])), (Wrd34.pObj));

DEFLABEL (label_26)
  (Wrd33.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_30]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_25)
  (Wrd17.Obj) = Rvl;
  goto label_66;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define LABEL_20_8 7
#define LABEL_20_12 9
#define LABEL_20_13 11
#define LABEL_20_14 13
#define LABEL_20_7 15
#define LABEL_20_9 17
#define LABEL_20_17 19
#define LABEL_20_18 21
#define LABEL_20_19 23
#define LABEL_20_10 25
#define LABEL_20_16 27
#define LABEL_20_21 29
#define LABEL_20_20 31
#define LABEL_20_23 33
#define LABEL_20_26 35
#define LABEL_20_27 37
#define LABEL_20_28 39
#define LABEL_20_22 41
#define LABEL_20_24 43
#define LABEL_20_25 45
#define ENVIRONMENT_LABEL_20_3 72
#define DEBUGGING_LABEL_20_2 71
#define OBJECT_20_9 70
#define OBJECT_20_8 69
#define OBJECT_20_7 68
#define OBJECT_20_6 67
#define OBJECT_20_5 66
#define OBJECT_20_4 65
#define OBJECT_20_3 64
#define OBJECT_20_2 63
#define OBJECT_20_1 62
#define OBJECT_20_0 61
#define EXECUTE_CACHE_20_30 47
#define EXECUTE_CACHE_20_29 49
#define EXECUTE_CACHE_20_15 51
#define EXECUTE_CACHE_20_11 53
#define EXECUTE_CACHE_20_6 55
#define FREE_REFERENCE_20_0 58
#define FREE_ASSIGNMENT_20_0 60
#define FREE_REFERENCES_LABEL_20_0 46
#define NUMBER_OF_LINKER_SECTIONS_20_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd42;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd35;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto cse_assign_register_17;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_20_8);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_20_12);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_20_13);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_20_14);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_20_7);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_20_9);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_20_17);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_20_18);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_20_19);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_20_10);
      goto continuation_5;

    case 12:
      current_block = (Rpc - LABEL_20_16);
      goto continuation_14;

    case 13:
      current_block = (Rpc - LABEL_20_21);
      goto label_26;

    case 14:
      current_block = (Rpc - LABEL_20_20);
      goto continuation_8;

    case 15:
      current_block = (Rpc - LABEL_20_23);
      goto label_27;

    case 16:
      current_block = (Rpc - LABEL_20_26);
      goto label_28;

    case 17:
      current_block = (Rpc - LABEL_20_27);
      goto label_29;

    case 18:
      current_block = (Rpc - LABEL_20_28);
      goto label_30;

    case 19:
      current_block = (Rpc - LABEL_20_22);
      goto continuation_16;

    case 20:
      current_block = (Rpc - LABEL_20_24);
      goto continuation_13;

    case 21:
      current_block = (Rpc - LABEL_20_25);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_register_32)
DEFLABEL (cse_assign_register_17)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_64;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_63)
  if (! ((Wrd7.Obj) == (current_block [OBJECT_20_1])))
    goto label_55;
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_9]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_10]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (current_block [OBJECT_20_2]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_20_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_20_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_20_7]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_20_20);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_46;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd6.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_45)
  if (! ((Wrd6.Obj) == (current_block [OBJECT_20_9])))
    goto label_37;
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_20_2]);
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_25]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (current_block [OBJECT_20_7]);
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd60.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_20_25);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_20_24);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_30]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_7);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_33;
  Rvl = (current_block [OBJECT_20_6]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_16]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_20_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_20_16);
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd6.uLng) == 26))
    goto label_36;
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Rvl));
  if (! ((Wrd7.Lng) < 5L))
    goto label_35;

DEFLABEL (label_34)
  Rvl = (current_block [OBJECT_20_6]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_22]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_20_22);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_29]));

DEFLABEL (label_36)
  (Wrd18.Obj) = (current_block [OBJECT_20_8]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_21]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_34;

DEFLABEL (label_37)
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_20_0]));
  (Wrd15.Obj) = (current_block [OBJECT_20_3]);
  (Wrd22.Obj) = ((Wrd14.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_44;

DEFLABEL (label_43)
  ((Wrd14.pObj) [0]) = (Wrd15.Obj);

DEFLABEL (label_42)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20_0]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_41;
  Wrd30 = Wrd34;

DEFLABEL (label_40)
  Wrd29 = Wrd30;
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_39;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd42.Lng))))
    goto label_39;
  (Wrd37.Obj) = ((Wrd40.pObj) [2]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_38)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_15]));

DEFLABEL (label_39)
  (Wrd45.Obj) = (current_block [OBJECT_20_4]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_28]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_5]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20_27])), (Wrd31.pObj));

DEFLABEL (label_29)
  (Wrd30.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_44)
  if ((Wrd22.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_43;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_20_26])), (Wrd14.pObj), (Wrd15.Obj));

DEFLABEL (label_28)
  goto label_42;

DEFLABEL (label_46)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_23]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_27)
  (Wrd6.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_20_0]));
  (Wrd13.Obj) = (current_block [OBJECT_20_3]);
  (Wrd20.Obj) = ((Wrd12.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_54;

DEFLABEL (label_53)
  ((Wrd12.pObj) [0]) = (Wrd13.Obj);

DEFLABEL (label_52)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20_0]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_51;
  Wrd28 = Wrd32;

DEFLABEL (label_50)
  Wrd27 = Wrd28;
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd41.uLng) == 10))
    goto label_49;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd40.Lng))))
    goto label_49;
  (Wrd35.Obj) = ((Wrd38.pObj) [2]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_48)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_15]));

DEFLABEL (label_49)
  (Wrd43.Obj) = (current_block [OBJECT_20_4]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_19]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_5]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20_18])), (Wrd29.pObj));

DEFLABEL (label_24)
  (Wrd28.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_54)
  if ((Wrd20.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_53;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_20_17])), (Wrd12.pObj), (Wrd13.Obj));

DEFLABEL (label_23)
  goto label_52;

DEFLABEL (label_55)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_20_0]));
  (Wrd18.Obj) = (current_block [OBJECT_20_3]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_62;

DEFLABEL (label_61)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_60)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20_0]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_59;
  Wrd33 = Wrd37;

DEFLABEL (label_58)
  Wrd32 = Wrd33;
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_57;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd45.Lng))))
    goto label_57;
  (Wrd40.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_56)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_15]));

DEFLABEL (label_57)
  (Wrd48.Obj) = (current_block [OBJECT_20_4]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_14]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_5]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20_13])), (Wrd34.pObj));

DEFLABEL (label_21)
  (Wrd33.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_62)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_61;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_20_12])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_20)
  goto label_60;

DEFLABEL (label_64)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_19)
  (Wrd7.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_65)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd63.Obj);
  goto label_56;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_7 7
#define ENVIRONMENT_LABEL_21_3 15
#define DEBUGGING_LABEL_21_2 14
#define OBJECT_21_0 13
#define EXECUTE_CACHE_21_8 9
#define EXECUTE_CACHE_21_6 11
#define FREE_REFERENCES_LABEL_21_0 8
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto cse_assign_stack_reference_2;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_21_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_stack_reference_5)
DEFLABEL (cse_assign_stack_reference_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_5);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_6;
  Rvl = (current_block [OBJECT_21_0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_7]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_21_7);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_8]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_6 5
#define LABEL_22_7 7
#define LABEL_22_8 9
#define LABEL_22_9 11
#define LABEL_22_5 13
#define LABEL_22_11 15
#define LABEL_22_12 17
#define LABEL_22_13 19
#define ENVIRONMENT_LABEL_22_3 36
#define DEBUGGING_LABEL_22_2 35
#define OBJECT_22_7 34
#define OBJECT_22_6 33
#define OBJECT_22_5 32
#define OBJECT_22_4 31
#define OBJECT_22_3 30
#define OBJECT_22_2 29
#define OBJECT_22_1 28
#define OBJECT_22_0 27
#define EXECUTE_CACHE_22_14 21
#define EXECUTE_CACHE_22_10 23
#define FREE_REFERENCE_22_0 26
#define FREE_REFERENCES_LABEL_22_0 20
#define NUMBER_OF_LINKER_SECTIONS_22_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd38;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd27;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd14;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto cse_assign_stack_push_14;

    case 1:
      current_block = (Rpc - LABEL_22_6);
      goto lambda_3;

    case 2:
      current_block = (Rpc - LABEL_22_7);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_22_8);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_22_9);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_22_11);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_22_12);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_22_13);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_stack_push_22)
DEFLABEL (cse_assign_stack_push_14)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  Rdl = (& (Rsp [5]));
  goto lambda_3;

DEFLABEL (label_24)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [1]));
  goto lambda_3;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_22_11);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_28;
  Wrd6 = Wrd10;

DEFLABEL (label_27)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_26;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_26;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);

DEFLABEL (label_25)
  (Wrd28.Obj) = (current_block [OBJECT_22_4]);
  (Wrd29.Obj) = (current_block [OBJECT_22_5]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Wrd33.Obj) = (current_block [OBJECT_22_6]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (Wrd44.Obj) = (current_block [OBJECT_22_7]);
  (* (Rhp++)) = (Wrd44.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (Rsp [3]) = (Wrd41.Obj);
  (Wrd45.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd45.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_14]));

DEFLABEL (label_26)
  (Wrd21.Obj) = (current_block [OBJECT_22_2]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_13]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_3]), 2);

DEFLABEL (label_20)
  (Wrd12.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22_12])), (Wrd7.pObj));

DEFLABEL (label_19)
  (Wrd6.Obj) = Rvl;
  goto label_27;

DEFLABEL (lambda_23)
DEFLABEL (lambda_3)
  DLINK_INTERRUPT_CHECK (25, LABEL_22_6);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_34;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_33)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_32;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_31)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_30;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_29)
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (label_30)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_9]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 1);

DEFLABEL (label_18)
  (Wrd38.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd38.Obj));
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_8]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_17)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_16)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd5.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_7 7
#define TAG_23_8 2
#define LABEL_23_10 9
#define ENVIRONMENT_LABEL_23_3 20
#define DEBUGGING_LABEL_23_2 19
#define EXECUTE_CACHE_23_12 11
#define EXECUTE_CACHE_23_11 13
#define EXECUTE_CACHE_23_9 15
#define EXECUTE_CACHE_23_6 17
#define FREE_REFERENCES_LABEL_23_0 10
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto cse_assign_interpreter_register_5;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_23_7);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_23_10);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_interpreter_register_8)
DEFLABEL (cse_assign_interpreter_register_5)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_7])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  ((Wrd9.pObj) [3]) = Rvl;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Rsp [5]) = (Wrd5.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_2;

DEFLABEL (label_10)
  (Rsp [3]) = Rvl;
  (Wrd16.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd16.Obj);
  (Rsp [5]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_9]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_23_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_23_10);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_12]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_6 7
#define TAG_24_7 2
#define LABEL_24_12 9
#define LABEL_24_16 11
#define LABEL_24_19 13
#define LABEL_24_21 15
#define LABEL_24_22 17
#define LABEL_24_10 19
#define LABEL_24_24 21
#define LABEL_24_26 23
#define LABEL_24_17 25
#define TAG_24_18 11
#define LABEL_24_28 27
#define LABEL_24_29 29
#define LABEL_24_15 31
#define LABEL_24_31 33
#define LABEL_24_13 35
#define TAG_24_14 16
#define LABEL_24_33 37
#define LABEL_24_34 39
#define ENVIRONMENT_LABEL_24_3 72
#define DEBUGGING_LABEL_24_2 71
#define OBJECT_24_3 70
#define OBJECT_24_2 69
#define OBJECT_24_1 68
#define OBJECT_24_0 67
#define EXECUTE_CACHE_24_37 41
#define EXECUTE_CACHE_24_36 43
#define EXECUTE_CACHE_24_35 45
#define EXECUTE_CACHE_24_32 47
#define EXECUTE_CACHE_24_30 49
#define EXECUTE_CACHE_24_27 51
#define EXECUTE_CACHE_24_25 53
#define EXECUTE_CACHE_24_23 55
#define EXECUTE_CACHE_24_20 57
#define EXECUTE_CACHE_24_11 59
#define EXECUTE_CACHE_24_9 61
#define EXECUTE_CACHE_24_8 63
#define FREE_REFERENCE_24_0 66
#define FREE_REFERENCES_LABEL_24_0 40
#define NUMBER_OF_LINKER_SECTIONS_24_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd45;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd72;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd90;
  machine_word Wrd94;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd91;
  machine_word Wrd92;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto cse_assign_general_19;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_18;

    case 2:
      current_block = (Rpc - LABEL_24_6);
      goto lambda_29;

    case 3:
      current_block = (Rpc - LABEL_24_12);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_24_16);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_24_19);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_24_21);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_24_22);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_24_10);
      goto continuation_0;

    case 9:
      current_block = (Rpc - LABEL_24_24);
      goto label_21;

    case 10:
      current_block = (Rpc - LABEL_24_26);
      goto lambda_15;

    case 11:
      current_block = (Rpc - LABEL_24_17);
      goto lambda_31;

    case 12:
      current_block = (Rpc - LABEL_24_28);
      goto label_24;

    case 13:
      current_block = (Rpc - LABEL_24_29);
      goto label_25;

    case 14:
      current_block = (Rpc - LABEL_24_15);
      goto lambda_11;

    case 15:
      current_block = (Rpc - LABEL_24_31);
      goto label_26;

    case 16:
      current_block = (Rpc - LABEL_24_13);
      goto lambda_30;

    case 17:
      current_block = (Rpc - LABEL_24_33);
      goto continuation_9;

    case 18:
      current_block = (Rpc - LABEL_24_34);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cse_assign_general_28)
DEFLABEL (cse_assign_general_19)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_24_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24_6])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_8]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_9]));

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_24_6);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_26]))));
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_36)
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;

DEFLABEL (label_34)
  (Wrd17.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd17.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd15.Obj) = (Rsp [3]);
  if (! ((Wrd15.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_34;
  (Wrd19.Obj) = ((Wrd10.pObj) [2]);
  (Rsp [3]) = (Wrd19.Obj);
  (Wrd22.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd22.Obj);
  (Wrd23.Obj) = ((Wrd10.pObj) [4]);
  (Rsp [1]) = (Wrd23.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_27]));

DEFLABEL (label_37)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_19]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_24_2]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [4]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_47;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_46)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_25]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_24_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_41;

DEFLABEL (label_40)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_12]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [4]);
  (* (--Rsp)) = (Wrd78.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_20]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_24_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_15]))));
  (* (--Rsp)) = (Wrd90.Obj);
  goto label_38;

DEFLABEL (label_39)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd92.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_24_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24_13])));
  Rhp += 2;
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd92.pObj)));
  Wrd95 = Wrd92;
  (Wrd96.Obj) = (Rsp [0]);
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [4]);
  ((Wrd95.pObj) [2]) = (Wrd98.Obj);
  (Wrd94.Obj) = (Rsp [1]);
  ((Wrd95.pObj) [3]) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);

DEFLABEL (label_38)
  goto label_36;

DEFLABEL (label_41)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_16]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd56.Obj) = (Rsp [1]);
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [4]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_45;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd51.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_44)
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd68.uLng) == 1))
    goto label_43;
  (Wrd66.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd67.Obj) = ((Wrd66.pObj) [0]);
  (* (--Rsp)) = (Wrd67.Obj);

DEFLABEL (label_42)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_23]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_24_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_40;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd82.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_24_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24_17])));
  Rhp += 1;
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd82.pObj)));
  Wrd83 = Wrd82;
  (Wrd84.Obj) = (Rsp [0]);
  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd86.Obj) = ((Wrd85.pObj) [4]);
  ((Wrd83.pObj) [2]) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  goto label_36;

DEFLABEL (label_43)
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_22]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_21]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_22)
  (Wrd51.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_24]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (lambda_32)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_24_26);
  Rvl = (current_block [OBJECT_24_3]);
  goto pop_return;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_24_17);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_51;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_50)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_49;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_48)
  (Rsp [0]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_30]));

DEFLABEL (label_49)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_29]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_25)
  (Wrd20.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_28]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_24)
  (Wrd5.Obj) = Rvl;
  goto label_50;

DEFLABEL (lambda_33)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_24_15);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_53;
  Wrd5 = Wrd9;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_32]));

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_24_31])), (Wrd6.pObj));

DEFLABEL (label_26)
  (Wrd5.Obj) = Rvl;
  goto label_52;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_24_13);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_34]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd12.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_35]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_24_34);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_37]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_24_33);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_36]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_7 7
#define LABEL_25_8 9
#define LABEL_25_9 11
#define ENVIRONMENT_LABEL_25_3 21
#define DEBUGGING_LABEL_25_2 20
#define OBJECT_25_2 19
#define OBJECT_25_1 18
#define OBJECT_25_0 17
#define EXECUTE_CACHE_25_10 13
#define EXECUTE_CACHE_25_6 15
#define FREE_REFERENCES_LABEL_25_0 12
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto notice_popB_4;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_25_7);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_25_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_25_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (notice_popB_10)
DEFLABEL (notice_popB_4)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rvl = (current_block [OBJECT_25_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_17;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_16)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_15;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_14)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_13;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_10]));

DEFLABEL (label_13)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_9]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_2]), 1);

DEFLABEL (label_8)
  (Wrd23.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_8]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_7)
  (Wrd16.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_5 5
#define LABEL_26_6 7
#define ENVIRONMENT_LABEL_26_3 12
#define DEBUGGING_LABEL_26_2 11
#define EXECUTE_CACHE_26_7 9
#define FREE_REFERENCES_LABEL_26_0 8
#define NUMBER_OF_LINKER_SECTIONS_26_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto assignment_memory_insertion_2;

    case 1:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_26_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assignment_memory_insertion_5)
DEFLABEL (assignment_memory_insertion_2)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_26_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_26_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 6
#define DEBUGGING_LABEL_27_2 5
#define OBJECT_27_0 4
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto trivial_action_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (trivial_action_3)
DEFLABEL (trivial_action_0)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_4;
  Rvl = (current_block [OBJECT_27_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_4)
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define TAG_28_6 1
#define LABEL_28_8 7
#define ENVIRONMENT_LABEL_28_3 16
#define DEBUGGING_LABEL_28_2 15
#define EXECUTE_CACHE_28_9 9
#define EXECUTE_CACHE_28_7 11
#define FREE_REFERENCE_28_0 14
#define FREE_REFERENCES_LABEL_28_0 8
#define NUMBER_OF_LINKER_SECTIONS_28_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto define_trivial_one_arg_method_1;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_28_8);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_trivial_one_arg_method_5)
DEFLABEL (define_trivial_one_arg_method_1)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_28_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_28_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_28_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_8;
  Wrd12 = Wrd16;

DEFLABEL (label_7)
  (Wrd18.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_8])), (Wrd13.pObj));

DEFLABEL (label_3)
  (Wrd12.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define TAG_29_6 1
#define LABEL_29_9 7
#define LABEL_29_8 9
#define LABEL_29_11 11
#define ENVIRONMENT_LABEL_29_3 20
#define DEBUGGING_LABEL_29_2 19
#define EXECUTE_CACHE_29_10 13
#define EXECUTE_CACHE_29_7 15
#define FREE_REFERENCE_29_0 18
#define FREE_REFERENCES_LABEL_29_0 12
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto define_trivial_two_arg_method_2;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_29_9);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_29_8);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_29_11);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_trivial_two_arg_method_7)
DEFLABEL (define_trivial_two_arg_method_2)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_29_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_29_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [4]) = (Wrd6.Obj);
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd16.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_29_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_12;
  Wrd8 = Wrd12;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_10;
  Wrd12 = Wrd16;

DEFLABEL (label_9)
  (Wrd18.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_10]));

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_11])), (Wrd13.pObj));

DEFLABEL (label_5)
  (Wrd12.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_9])), (Wrd9.pObj));

DEFLABEL (label_4)
  (Wrd8.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define ENVIRONMENT_LABEL_30_3 6
#define DEBUGGING_LABEL_30_2 5
#define OBJECT_30_0 4
#define FREE_REFERENCES_LABEL_30_0 4
#define NUMBER_OF_LINKER_SECTIONS_30_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto method_noop_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (method_noop_3)
DEFLABEL (method_noop_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  Rvl = (current_block [OBJECT_30_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_9 7
#define LABEL_31_10 9
#define LABEL_31_6 11
#define LABEL_31_12 13
#define LABEL_31_13 15
#define LABEL_31_14 17
#define LABEL_31_8 19
#define LABEL_31_17 21
#define LABEL_31_18 23
#define LABEL_31_16 25
#define LABEL_31_20 27
#define LABEL_31_21 29
#define ENVIRONMENT_LABEL_31_3 50
#define DEBUGGING_LABEL_31_2 49
#define OBJECT_31_6 48
#define OBJECT_31_5 47
#define OBJECT_31_4 46
#define OBJECT_31_3 45
#define OBJECT_31_2 44
#define OBJECT_31_1 43
#define OBJECT_31_0 42
#define EXECUTE_CACHE_31_19 31
#define EXECUTE_CACHE_31_15 33
#define EXECUTE_CACHE_31_11 35
#define EXECUTE_CACHE_31_7 37
#define FREE_REFERENCE_31_1 40
#define FREE_REFERENCE_31_0 41
#define FREE_REFERENCES_LABEL_31_0 30
#define NUMBER_OF_LINKER_SECTIONS_31_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd37;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto method_unknown_invocation_11;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_31_9);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_31_10);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_31_6);
      goto lambda_3;

    case 5:
      current_block = (Rpc - LABEL_31_12);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_31_13);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_31_14);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_31_8);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_31_17);
      goto label_18;

    case 10:
      current_block = (Rpc - LABEL_31_18);
      goto label_19;

    case 11:
      current_block = (Rpc - LABEL_31_16);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_31_20);
      goto label_20;

    case 13:
      current_block = (Rpc - LABEL_31_21);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (method_unknown_invocation_23)
DEFLABEL (method_unknown_invocation_11)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_36;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_35)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_34;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_33)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_11]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_31_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_32;
  Wrd9 = Wrd13;

DEFLABEL (label_31)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_30;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_30;
  (Wrd16.Obj) = ((Wrd19.pObj) [5]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_29)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_19]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_31_16);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_28;
  Wrd6 = Wrd10;

DEFLABEL (label_27)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_26;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_26;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_19]));

DEFLABEL (label_26)
  (Wrd21.Obj) = (current_block [OBJECT_31_6]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_21]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 2);

DEFLABEL (label_21)
  (Wrd12.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31_20])), (Wrd7.pObj));

DEFLABEL (label_20)
  (Wrd6.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd24.Obj) = (current_block [OBJECT_31_5]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_18]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31_17])), (Wrd10.pObj));

DEFLABEL (label_18)
  (Wrd9.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_0]), 1);

DEFLABEL (label_13)
  (Wrd8.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_24)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_31_6);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_43;
  Wrd6 = Wrd10;

DEFLABEL (label_42)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_41;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_41;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);

DEFLABEL (label_40)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_39;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_39;
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd33.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_39;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd29.pObj) = (& ((Wrd34.pObj) [(Wrd27.Lng)]));
  (Wrd25.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_38)
  (Rsp [0]) = (Wrd25.Obj);
  if ((Wrd25.Obj) == ((SCHEME_OBJECT) 0))
    goto label_37;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_15]));

DEFLABEL (label_37)
  Rvl = (current_block [OBJECT_31_4]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_39)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_14]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 2);

DEFLABEL (label_17)
  (Wrd25.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd21.Obj) = (current_block [OBJECT_31_2]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_13]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 2);

DEFLABEL (label_16)
  (Wrd12.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31_12])), (Wrd7.pObj));

DEFLABEL (label_15)
  (Wrd6.Obj) = Rvl;
  goto label_42;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_6 5
#define LABEL_32_7 7
#define LABEL_32_8 9
#define LABEL_32_5 11
#define ENVIRONMENT_LABEL_32_3 22
#define DEBUGGING_LABEL_32_2 21
#define EXECUTE_CACHE_32_10 13
#define EXECUTE_CACHE_32_9 15
#define FREE_REFERENCE_32_2 18
#define FREE_REFERENCE_32_1 19
#define FREE_REFERENCE_32_0 20
#define FREE_REFERENCES_LABEL_32_0 12
#define NUMBER_OF_LINKER_SECTIONS_32_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_32_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_32_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_32_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_13;
  Wrd8 = Wrd12;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_11;
  Wrd15 = Wrd19;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_9;
  Wrd21 = Wrd25;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_10]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32_8])), (Wrd22.pObj));

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32_7])), (Wrd16.pObj));

DEFLABEL (label_4)
  (Wrd15.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32_6])), (Wrd9.pObj));

DEFLABEL (label_3)
  (Wrd8.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_6 5
#define LABEL_33_7 7
#define LABEL_33_8 9
#define LABEL_33_5 11
#define ENVIRONMENT_LABEL_33_3 22
#define DEBUGGING_LABEL_33_2 21
#define EXECUTE_CACHE_33_10 13
#define EXECUTE_CACHE_33_9 15
#define FREE_REFERENCE_33_2 18
#define FREE_REFERENCE_33_1 19
#define FREE_REFERENCE_33_0 20
#define FREE_REFERENCES_LABEL_33_0 12
#define NUMBER_OF_LINKER_SECTIONS_33_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_33_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_33_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_33_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_13;
  Wrd8 = Wrd12;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_11;
  Wrd15 = Wrd19;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_9;
  Wrd21 = Wrd25;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_10]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_8])), (Wrd22.pObj));

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_7])), (Wrd16.pObj));

DEFLABEL (label_4)
  (Wrd15.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_6])), (Wrd9.pObj));

DEFLABEL (label_3)
  (Wrd8.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_6 5
#define LABEL_34_7 7
#define LABEL_34_8 9
#define LABEL_34_5 11
#define LABEL_34_10 13
#define LABEL_34_11 15
#define LABEL_34_12 17
#define ENVIRONMENT_LABEL_34_3 34
#define DEBUGGING_LABEL_34_2 33
#define OBJECT_34_2 32
#define OBJECT_34_1 31
#define OBJECT_34_0 30
#define EXECUTE_CACHE_34_13 19
#define EXECUTE_CACHE_34_9 21
#define FREE_REFERENCE_34_3 24
#define FREE_REFERENCE_34_2 25
#define FREE_REFERENCE_34_1 26
#define FREE_REFERENCE_34_0 27
#define FREE_ASSIGNMENT_34_0 29
#define FREE_REFERENCES_LABEL_34_0 18
#define NUMBER_OF_LINKER_SECTIONS_34_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_34_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_34_7);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_34_8);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_34_5);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_34_10);
      goto label_7;

    case 6:
      current_block = (Rpc - LABEL_34_11);
      goto label_8;

    case 7:
      current_block = (Rpc - LABEL_34_12);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_11)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_24;
  Wrd8 = Wrd12;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_22;
  Wrd15 = Wrd19;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_20;
  Wrd21 = Wrd25;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_34_5);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_34_0]));
  (Wrd6.Obj) = (current_block [OBJECT_34_0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_18;

DEFLABEL (label_17)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_16)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_3]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_15;
  Wrd18 = Wrd22;

DEFLABEL (label_14)
  Wrd17 = Wrd18;
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_13;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_13;
  (Wrd24.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_13]));

DEFLABEL (label_13)
  (Wrd33.Obj) = (current_block [OBJECT_34_1]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_12]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_2]), 2);

DEFLABEL (label_9)
  (Wrd24.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_11])), (Wrd19.pObj));

DEFLABEL (label_8)
  (Wrd18.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_18)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_17;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_34_10])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_7)
  goto label_16;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_8])), (Wrd22.pObj));

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_7])), (Wrd16.pObj));

DEFLABEL (label_5)
  (Wrd15.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_6])), (Wrd9.pObj));

DEFLABEL (label_4)
  (Wrd8.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_6 5
#define LABEL_35_7 7
#define LABEL_35_8 9
#define LABEL_35_5 11
#define LABEL_35_11 13
#define LABEL_35_12 15
#define LABEL_35_13 17
#define LABEL_35_10 19
#define LABEL_35_14 21
#define LABEL_35_15 23
#define LABEL_35_16 25
#define ENVIRONMENT_LABEL_35_3 44
#define DEBUGGING_LABEL_35_2 43
#define OBJECT_35_2 42
#define OBJECT_35_1 41
#define OBJECT_35_0 40
#define EXECUTE_CACHE_35_17 27
#define EXECUTE_CACHE_35_9 29
#define FREE_REFERENCE_35_5 32
#define FREE_REFERENCE_35_4 33
#define FREE_REFERENCE_35_3 34
#define FREE_REFERENCE_35_2 35
#define FREE_REFERENCE_35_1 36
#define FREE_REFERENCE_35_0 37
#define FREE_ASSIGNMENT_35_0 39
#define FREE_REFERENCES_LABEL_35_0 26
#define NUMBER_OF_LINKER_SECTIONS_35_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_35_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_35_7);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_35_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_35_11);
      goto label_8;

    case 6:
      current_block = (Rpc - LABEL_35_12);
      goto label_9;

    case 7:
      current_block = (Rpc - LABEL_35_13);
      goto label_10;

    case 8:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_1;

    case 9:
      current_block = (Rpc - LABEL_35_14);
      goto label_11;

    case 10:
      current_block = (Rpc - LABEL_35_15);
      goto label_12;

    case 11:
      current_block = (Rpc - LABEL_35_16);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_15)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_34;
  Wrd8 = Wrd12;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_32;
  Wrd15 = Wrd19;

DEFLABEL (label_31)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_30;
  Wrd21 = Wrd25;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_28;
  Wrd8 = Wrd12;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_3]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_26;
  Wrd15 = Wrd19;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_4]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_24;
  Wrd21 = Wrd25;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_10);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_35_0]));
  (Wrd6.Obj) = (current_block [OBJECT_35_0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_22;

DEFLABEL (label_21)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_20)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_5]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_19;
  Wrd18 = Wrd22;

DEFLABEL (label_18)
  Wrd17 = Wrd18;
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_17;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_17;
  (Wrd24.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_16)
  (Rsp [0]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_17]));

DEFLABEL (label_17)
  (Wrd33.Obj) = (current_block [OBJECT_35_1]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_16]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 2);

DEFLABEL (label_13)
  (Wrd24.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_15])), (Wrd19.pObj));

DEFLABEL (label_12)
  (Wrd18.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_22)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_21;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_35_14])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_11)
  goto label_20;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_13])), (Wrd22.pObj));

DEFLABEL (label_10)
  (Wrd21.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_12])), (Wrd16.pObj));

DEFLABEL (label_9)
  (Wrd15.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_11])), (Wrd9.pObj));

DEFLABEL (label_8)
  (Wrd8.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_8])), (Wrd22.pObj));

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_7])), (Wrd16.pObj));

DEFLABEL (label_6)
  (Wrd15.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_6])), (Wrd9.pObj));

DEFLABEL (label_5)
  (Wrd8.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define TAG_36_6 1
#define LABEL_36_8 7
#define TAG_36_9 2
#define LABEL_36_11 9
#define LABEL_36_12 11
#define LABEL_36_13 13
#define ENVIRONMENT_LABEL_36_3 25
#define DEBUGGING_LABEL_36_2 24
#define OBJECT_36_0 23
#define EXECUTE_CACHE_36_15 15
#define EXECUTE_CACHE_36_14 17
#define EXECUTE_CACHE_36_10 19
#define EXECUTE_CACHE_36_7 21
#define FREE_REFERENCES_LABEL_36_0 14
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto define_lookup_method_5;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto lambda_9;

    case 2:
      current_block = (Rpc - LABEL_36_8);
      goto lambda_10;

    case 3:
      current_block = (Rpc - LABEL_36_11);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_36_12);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_36_13);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_lookup_method_8)
DEFLABEL (define_lookup_method_5)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_36_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_36_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd14.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_7]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_36_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_36_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_36_8])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_10]));

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_36_8);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_36_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_15]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_36_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_36_13);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = (current_block [OBJECT_36_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_11)
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define TAG_37_6 1
#define LABEL_37_9 7
#define LABEL_37_8 9
#define LABEL_37_11 11
#define LABEL_37_12 13
#define LABEL_37_14 15
#define ENVIRONMENT_LABEL_37_3 29
#define DEBUGGING_LABEL_37_2 28
#define OBJECT_37_0 27
#define EXECUTE_CACHE_37_15 17
#define EXECUTE_CACHE_37_13 19
#define EXECUTE_CACHE_37_10 21
#define EXECUTE_CACHE_37_7 23
#define FREE_REFERENCE_37_0 26
#define FREE_REFERENCES_LABEL_37_0 16
#define NUMBER_OF_LINKER_SECTIONS_37_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcse1_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto define_assignment_method_5;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto lambda_10;

    case 2:
      current_block = (Rpc - LABEL_37_9);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_37_8);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_37_11);
      goto lambda_3;

    case 5:
      current_block = (Rpc - LABEL_37_12);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_37_14);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_assignment_method_9)
DEFLABEL (define_assignment_method_5)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [4]) = (Wrd6.Obj);
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd16.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_37_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_37_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_13;
  Wrd8 = Wrd12;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_11]))));
  (Wrd13.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd13.Obj);
  (Rsp [3]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37_9])), (Wrd9.pObj));

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_12;

DEFLABEL (lambda_11)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_37_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_37_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_15]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_37_14);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_14;
  Rvl = (current_block [OBJECT_37_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_7 7
#define LABEL_10 9
#define LABEL_11 11
#define LABEL_12 13
#define LABEL_13 15
#define LABEL_9 17
#define LABEL_16 19
#define LABEL_17 21
#define LABEL_15 23
#define LABEL_20 25
#define LABEL_21 27
#define LABEL_22 29
#define LABEL_23 31
#define LABEL_19 33
#define LABEL_25 35
#define LABEL_26 37
#define LABEL_24 39
#define LABEL_28 41
#define LABEL_29 43
#define LABEL_30 45
#define LABEL_31 47
#define LABEL_27 49
#define LABEL_33 51
#define LABEL_34 53
#define LABEL_32 55
#define LABEL_36 57
#define LABEL_37 59
#define LABEL_38 61
#define LABEL_39 63
#define LABEL_35 65
#define LABEL_41 67
#define LABEL_42 69
#define LABEL_40 71
#define LABEL_43 73
#define LABEL_45 75
#define LABEL_44 77
#define LABEL_48 79
#define LABEL_47 81
#define LABEL_50 83
#define LABEL_49 85
#define LABEL_52 87
#define LABEL_51 89
#define LABEL_54 91
#define LABEL_53 93
#define LABEL_56 95
#define LABEL_55 97
#define LABEL_58 99
#define LABEL_57 101
#define LABEL_60 103
#define LABEL_59 105
#define LABEL_62 107
#define LABEL_61 109
#define LABEL_64 111
#define LABEL_63 113
#define LABEL_65 115
#define LABEL_67 117
#define LABEL_66 119
#define LABEL_69 121
#define LABEL_68 123
#define LABEL_71 125
#define LABEL_70 127
#define LABEL_73 129
#define LABEL_72 131
#define LABEL_75 133
#define LABEL_74 135
#define LABEL_77 137
#define LABEL_76 139
#define LABEL_79 141
#define LABEL_78 143
#define LABEL_80 145
#define LABEL_81 147
#define LABEL_82 149
#define LABEL_83 151
#define LABEL_84 153
#define LABEL_86 155
#define LABEL_87 157
#define LABEL_88 159
#define LABEL_85 161
#define LABEL_91 163
#define LABEL_92 165
#define LABEL_93 167
#define LABEL_90 169
#define LABEL_95 171
#define LABEL_96 173
#define LABEL_97 175
#define LABEL_94 177
#define LABEL_99 179
#define LABEL_100 181
#define LABEL_101 183
#define LABEL_98 185
#define LABEL_103 187
#define LABEL_104 189
#define LABEL_105 191
#define LABEL_102 193
#define LABEL_107 195
#define LABEL_108 197
#define LABEL_109 199
#define LABEL_106 201
#define LABEL_110 203
#define LABEL_112 205
#define LABEL_113 207
#define LABEL_114 209
#define LABEL_115 211
#define LABEL_111 213
#define LABEL_118 215
#define LABEL_119 217
#define LABEL_120 219
#define LABEL_121 221
#define LABEL_117 223
#define LABEL_122 225
#define LABEL_123 227
#define LABEL_124 229
#define LABEL_125 231
#define LABEL_126 233
#define LABEL_127 235
#define LABEL_128 237
#define ENVIRONMENT_LABEL_3 377
#define DEBUGGING_LABEL_2 376
#define PURIFICATION_ROOT 375
#define OBJECT_63 374
#define OBJECT_62 373
#define OBJECT_61 372
#define OBJECT_60 371
#define OBJECT_59 370
#define OBJECT_58 369
#define OBJECT_57 368
#define OBJECT_56 367
#define OBJECT_55 366
#define OBJECT_54 365
#define OBJECT_53 364
#define OBJECT_52 363
#define OBJECT_51 362
#define OBJECT_50 361
#define OBJECT_49 360
#define OBJECT_48 359
#define OBJECT_47 358
#define OBJECT_46 357
#define OBJECT_45 356
#define OBJECT_44 355
#define OBJECT_43 354
#define OBJECT_42 353
#define OBJECT_41 352
#define OBJECT_40 351
#define OBJECT_39 350
#define OBJECT_38 349
#define OBJECT_37 348
#define OBJECT_36 347
#define OBJECT_35 346
#define OBJECT_34 345
#define OBJECT_33 344
#define OBJECT_32 343
#define OBJECT_31 342
#define OBJECT_30 341
#define OBJECT_29 340
#define OBJECT_28 339
#define OBJECT_27 338
#define OBJECT_26 337
#define OBJECT_25 336
#define OBJECT_24 335
#define OBJECT_23 334
#define OBJECT_22 333
#define OBJECT_21 332
#define OBJECT_20 331
#define OBJECT_19 330
#define OBJECT_18 329
#define OBJECT_17 328
#define OBJECT_16 327
#define OBJECT_15 326
#define OBJECT_14 325
#define OBJECT_13 324
#define OBJECT_12 323
#define OBJECT_11 322
#define OBJECT_10 321
#define OBJECT_9 320
#define OBJECT_8 319
#define OBJECT_7 318
#define OBJECT_6 317
#define OBJECT_5 316
#define OBJECT_4 315
#define OBJECT_3 314
#define OBJECT_2 313
#define OBJECT_1 312
#define OBJECT_0 311
#define EXECUTE_CACHE_116 239
#define EXECUTE_CACHE_89 241
#define EXECUTE_CACHE_46 243
#define EXECUTE_CACHE_18 245
#define EXECUTE_CACHE_14 247
#define FREE_REFERENCE_55 250
#define FREE_REFERENCE_54 251
#define FREE_REFERENCE_53 252
#define FREE_REFERENCE_52 253
#define FREE_REFERENCE_51 254
#define FREE_REFERENCE_50 255
#define FREE_REFERENCE_49 256
#define FREE_REFERENCE_48 257
#define FREE_REFERENCE_47 258
#define FREE_REFERENCE_46 259
#define FREE_REFERENCE_45 260
#define FREE_REFERENCE_44 261
#define FREE_REFERENCE_43 262
#define FREE_REFERENCE_42 263
#define FREE_REFERENCE_41 264
#define FREE_REFERENCE_40 265
#define FREE_REFERENCE_39 266
#define FREE_REFERENCE_38 267
#define FREE_REFERENCE_37 268
#define FREE_REFERENCE_36 269
#define FREE_REFERENCE_35 270
#define FREE_REFERENCE_34 271
#define FREE_REFERENCE_33 272
#define FREE_REFERENCE_32 273
#define FREE_REFERENCE_31 274
#define FREE_REFERENCE_30 275
#define FREE_REFERENCE_29 276
#define FREE_REFERENCE_28 277
#define FREE_REFERENCE_27 278
#define FREE_REFERENCE_26 279
#define FREE_REFERENCE_25 280
#define FREE_REFERENCE_24 281
#define FREE_REFERENCE_23 282
#define FREE_REFERENCE_22 283
#define FREE_REFERENCE_21 284
#define FREE_REFERENCE_20 285
#define FREE_REFERENCE_19 286
#define FREE_REFERENCE_18 287
#define FREE_REFERENCE_17 288
#define FREE_REFERENCE_16 289
#define FREE_REFERENCE_15 290
#define FREE_REFERENCE_14 291
#define FREE_REFERENCE_13 292
#define FREE_REFERENCE_12 293
#define FREE_REFERENCE_11 294
#define FREE_REFERENCE_10 295
#define FREE_REFERENCE_9 296
#define FREE_REFERENCE_8 297
#define FREE_REFERENCE_7 298
#define FREE_REFERENCE_6 299
#define FREE_REFERENCE_5 300
#define FREE_REFERENCE_4 301
#define FREE_REFERENCE_3 302
#define FREE_REFERENCE_2 303
#define FREE_REFERENCE_1 304
#define FREE_REFERENCE_0 305
#define GLOBAL_EXECUTE_CACHE_8 307
#define GLOBAL_EXECUTE_CACHE_6 309
#define FREE_REFERENCES_LABEL_0 238
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
rcse1_so_56d55eb8a5a8b574 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_10);
      goto label_47;

    case 4:
      current_block = (Rpc - LABEL_11);
      goto label_48;

    case 5:
      current_block = (Rpc - LABEL_12);
      goto label_49;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto label_50;

    case 7:
      current_block = (Rpc - LABEL_9);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_16);
      goto label_51;

    case 9:
      current_block = (Rpc - LABEL_17);
      goto label_52;

    case 10:
      current_block = (Rpc - LABEL_15);
      goto continuation_5;

    case 11:
      current_block = (Rpc - LABEL_20);
      goto label_53;

    case 12:
      current_block = (Rpc - LABEL_21);
      goto label_54;

    case 13:
      current_block = (Rpc - LABEL_22);
      goto label_55;

    case 14:
      current_block = (Rpc - LABEL_23);
      goto label_56;

    case 15:
      current_block = (Rpc - LABEL_19);
      goto continuation_6;

    case 16:
      current_block = (Rpc - LABEL_25);
      goto label_57;

    case 17:
      current_block = (Rpc - LABEL_26);
      goto label_58;

    case 18:
      current_block = (Rpc - LABEL_24);
      goto continuation_7;

    case 19:
      current_block = (Rpc - LABEL_28);
      goto label_59;

    case 20:
      current_block = (Rpc - LABEL_29);
      goto label_60;

    case 21:
      current_block = (Rpc - LABEL_30);
      goto label_61;

    case 22:
      current_block = (Rpc - LABEL_31);
      goto label_62;

    case 23:
      current_block = (Rpc - LABEL_27);
      goto continuation_8;

    case 24:
      current_block = (Rpc - LABEL_33);
      goto label_63;

    case 25:
      current_block = (Rpc - LABEL_34);
      goto label_64;

    case 26:
      current_block = (Rpc - LABEL_32);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_36);
      goto label_65;

    case 28:
      current_block = (Rpc - LABEL_37);
      goto label_66;

    case 29:
      current_block = (Rpc - LABEL_38);
      goto label_67;

    case 30:
      current_block = (Rpc - LABEL_39);
      goto label_68;

    case 31:
      current_block = (Rpc - LABEL_35);
      goto continuation_10;

    case 32:
      current_block = (Rpc - LABEL_41);
      goto label_69;

    case 33:
      current_block = (Rpc - LABEL_42);
      goto label_70;

    case 34:
      current_block = (Rpc - LABEL_40);
      goto continuation_11;

    case 35:
      current_block = (Rpc - LABEL_43);
      goto continuation_12;

    case 36:
      current_block = (Rpc - LABEL_45);
      goto label_71;

    case 37:
      current_block = (Rpc - LABEL_44);
      goto continuation_13;

    case 38:
      current_block = (Rpc - LABEL_48);
      goto label_72;

    case 39:
      current_block = (Rpc - LABEL_47);
      goto continuation_14;

    case 40:
      current_block = (Rpc - LABEL_50);
      goto label_73;

    case 41:
      current_block = (Rpc - LABEL_49);
      goto continuation_15;

    case 42:
      current_block = (Rpc - LABEL_52);
      goto label_74;

    case 43:
      current_block = (Rpc - LABEL_51);
      goto continuation_16;

    case 44:
      current_block = (Rpc - LABEL_54);
      goto label_75;

    case 45:
      current_block = (Rpc - LABEL_53);
      goto continuation_17;

    case 46:
      current_block = (Rpc - LABEL_56);
      goto label_76;

    case 47:
      current_block = (Rpc - LABEL_55);
      goto continuation_18;

    case 48:
      current_block = (Rpc - LABEL_58);
      goto label_77;

    case 49:
      current_block = (Rpc - LABEL_57);
      goto continuation_19;

    case 50:
      current_block = (Rpc - LABEL_60);
      goto label_78;

    case 51:
      current_block = (Rpc - LABEL_59);
      goto continuation_20;

    case 52:
      current_block = (Rpc - LABEL_62);
      goto label_79;

    case 53:
      current_block = (Rpc - LABEL_61);
      goto continuation_21;

    case 54:
      current_block = (Rpc - LABEL_64);
      goto label_80;

    case 55:
      current_block = (Rpc - LABEL_63);
      goto continuation_22;

    case 56:
      current_block = (Rpc - LABEL_65);
      goto continuation_23;

    case 57:
      current_block = (Rpc - LABEL_67);
      goto label_81;

    case 58:
      current_block = (Rpc - LABEL_66);
      goto continuation_24;

    case 59:
      current_block = (Rpc - LABEL_69);
      goto label_82;

    case 60:
      current_block = (Rpc - LABEL_68);
      goto continuation_25;

    case 61:
      current_block = (Rpc - LABEL_71);
      goto label_83;

    case 62:
      current_block = (Rpc - LABEL_70);
      goto continuation_26;

    case 63:
      current_block = (Rpc - LABEL_73);
      goto label_84;

    case 64:
      current_block = (Rpc - LABEL_72);
      goto continuation_27;

    case 65:
      current_block = (Rpc - LABEL_75);
      goto label_85;

    case 66:
      current_block = (Rpc - LABEL_74);
      goto continuation_28;

    case 67:
      current_block = (Rpc - LABEL_77);
      goto label_86;

    case 68:
      current_block = (Rpc - LABEL_76);
      goto continuation_29;

    case 69:
      current_block = (Rpc - LABEL_79);
      goto label_87;

    case 70:
      current_block = (Rpc - LABEL_78);
      goto continuation_30;

    case 71:
      current_block = (Rpc - LABEL_80);
      goto continuation_31;

    case 72:
      current_block = (Rpc - LABEL_81);
      goto continuation_32;

    case 73:
      current_block = (Rpc - LABEL_82);
      goto continuation_33;

    case 74:
      current_block = (Rpc - LABEL_83);
      goto continuation_34;

    case 75:
      current_block = (Rpc - LABEL_84);
      goto continuation_35;

    case 76:
      current_block = (Rpc - LABEL_86);
      goto label_88;

    case 77:
      current_block = (Rpc - LABEL_87);
      goto label_89;

    case 78:
      current_block = (Rpc - LABEL_88);
      goto label_90;

    case 79:
      current_block = (Rpc - LABEL_85);
      goto continuation_36;

    case 80:
      current_block = (Rpc - LABEL_91);
      goto label_91;

    case 81:
      current_block = (Rpc - LABEL_92);
      goto label_92;

    case 82:
      current_block = (Rpc - LABEL_93);
      goto label_93;

    case 83:
      current_block = (Rpc - LABEL_90);
      goto continuation_37;

    case 84:
      current_block = (Rpc - LABEL_95);
      goto label_94;

    case 85:
      current_block = (Rpc - LABEL_96);
      goto label_95;

    case 86:
      current_block = (Rpc - LABEL_97);
      goto label_96;

    case 87:
      current_block = (Rpc - LABEL_94);
      goto continuation_38;

    case 88:
      current_block = (Rpc - LABEL_99);
      goto label_97;

    case 89:
      current_block = (Rpc - LABEL_100);
      goto label_98;

    case 90:
      current_block = (Rpc - LABEL_101);
      goto label_99;

    case 91:
      current_block = (Rpc - LABEL_98);
      goto continuation_39;

    case 92:
      current_block = (Rpc - LABEL_103);
      goto label_100;

    case 93:
      current_block = (Rpc - LABEL_104);
      goto label_101;

    case 94:
      current_block = (Rpc - LABEL_105);
      goto label_102;

    case 95:
      current_block = (Rpc - LABEL_102);
      goto continuation_40;

    case 96:
      current_block = (Rpc - LABEL_107);
      goto label_103;

    case 97:
      current_block = (Rpc - LABEL_108);
      goto label_104;

    case 98:
      current_block = (Rpc - LABEL_109);
      goto label_105;

    case 99:
      current_block = (Rpc - LABEL_106);
      goto continuation_41;

    case 100:
      current_block = (Rpc - LABEL_110);
      goto continuation_42;

    case 101:
      current_block = (Rpc - LABEL_112);
      goto label_106;

    case 102:
      current_block = (Rpc - LABEL_113);
      goto label_107;

    case 103:
      current_block = (Rpc - LABEL_114);
      goto label_108;

    case 104:
      current_block = (Rpc - LABEL_115);
      goto label_109;

    case 105:
      current_block = (Rpc - LABEL_111);
      goto continuation_43;

    case 106:
      current_block = (Rpc - LABEL_118);
      goto label_110;

    case 107:
      current_block = (Rpc - LABEL_119);
      goto label_111;

    case 108:
      current_block = (Rpc - LABEL_120);
      goto label_112;

    case 109:
      current_block = (Rpc - LABEL_121);
      goto label_113;

    case 110:
      current_block = (Rpc - LABEL_117);
      goto continuation_44;

    case 111:
      current_block = (Rpc - LABEL_122);
      goto label_114;

    case 112:
      current_block = (Rpc - LABEL_123);
      goto label_115;

    case 113:
      current_block = (Rpc - LABEL_124);
      goto label_116;

    case 114:
      current_block = (Rpc - LABEL_125);
      goto label_117;

    case 115:
      current_block = (Rpc - LABEL_126);
      goto label_120;

    case 116:
      current_block = (Rpc - LABEL_127);
      goto label_121;

    case 117:
      current_block = (Rpc - LABEL_128);
      goto expression_46;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_46)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_127])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_121)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_120)
  {
    static const short sections [] =
      {
	0,
	2,
	1,
	3,
	3,
	2,
	2,
	2,
	0,
	2,
	2,
	0,
	1,
	1,
	2,
	1,
	2,
	1,
	3,
	2,
	3,
	1,
	1,
	3,
	2,
	3,
	0,
	0,
	0,
	0,
	0,
	3,
	3,
	2,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 37)
      goto label_119;
    blocks = (current_block [OBJECT_63]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_126])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_119)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd21.Obj) = (MAKE_OBJECT (0, 4));
  (Wrd22.Obj) = (current_block [OBJECT_1]);
  (Wrd23.Obj) = (current_block [OBJECT_2]);
  (Wrd24.Obj) = (current_block [OBJECT_3]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_4]);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd16.pObj) = (& (Rhp [-5]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_263;
  Wrd8 = Wrd12;

DEFLABEL (label_262)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_261;
  Wrd14 = Wrd18;

DEFLABEL (label_260)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_259;
  Wrd20 = Wrd24;

DEFLABEL (label_258)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_257;
  Wrd26 = Wrd30;

DEFLABEL (label_256)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_255;
  Wrd8 = Wrd12;

DEFLABEL (label_254)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_253;
  Wrd14 = Wrd18;

DEFLABEL (label_252)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_251;
  Wrd8 = Wrd12;

DEFLABEL (label_250)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_249;
  Wrd14 = Wrd18;

DEFLABEL (label_248)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_247;
  Wrd20 = Wrd24;

DEFLABEL (label_246)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_245;
  Wrd26 = Wrd30;

DEFLABEL (label_244)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_243;
  Wrd8 = Wrd12;

DEFLABEL (label_242)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_241;
  Wrd14 = Wrd18;

DEFLABEL (label_240)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_239;
  Wrd8 = Wrd12;

DEFLABEL (label_238)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_237;
  Wrd14 = Wrd18;

DEFLABEL (label_236)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_235;
  Wrd20 = Wrd24;

DEFLABEL (label_234)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_233;
  Wrd26 = Wrd30;

DEFLABEL (label_232)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_231;
  Wrd8 = Wrd12;

DEFLABEL (label_230)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_229;
  Wrd14 = Wrd18;

DEFLABEL (label_228)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_227;
  Wrd8 = Wrd12;

DEFLABEL (label_226)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_225;
  Wrd14 = Wrd18;

DEFLABEL (label_224)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_223;
  Wrd20 = Wrd24;

DEFLABEL (label_222)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_221;
  Wrd26 = Wrd30;

DEFLABEL (label_220)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_219;
  Wrd8 = Wrd12;

DEFLABEL (label_218)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_217;
  Wrd14 = Wrd18;

DEFLABEL (label_216)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 3);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_43);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_215;
  Wrd8 = Wrd12;

DEFLABEL (label_214)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_213;
  Wrd8 = Wrd12;

DEFLABEL (label_212)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_47);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_211;
  Wrd8 = Wrd12;

DEFLABEL (label_210)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_49);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_209;
  Wrd8 = Wrd12;

DEFLABEL (label_208)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_207;
  Wrd8 = Wrd12;

DEFLABEL (label_206)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_53);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_205;
  Wrd8 = Wrd12;

DEFLABEL (label_204)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_55);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_203;
  Wrd8 = Wrd12;

DEFLABEL (label_202)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_57);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_201;
  Wrd8 = Wrd12;

DEFLABEL (label_200)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_59);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_199;
  Wrd8 = Wrd12;

DEFLABEL (label_198)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_197;
  Wrd8 = Wrd12;

DEFLABEL (label_196)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_63);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 3);

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_65);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_195;
  Wrd8 = Wrd12;

DEFLABEL (label_194)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_66);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_193;
  Wrd8 = Wrd12;

DEFLABEL (label_192)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_68);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_191;
  Wrd8 = Wrd12;

DEFLABEL (label_190)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_70);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_189;
  Wrd8 = Wrd12;

DEFLABEL (label_188)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_72);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_187;
  Wrd8 = Wrd12;

DEFLABEL (label_186)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_74);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_185;
  Wrd8 = Wrd12;

DEFLABEL (label_184)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_183;
  Wrd8 = Wrd12;

DEFLABEL (label_182)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_78);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_80);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_81);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_83);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 3);

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_84);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_181;
  Wrd8 = Wrd12;

DEFLABEL (label_180)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_179;
  Wrd14 = Wrd18;

DEFLABEL (label_178)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_177;
  Wrd20 = Wrd24;

DEFLABEL (label_176)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_85);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_175;
  Wrd8 = Wrd12;

DEFLABEL (label_174)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_173;
  Wrd14 = Wrd18;

DEFLABEL (label_172)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_171;
  Wrd20 = Wrd24;

DEFLABEL (label_170)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_90);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_169;
  Wrd8 = Wrd12;

DEFLABEL (label_168)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_167;
  Wrd14 = Wrd18;

DEFLABEL (label_166)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_165;
  Wrd20 = Wrd24;

DEFLABEL (label_164)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_94);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_163;
  Wrd8 = Wrd12;

DEFLABEL (label_162)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_161;
  Wrd14 = Wrd18;

DEFLABEL (label_160)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_37]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_159;
  Wrd20 = Wrd24;

DEFLABEL (label_158)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_98);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_38]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_157;
  Wrd8 = Wrd12;

DEFLABEL (label_156)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_39]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_155;
  Wrd14 = Wrd18;

DEFLABEL (label_154)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_153;
  Wrd20 = Wrd24;

DEFLABEL (label_152)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_102);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_151;
  Wrd8 = Wrd12;

DEFLABEL (label_150)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_149;
  Wrd14 = Wrd18;

DEFLABEL (label_148)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_43]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_147;
  Wrd20 = Wrd24;

DEFLABEL (label_146)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_57]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_106);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 3);

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_110);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_44]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_145;
  Wrd8 = Wrd12;

DEFLABEL (label_144)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_143;
  Wrd14 = Wrd18;

DEFLABEL (label_142)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_141;
  Wrd20 = Wrd24;

DEFLABEL (label_140)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_139;
  Wrd26 = Wrd30;

DEFLABEL (label_138)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_111);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_48]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_137;
  Wrd8 = Wrd12;

DEFLABEL (label_136)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_135;
  Wrd14 = Wrd18;

DEFLABEL (label_134)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_133;
  Wrd20 = Wrd24;

DEFLABEL (label_132)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_51]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_131;
  Wrd26 = Wrd30;

DEFLABEL (label_130)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_117);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_129;
  Wrd5 = Wrd9;

DEFLABEL (label_128)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_53]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_127;
  Wrd11 = Wrd15;

DEFLABEL (label_126)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_125;
  Wrd17 = Wrd21;

DEFLABEL (label_124)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_123;
  Wrd25 = Wrd29;

DEFLABEL (label_122)
  (Rsp [4]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_125])), (Wrd26.pObj));

DEFLABEL (label_117)
  (Wrd25.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_124])), (Wrd18.pObj));

DEFLABEL (label_116)
  (Wrd17.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_123])), (Wrd12.pObj));

DEFLABEL (label_115)
  (Wrd11.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_122])), (Wrd6.pObj));

DEFLABEL (label_114)
  (Wrd5.Obj) = Rvl;
  goto label_128;

DEFLABEL (label_131)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_121])), (Wrd27.pObj));

DEFLABEL (label_113)
  (Wrd26.Obj) = Rvl;
  goto label_130;

DEFLABEL (label_133)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_120])), (Wrd21.pObj));

DEFLABEL (label_112)
  (Wrd20.Obj) = Rvl;
  goto label_132;

DEFLABEL (label_135)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_119])), (Wrd15.pObj));

DEFLABEL (label_111)
  (Wrd14.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_118])), (Wrd9.pObj));

DEFLABEL (label_110)
  (Wrd8.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_115])), (Wrd27.pObj));

DEFLABEL (label_109)
  (Wrd26.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_114])), (Wrd21.pObj));

DEFLABEL (label_108)
  (Wrd20.Obj) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113])), (Wrd15.pObj));

DEFLABEL (label_107)
  (Wrd14.Obj) = Rvl;
  goto label_142;

DEFLABEL (label_145)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_112])), (Wrd9.pObj));

DEFLABEL (label_106)
  (Wrd8.Obj) = Rvl;
  goto label_144;

DEFLABEL (label_147)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_109])), (Wrd21.pObj));

DEFLABEL (label_105)
  (Wrd20.Obj) = Rvl;
  goto label_146;

DEFLABEL (label_149)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_108])), (Wrd15.pObj));

DEFLABEL (label_104)
  (Wrd14.Obj) = Rvl;
  goto label_148;

DEFLABEL (label_151)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107])), (Wrd9.pObj));

DEFLABEL (label_103)
  (Wrd8.Obj) = Rvl;
  goto label_150;

DEFLABEL (label_153)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105])), (Wrd21.pObj));

DEFLABEL (label_102)
  (Wrd20.Obj) = Rvl;
  goto label_152;

DEFLABEL (label_155)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104])), (Wrd15.pObj));

DEFLABEL (label_101)
  (Wrd14.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103])), (Wrd9.pObj));

DEFLABEL (label_100)
  (Wrd8.Obj) = Rvl;
  goto label_156;

DEFLABEL (label_159)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101])), (Wrd21.pObj));

DEFLABEL (label_99)
  (Wrd20.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_161)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100])), (Wrd15.pObj));

DEFLABEL (label_98)
  (Wrd14.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_163)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99])), (Wrd9.pObj));

DEFLABEL (label_97)
  (Wrd8.Obj) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_97])), (Wrd21.pObj));

DEFLABEL (label_96)
  (Wrd20.Obj) = Rvl;
  goto label_164;

DEFLABEL (label_167)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96])), (Wrd15.pObj));

DEFLABEL (label_95)
  (Wrd14.Obj) = Rvl;
  goto label_166;

DEFLABEL (label_169)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95])), (Wrd9.pObj));

DEFLABEL (label_94)
  (Wrd8.Obj) = Rvl;
  goto label_168;

DEFLABEL (label_171)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93])), (Wrd21.pObj));

DEFLABEL (label_93)
  (Wrd20.Obj) = Rvl;
  goto label_170;

DEFLABEL (label_173)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_92])), (Wrd15.pObj));

DEFLABEL (label_92)
  (Wrd14.Obj) = Rvl;
  goto label_172;

DEFLABEL (label_175)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_91])), (Wrd9.pObj));

DEFLABEL (label_91)
  (Wrd8.Obj) = Rvl;
  goto label_174;

DEFLABEL (label_177)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_88])), (Wrd21.pObj));

DEFLABEL (label_90)
  (Wrd20.Obj) = Rvl;
  goto label_176;

DEFLABEL (label_179)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_87])), (Wrd15.pObj));

DEFLABEL (label_89)
  (Wrd14.Obj) = Rvl;
  goto label_178;

DEFLABEL (label_181)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_86])), (Wrd9.pObj));

DEFLABEL (label_88)
  (Wrd8.Obj) = Rvl;
  goto label_180;

DEFLABEL (label_183)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79])), (Wrd9.pObj));

DEFLABEL (label_87)
  (Wrd8.Obj) = Rvl;
  goto label_182;

DEFLABEL (label_185)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77])), (Wrd9.pObj));

DEFLABEL (label_86)
  (Wrd8.Obj) = Rvl;
  goto label_184;

DEFLABEL (label_187)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75])), (Wrd9.pObj));

DEFLABEL (label_85)
  (Wrd8.Obj) = Rvl;
  goto label_186;

DEFLABEL (label_189)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_73])), (Wrd9.pObj));

DEFLABEL (label_84)
  (Wrd8.Obj) = Rvl;
  goto label_188;

DEFLABEL (label_191)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71])), (Wrd9.pObj));

DEFLABEL (label_83)
  (Wrd8.Obj) = Rvl;
  goto label_190;

DEFLABEL (label_193)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69])), (Wrd9.pObj));

DEFLABEL (label_82)
  (Wrd8.Obj) = Rvl;
  goto label_192;

DEFLABEL (label_195)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67])), (Wrd9.pObj));

DEFLABEL (label_81)
  (Wrd8.Obj) = Rvl;
  goto label_194;

DEFLABEL (label_197)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64])), (Wrd9.pObj));

DEFLABEL (label_80)
  (Wrd8.Obj) = Rvl;
  goto label_196;

DEFLABEL (label_199)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62])), (Wrd9.pObj));

DEFLABEL (label_79)
  (Wrd8.Obj) = Rvl;
  goto label_198;

DEFLABEL (label_201)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd9.pObj));

DEFLABEL (label_78)
  (Wrd8.Obj) = Rvl;
  goto label_200;

DEFLABEL (label_203)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58])), (Wrd9.pObj));

DEFLABEL (label_77)
  (Wrd8.Obj) = Rvl;
  goto label_202;

DEFLABEL (label_205)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd9.pObj));

DEFLABEL (label_76)
  (Wrd8.Obj) = Rvl;
  goto label_204;

DEFLABEL (label_207)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54])), (Wrd9.pObj));

DEFLABEL (label_75)
  (Wrd8.Obj) = Rvl;
  goto label_206;

DEFLABEL (label_209)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52])), (Wrd9.pObj));

DEFLABEL (label_74)
  (Wrd8.Obj) = Rvl;
  goto label_208;

DEFLABEL (label_211)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50])), (Wrd9.pObj));

DEFLABEL (label_73)
  (Wrd8.Obj) = Rvl;
  goto label_210;

DEFLABEL (label_213)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_48])), (Wrd9.pObj));

DEFLABEL (label_72)
  (Wrd8.Obj) = Rvl;
  goto label_212;

DEFLABEL (label_215)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45])), (Wrd9.pObj));

DEFLABEL (label_71)
  (Wrd8.Obj) = Rvl;
  goto label_214;

DEFLABEL (label_217)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42])), (Wrd15.pObj));

DEFLABEL (label_70)
  (Wrd14.Obj) = Rvl;
  goto label_216;

DEFLABEL (label_219)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41])), (Wrd9.pObj));

DEFLABEL (label_69)
  (Wrd8.Obj) = Rvl;
  goto label_218;

DEFLABEL (label_221)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_39])), (Wrd27.pObj));

DEFLABEL (label_68)
  (Wrd26.Obj) = Rvl;
  goto label_220;

DEFLABEL (label_223)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38])), (Wrd21.pObj));

DEFLABEL (label_67)
  (Wrd20.Obj) = Rvl;
  goto label_222;

DEFLABEL (label_225)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37])), (Wrd15.pObj));

DEFLABEL (label_66)
  (Wrd14.Obj) = Rvl;
  goto label_224;

DEFLABEL (label_227)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36])), (Wrd9.pObj));

DEFLABEL (label_65)
  (Wrd8.Obj) = Rvl;
  goto label_226;

DEFLABEL (label_229)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34])), (Wrd15.pObj));

DEFLABEL (label_64)
  (Wrd14.Obj) = Rvl;
  goto label_228;

DEFLABEL (label_231)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33])), (Wrd9.pObj));

DEFLABEL (label_63)
  (Wrd8.Obj) = Rvl;
  goto label_230;

DEFLABEL (label_233)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31])), (Wrd27.pObj));

DEFLABEL (label_62)
  (Wrd26.Obj) = Rvl;
  goto label_232;

DEFLABEL (label_235)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30])), (Wrd21.pObj));

DEFLABEL (label_61)
  (Wrd20.Obj) = Rvl;
  goto label_234;

DEFLABEL (label_237)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29])), (Wrd15.pObj));

DEFLABEL (label_60)
  (Wrd14.Obj) = Rvl;
  goto label_236;

DEFLABEL (label_239)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28])), (Wrd9.pObj));

DEFLABEL (label_59)
  (Wrd8.Obj) = Rvl;
  goto label_238;

DEFLABEL (label_241)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26])), (Wrd15.pObj));

DEFLABEL (label_58)
  (Wrd14.Obj) = Rvl;
  goto label_240;

DEFLABEL (label_243)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25])), (Wrd9.pObj));

DEFLABEL (label_57)
  (Wrd8.Obj) = Rvl;
  goto label_242;

DEFLABEL (label_245)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23])), (Wrd27.pObj));

DEFLABEL (label_56)
  (Wrd26.Obj) = Rvl;
  goto label_244;

DEFLABEL (label_247)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22])), (Wrd21.pObj));

DEFLABEL (label_55)
  (Wrd20.Obj) = Rvl;
  goto label_246;

DEFLABEL (label_249)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21])), (Wrd15.pObj));

DEFLABEL (label_54)
  (Wrd14.Obj) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20])), (Wrd9.pObj));

DEFLABEL (label_53)
  (Wrd8.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17])), (Wrd15.pObj));

DEFLABEL (label_52)
  (Wrd14.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16])), (Wrd9.pObj));

DEFLABEL (label_51)
  (Wrd8.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13])), (Wrd27.pObj));

DEFLABEL (label_50)
  (Wrd26.Obj) = Rvl;
  goto label_256;

DEFLABEL (label_259)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12])), (Wrd21.pObj));

DEFLABEL (label_49)
  (Wrd20.Obj) = Rvl;
  goto label_258;

DEFLABEL (label_261)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd15.pObj));

DEFLABEL (label_48)
  (Wrd14.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10])), (Wrd9.pObj));

DEFLABEL (label_47)
  (Wrd8.Obj) = Rvl;
  goto label_262;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_rcse1_so_56d55eb8a5a8b574 [37] =
  {
    { "rcse1_so_code_1", 1, rcse1_so_code_1 },
    { "rcse1_so_code_2", 1, rcse1_so_code_2 },
    { "rcse1_so_code_3", 1, rcse1_so_code_3 },
    { "rcse1_so_code_4", 1, rcse1_so_code_4 },
    { "rcse1_so_code_5", 3, rcse1_so_code_5 },
    { "rcse1_so_code_6", 47, rcse1_so_code_6 },
    { "rcse1_so_code_7", 22, rcse1_so_code_7 },
    { "rcse1_so_code_8", 1, rcse1_so_code_8 },
    { "rcse1_so_code_9", 1, rcse1_so_code_9 },
    { "rcse1_so_code_10", 1, rcse1_so_code_10 },
    { "rcse1_so_code_11", 1, rcse1_so_code_11 },
    { "rcse1_so_code_12", 1, rcse1_so_code_12 },
    { "rcse1_so_code_13", 7, rcse1_so_code_13 },
    { "rcse1_so_code_14", 12, rcse1_so_code_14 },
    { "rcse1_so_code_15", 43, rcse1_so_code_15 },
    { "rcse1_so_code_16", 2, rcse1_so_code_16 },
    { "rcse1_so_code_17", 3, rcse1_so_code_17 },
    { "rcse1_so_code_18", 6, rcse1_so_code_18 },
    { "rcse1_so_code_19", 24, rcse1_so_code_19 },
    { "rcse1_so_code_20", 22, rcse1_so_code_20 },
    { "rcse1_so_code_21", 3, rcse1_so_code_21 },
    { "rcse1_so_code_22", 9, rcse1_so_code_22 },
    { "rcse1_so_code_23", 4, rcse1_so_code_23 },
    { "rcse1_so_code_24", 19, rcse1_so_code_24 },
    { "rcse1_so_code_25", 5, rcse1_so_code_25 },
    { "rcse1_so_code_26", 3, rcse1_so_code_26 },
    { "rcse1_so_code_27", 1, rcse1_so_code_27 },
    { "rcse1_so_code_28", 3, rcse1_so_code_28 },
    { "rcse1_so_code_29", 5, rcse1_so_code_29 },
    { "rcse1_so_code_30", 1, rcse1_so_code_30 },
    { "rcse1_so_code_31", 14, rcse1_so_code_31 },
    { "rcse1_so_code_32", 5, rcse1_so_code_32 },
    { "rcse1_so_code_33", 5, rcse1_so_code_33 },
    { "rcse1_so_code_34", 8, rcse1_so_code_34 },
    { "rcse1_so_code_35", 12, rcse1_so_code_35 },
    { "rcse1_so_code_36", 6, rcse1_so_code_36 },
    { "rcse1_so_code_37", 7, rcse1_so_code_37 }
  };

int
decl_rcse1_so_56d55eb8a5a8b574 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcse1_so_56d55eb8a5a8b574);
  return (0);
}

DECLARE_COMPILED_CODE ("rcse1.so", 118, decl_rcse1_so_56d55eb8a5a8b574, rcse1_so_56d55eb8a5a8b574)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_rcse1_so_data_56d55eb8a5a8b574 [10245] =
  "\xfa\x02\x3f\xcd\x0e\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21"
  "\x9c\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83"
  "\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c\x2b"
  "\xbc\x1d\xb0\x85\x88\x0d\xbd\x24\x28\x0d\x28\x0d\xbe\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\xbf\x1d\xb0\x86\x88\xc2\x1c\x1d\x80"
  "\x08\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x25\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28\x0d\x28\x0d\x28"
  "\x0d\x28\x0d\x28\xb6\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe"
  "\x1d\xb0\x02\x88\x1d\x83\x82\x81\x1b\x80\xc1\x1c\xc1\x1c\x08\x1b"
  "\x1b\x1b\x1b\x1b\x25\x1b\x1b\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x80\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x08\x80\x1b\x1b\x1b\x25\x1b\x24\x28\x0d\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x0d\x80\x1b\x0c\x1b\x1b\x86"
  "\x1b\x25\x0d\x1c\x0d\x1c\x1b\x1b\x24\x28\x0d\x28\x0d\x1c\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2\x1b\x25"
  "\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x02\x0d\x1b\x0d\x1c\x1b"
  "\xc2\x86\x0d\x0d\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x24\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x85\x02\x1d\x1b"
  "\x81\x08\x86\x0d\x1c\x1b\x1b\x25\x0d\x1c\x24\x28\x1b\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1b\x08\x80\x1b\x81\x1b\x1b\x1b\x24\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x0d\x08\x89\x1b\x1b\x0d\x24\x28"
  "\x0d\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28\x1b"
  "\x28\x0d\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1d\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c"
  "\x24\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x82\x84\x1d\x1b\x83\x1b\x1b"
  "\x1b\x1b\x24\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x0d\x0d\x24\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x0d"
  "\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x08\x1b\x25\x1b\x0d\x0d"
  "\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x81\x08\x1b\x25\x1b\x0d\x0d\x0d\x0d\x1b\x24\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88"
  "\x1b\x0d\x0d\x0d\x0d\x1c\x1b\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1c"
  "\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x1c\x1b\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\xc3\x0d"
  "\x0d\x1c\x0d\x1c\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d"
  "\x0d\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x1b\x1b\xb5\x0d\x1b\x1b\x17\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x08\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a"
  "\xb7\x2a\x1e\x1e\x17\x0d\x0c\x0d\x0d\x0d\x0d\x9b\x83\x82\x81\x80"
  "\x9b\xb4\x2a\xb3\x2a\xb2\x2a\xb1\x2a\x84\x28\x0d\x28\x0d\x26\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x02\x4e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f"
  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30"
  "\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
  "\x72\x74\x6c\x6f\x70\x74\x2f\x72\x63\x73\x65\x31\x2e\x69\x6e\x66"
  "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
  "\x72\x6f\x6f\x74\x5d\x02\x77\x04\x82\x02\x03\x02\x78\x04\x82\x02"
  "\x03\x02\x79\x04\x82\x02\x03\x02\x7a\x04\x82\x02\x03\x02\x0b\x63"
  "\x73\x65\x2d\x72\x67\x72\x61\x70\x68\x02\x03\x14\x77\x69\x74\x68"
  "\x2d\x6e\x65\x77\x2d\x6e\x6f\x64\x65\x2d\x6d\x61\x72\x6b\x73\x04"
  "\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x03\x7d\x08\x81\x83\x02\x7c"
  "\x06\x81\x83\x02\x7b\x04\x83\x04\x07\x11\x02\x0b\x76\x65\x63\x74"
  "\x6f\x72\x2d\x72\x65\x66\x09\x02\x11\x2a\x63\x75\x72\x72\x65\x6e"
  "\x74\x2d\x72\x67\x72\x61\x70\x68\x2a\x0a\x17\x2a\x6e\x65\x78\x74"
  "\x2d\x71\x75\x61\x6e\x74\x69\x74\x79\x2d\x6e\x75\x6d\x62\x65\x72"
  "\x2a\x0b\x10\x2a\x69\x6e\x69\x74\x69\x61\x6c\x2d\x71\x75\x65\x75"
  "\x65\x2a\x0c\x0f\x2a\x62\x72\x61\x6e\x63\x68\x2d\x71\x75\x65\x75"
  "\x65\x2a\x0d\x12\x2a\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x74\x61"
  "\x62\x6c\x65\x73\x2a\x0e\x0d\x2a\x68\x61\x73\x68\x2d\x74\x61\x62"
  "\x6c\x65\x2a\x0f\x0f\x2a\x73\x74\x61\x63\x6b\x2d\x6f\x66\x66\x73"
  "\x65\x74\x2a\x10\x1d\x2a\x73\x74\x61\x63\x6b\x2d\x72\x65\x66\x65"
  "\x72\x65\x6e\x63\x65\x2d\x71\x75\x61\x6e\x74\x69\x74\x69\x65\x73"
  "\x2a\x11\x09\x0a\x0b\x0c\x0d\x0e\x0f\x10\x11\x09\x02\x0b\x6d\x61"
  "\x6b\x65\x2d\x71\x75\x65\x75\x65\x05\x13\x73\x68\x61\x6c\x6c\x6f"
  "\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x03\x15\x72\x67"
  "\x72\x61\x70\x68\x2d\x69\x6e\x69\x74\x69\x61\x6c\x2d\x65\x64\x67"
  "\x65\x73\x03\x15\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x74\x61\x62"
  "\x6c\x65\x73\x2f\x6d\x61\x6b\x65\x04\x03\x10\x65\x64\x67\x65\x2d"
  "\x72\x69\x67\x68\x74\x2d\x6e\x6f\x64\x65\x02\x0e\x63\x6f\x6e\x74"
  "\x69\x6e\x75\x65\x2d\x77\x61\x6c\x6b\x0b\x04\x10\x65\x6e\x71\x75"
  "\x65\x75\x65\x21\x2f\x75\x6e\x73\x61\x66\x65\x0a\x09\xac\x01\x60"
  "\x81\x85\x02\xab\x01\x5e\x82\x02\xaa\x01\x5c\x81\x87\x02\xa9\x01"
  "\x5a\x81\x85\x02\xa8\x01\x58\x81\x87\x02\xa7\x01\x56\x81\x85\x02"
  "\xa6\x01\x54\x81\x87\x02\xa5\x01\x52\x81\x85\x02\xa4\x01\x50\x81"
  "\x87\x02\xa3\x01\x4e\x81\x85\x02\xa2\x01\x4c\x81\x83\x02\xa1\x01"
  "\x4a\x81\x87\x02\xa0\x01\x48\x81\x85\x02\x9f\x01\x46\x81\x87\x02"
  "\x9e\x01\x44\x81\x85\x02\x9d\x01\x42\x81\x87\x02\x9c\x01\x40\x81"
  "\x85\x02\x9b\x01\x3e\x81\x87\x02\x9a\x01\x3c\x81\x85\x02\x99\x01"
  "\x3a\x81\x83\x02\x98\x01\x38\x81\x83\x02\x97\x01\x36\x83\x04\x96"
  "\x01\x34\x81\x8f\x02\x95\x01\x32\x81\x85\x02\x94\x01\x30\x81\x91"
  "\x02\x93\x01\x2e\x81\x83\x02\x92\x01\x2c\x81\x87\x02\x91\x01\x2a"
  "\x81\x85\x02\x90\x01\x28\x81\x87\x02\x8f\x01\x26\x81\x85\x02\x8e"
  "\x01\x24\x81\x87\x02\x8d\x01\x22\x81\x85\x02\x8c\x01\x20\x81\x87"
  "\x02\x8b\x01\x1e\x81\x85\x02\x8a\x01\x1c\x81\x83\x02\x89\x01\x1a"
  "\x81\x83\x02\x88\x01\x18\x81\x87\x02\x87\x01\x16\x81\x85\x02\x86"
  "\x01\x14\x81\x87\x02\x85\x01\x12\x81\x85\x02\x84\x01\x10\x81\x87"
  "\x02\x83\x01\x0e\x81\x85\x02\x82\x01\x0c\x81\x87\x02\x81\x01\x0a"
  "\x81\x85\x02\x80\x01\x08\x81\x83\x02\x7f\x06\x81\x8d\x02\x7e\x04"
  "\x83\x04\x5f\x89\x01\x02\x08\x02\x09\x04\x63\x64\x72\x12\x04\x63"
  "\x61\x72\x13\x0d\x0e\x0f\x10\x11\x06\x0d\x0c\x03\x03\x0d\x71\x75"
  "\x65\x75\x65\x2d\x65\x6d\x70\x74\x79\x3f\x03\x0c\x77\x61\x6c\x6b"
  "\x2d\x62\x62\x6c\x6f\x63\x6b\x14\x02\x0d\x73\x74\x61\x74\x65\x2f"
  "\x72\x65\x73\x65\x74\x21\x15\x03\x10\x64\x65\x71\x75\x65\x75\x65"
  "\x21\x2f\x75\x6e\x73\x61\x66\x65\x05\xc2\x01\x2e\x81\x81\x02\xc1"
  "\x01\x2c\x81\x83\x02\xc0\x01\x2a\x81\x81\x02\xbf\x01\x28\x81\x81"
  "\x02\xbe\x01\x26\x81\x83\x02\xbd\x01\x24\x81\x85\x02\xbc\x01\x22"
  "\x81\x85\x02\xbb\x01\x20\x81\x85\x02\xba\x01\x1e\x81\x85\x02\xb9"
  "\x01\x1c\x81\x85\x02\xb8\x01\x1a\x81\x85\x02\xb7\x01\x18\x81\x85"
  "\x02\xb6\x01\x16\x81\x85\x02\xb5\x01\x14\x81\x83\x02\xb4\x01\x12"
  "\x81\x83\x02\xb3\x01\x10\x81\x83\x02\xb2\x01\x0e\x81\x83\x02\xb1"
  "\x01\x0c\x81\x81\x02\xb0\x01\x0a\x81\x81\x02\xaf\x01\x08\x81\x83"
  "\x02\xae\x01\x06\x81\x81\x02\xad\x01\x04\x82\x02\x2d\x4b\x16\x02"
  "\x09\xc3\x01\x04\x86\x0a\x03\x17\x02\x0a\x09\xc4\x01\x04\x83\x04"
  "\x03\x18\x02\x0b\x09\xc5\x01\x04\x83\x04\x03\x19\x02\x0c\x09\xc6"
  "\x01\x04\x83\x04\x03\x1a\x02\x0d\x09\xc7\x01\x04\x83\x04\x03\x1b"
  "\x02\x0e\x02\x0f\x10\x11\x04\x0e\x02\x03\x17\x72\x65\x67\x69\x73"
  "\x74\x65\x72\x2d\x74\x61\x62\x6c\x65\x73\x2f\x72\x65\x73\x65\x74"
  "\x21\x02\x10\x6d\x61\x6b\x65\x2d\x68\x61\x73\x68\x2d\x74\x61\x62"
  "\x6c\x65\x03\xce\x01\x10\x81\x81\x02\xcd\x01\x0e\x81\x81\x02\xcc"
  "\x01\x0c\x81\x81\x02\xcb\x01\x0a\x81\x81\x02\xca\x01\x08\x81\x81"
  "\x02\xc9\x01\x06\x81\x83\x02\xc8\x01\x04\x82\x02\x0f\x20\x1c\x02"
  "\x0f\x13\x12\x11\x10\x0f\x0e\x05\x04\x04\x6d\x61\x70\x03\x10\x68"
  "\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d\x63\x6f\x70\x79\x03\x0e"
  "\x71\x75\x61\x6e\x74\x69\x74\x79\x2d\x63\x6f\x70\x79\x03\x15\x72"
  "\x65\x67\x69\x73\x74\x65\x72\x2d\x74\x61\x62\x6c\x65\x73\x2f\x63"
  "\x6f\x70\x79\x06\x0b\x6d\x61\x6b\x65\x2d\x73\x74\x61\x74\x65\x10"
  "\x06\xda\x01\x1a\x81\x87\x02\xd9\x01\x18\x81\x85\x02\xd8\x01\x16"
  "\x81\x83\x02\xd7\x01\x14\x81\x89\x02\xd6\x01\x12\x81\x85\x02\xd5"
  "\x01\x10\x81\x85\x02\xd4\x01\x0e\x83\x04\xd3\x01\x0c\x81\x87\x02"
  "\xd2\x01\x0a\x81\x83\x02\xd1\x01\x08\x81\x81\x02\xd0\x01\x06\x81"
  "\x83\x02\xcf\x01\x04\x82\x02\x19\x2e\x0f\x02\x10\x07\x61\x73\x73"
  "\x69\x67\x6e\x12\x13\x4d\x69\x73\x73\x69\x6e\x67\x20\x43\x53\x45"
  "\x20\x6d\x65\x74\x68\x6f\x64\x13\x09\x0d\x02\x0b\x63\x73\x65\x2f"
  "\x61\x73\x73\x69\x67\x6e\x1d\x0c\x63\x73\x65\x2d\x6d\x65\x74\x68"
  "\x6f\x64\x73\x1e\x0c\x0d\x05\x04\x06\x65\x72\x72\x6f\x72\x04\x05"
  "\x61\x73\x73\x71\x1f\x03\x0b\x6e\x6f\x64\x65\x2d\x6d\x61\x72\x6b"
  "\x21\x03\x08\x73\x62\x6c\x6f\x63\x6b\x3f\x03\x11\x70\x6e\x6f\x64"
  "\x65\x2d\x63\x6f\x6e\x73\x65\x71\x75\x65\x6e\x74\x03\x0b\x73\x6e"
  "\x6f\x64\x65\x2d\x6e\x65\x78\x74\x02\x0b\x03\x0d\x6e\x6f\x64\x65"
  "\x2d\x6d\x61\x72\x6b\x65\x64\x3f\x20\x03\x12\x70\x6e\x6f\x64\x65"
  "\x2d\x61\x6c\x74\x65\x72\x6e\x61\x74\x69\x76\x65\x03\x11\x6e\x6f"
  "\x64\x65\x2d\x70\x72\x65\x76\x69\x6f\x75\x73\x3e\x31\x3f\x21\x03"
  "\x14\x02\x15\x04\x0a\x02\x0a\x73\x74\x61\x74\x65\x2f\x67\x65\x74"
  "\x0a\x0f\x85\x02\x58\x81\x85\x02\x84\x02\x56\x81\x85\x02\x83\x02"
  "\x54\x81\x87\x02\x82\x02\x52\x81\x85\x02\x81\x02\x50\x81\x85\x02"
  "\x80\x02\x4e\x81\x89\x02\xff\x01\x4c\x81\x85\x02\xfe\x01\x4a\x81"
  "\x85\x02\xfd\x01\x48\x81\x85\x02\xfc\x01\x46\x81\x89\x02\xfb\x01"
  "\x44\x81\x85\x02\xfa\x01\x42\x81\x85\x02\xf9\x01\x40\x81\x85\x02"
  "\xf8\x01\x3e\x81\x85\x02\xf7\x01\x3c\x81\x85\x02\xf6\x01\x3a\x81"
  "\x85\x02\xf5\x01\x38\x81\x85\x02\xf4\x01\x36\x81\x85\x02\xf3\x01"
  "\x34\x81\x85\x02\xf2\x01\x32\x81\x83\x02\xf1\x01\x30\x81\x83\x02"
  "\xf0\x01\x2e\x81\x85\x02\xef\x01\x2c\x81\x85\x02\xee\x01\x2a\x81"
  "\x83\x02\xed\x01\x28\x81\x83\x02\xec\x01\x26\x81\x83\x02\xeb\x01"
  "\x24\x81\x83\x02\xea\x01\x22\x81\x83\x02\xe9\x01\x20\x81\x85\x02"
  "\xe8\x01\x1e\x81\x85\x02\xe7\x01\x1c\x81\x85\x02\xe6\x01\x1a\x81"
  "\x89\x02\xe5\x01\x18\x81\x87\x02\xe4\x01\x16\x81\x85\x02\xe3\x01"
  "\x14\x81\x85\x02\xe2\x01\x12\x81\x87\x02\xe1\x01\x10\x81\x85\x02"
  "\xe0\x01\x0e\x81\x83\x02\xdf\x01\x0c\x81\x85\x02\xde\x01\x0a\x81"
  "\x85\x02\xdd\x01\x08\x81\x83\x02\xdc\x01\x06\x81\x83\x02\xdb\x01"
  "\x04\x83\x04\x57\x86\x01\x22\x02\x11\x03\x20\x02\x87\x02\x06\x81"
  "\x83\x02\x86\x02\x04\x83\x04\x05\x0c\x20\x02\x12\x03\x21\x03\x14"
  "\x02\x15\x04\x8a\x02\x08\x81\x83\x02\x89\x02\x06\x81\x83\x02\x88"
  "\x02\x04\x83\x04\x07\x11\x21\x02\x13\x09\x73\x65\x74\x2d\x63\x64"
  "\x72\x21\x1e\x02\x1e\x02\x04\x1f\x02\x90\x02\x0e\x81\x85\x02\x8f"
  "\x02\x0c\x81\x83\x02\x8e\x02\x0a\x81\x83\x02\x8d\x02\x08\x81\x87"
  "\x02\x8c\x02\x06\x81\x89\x02\x8b\x02\x04\x84\x06\x0d\x18\x1f\x02"
  "\x14\x0d\x09\x72\x65\x67\x69\x73\x74\x65\x72\x12\x0e\x70\x72\x65"
  "\x2d\x69\x6e\x63\x72\x65\x6d\x65\x6e\x74\x23\x13\x09\x73\x65\x74"
  "\x2d\x63\x61\x72\x21\x1b\x72\x74\x6c\x3a\x73\x65\x74\x2d\x61\x73"
  "\x73\x69\x67\x6e\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x21"
  "\x16\x72\x74\x6c\x3a\x61\x73\x73\x69\x67\x6e\x2d\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x13\x63\x73\x65\x2f\x61\x73\x73\x69\x67"
  "\x6e\x2f\x67\x65\x6e\x65\x72\x61\x6c\x24\x16\x63\x73\x65\x2f\x61"
  "\x73\x73\x69\x67\x6e\x2f\x73\x74\x61\x63\x6b\x2d\x70\x75\x73\x68"
  "\x25\x20\x63\x73\x65\x2f\x61\x73\x73\x69\x67\x6e\x2f\x69\x6e\x74"
  "\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65"
  "\x72\x26\x1b\x63\x73\x65\x2f\x61\x73\x73\x69\x67\x6e\x2f\x73\x74"
  "\x61\x63\x6b\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x27\x14\x63"
  "\x73\x65\x2f\x61\x73\x73\x69\x67\x6e\x2f\x72\x65\x67\x69\x73\x74"
  "\x65\x72\x28\x08\x06\x14\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x72\x65\x70\x6c\x61\x63\x65\x21\x29\x04\x10\x67\x65\x6e\x65"
  "\x72\x61\x6c\x2d\x63\x61\x72\x2d\x63\x64\x72\x2a\x03\x18\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x63\x61\x6e\x6f\x6e\x69\x63"
  "\x61\x6c\x69\x7a\x65\x03\x1b\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x73\x74\x61\x63\x6b\x2d\x70\x6f\x69\x6e\x74\x65\x72"
  "\x3f\x2b\x03\x20\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x72\x65\x66\x65\x72\x65\x6e"
  "\x63\x65\x3f\x03\x11\x73\x74\x61\x63\x6b\x2d\x72\x65\x66\x65\x72"
  "\x65\x6e\x63\x65\x3f\x03\x0c\x6e\x6f\x74\x69\x63\x65\x2d\x70\x6f"
  "\x70\x21\x2c\x08\xa8\x02\x32\x81\x8b\x02\xa7\x02\x30\x81\x8b\x02"
  "\xa6\x02\x2e\x81\x8d\x02\xa5\x02\x2c\x81\x8b\x02\xa4\x02\x2a\x81"
  "\x8b\x02\xa3\x02\x28\x81\x89\x02\xa2\x02\x26\x81\x8b\x02\xa1\x02"
  "\x24\x81\x8b\x02\xa0\x02\x22\x81\x8d\x02\x9f\x02\x20\x81\x8d\x02"
  "\x9e\x02\x1e\x81\x8b\x02\x9d\x02\x1c\x81\x8b\x02\x9c\x02\x1a\x81"
  "\x8b\x02\x9b\x02\x18\x81\x8b\x02\x9a\x02\x16\x81\x8b\x02\x99\x02"
  "\x14\x81\x8b\x02\x98\x02\x12\x81\x8b\x02\x97\x02\x10\x81\x8b\x02"
  "\x96\x02\x0e\x81\x8b\x02\x95\x02\x0c\x81\x87\x02\x94\x02\x0a\x81"
  "\x87\x02\x93\x02\x08\x81\x87\x02\x92\x02\x06\x81\x85\x02\x91\x02"
  "\x04\x83\x04\x31\x53\x2d\x02\x15\x11\x6d\x61\x63\x68\x69\x6e\x65"
  "\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2e\x0d\x02\x09\x07\x6f\x66"
  "\x66\x73\x65\x74\x2f\x13\x11\x02\x17\x2a\x6d\x61\x63\x68\x69\x6e"
  "\x65\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x6d\x61\x70\x2a\x30"
  "\x02\x03\x2b\x04\x2a\x03\x20\x72\x65\x67\x69\x73\x74\x65\x72\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x69\x6e\x76\x61\x6c"
  "\x69\x64\x61\x74\x65\x21\x2b\x04\x1d\x69\x6e\x73\x65\x72\x74\x2d"
  "\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x64\x65\x73\x74\x69\x6e\x61"
  "\x74\x69\x6f\x6e\x21\x03\x16\x73\x74\x61\x63\x6b\x2d\x70\x6f\x69"
  "\x6e\x74\x65\x72\x2d\x61\x64\x6a\x75\x73\x74\x21\x2a\x06\xbe\x02"
  "\x2e\x81\x8f\x02\xbd\x02\x2c\x81\x8b\x02\xbc\x02\x2a\x81\x89\x02"
  "\xbb\x02\x28\x81\x8b\x02\xba\x02\x26\x81\x8b\x02\xb9\x02\x24\x81"
  "\x89\x02\xb8\x02\x22\x81\x89\x02\xb7\x02\x20\x81\x89\x02\xb6\x02"
  "\x1e\x81\x89\x02\xb5\x02\x1c\x81\x89\x02\xb4\x02\x1a\x81\x8b\x02"
  "\xb3\x02\x18\x81\x8b\x02\xb2\x02\x16\x81\x8b\x02\xb1\x02\x14\x81"
  "\x89\x02\xb0\x02\x12\x81\x89\x02\xaf\x02\x10\x81\x89\x02\xae\x02"
  "\x0e\x81\x8b\x02\xad\x02\x0c\x81\x8b\x02\xac\x02\x0a\x81\x89\x02"
  "\xab\x02\x08\x81\x89\x02\xaa\x02\x06\x81\x89\x02\xa9\x02\x04\x86"
  "\x0a\x2d\x49\x31\x02\x16\x02\x03\x1c\x73\x74\x61\x63\x6b\x2d\x72"
  "\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x69\x6e\x76\x61\x6c\x69\x64"
  "\x61\x74\x65\x21\x04\x1a\x69\x6e\x73\x65\x72\x74\x2d\x73\x74\x61"
  "\x63\x6b\x2d\x64\x65\x73\x74\x69\x6e\x61\x74\x69\x6f\x6e\x21\x32"
  "\x03\xc1\x02\x08\x81\x89\x02\xc0\x02\x06\x81\x89\x02\xbf\x02\x04"
  "\x86\x0a\x07\x10\x33\x02\x17\x2f\x2e\x09\x13\x12\x30\x02\x03\x2a"
  "\x04\x32\x03\xca\x02\x14\x81\x8b\x02\xc9\x02\x12\x81\x8b\x02\xc8"
  "\x02\x10\x81\x8b\x02\xc7\x02\x0e\x81\x89\x02\xc6\x02\x0c\xfd\xff"
  "\x03\xc5\x02\x0a\xfd\xff\x03\xc4\x02\x08\xfd\xff\x03\xc3\x02\x06"
  "\xff\xff\x03\xc2\x02\x04\x86\x0a\x13\x25\x32\x02\x18\x03\x10\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x68\x61\x73\x68\x06\x1c"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x6d\x65\x6d\x6f\x72"
  "\x79\x2d\x69\x6e\x73\x65\x72\x74\x69\x6f\x6e\x2f\x04\x12\x68\x61"
  "\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d\x6c\x6f\x6f\x6b\x75\x70\x2e"
  "\x04\x13\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d\x64\x65\x6c"
  "\x65\x74\x65\x21\x34\x05\xce\x02\x0a\x81\x85\x02\xcd\x02\x08\x81"
  "\x83\x02\xcc\x02\x06\x81\x89\x02\xcb\x02\x04\x86\x0a\x09\x15\x35"
  "\x02\x19\x02\x23\x0f\x70\x6f\x73\x74\x2d\x69\x6e\x63\x72\x65\x6d"
  "\x65\x6e\x74\x13\x12\x13\x65\x6c\x65\x6d\x65\x6e\x74\x2d\x69\x6e"
  "\x2d\x6d\x65\x6d\x6f\x72\x79\x3f\x02\x04\x15\x66\x75\x6c\x6c\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x68\x61\x73\x68\x03"
  "\x2c\x03\x0b\x73\x74\x61\x63\x6b\x2d\x70\x6f\x70\x3f\x23\x03\x1b"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x61\x64\x64\x72\x65"
  "\x73\x73\x2d\x76\x61\x72\x69\x65\x73\x3f\x03\x1a\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x66\x72\x65\x65\x2d\x70\x6f\x69"
  "\x6e\x74\x65\x72\x3f\x04\x05\x6d\x65\x6d\x71\x06\x2f\x03\x2b\x03"
  "\x19\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d\x64\x65\x6c\x65"
  "\x74\x65\x2d\x63\x6c\x61\x73\x73\x21\x04\x2e\x02\x1c\x76\x61\x72"
  "\x79\x69\x6e\x67\x2d\x61\x64\x64\x72\x65\x73\x73\x2d\x69\x6e\x76"
  "\x61\x6c\x69\x64\x61\x74\x65\x21\x2e\x04\x34\x0d\xe1\x02\x28\x81"
  "\x85\x02\xe0\x02\x26\x81\x83\x02\xdf\x02\x24\x81\x83\x02\xde\x02"
  "\x22\x81\x81\x02\xdd\x02\x20\x82\x02\xdc\x02\x1e\x81\x83\x02\xdb"
  "\x02\x1c\x81\x83\x02\xda\x02\x1a\x81\x83\x02\xd9\x02\x18\x82\x02"
  "\xd8\x02\x16\x81\x8d\x02\xd7\x02\x14\x81\x89\x02\xd6\x02\x12\x81"
  "\x8b\x02\xd5\x02\x10\x81\x8b\x02\xd4\x02\x0e\x81\x89\x02\xd3\x02"
  "\x0c\x81\x89\x02\xd2\x02\x0a\x81\x89\x02\xd1\x02\x08\x81\x89\x02"
  "\xd0\x02\x06\x81\x89\x02\xcf\x02\x04\x86\x0a\x27\x49\x34\x02\x1a"
  "\x13\x12\x02\x03\x23\x03\x2a\x03\xe6\x02\x0c\x81\x83\x02\xe5\x02"
  "\x0a\x81\x83\x02\xe4\x02\x08\x81\x83\x02\xe3\x02\x06\x81\x83\x02"
  "\xe2\x02\x04\x83\x04\x0b\x16\x23\x02\x1b\x03\x13\x6d\x65\x6e\x74"
  "\x69\x6f\x6e\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x73\x21\x02\xe9"
  "\x02\x08\x81\x89\x02\xe8\x02\x06\x81\x89\x02\xe7\x02\x04\x86\x0a"
  "\x07\x0d\x36\x02\x1c\x02\xea\x02\x04\x84\x06\x03\x37\x02\x1d\x0f"
  "\x74\x72\x69\x76\x69\x61\x6c\x2d\x61\x63\x74\x69\x6f\x6e\x38\x02"
  "\x04\x12\x64\x65\x66\x69\x6e\x65\x2d\x63\x73\x65\x2d\x6d\x65\x74"
  "\x68\x6f\x64\x39\x06\x29\x03\xed\x02\x08\x81\x89\x02\xec\x02\x06"
  "\x81\x85\x02\xeb\x02\x04\x85\x08\x07\x11\x3a\x02\x1e\x38\x02\x04"
  "\x39\x06\x29\x03\xf2\x02\x0c\x81\x89\x02\xf1\x02\x0a\x81\x85\x02"
  "\xf0\x02\x08\x81\x87\x02\xef\x02\x06\x81\x85\x02\xee\x02\x04\x87"
  "\x0c\x0b\x15\x3b\x02\x1f\x02\xf3\x02\x04\x83\x04\x03\x3c\x02\x20"
  "\x02\x09\x13\x12\x0e\x30\x03\x03\x19\x66\x6f\x72\x2d\x65\x61\x63"
  "\x68\x2d\x70\x73\x65\x75\x64\x6f\x2d\x72\x65\x67\x69\x73\x74\x65"
  "\x72\x03\x2a\x03\x2b\x03\x17\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x2d\x69\x6e\x76\x61\x6c\x69\x64\x61\x74\x65\x21\x2a\x05\x81"
  "\x03\x1e\x81\x83\x02\x80\x03\x1c\x81\x83\x02\xff\x02\x1a\x81\x83"
  "\x02\xfe\x02\x18\x81\x85\x02\xfd\x02\x16\x81\x85\x02\xfc\x02\x14"
  "\x81\x83\x02\xfb\x02\x12\x81\x83\x02\xfa\x02\x10\x81\x83\x02\xf9"
  "\x02\x0e\x81\x83\x02\xf8\x02\x0c\x83\x04\xf7\x02\x0a\x81\x85\x02"
  "\xf6\x02\x08\x81\x85\x02\xf5\x02\x06\x81\x83\x02\xf4\x02\x04\x83"
  "\x04\x1d\x33\x13\x02\x21\x38\x29\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x63\x61\x63\x68\x65"
  "\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x6e\x61\x6d\x65\x21"
  "\x24\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a"
  "\x63\x61\x63\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d"
  "\x6e\x61\x6d\x65\x04\x06\x29\x03\x1a\x6d\x65\x74\x68\x6f\x64\x2f"
  "\x75\x6e\x6b\x6e\x6f\x77\x6e\x2d\x69\x6e\x76\x6f\x63\x61\x74\x69"
  "\x6f\x6e\x12\x03\x86\x03\x0c\x81\x83\x02\x85\x03\x0a\x81\x8b\x02"
  "\x84\x03\x08\x81\x89\x02\x83\x03\x06\x81\x85\x02\x82\x03\x04\x83"
  "\x04\x0b\x17\x0e\x02\x22\x38\x27\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x6f\x6f\x6b\x75"
  "\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x22\x72"
  "\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x6f"
  "\x6f\x6b\x75\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x04\x06\x29\x03\x12\x03\x8b\x03\x0c\x81\x83\x02\x8a\x03\x0a\x81"
  "\x8b\x02\x89\x03\x08\x81\x89\x02\x88\x03\x06\x81\x85\x02\x87\x03"
  "\x04\x83\x04\x0b\x17\x3d\x02\x23\x09\x11\x02\x38\x32\x72\x74\x6c"
  "\x3a\x73\x65\x74\x2d\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d"
  "\x70\x72\x65\x66\x69\x78\x3a\x6d\x6f\x76\x65\x2d\x66\x72\x61\x6d"
  "\x65\x2d\x75\x70\x2d\x6c\x6f\x63\x61\x74\x69\x76\x65\x21\x2d\x72"
  "\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72"
  "\x65\x66\x69\x78\x3a\x6d\x6f\x76\x65\x2d\x66\x72\x61\x6d\x65\x2d"
  "\x75\x70\x2d\x6c\x6f\x63\x61\x74\x69\x76\x65\x30\x05\x06\x29\x03"
  "\x2b\x03\x93\x03\x12\x81\x83\x02\x92\x03\x10\x81\x83\x02\x91\x03"
  "\x0e\x81\x83\x02\x90\x03\x0c\x81\x83\x02\x8f\x03\x0a\x81\x8b\x02"
  "\x8e\x03\x08\x81\x89\x02\x8d\x03\x06\x81\x85\x02\x8c\x03\x04\x83"
  "\x04\x11\x23\x3e\x02\x24\x09\x11\x02\x38\x31\x72\x74\x6c\x3a\x73"
  "\x65\x74\x2d\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72"
  "\x65\x66\x69\x78\x3a\x64\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e"
  "\x6b\x2d\x6c\x6f\x63\x61\x74\x69\x76\x65\x21\x2c\x72\x74\x6c\x3a"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69"
  "\x78\x3a\x64\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x6c"
  "\x6f\x63\x61\x74\x69\x76\x65\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69"
  "\x78\x3a\x64\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x72"
  "\x65\x67\x69\x73\x74\x65\x72\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x64"
  "\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x72\x65\x67\x69"
  "\x73\x74\x65\x72\x30\x07\x06\x29\x03\x2b\x03\x9f\x03\x1a\x81\x83"
  "\x02\x9e\x03\x18\x81\x83\x02\x9d\x03\x16\x81\x83\x02\x9c\x03\x14"
  "\x81\x83\x02\x9b\x03\x12\x81\x8b\x02\x9a\x03\x10\x81\x89\x02\x99"
  "\x03\x0e\x81\x85\x02\x98\x03\x0c\x81\x83\x02\x97\x03\x0a\x81\x8b"
  "\x02\x96\x03\x08\x81\x89\x02\x95\x03\x06\x81\x85\x02\x94\x03\x04"
  "\x83\x04\x19\x2d\x30\x02\x25\x02\x04\x39\x06\x29\x02\x17\x6e\x6f"
  "\x6e\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x69\x6e\x76\x61\x6c\x69\x64"
  "\x61\x74\x65\x21\x2b\x03\x2a\x05\xa5\x03\x0e\x81\x87\x02\xa4\x03"
  "\x0c\x81\x89\x02\xa3\x03\x0a\x81\x87\x02\xa2\x03\x08\x81\x87\x02"
  "\xa1\x03\x06\x81\x85\x02\xa0\x03\x04\x86\x0a\x0d\x1a\x2a\x02\x26"
  "\x02\x38\x02\x04\x39\x06\x29\x02\x2e\x02\x2b\x05\xac\x03\x10\x81"
  "\x85\x02\xab\x03\x0e\x81\x85\x02\xaa\x03\x0c\x84\x06\xa9\x03\x0a"
  "\x81\x85\x02\xa8\x03\x08\x81\x87\x02\xa7\x03\x06\x81\x85\x02\xa6"
  "\x03\x04\x87\x0c\x0f\x1e\x2e\x26\x2b\x2b\x16\x69\x6e\x74\x65\x72"
  "\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x73\x65\x74\x21"
  "\x18\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c"
  "\x6c\x3a\x64\x65\x66\x69\x6e\x65\x22\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x19\x64\x65\x66\x69\x6e"
  "\x65\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x6d\x65\x74"
  "\x68\x6f\x64\x2b\x2e\x04\x1a\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x3f"
  "\x1d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c"
  "\x6c\x3a\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x18\x69\x6e"
  "\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x6c"
  "\x6f\x6f\x6b\x75\x70\x23\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x75\x6e\x61"
  "\x73\x73\x69\x67\x6e\x65\x64\x3f\x21\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d"
  "\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x18\x69\x6e\x74\x65\x72\x70"
  "\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x61\x63\x63\x65\x73"
  "\x73\x15\x64\x65\x66\x69\x6e\x65\x2d\x6c\x6f\x6f\x6b\x75\x70\x2d"
  "\x6d\x65\x74\x68\x6f\x64\x2e\x2a\x04\x1f\x69\x6e\x76\x6f\x63\x61"
  "\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x64\x79\x6e\x61"
  "\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x30\x04\x20\x69\x6e\x76\x6f\x63"
  "\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x6d\x6f\x76"
  "\x65\x2d\x66\x72\x61\x6d\x65\x2d\x75\x70\x3e\x04\x12\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x6f\x6f\x6b\x75\x70\x3d\x04"
  "\x1b\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x63\x61\x63\x68"
  "\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x0e\x04\x1d\x69\x6e"
  "\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x73\x70\x65\x63\x69\x61\x6c"
  "\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x15\x69\x6e\x76\x6f\x63"
  "\x61\x74\x69\x6f\x6e\x3a\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x17"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x67\x6c\x6f\x62\x61"
  "\x6c\x2d\x6c\x69\x6e\x6b\x14\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f"
  "\x6e\x3a\x75\x75\x6f\x2d\x6c\x69\x6e\x6b\x1a\x69\x6e\x76\x6f\x63"
  "\x61\x74\x69\x6f\x6e\x3a\x63\x6f\x6d\x70\x75\x74\x65\x64\x2d\x6c"
  "\x65\x78\x70\x72\x19\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a"
  "\x63\x6f\x6d\x70\x75\x74\x65\x64\x2d\x6a\x75\x6d\x70\x11\x69\x6e"
  "\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x61\x70\x70\x6c\x79\x12\x13"
  "\x04\x11\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x65\x78"
  "\x70\x72\x10\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6a\x75"
  "\x6d\x70\x0f\x63\x6c\x6f\x73\x75\x72\x65\x2d\x68\x65\x61\x64\x65"
  "\x72\x11\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x68\x65\x61\x64"
  "\x65\x72\x16\x6f\x70\x65\x6e\x2d\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x68\x65\x61\x64\x65\x72\x14\x69\x63\x2d\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x2d\x68\x65\x61\x64\x65\x72\x14\x63\x6f\x6e"
  "\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x68\x65\x61\x64\x65\x72"
  "\x13\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x65\x6e"
  "\x74\x72\x79\x0b\x70\x6f\x70\x2d\x72\x65\x74\x75\x72\x6e\x0e\x6f"
  "\x76\x65\x72\x66\x6c\x6f\x77\x2d\x74\x65\x73\x74\x0c\x6d\x65\x74"
  "\x68\x6f\x64\x2f\x6e\x6f\x6f\x70\x3e\x3c\x04\x0a\x74\x79\x70\x65"
  "\x2d\x74\x65\x73\x74\x13\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65"
  "\x64\x2d\x32\x2d\x61\x72\x67\x73\x12\x66\x6c\x6f\x6e\x75\x6d\x2d"
  "\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x13\x66\x69\x78\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x12\x66\x69"
  "\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x0c"
  "\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x0b\x70\x72\x65\x64"
  "\x2d\x31\x2d\x61\x72\x67\x08\x65\x71\x2d\x74\x65\x73\x74\x11\x6c"
  "\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0a"
  "\x72\x74\x64\x3a\x73\x74\x61\x74\x65\x1e\x64\x65\x66\x69\x6e\x65"
  "\x2d\x74\x72\x69\x76\x69\x61\x6c\x2d\x74\x77\x6f\x2d\x61\x72\x67"
  "\x2d\x6d\x65\x74\x68\x6f\x64\x3d\x1e\x64\x65\x66\x69\x6e\x65\x2d"
  "\x74\x72\x69\x76\x69\x61\x6c\x2d\x6f\x6e\x65\x2d\x61\x72\x67\x2d"
  "\x6d\x65\x74\x68\x6f\x64\x3c\x38\x2f\x2c\x24\x26\x25\x27\x28\x1d"
  "\x1e\x39\x0a\x77\x61\x6c\x6b\x2d\x6e\x65\x78\x74\x0b\x77\x61\x6c"
  "\x6b\x2d\x6e\x65\x78\x74\x3f\x14\x0a\x15\x21\x73\x74\x61\x74\x65"
  "\x2f\x73\x74\x61\x63\x6b\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65"
  "\x2d\x71\x75\x61\x6e\x74\x69\x74\x69\x65\x73\x13\x73\x74\x61\x74"
  "\x65\x2f\x73\x74\x61\x63\x6b\x2d\x6f\x66\x66\x73\x65\x74\x11\x73"
  "\x74\x61\x74\x65\x2f\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x16"
  "\x73\x74\x61\x74\x65\x2f\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x74"
  "\x61\x62\x6c\x65\x73\x10\x0b\x21\x63\x6f\x6d\x6d\x6f\x6e\x2d\x73"
  "\x75\x62\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x65\x6c\x69"
  "\x6d\x69\x6e\x61\x74\x69\x6f\x6e\x0d\x0c\x1d\x3b\x04\x3a\x04\x37"
  "\x04\x36\x04\x23\x04\x34\x04\x35\x04\x32\x04\x33\x04\x31\x04\x2d"
  "\x04\x1f\x04\x21\x04\x20\x04\x22\x04\x0f\x04\x1c\x04\x1b\x04\x1a"
  "\x04\x19\x04\x18\x04\x17\x04\x16\x04\x04\x04\x1d\x07\x76\x65\x63"
  "\x74\x6f\x72\x06\x73\x74\x61\x74\x65\x1b\x73\x74\x61\x63\x6b\x2d"
  "\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x71\x75\x61\x6e\x74\x69"
  "\x74\x69\x65\x73\x0d\x73\x74\x61\x63\x6b\x2d\x6f\x66\x66\x73\x65"
  "\x74\x0b\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x10\x72\x65\x67"
  "\x69\x73\x74\x65\x72\x2d\x74\x61\x62\x6c\x65\x73\x04\x04\x04\x04"
  "\x0a\x1b\x6d\x61\x6b\x65\x2d\x64\x65\x66\x69\x6e\x65\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\x2d\x74\x79\x70\x65\x05\x10\x64\x65"
  "\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x03\x1e\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x65\x71\x2d\x74\x65\x73\x74\x2d\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x32\x21\x19\x72\x74\x6c"
  "\x3a\x65\x71\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72\x65\x73\x73"
  "\x69\x6f\x6e\x2d\x32\x1e\x72\x74\x6c\x3a\x73\x65\x74\x2d\x65\x71"
  "\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x31\x21\x19\x72\x74\x6c\x3a\x65\x71\x2d\x74\x65\x73\x74\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x31\x1c\x72\x74\x6c"
  "\x3a\x73\x65\x74\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d"
  "\x6f\x70\x65\x72\x61\x6e\x64\x21\x17\x72\x74\x6c\x3a\x70\x72\x65"
  "\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72\x61\x6e\x64\x1f"
  "\x72\x74\x6c\x3a\x73\x65\x74\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61"
  "\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x32\x21\x1a\x72"
  "\x74\x6c\x3a\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f"
  "\x70\x65\x72\x61\x6e\x64\x2d\x32\x1f\x72\x74\x6c\x3a\x73\x65\x74"
  "\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65"
  "\x72\x61\x6e\x64\x2d\x31\x21\x1a\x72\x74\x6c\x3a\x70\x72\x65\x64"
  "\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d"
  "\x31\x23\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x69\x78\x6e\x75\x6d"
  "\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72"
  "\x61\x6e\x64\x21\x1e\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75\x6d\x2d"
  "\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72\x61"
  "\x6e\x64\x26\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70"
  "\x65\x72\x61\x6e\x64\x2d\x32\x21\x21\x72\x74\x6c\x3a\x66\x69\x78"
  "\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d"
  "\x6f\x70\x65\x72\x61\x6e\x64\x2d\x32\x26\x72\x74\x6c\x3a\x73\x65"
  "\x74\x2d\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d"
  "\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31\x21\x21"
  "\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d"
  "\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31"
  "\x23\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d"
  "\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72\x61"
  "\x6e\x64\x21\x1e\x72\x74\x6c\x3a\x66\x6c\x6f\x6e\x75\x6d\x2d\x70"
  "\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72\x61\x6e"
  "\x64\x26\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x6c\x6f\x6e\x75\x6d"
  "\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65"
  "\x72\x61\x6e\x64\x2d\x32\x21\x21\x72\x74\x6c\x3a\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f"
  "\x70\x65\x72\x61\x6e\x64\x2d\x32\x26\x72\x74\x6c\x3a\x73\x65\x74"
  "\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61"
  "\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31\x21\x21\x72"
  "\x74\x6c\x3a\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32"
  "\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31\x1e"
  "\x72\x74\x6c\x3a\x73\x65\x74\x2d\x74\x79\x70\x65\x2d\x74\x65\x73"
  "\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x21\x19\x72\x74"
  "\x6c\x3a\x74\x79\x70\x65\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x3e\x12\x1c\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x3a\x61\x63"
  "\x63\x65\x73\x73\x2d\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74"
  "\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x61\x63"
  "\x63\x65\x73\x73\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x21\x28\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x61\x63\x63\x65\x73\x73\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x25\x69\x6e\x74\x65\x72\x70"
  "\x72\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x3a\x63"
  "\x61\x63\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2f\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x72\x65"
  "\x66\x65\x72\x65\x6e\x63\x65\x2d\x6e\x61\x6d\x65\x21\x2a\x72\x74"
  "\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61"
  "\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e"
  "\x63\x65\x2d\x6e\x61\x6d\x65\x27\x69\x6e\x74\x65\x72\x70\x72\x65"
  "\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x3a\x63\x61\x63"
  "\x68\x65\x2d\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x31\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x75\x6e"
  "\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x2d\x6e\x61\x6d\x65\x21\x2c"
  "\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x75\x6e\x61\x73\x73"
  "\x69\x67\x6e\x65\x64\x3f\x2d\x6e\x61\x6d\x65\x1c\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65\x72"
  "\x3a\x6c\x6f\x6f\x6b\x75\x70\x2d\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c"
  "\x3a\x6c\x6f\x6f\x6b\x75\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x21\x28\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x6c\x6f\x6f\x6b\x75\x70"
  "\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x69\x6e\x74"
  "\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65"
  "\x72\x3a\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x32\x72\x74"
  "\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x61\x73\x73\x69\x67\x6e\x65"
  "\x64\x3f\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x2d"
  "\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x63\x61\x6c\x6c\x3a\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f"
  "\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x1e\x69\x6e\x74"
  "\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x72\x65\x67\x69\x73\x74\x65"
  "\x72\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x3f\x2f\x72\x74\x6c\x3a\x73"
  "\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63"
  "\x61\x6c\x6c\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x3f\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x2a\x72\x74\x6c\x3a\x69\x6e"
  "\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75"
  "\x6e\x62\x6f\x75\x6e\x64\x3f\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63"
  "\x68\x65\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x76\x61"
  "\x6c\x75\x65\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x76\x61\x6c\x75\x65"
  "\x30\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x6e\x61\x6d\x65\x21"
  "\x2b\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72"
  "\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x61\x73\x73\x69"
  "\x67\x6e\x6d\x65\x6e\x74\x2d\x6e\x61\x6d\x65\x27\x72\x74\x6c\x3a"
  "\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x76\x61\x6c\x75"
  "\x65\x21\x22\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x76"
  "\x61\x6c\x75\x65\x2d\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74"
  "\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x64\x65"
  "\x66\x69\x6e\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x21\x28\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x20\x72\x74\x6c\x3a\x69\x6e"
  "\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x73"
  "\x65\x74\x21\x2d\x76\x61\x6c\x75\x65\x2b\x72\x74\x6c\x3a\x73\x65"
  "\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61"
  "\x6c\x6c\x3a\x73\x65\x74\x21\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x21\x26\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x73\x65\x74\x21\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x25\x72\x74\x6c\x3a\x73"
  "\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63"
  "\x61\x6c\x6c\x3a\x73\x65\x74\x21\x2d\x76\x61\x6c\x75\x65\x21\x39"
  "\x07\x3d\x05\x3c\x04\x39\x06\x2e\x07\x2b\x06\x76\xee\x01\x80\x80"
  "\x04\x75\xec\x01\x81\x81\x02\x74\xea\x01\x81\x81\x02\x73\xe8\x01"
  "\x81\x8b\x02\x72\xe6\x01\x81\x87\x02\x71\xe4\x01\x81\x85\x02\x70"
  "\xe2\x01\x81\x83\x02\x6f\xe0\x01\x81\x83\x02\x6e\xde\x01\x81\x8b"
  "\x02\x6d\xdc\x01\x81\x89\x02\x6c\xda\x01\x81\x87\x02\x6b\xd8\x01"
  "\x81\x85\x02\x6a\xd6\x01\x81\x83\x02\x69\xd4\x01\x81\x8b\x02\x68"
  "\xd2\x01\x81\x89\x02\x67\xd0\x01\x81\x87\x02\x66\xce\x01\x81\x85"
  "\x02\x65\xcc\x01\x81\x83\x02\x64\xca\x01\x81\x83\x02\x63\xc8\x01"
  "\x81\x89\x02\x62\xc6\x01\x81\x87\x02\x61\xc4\x01\x81\x85\x02\x60"
  "\xc2\x01\x81\x83\x02\x5f\xc0\x01\x81\x89\x02\x5e\xbe\x01\x81\x87"
  "\x02\x5d\xbc\x01\x81\x85\x02\x5c\xba\x01\x81\x83\x02\x5b\xb8\x01"
  "\x81\x89\x02\x5a\xb6\x01\x81\x87\x02\x59\xb4\x01\x81\x85\x02\x58"
  "\xb2\x01\x81\x83\x02\x57\xb0\x01\x81\x89\x02\x56\xae\x01\x81\x87"
  "\x02\x55\xac\x01\x81\x85\x02\x54\xaa\x01\x81\x83\x02\x53\xa8\x01"
  "\x81\x89\x02\x52\xa6\x01\x81\x87\x02\x51\xa4\x01\x81\x85\x02\x50"
  "\xa2\x01\x81\x83\x02\x4f\xa0\x01\x81\x89\x02\x4e\x9e\x01\x81\x87"
  "\x02\x4d\x9c\x01\x81\x85\x02\x4c\x9a\x01\x81\x83\x02\x4b\x98\x01"
  "\x81\x83\x02\x4a\x96\x01\x81\x83\x02\x49\x94\x01\x81\x83\x02\x48"
  "\x92\x01\x81\x83\x02\x47\x90\x01\x81\x83\x02\x46\x8e\x01\x81\x85"
  "\x02\x45\x8c\x01\x81\x83\x02\x44\x8a\x01\x81\x85\x02\x43\x88\x01"
  "\x81\x83\x02\x42\x86\x01\x81\x85\x02\x41\x84\x01\x81\x83\x02\x40"
  "\x82\x01\x81\x85\x02\x3f\x80\x01\x81\x83\x02\x3e\x7e\x81\x85\x02"
  "\x3d\x7c\x81\x83\x02\x3c\x7a\x81\x85\x02\x3b\x78\x81\x83\x02\x3a"
  "\x76\x81\x85\x02\x39\x74\x81\x83\x02\x38\x72\x81\x83\x02\x37\x70"
  "\x81\x85\x02\x36\x6e\x81\x83\x02\x35\x6c\x81\x85\x02\x34\x6a\x81"
  "\x83\x02\x33\x68\x81\x85\x02\x32\x66\x81\x83\x02\x31\x64\x81\x85"
  "\x02\x30\x62\x81\x83\x02\x2f\x60\x81\x85\x02\x2e\x5e\x81\x83\x02"
  "\x2d\x5c\x81\x85\x02\x2c\x5a\x81\x83\x02\x2b\x58\x81\x85\x02\x2a"
  "\x56\x81\x83\x02\x29\x54\x81\x85\x02\x28\x52\x81\x83\x02\x27\x50"
  "\x81\x85\x02\x26\x4e\x81\x83\x02\x25\x4c\x81\x85\x02\x24\x4a\x81"
  "\x83\x02\x23\x48\x81\x83\x02\x22\x46\x81\x87\x02\x21\x44\x81\x85"
  "\x02\x20\x42\x81\x83\x02\x1f\x40\x81\x8b\x02\x1e\x3e\x81\x89\x02"
  "\x1d\x3c\x81\x87\x02\x1c\x3a\x81\x85\x02\x1b\x38\x81\x83\x02\x1a"
  "\x36\x81\x87\x02\x19\x34\x81\x85\x02\x18\x32\x81\x83\x02\x17\x30"
  "\x81\x8b\x02\x16\x2e\x81\x89\x02\x15\x2c\x81\x87\x02\x14\x2a\x81"
  "\x85\x02\x13\x28\x81\x83\x02\x12\x26\x81\x87\x02\x11\x24\x81\x85"
  "\x02\x10\x22\x81\x83\x02\x0f\x20\x81\x8b\x02\x0e\x1e\x81\x89\x02"
  "\x0d\x1c\x81\x87\x02\x0c\x1a\x81\x85\x02\x0b\x18\x81\x83\x02\x0a"
  "\x16\x81\x87\x02\x09\x14\x81\x85\x02\x08\x12\x81\x83\x02\x07\x10"
  "\x81\x8b\x02\x06\x0e\x81\x89\x02\x05\x0c\x81\x87\x02\x04\x0a\x81"
  "\x85\x02\x03\x08\x81\x83\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83"
  "\x02\xed\x01\xfa\x02";

SCHEME_OBJECT *
rcse1_so_data_56d55eb8a5a8b574 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_rcse1_so_data_56d55eb8a5a8b574 [0]))), (sizeof (prog_rcse1_so_data_56d55eb8a5a8b574)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_128]));
}

DECLARE_COMPILED_DATA_NS ("rcse1.so", rcse1_so_data_56d55eb8a5a8b574)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("rcse1.so", "7794703d6c0ac900")
