/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:20:19-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_7 5
#define LABEL_1_8 7
#define LABEL_1_5 9
#define LABEL_1_12 11
#define LABEL_1_13 13
#define LABEL_1_6 15
#define LABEL_1_14 17
#define LABEL_1_15 19
#define LABEL_1_16 21
#define LABEL_1_17 23
#define LABEL_1_18 25
#define LABEL_1_19 27
#define LABEL_1_10 29
#define LABEL_1_22 31
#define LABEL_1_23 33
#define LABEL_1_11 35
#define LABEL_1_24 37
#define LABEL_1_25 39
#define LABEL_1_26 41
#define LABEL_1_27 43
#define LABEL_1_28 45
#define LABEL_1_29 47
#define LABEL_1_20 49
#define LABEL_1_31 51
#define LABEL_1_32 53
#define LABEL_1_33 55
#define LABEL_1_21 57
#define LABEL_1_35 59
#define LABEL_1_36 61
#define LABEL_1_37 63
#define LABEL_1_38 65
#define LABEL_1_39 67
#define LABEL_1_40 69
#define LABEL_1_30 71
#define LABEL_1_41 73
#define LABEL_1_43 75
#define LABEL_1_44 77
#define LABEL_1_45 79
#define LABEL_1_42 81
#define LABEL_1_47 83
#define LABEL_1_49 85
#define LABEL_1_50 87
#define LABEL_1_51 89
#define LABEL_1_48 91
#define LABEL_1_52 93
#define LABEL_1_54 95
#define LABEL_1_55 97
#define LABEL_1_56 99
#define LABEL_1_53 101
#define LABEL_1_57 103
#define LABEL_1_59 105
#define LABEL_1_60 107
#define LABEL_1_61 109
#define LABEL_1_58 111
#define LABEL_1_62 113
#define LABEL_1_64 115
#define LABEL_1_65 117
#define LABEL_1_66 119
#define LABEL_1_63 121
#define LABEL_1_67 123
#define LABEL_1_69 125
#define LABEL_1_70 127
#define LABEL_1_71 129
#define LABEL_1_68 131
#define LABEL_1_72 133
#define LABEL_1_74 135
#define LABEL_1_75 137
#define LABEL_1_76 139
#define LABEL_1_73 141
#define LABEL_1_77 143
#define LABEL_1_79 145
#define LABEL_1_80 147
#define LABEL_1_81 149
#define LABEL_1_78 151
#define LABEL_1_82 153
#define LABEL_1_84 155
#define LABEL_1_85 157
#define LABEL_1_86 159
#define LABEL_1_83 161
#define LABEL_1_87 163
#define LABEL_1_88 165
#define ENVIRONMENT_LABEL_1_3 247
#define DEBUGGING_LABEL_1_2 246
#define OBJECT_1_8 245
#define OBJECT_1_7 244
#define OBJECT_1_6 243
#define OBJECT_1_5 242
#define OBJECT_1_4 241
#define OBJECT_1_3 240
#define OBJECT_1_2 239
#define OBJECT_1_1 238
#define OBJECT_1_0 237
#define EXECUTE_CACHE_1_46 167
#define EXECUTE_CACHE_1_34 169
#define EXECUTE_CACHE_1_9 171
#define FREE_REFERENCE_1_36 174
#define FREE_REFERENCE_1_35 175
#define FREE_REFERENCE_1_34 176
#define FREE_REFERENCE_1_33 177
#define FREE_REFERENCE_1_32 178
#define FREE_REFERENCE_1_31 179
#define FREE_REFERENCE_1_30 180
#define FREE_REFERENCE_1_29 181
#define FREE_REFERENCE_1_28 182
#define FREE_REFERENCE_1_27 183
#define FREE_REFERENCE_1_26 184
#define FREE_REFERENCE_1_25 185
#define FREE_REFERENCE_1_24 186
#define FREE_REFERENCE_1_23 187
#define FREE_REFERENCE_1_22 188
#define FREE_REFERENCE_1_21 189
#define FREE_REFERENCE_1_20 190
#define FREE_REFERENCE_1_19 191
#define FREE_REFERENCE_1_18 192
#define FREE_REFERENCE_1_17 193
#define FREE_REFERENCE_1_16 194
#define FREE_REFERENCE_1_15 195
#define FREE_REFERENCE_1_14 196
#define FREE_REFERENCE_1_13 197
#define FREE_REFERENCE_1_12 198
#define FREE_REFERENCE_1_11 199
#define FREE_REFERENCE_1_10 200
#define FREE_REFERENCE_1_9 201
#define FREE_REFERENCE_1_8 202
#define FREE_REFERENCE_1_7 203
#define FREE_REFERENCE_1_6 204
#define FREE_REFERENCE_1_5 205
#define FREE_REFERENCE_1_4 206
#define FREE_REFERENCE_1_3 207
#define FREE_REFERENCE_1_2 208
#define FREE_REFERENCE_1_1 209
#define FREE_REFERENCE_1_0 210
#define FREE_ASSIGNMENT_1_24 212
#define FREE_ASSIGNMENT_1_23 213
#define FREE_ASSIGNMENT_1_22 214
#define FREE_ASSIGNMENT_1_21 215
#define FREE_ASSIGNMENT_1_20 216
#define FREE_ASSIGNMENT_1_19 217
#define FREE_ASSIGNMENT_1_18 218
#define FREE_ASSIGNMENT_1_17 219
#define FREE_ASSIGNMENT_1_16 220
#define FREE_ASSIGNMENT_1_15 221
#define FREE_ASSIGNMENT_1_14 222
#define FREE_ASSIGNMENT_1_13 223
#define FREE_ASSIGNMENT_1_12 224
#define FREE_ASSIGNMENT_1_11 225
#define FREE_ASSIGNMENT_1_10 226
#define FREE_ASSIGNMENT_1_9 227
#define FREE_ASSIGNMENT_1_8 228
#define FREE_ASSIGNMENT_1_7 229
#define FREE_ASSIGNMENT_1_6 230
#define FREE_ASSIGNMENT_1_5 231
#define FREE_ASSIGNMENT_1_4 232
#define FREE_ASSIGNMENT_1_3 233
#define FREE_ASSIGNMENT_1_2 234
#define FREE_ASSIGNMENT_1_1 235
#define FREE_ASSIGNMENT_1_0 236
#define FREE_REFERENCES_LABEL_1_0 166
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd53;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto initialize_packageB_24;

    case 1:
      current_block = (Rpc - LABEL_1_7);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_1_12);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_1_13);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_1_6);
      goto lambda_2;

    case 7:
      current_block = (Rpc - LABEL_1_14);
      goto label_30;

    case 8:
      current_block = (Rpc - LABEL_1_15);
      goto label_31;

    case 9:
      current_block = (Rpc - LABEL_1_16);
      goto label_32;

    case 10:
      current_block = (Rpc - LABEL_1_17);
      goto label_33;

    case 11:
      current_block = (Rpc - LABEL_1_18);
      goto label_34;

    case 12:
      current_block = (Rpc - LABEL_1_19);
      goto label_35;

    case 13:
      current_block = (Rpc - LABEL_1_10);
      goto continuation_7;

    case 14:
      current_block = (Rpc - LABEL_1_22);
      goto label_36;

    case 15:
      current_block = (Rpc - LABEL_1_23);
      goto label_37;

    case 16:
      current_block = (Rpc - LABEL_1_11);
      goto lambda_6;

    case 17:
      current_block = (Rpc - LABEL_1_24);
      goto label_38;

    case 18:
      current_block = (Rpc - LABEL_1_25);
      goto label_39;

    case 19:
      current_block = (Rpc - LABEL_1_26);
      goto label_40;

    case 20:
      current_block = (Rpc - LABEL_1_27);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_1_28);
      goto label_42;

    case 22:
      current_block = (Rpc - LABEL_1_29);
      goto label_43;

    case 23:
      current_block = (Rpc - LABEL_1_20);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_1_31);
      goto label_44;

    case 25:
      current_block = (Rpc - LABEL_1_32);
      goto label_45;

    case 26:
      current_block = (Rpc - LABEL_1_33);
      goto label_46;

    case 27:
      current_block = (Rpc - LABEL_1_21);
      goto lambda_10;

    case 28:
      current_block = (Rpc - LABEL_1_35);
      goto label_47;

    case 29:
      current_block = (Rpc - LABEL_1_36);
      goto label_48;

    case 30:
      current_block = (Rpc - LABEL_1_37);
      goto label_49;

    case 31:
      current_block = (Rpc - LABEL_1_38);
      goto label_50;

    case 32:
      current_block = (Rpc - LABEL_1_39);
      goto label_51;

    case 33:
      current_block = (Rpc - LABEL_1_40);
      goto label_52;

    case 34:
      current_block = (Rpc - LABEL_1_30);
      goto continuation_12;

    case 35:
      current_block = (Rpc - LABEL_1_41);
      goto label_53;

    case 36:
      current_block = (Rpc - LABEL_1_43);
      goto label_54;

    case 37:
      current_block = (Rpc - LABEL_1_44);
      goto label_55;

    case 38:
      current_block = (Rpc - LABEL_1_45);
      goto label_56;

    case 39:
      current_block = (Rpc - LABEL_1_42);
      goto continuation_13;

    case 40:
      current_block = (Rpc - LABEL_1_47);
      goto label_57;

    case 41:
      current_block = (Rpc - LABEL_1_49);
      goto label_58;

    case 42:
      current_block = (Rpc - LABEL_1_50);
      goto label_59;

    case 43:
      current_block = (Rpc - LABEL_1_51);
      goto label_60;

    case 44:
      current_block = (Rpc - LABEL_1_48);
      goto continuation_14;

    case 45:
      current_block = (Rpc - LABEL_1_52);
      goto label_61;

    case 46:
      current_block = (Rpc - LABEL_1_54);
      goto label_62;

    case 47:
      current_block = (Rpc - LABEL_1_55);
      goto label_63;

    case 48:
      current_block = (Rpc - LABEL_1_56);
      goto label_64;

    case 49:
      current_block = (Rpc - LABEL_1_53);
      goto continuation_15;

    case 50:
      current_block = (Rpc - LABEL_1_57);
      goto label_65;

    case 51:
      current_block = (Rpc - LABEL_1_59);
      goto label_66;

    case 52:
      current_block = (Rpc - LABEL_1_60);
      goto label_67;

    case 53:
      current_block = (Rpc - LABEL_1_61);
      goto label_68;

    case 54:
      current_block = (Rpc - LABEL_1_58);
      goto continuation_16;

    case 55:
      current_block = (Rpc - LABEL_1_62);
      goto label_69;

    case 56:
      current_block = (Rpc - LABEL_1_64);
      goto label_70;

    case 57:
      current_block = (Rpc - LABEL_1_65);
      goto label_71;

    case 58:
      current_block = (Rpc - LABEL_1_66);
      goto label_72;

    case 59:
      current_block = (Rpc - LABEL_1_63);
      goto continuation_17;

    case 60:
      current_block = (Rpc - LABEL_1_67);
      goto label_73;

    case 61:
      current_block = (Rpc - LABEL_1_69);
      goto label_74;

    case 62:
      current_block = (Rpc - LABEL_1_70);
      goto label_75;

    case 63:
      current_block = (Rpc - LABEL_1_71);
      goto label_76;

    case 64:
      current_block = (Rpc - LABEL_1_68);
      goto continuation_18;

    case 65:
      current_block = (Rpc - LABEL_1_72);
      goto label_77;

    case 66:
      current_block = (Rpc - LABEL_1_74);
      goto label_78;

    case 67:
      current_block = (Rpc - LABEL_1_75);
      goto label_79;

    case 68:
      current_block = (Rpc - LABEL_1_76);
      goto label_80;

    case 69:
      current_block = (Rpc - LABEL_1_73);
      goto continuation_19;

    case 70:
      current_block = (Rpc - LABEL_1_77);
      goto label_81;

    case 71:
      current_block = (Rpc - LABEL_1_79);
      goto label_82;

    case 72:
      current_block = (Rpc - LABEL_1_80);
      goto label_83;

    case 73:
      current_block = (Rpc - LABEL_1_81);
      goto label_84;

    case 74:
      current_block = (Rpc - LABEL_1_78);
      goto continuation_20;

    case 75:
      current_block = (Rpc - LABEL_1_82);
      goto label_85;

    case 76:
      current_block = (Rpc - LABEL_1_84);
      goto label_86;

    case 77:
      current_block = (Rpc - LABEL_1_85);
      goto label_87;

    case 78:
      current_block = (Rpc - LABEL_1_86);
      goto label_88;

    case 79:
      current_block = (Rpc - LABEL_1_83);
      goto continuation_21;

    case 80:
      current_block = (Rpc - LABEL_1_87);
      goto label_89;

    case 81:
      current_block = (Rpc - LABEL_1_88);
      goto label_90;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_92)
DEFLABEL (initialize_packageB_24)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_200;
  Wrd10 = Wrd14;

DEFLABEL (label_199)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_198;
  Wrd16 = Wrd20;

DEFLABEL (label_197)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_196;
  Wrd10 = Wrd14;

DEFLABEL (label_195)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_194;
  Wrd16 = Wrd20;

DEFLABEL (label_193)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_9]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_1_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_5]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_192;
  Wrd10 = Wrd14;

DEFLABEL (label_191)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_6]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_190;
  Wrd16 = Wrd20;

DEFLABEL (label_189)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_9]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_1_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_8]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_188;
  Wrd8 = Wrd12;

DEFLABEL (label_187)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_9]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_186;
  Wrd14 = Wrd18;

DEFLABEL (label_185)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_10]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_184;
  Wrd20 = Wrd24;

DEFLABEL (label_183)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_34]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_1_30);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_15]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_182;

DEFLABEL (label_181)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_180)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_42]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_12]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_179;
  Wrd21 = Wrd25;

DEFLABEL (label_178)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_13]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_177;
  Wrd27 = Wrd31;

DEFLABEL (label_176)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_14]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_175;
  Wrd33 = Wrd37;

DEFLABEL (label_174)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_1]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_1_42);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_16]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_173;

DEFLABEL (label_172)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_171)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_48]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_15]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_170;
  Wrd21 = Wrd25;

DEFLABEL (label_169)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_16]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_168;
  Wrd27 = Wrd31;

DEFLABEL (label_167)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_17]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_166;
  Wrd33 = Wrd37;

DEFLABEL (label_165)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_2]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_34]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_1_48);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_17]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_164;

DEFLABEL (label_163)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_162)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_53]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_18]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_161;
  Wrd21 = Wrd25;

DEFLABEL (label_160)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_19]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_159;
  Wrd27 = Wrd31;

DEFLABEL (label_158)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_20]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_157;
  Wrd33 = Wrd37;

DEFLABEL (label_156)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_3]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_34]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_1_53);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_18]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_155;

DEFLABEL (label_154)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_153)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_58]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_21]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_152;
  Wrd21 = Wrd25;

DEFLABEL (label_151)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_22]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_150;
  Wrd27 = Wrd31;

DEFLABEL (label_149)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_23]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_148;
  Wrd33 = Wrd37;

DEFLABEL (label_147)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_4]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_1_58);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_19]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_146;

DEFLABEL (label_145)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_144)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_63]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_24]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_143;
  Wrd21 = Wrd25;

DEFLABEL (label_142)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_25]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_141;
  Wrd27 = Wrd31;

DEFLABEL (label_140)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_26]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_139;
  Wrd33 = Wrd37;

DEFLABEL (label_138)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_1_63);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_20]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_137;

DEFLABEL (label_136)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_135)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_68]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_11]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_134;
  Wrd21 = Wrd25;

DEFLABEL (label_133)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_7]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_132;
  Wrd27 = Wrd31;

DEFLABEL (label_131)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_4]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_130;
  Wrd33 = Wrd37;

DEFLABEL (label_129)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_6]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_34]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_1_68);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_21]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_128;

DEFLABEL (label_127)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_126)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_73]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_27]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_125;
  Wrd21 = Wrd25;

DEFLABEL (label_124)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_28]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_123;
  Wrd27 = Wrd31;

DEFLABEL (label_122)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_29]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_121;
  Wrd33 = Wrd37;

DEFLABEL (label_120)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_7]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_1_73);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_22]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_119;

DEFLABEL (label_118)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_117)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_78]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_30]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_116;
  Wrd21 = Wrd25;

DEFLABEL (label_115)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_31]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_114;
  Wrd27 = Wrd31;

DEFLABEL (label_113)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_32]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_112;
  Wrd33 = Wrd37;

DEFLABEL (label_111)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_7]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_1_78);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_23]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_110;

DEFLABEL (label_109)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_108)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_83]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_33]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_107;
  Wrd21 = Wrd25;

DEFLABEL (label_106)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_34]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_105;
  Wrd27 = Wrd31;

DEFLABEL (label_104)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_35]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_103;
  Wrd33 = Wrd37;

DEFLABEL (label_102)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_1_8]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_46]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_1_83);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_36]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_101;

DEFLABEL (label_100)
  Wrd5 = Wrd9;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_24]));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_98;

DEFLABEL (label_97)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_96)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_98)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_97;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_88])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_90)
  goto label_96;

DEFLABEL (label_101)
  if ((Wrd9.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_100;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_87])), (Wrd6.pObj));

DEFLABEL (label_89)
  (Wrd5.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_103)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_86])), (Wrd34.pObj));

DEFLABEL (label_88)
  (Wrd33.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_85])), (Wrd28.pObj));

DEFLABEL (label_87)
  (Wrd27.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_84])), (Wrd22.pObj));

DEFLABEL (label_86)
  (Wrd21.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_110)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_109;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_82])), (Wrd6.pObj), Rvl);

DEFLABEL (label_85)
  goto label_108;

DEFLABEL (label_112)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_81])), (Wrd34.pObj));

DEFLABEL (label_84)
  (Wrd33.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_80])), (Wrd28.pObj));

DEFLABEL (label_83)
  (Wrd27.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_79])), (Wrd22.pObj));

DEFLABEL (label_82)
  (Wrd21.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_119)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_118;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_77])), (Wrd6.pObj), Rvl);

DEFLABEL (label_81)
  goto label_117;

DEFLABEL (label_121)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_76])), (Wrd34.pObj));

DEFLABEL (label_80)
  (Wrd33.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_75])), (Wrd28.pObj));

DEFLABEL (label_79)
  (Wrd27.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_74])), (Wrd22.pObj));

DEFLABEL (label_78)
  (Wrd21.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_128)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_127;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_72])), (Wrd6.pObj), Rvl);

DEFLABEL (label_77)
  goto label_126;

DEFLABEL (label_130)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_71])), (Wrd34.pObj));

DEFLABEL (label_76)
  (Wrd33.Obj) = Rvl;
  goto label_129;

DEFLABEL (label_132)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_70])), (Wrd28.pObj));

DEFLABEL (label_75)
  (Wrd27.Obj) = Rvl;
  goto label_131;

DEFLABEL (label_134)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_69])), (Wrd22.pObj));

DEFLABEL (label_74)
  (Wrd21.Obj) = Rvl;
  goto label_133;

DEFLABEL (label_137)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_136;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_67])), (Wrd6.pObj), Rvl);

DEFLABEL (label_73)
  goto label_135;

DEFLABEL (label_139)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_66])), (Wrd34.pObj));

DEFLABEL (label_72)
  (Wrd33.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_65])), (Wrd28.pObj));

DEFLABEL (label_71)
  (Wrd27.Obj) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_64])), (Wrd22.pObj));

DEFLABEL (label_70)
  (Wrd21.Obj) = Rvl;
  goto label_142;

DEFLABEL (label_146)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_145;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_62])), (Wrd6.pObj), Rvl);

DEFLABEL (label_69)
  goto label_144;

DEFLABEL (label_148)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_61])), (Wrd34.pObj));

DEFLABEL (label_68)
  (Wrd33.Obj) = Rvl;
  goto label_147;

DEFLABEL (label_150)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_60])), (Wrd28.pObj));

DEFLABEL (label_67)
  (Wrd27.Obj) = Rvl;
  goto label_149;

DEFLABEL (label_152)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_59])), (Wrd22.pObj));

DEFLABEL (label_66)
  (Wrd21.Obj) = Rvl;
  goto label_151;

DEFLABEL (label_155)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_154;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_57])), (Wrd6.pObj), Rvl);

DEFLABEL (label_65)
  goto label_153;

DEFLABEL (label_157)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_56])), (Wrd34.pObj));

DEFLABEL (label_64)
  (Wrd33.Obj) = Rvl;
  goto label_156;

DEFLABEL (label_159)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_55])), (Wrd28.pObj));

DEFLABEL (label_63)
  (Wrd27.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_161)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_54])), (Wrd22.pObj));

DEFLABEL (label_62)
  (Wrd21.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_164)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_163;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_52])), (Wrd6.pObj), Rvl);

DEFLABEL (label_61)
  goto label_162;

DEFLABEL (label_166)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_51])), (Wrd34.pObj));

DEFLABEL (label_60)
  (Wrd33.Obj) = Rvl;
  goto label_165;

DEFLABEL (label_168)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_50])), (Wrd28.pObj));

DEFLABEL (label_59)
  (Wrd27.Obj) = Rvl;
  goto label_167;

DEFLABEL (label_170)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_49])), (Wrd22.pObj));

DEFLABEL (label_58)
  (Wrd21.Obj) = Rvl;
  goto label_169;

DEFLABEL (label_173)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_172;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_47])), (Wrd6.pObj), Rvl);

DEFLABEL (label_57)
  goto label_171;

DEFLABEL (label_175)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_45])), (Wrd34.pObj));

DEFLABEL (label_56)
  (Wrd33.Obj) = Rvl;
  goto label_174;

DEFLABEL (label_177)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_44])), (Wrd28.pObj));

DEFLABEL (label_55)
  (Wrd27.Obj) = Rvl;
  goto label_176;

DEFLABEL (label_179)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_43])), (Wrd22.pObj));

DEFLABEL (label_54)
  (Wrd21.Obj) = Rvl;
  goto label_178;

DEFLABEL (label_182)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_181;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_41])), (Wrd6.pObj), Rvl);

DEFLABEL (label_53)
  goto label_180;

DEFLABEL (label_184)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_33])), (Wrd21.pObj));

DEFLABEL (label_46)
  (Wrd20.Obj) = Rvl;
  goto label_183;

DEFLABEL (label_186)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_32])), (Wrd15.pObj));

DEFLABEL (label_45)
  (Wrd14.Obj) = Rvl;
  goto label_185;

DEFLABEL (label_188)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_31])), (Wrd9.pObj));

DEFLABEL (label_44)
  (Wrd8.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_23])), (Wrd17.pObj));

DEFLABEL (label_37)
  (Wrd16.Obj) = Rvl;
  goto label_189;

DEFLABEL (label_192)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_22])), (Wrd11.pObj));

DEFLABEL (label_36)
  (Wrd10.Obj) = Rvl;
  goto label_191;

DEFLABEL (label_194)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_13])), (Wrd17.pObj));

DEFLABEL (label_29)
  (Wrd16.Obj) = Rvl;
  goto label_193;

DEFLABEL (label_196)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_12])), (Wrd11.pObj));

DEFLABEL (label_28)
  (Wrd10.Obj) = Rvl;
  goto label_195;

DEFLABEL (label_198)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_8])), (Wrd17.pObj));

DEFLABEL (label_27)
  (Wrd16.Obj) = Rvl;
  goto label_197;

DEFLABEL (label_200)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_7])), (Wrd11.pObj));

DEFLABEL (label_26)
  (Wrd10.Obj) = Rvl;
  goto label_199;

DEFLABEL (lambda_93)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_1_6);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_218;

DEFLABEL (label_217)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_216)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_1]));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_215;

DEFLABEL (label_214)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_213)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_2]));
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd37.Obj) = ((Wrd29.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_212;

DEFLABEL (label_211)
  ((Wrd29.pObj) [0]) = (Wrd30.Obj);

DEFLABEL (label_210)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_3]));
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd49.Obj) = ((Wrd41.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_209;

DEFLABEL (label_208)
  ((Wrd41.pObj) [0]) = (Wrd42.Obj);

DEFLABEL (label_207)
  Rsp = (& (Rsp [4]));
  (Wrd54.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_4]));
  (Wrd57.Obj) = ((Wrd54.pObj) [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if ((Wrd58.uLng) == 50)
    goto label_206;

DEFLABEL (label_205)
  Wrd53 = Wrd57;

DEFLABEL (label_204)
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd65.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_4]));
  (Wrd66.Obj) = (Rsp [1]);
  (Wrd73.Obj) = ((Wrd65.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_203;

DEFLABEL (label_202)
  ((Wrd65.pObj) [0]) = (Wrd66.Obj);

DEFLABEL (label_201)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_203)
  if ((Wrd73.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_202;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_19])), (Wrd65.pObj), (Wrd66.Obj));

DEFLABEL (label_35)
  goto label_201;

DEFLABEL (label_206)
  if ((Wrd57.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_205;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_18])), (Wrd54.pObj));

DEFLABEL (label_34)
  (Wrd53.Obj) = Rvl;
  goto label_204;

DEFLABEL (label_209)
  if ((Wrd49.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_208;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_17])), (Wrd41.pObj), (Wrd42.Obj));

DEFLABEL (label_33)
  goto label_207;

DEFLABEL (label_212)
  if ((Wrd37.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_211;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_16])), (Wrd29.pObj), (Wrd30.Obj));

DEFLABEL (label_32)
  goto label_210;

DEFLABEL (label_215)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_214;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_15])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_31)
  goto label_213;

DEFLABEL (label_218)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_217;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_14])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_30)
  goto label_216;

DEFLABEL (lambda_94)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_1_11);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_5]));
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_236;

DEFLABEL (label_235)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_234)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_6]));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_233;

DEFLABEL (label_232)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_231)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_7]));
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd37.Obj) = ((Wrd29.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_230;

DEFLABEL (label_229)
  ((Wrd29.pObj) [0]) = (Wrd30.Obj);

DEFLABEL (label_228)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_8]));
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd49.Obj) = ((Wrd41.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_227;

DEFLABEL (label_226)
  ((Wrd41.pObj) [0]) = (Wrd42.Obj);

DEFLABEL (label_225)
  Rsp = (& (Rsp [4]));
  (Wrd54.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_7]));
  (Wrd57.Obj) = ((Wrd54.pObj) [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if ((Wrd58.uLng) == 50)
    goto label_224;

DEFLABEL (label_223)
  Wrd53 = Wrd57;

DEFLABEL (label_222)
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd65.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_9]));
  (Wrd66.Obj) = (Rsp [1]);
  (Wrd73.Obj) = ((Wrd65.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_221;

DEFLABEL (label_220)
  ((Wrd65.pObj) [0]) = (Wrd66.Obj);

DEFLABEL (label_219)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_221)
  if ((Wrd73.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_220;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_29])), (Wrd65.pObj), (Wrd66.Obj));

DEFLABEL (label_43)
  goto label_219;

DEFLABEL (label_224)
  if ((Wrd57.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_223;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_28])), (Wrd54.pObj));

DEFLABEL (label_42)
  (Wrd53.Obj) = Rvl;
  goto label_222;

DEFLABEL (label_227)
  if ((Wrd49.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_226;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_27])), (Wrd41.pObj), (Wrd42.Obj));

DEFLABEL (label_41)
  goto label_225;

DEFLABEL (label_230)
  if ((Wrd37.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_229;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_26])), (Wrd29.pObj), (Wrd30.Obj));

DEFLABEL (label_40)
  goto label_228;

DEFLABEL (label_233)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_232;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_25])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_39)
  goto label_231;

DEFLABEL (label_236)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_235;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_24])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_38)
  goto label_234;

DEFLABEL (lambda_95)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_1_21);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_10]));
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_254;

DEFLABEL (label_253)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_252)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_11]));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_251;

DEFLABEL (label_250)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_249)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_12]));
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd37.Obj) = ((Wrd29.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_248;

DEFLABEL (label_247)
  ((Wrd29.pObj) [0]) = (Wrd30.Obj);

DEFLABEL (label_246)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_13]));
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd49.Obj) = ((Wrd41.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_245;

DEFLABEL (label_244)
  ((Wrd41.pObj) [0]) = (Wrd42.Obj);

DEFLABEL (label_243)
  Rsp = (& (Rsp [4]));
  (Wrd54.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_11]));
  (Wrd57.Obj) = ((Wrd54.pObj) [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if ((Wrd58.uLng) == 50)
    goto label_242;

DEFLABEL (label_241)
  Wrd53 = Wrd57;

DEFLABEL (label_240)
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd65.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_14]));
  (Wrd66.Obj) = (Rsp [1]);
  (Wrd73.Obj) = ((Wrd65.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_239;

DEFLABEL (label_238)
  ((Wrd65.pObj) [0]) = (Wrd66.Obj);

DEFLABEL (label_237)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_239)
  if ((Wrd73.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_238;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_40])), (Wrd65.pObj), (Wrd66.Obj));

DEFLABEL (label_52)
  goto label_237;

DEFLABEL (label_242)
  if ((Wrd57.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_241;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_39])), (Wrd54.pObj));

DEFLABEL (label_51)
  (Wrd53.Obj) = Rvl;
  goto label_240;

DEFLABEL (label_245)
  if ((Wrd49.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_244;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_38])), (Wrd41.pObj), (Wrd42.Obj));

DEFLABEL (label_50)
  goto label_243;

DEFLABEL (label_248)
  if ((Wrd37.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_247;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_37])), (Wrd29.pObj), (Wrd30.Obj));

DEFLABEL (label_49)
  goto label_246;

DEFLABEL (label_251)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_250;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_36])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_48)
  goto label_249;

DEFLABEL (label_254)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_253;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_35])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_47)
  goto label_252;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define TAG_2_6 1
#define LABEL_2_7 7
#define TAG_2_8 2
#define LABEL_2_9 9
#define TAG_2_10 3
#define LABEL_2_11 11
#define TAG_2_12 4
#define LABEL_2_13 13
#define TAG_2_14 5
#define LABEL_2_15 15
#define LABEL_2_16 17
#define LABEL_2_17 19
#define LABEL_2_18 21
#define LABEL_2_19 23
#define LABEL_2_20 25
#define LABEL_2_21 27
#define LABEL_2_23 29
#define LABEL_2_24 31
#define LABEL_2_25 33
#define LABEL_2_26 35
#define LABEL_2_27 37
#define LABEL_2_28 39
#define LABEL_2_35 41
#define LABEL_2_32 43
#define LABEL_2_37 45
#define LABEL_2_30 47
#define TAG_2_31 22
#define LABEL_2_41 49
#define LABEL_2_33 51
#define LABEL_2_34 53
#define LABEL_2_43 55
#define LABEL_2_36 57
#define LABEL_2_44 59
#define LABEL_2_38 61
#define LABEL_2_40 63
#define LABEL_2_45 65
#define TAG_2_46 31
#define LABEL_2_47 67
#define LABEL_2_49 69
#define ENVIRONMENT_LABEL_2_3 90
#define DEBUGGING_LABEL_2_2 89
#define OBJECT_2_5 88
#define OBJECT_2_4 87
#define OBJECT_2_3 86
#define OBJECT_2_2 85
#define OBJECT_2_1 84
#define OBJECT_2_0 83
#define EXECUTE_CACHE_2_48 71
#define EXECUTE_CACHE_2_42 73
#define EXECUTE_CACHE_2_39 75
#define EXECUTE_CACHE_2_29 77
#define EXECUTE_CACHE_2_22 79
#define FREE_REFERENCE_2_0 82
#define FREE_REFERENCES_LABEL_2_0 70
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lambda_body_procedures_37;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto wrapper_components_46;

    case 2:
      current_block = (Rpc - LABEL_2_7);
      goto wrap_bodyB_47;

    case 3:
      current_block = (Rpc - LABEL_2_9);
      goto set_unwrapped_bodyB_48;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto unwrapped_body_49;

    case 5:
      current_block = (Rpc - LABEL_2_13);
      goto unwrap_bodyB_50;

    case 6:
      current_block = (Rpc - LABEL_2_15);
      goto continuation_13;

    case 7:
      current_block = (Rpc - LABEL_2_16);
      goto continuation_0;

    case 8:
      current_block = (Rpc - LABEL_2_17);
      goto continuation_33;

    case 9:
      current_block = (Rpc - LABEL_2_18);
      goto continuation_32;

    case 10:
      current_block = (Rpc - LABEL_2_19);
      goto continuation_27;

    case 11:
      current_block = (Rpc - LABEL_2_20);
      goto continuation_21;

    case 12:
      current_block = (Rpc - LABEL_2_21);
      goto continuation_14;

    case 13:
      current_block = (Rpc - LABEL_2_23);
      goto continuation_1;

    case 14:
      current_block = (Rpc - LABEL_2_24);
      goto continuation_35;

    case 15:
      current_block = (Rpc - LABEL_2_25);
      goto continuation_34;

    case 16:
      current_block = (Rpc - LABEL_2_26);
      goto continuation_28;

    case 17:
      current_block = (Rpc - LABEL_2_27);
      goto continuation_22;

    case 18:
      current_block = (Rpc - LABEL_2_28);
      goto continuation_15;

    case 19:
      current_block = (Rpc - LABEL_2_35);
      goto label_39;

    case 20:
      current_block = (Rpc - LABEL_2_32);
      goto continuation_6;

    case 21:
      current_block = (Rpc - LABEL_2_37);
      goto label_40;

    case 22:
      current_block = (Rpc - LABEL_2_30);
      goto lambda_51;

    case 23:
      current_block = (Rpc - LABEL_2_41);
      goto label_41;

    case 24:
      current_block = (Rpc - LABEL_2_33);
      goto continuation_29;

    case 25:
      current_block = (Rpc - LABEL_2_34);
      goto continuation_23;

    case 26:
      current_block = (Rpc - LABEL_2_43);
      goto label_42;

    case 27:
      current_block = (Rpc - LABEL_2_36);
      goto continuation_17;

    case 28:
      current_block = (Rpc - LABEL_2_44);
      goto label_43;

    case 29:
      current_block = (Rpc - LABEL_2_38);
      goto continuation_5;

    case 30:
      current_block = (Rpc - LABEL_2_40);
      goto continuation_3;

    case 31:
      current_block = (Rpc - LABEL_2_45);
      goto lambda_52;

    case 32:
      current_block = (Rpc - LABEL_2_47);
      goto continuation_8;

    case 33:
      current_block = (Rpc - LABEL_2_49);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_body_procedures_45)
DEFLABEL (lambda_body_procedures_37)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_7])));
  Rhp += 2;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd13 = Wrd10;
  (Wrd14.Obj) = (Rsp [2]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  ((Wrd13.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_9])));
  Rhp += 2;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd21 = Wrd18;
  ((Wrd21.pObj) [2]) = (Wrd14.Obj);
  ((Wrd21.pObj) [3]) = (Wrd8.Obj);
  (Rsp [5]) = (Wrd17.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_11])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  ((Wrd25.pObj) [2]) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd30.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_13])));
  Rhp += 2;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd30.pObj)));
  Wrd33 = Wrd30;
  ((Wrd33.pObj) [2]) = (Wrd14.Obj);
  ((Wrd33.pObj) [3]) = (Wrd8.Obj);
  (Rsp [3]) = (Wrd29.Obj);
  (Rsp [4]) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 6);
  }

DEFLABEL (wrapper_components_46)
  CLOSURE_HEADER (LABEL_2_5);

DEFLABEL (wrapper_components_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_2_15);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_2_21);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_53;
  (Wrd11.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_2_0]);
  (Rsp [3]) = (Wrd13.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_53)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_28]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_2_28);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_57;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd12.Lng))))
    goto label_57;
  (Wrd6.Obj) = ((Wrd10.pObj) [2]);

DEFLABEL (label_56)
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_36]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_2_36);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_55;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd12.Lng))))
    goto label_55;
  (Wrd6.Obj) = ((Wrd10.pObj) [3]);

DEFLABEL (label_54)
  (Wrd19.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd19.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_55)
  (Wrd15.Obj) = (current_block [OBJECT_2_5]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_44]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_4]), 2);

DEFLABEL (label_43)
  (Wrd6.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd15.Obj) = (current_block [OBJECT_2_1]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_35]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_4]), 2);

DEFLABEL (label_39)
  (Wrd6.Obj) = Rvl;
  goto label_56;

DEFLABEL (wrap_bodyB_47)
  CLOSURE_HEADER (LABEL_2_7);

DEFLABEL (wrap_bodyB_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_23);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_58;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_31);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_30])));
  Rhp += 3;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd18 = Wrd13;
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [0]);
  ((Wrd18.pObj) [4]) = (Wrd15.Obj);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_2_0]);
  (Rsp [2]) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Rsp [0]) = (Wrd24.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_58)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_32]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_2_32);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_60;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd12.Lng))))
    goto label_60;
  (Wrd6.Obj) = ((Wrd10.pObj) [3]);

DEFLABEL (label_59)
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_38]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_39]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_2_38);
  (Wrd5.Obj) = (Rsp [3]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_46);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_45])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [3]) = (Wrd7.Obj);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_60)
  (Wrd15.Obj) = (current_block [OBJECT_2_5]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_37]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_4]), 2);

DEFLABEL (label_40)
  (Wrd6.Obj) = Rvl;
  goto label_59;

DEFLABEL (set_unwrapped_bodyB_48)
  CLOSURE_HEADER (LABEL_2_9);

DEFLABEL (set_unwrapped_bodyB_36)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_2_18);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_2_17);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_61;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [2]);
  (Rsp [0]) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_61)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_25]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_2_25);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_2_24);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_2_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd19.uLng) == 10)
    goto label_63;

DEFLABEL (label_62)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 3);

DEFLABEL (label_63)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd17.Lng))))
    goto label_62;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [2]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (unwrapped_body_49)
  CLOSURE_HEADER (LABEL_2_11);

DEFLABEL (unwrapped_body_31)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_2_19);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_2_26);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_64;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_33]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_2_33);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_2_1]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_66;

DEFLABEL (label_65)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_4]), 2);

DEFLABEL (label_66)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_65;
  Rvl = ((Wrd13.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (unwrap_bodyB_50)
  CLOSURE_HEADER (LABEL_2_13);

DEFLABEL (unwrap_bodyB_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_2_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_2_27);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_67;
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_67)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_34]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_2_34);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_69;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd12.Lng))))
    goto label_69;
  (Wrd6.Obj) = ((Wrd10.pObj) [2]);

DEFLABEL (label_68)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [2]);
  (Rsp [0]) = (Wrd19.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd22.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_69)
  (Wrd15.Obj) = (current_block [OBJECT_2_1]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_43]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_4]), 2);

DEFLABEL (label_42)
  (Wrd6.Obj) = Rvl;
  goto label_68;

DEFLABEL (lambda_51)
  CLOSURE_HEADER (LABEL_2_30);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_71;
  Wrd10 = Wrd14;

DEFLABEL (label_70)
  (Wrd21.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [4]);
  (Wrd25.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd17.pObj) = (& (Rhp [-4]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_42]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_40);
  (Rsp [2]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_41])), (Wrd11.pObj));

DEFLABEL (label_41)
  (Wrd10.Obj) = Rvl;
  goto label_70;

DEFLABEL (lambda_52)
  CLOSURE_HEADER (LABEL_2_45);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_48]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_2_47);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_29]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_2_49);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_2_5]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd19.uLng) == 10)
    goto label_73;

DEFLABEL (label_72)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 3);

DEFLABEL (label_73)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_72;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define ENVIRONMENT_LABEL_3_3 12
#define DEBUGGING_LABEL_3_2 11
#define EXECUTE_CACHE_3_6 7
#define FREE_REFERENCE_3_0 10
#define FREE_REFERENCES_LABEL_3_0 6
#define NUMBER_OF_LINKER_SECTIONS_3_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto make_wrapper_1;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_wrapper_5)
DEFLABEL (make_wrapper_1)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_7;
  Wrd7 = Wrd11;

DEFLABEL (label_6)
  (Wrd18.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd15.pObj) = (& (Rhp [-4]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd15.pObj)));
  (Rsp [2]) = (Wrd13.Obj);
  (Wrd21.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_6]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_5])), (Wrd8.pObj));

DEFLABEL (label_3)
  (Wrd7.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_7 7
#define LABEL_4_9 9
#define LABEL_4_10 11
#define LABEL_4_11 13
#define LABEL_4_12 15
#define ENVIRONMENT_LABEL_4_3 28
#define DEBUGGING_LABEL_4_2 27
#define OBJECT_4_3 26
#define OBJECT_4_2 25
#define OBJECT_4_1 24
#define OBJECT_4_0 23
#define EXECUTE_CACHE_4_8 17
#define EXECUTE_CACHE_4_6 19
#define FREE_REFERENCE_4_0 22
#define FREE_REFERENCES_LABEL_4_0 16
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd33;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd53;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto wrapperP_7;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_4_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_4_9);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_4_10);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_4_11);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_4_12);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wrapperP_14)
DEFLABEL (wrapperP_7)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_4_7);
  (Rsp [0]) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd7.uLng) == 10)
    goto label_18;

DEFLABEL (label_17)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_16)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  if (! ((Wrd7.uLng) == 10))
    goto label_26;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd10.Obj) = (MAKE_OBJECT (26, (Wrd14.uLng)));

DEFLABEL (label_25)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_24;
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  if ((Wrd53.Lng) == 0)
    goto label_17;

DEFLABEL (label_23)
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_22;
  Wrd27 = Wrd31;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_20;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd41.Lng))))
    goto label_20;
  (Wrd33.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_19)
  (Wrd49.Obj) = (* (Rsp++));
  if (! ((Wrd33.Obj) == (Wrd49.Obj)))
    goto label_17;
  Rvl = (current_block [OBJECT_4_3]);
  goto label_16;

DEFLABEL (label_20)
  (Wrd44.Obj) = (Rsp [1]);
  (Wrd45.Obj) = (current_block [OBJECT_4_1]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_12]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_2]), 2);

DEFLABEL (label_12)
  (Wrd33.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_11])), (Wrd28.pObj));

DEFLABEL (label_11)
  (Wrd27.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  goto label_17;

DEFLABEL (label_26)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_9)
  (Wrd10.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 8
#define DEBUGGING_LABEL_5_2 7
#define EXECUTE_CACHE_5_5 5
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto wrapper_body_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wrapper_body_3)
DEFLABEL (wrapper_body_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 8
#define DEBUGGING_LABEL_6_2 7
#define EXECUTE_CACHE_6_5 5
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto set_wrapper_bodyB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_wrapper_bodyB_3)
DEFLABEL (set_wrapper_bodyB_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define ENVIRONMENT_LABEL_7_3 12
#define DEBUGGING_LABEL_7_2 11
#define OBJECT_7_1 10
#define OBJECT_7_0 9
#define EXECUTE_CACHE_7_6 7
#define FREE_REFERENCES_LABEL_7_0 6
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto wrapper_state_1;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wrapper_state_4)
DEFLABEL (wrapper_state_1)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_7_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define ENVIRONMENT_LABEL_8_3 13
#define DEBUGGING_LABEL_8_2 12
#define OBJECT_8_2 11
#define OBJECT_8_1 10
#define OBJECT_8_0 9
#define EXECUTE_CACHE_8_6 7
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto set_wrapper_stateB_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_wrapper_stateB_4)
DEFLABEL (set_wrapper_stateB_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_8_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_8_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd18.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_2]), 3);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd9.Obj);
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define ENVIRONMENT_LABEL_9_3 12
#define DEBUGGING_LABEL_9_2 11
#define OBJECT_9_1 10
#define OBJECT_9_0 9
#define EXECUTE_CACHE_9_6 7
#define FREE_REFERENCES_LABEL_9_0 6
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto wrapper_original_body_1;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wrapper_original_body_4)
DEFLABEL (wrapper_original_body_1)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_9_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define ENVIRONMENT_LABEL_10_3 13
#define DEBUGGING_LABEL_10_2 12
#define OBJECT_10_2 11
#define OBJECT_10_1 10
#define OBJECT_10_0 9
#define EXECUTE_CACHE_10_6 7
#define FREE_REFERENCES_LABEL_10_0 6
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto set_wrapper_original_bodyB_1;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_wrapper_original_bodyB_4)
DEFLABEL (set_wrapper_original_bodyB_1)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_10_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_10_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd18.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 3);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [2]) = (Wrd9.Obj);
  Rvl = (current_block [OBJECT_10_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_5 3
#define LABEL_11_4 5
#define LABEL_11_8 7
#define LABEL_11_6 9
#define LABEL_11_10 11
#define LABEL_11_11 13
#define ENVIRONMENT_LABEL_11_3 27
#define DEBUGGING_LABEL_11_2 26
#define OBJECT_11_2 25
#define OBJECT_11_1 24
#define OBJECT_11_0 23
#define EXECUTE_CACHE_11_13 15
#define EXECUTE_CACHE_11_12 17
#define EXECUTE_CACHE_11_9 19
#define EXECUTE_CACHE_11_7 21
#define FREE_REFERENCES_LABEL_11_0 14
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd15;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_11_4);
      goto make_clambda_8;

    case 2:
      current_block = (Rpc - LABEL_11_8);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_11_6);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_11_10);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_11_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_clambda_11)
DEFLABEL (make_clambda_8)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  if ((Wrd8.Obj) == (current_block [OBJECT_11_0]))
    goto label_13;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_8]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_11_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_11_1]);
  (Wrd15.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_11_11);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_11_2]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_11_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (Wrd15.Obj) = Rvl;

DEFLABEL (label_12)
  (Rsp [2]) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_6]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_11_6);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_11_2]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_12]));

DEFLABEL (label_13)
  (Wrd15.Obj) = (Rsp [4]);
  Rsp = (& (Rsp [1]));
  goto label_12;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define TAG_12_6 1
#define LABEL_12_8 7
#define LABEL_12_10 9
#define ENVIRONMENT_LABEL_12_3 19
#define DEBUGGING_LABEL_12_2 18
#define OBJECT_12_0 17
#define EXECUTE_CACHE_12_11 11
#define EXECUTE_CACHE_12_9 13
#define EXECUTE_CACHE_12_7 15
#define FREE_REFERENCES_LABEL_12_0 10
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto clambda_components_3;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_12_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_12_10);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clambda_components_6)
DEFLABEL (clambda_components_3)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_12_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Rsp [4]) = ((SCHEME_OBJECT) 0);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_8);
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_10);
  (Rsp [6]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_12_0]);
  (Rsp [3]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 7);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_7 7
#define ENVIRONMENT_LABEL_13_3 16
#define DEBUGGING_LABEL_13_2 15
#define EXECUTE_CACHE_13_9 9
#define EXECUTE_CACHE_13_8 11
#define EXECUTE_CACHE_13_6 13
#define FREE_REFERENCES_LABEL_13_0 8
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto clambda_bound_2;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto lambda_1;

    case 2:
      current_block = (Rpc - LABEL_13_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clambda_bound_5)
DEFLABEL (clambda_bound_2)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (lambda_6)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_13_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_7);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define ENVIRONMENT_LABEL_14_3 12
#define DEBUGGING_LABEL_14_2 11
#define EXECUTE_CACHE_14_7 7
#define EXECUTE_CACHE_14_6 9
#define FREE_REFERENCES_LABEL_14_0 6
#define NUMBER_OF_LINKER_SECTIONS_14_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto clambda_has_internal_lambdaP_1;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clambda_has_internal_lambdaP_4)
DEFLABEL (clambda_has_internal_lambdaP_1)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define LABEL_15_7 7
#define LABEL_15_9 9
#define ENVIRONMENT_LABEL_15_3 21
#define DEBUGGING_LABEL_15_2 20
#define OBJECT_15_0 19
#define EXECUTE_CACHE_15_11 11
#define EXECUTE_CACHE_15_10 13
#define EXECUTE_CACHE_15_8 15
#define EXECUTE_CACHE_15_6 17
#define FREE_REFERENCES_LABEL_15_0 10
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto lambda_body_auxiliary_4;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_15_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_15_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_body_auxiliary_7)
DEFLABEL (lambda_body_auxiliary_4)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;
  Rvl = (current_block [OBJECT_15_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_15_7);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_15_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_11]));

DEFLABEL (label_9)
  Rvl = (current_block [OBJECT_15_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define LABEL_16_7 7
#define LABEL_16_9 9
#define ENVIRONMENT_LABEL_16_3 18
#define DEBUGGING_LABEL_16_2 17
#define EXECUTE_CACHE_16_10 11
#define EXECUTE_CACHE_16_8 13
#define EXECUTE_CACHE_16_6 15
#define FREE_REFERENCES_LABEL_16_0 10
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto lambda_body_has_internal_lambdaP_4;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_16_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_16_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_body_has_internal_lambdaP_7)
DEFLABEL (lambda_body_has_internal_lambdaP_4)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_16_7);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_16_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  Rvl = (Rsp [0]);
  goto label_9;

DEFLABEL (label_10)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_9)
DEFLABEL (label_11)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define ENVIRONMENT_LABEL_17_3 12
#define DEBUGGING_LABEL_17_2 11
#define EXECUTE_CACHE_17_7 7
#define EXECUTE_CACHE_17_6 9
#define FREE_REFERENCES_LABEL_17_0 6
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto clambda_physical_body_3;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clambda_physical_body_6)
DEFLABEL (clambda_physical_body_3)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  (Wrd8.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_8)
  (Wrd8.Obj) = (Rsp [1]);

DEFLABEL (label_7)
DEFLABEL (label_9)
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define ENVIRONMENT_LABEL_18_3 12
#define DEBUGGING_LABEL_18_2 11
#define EXECUTE_CACHE_18_7 7
#define EXECUTE_CACHE_18_6 9
#define FREE_REFERENCES_LABEL_18_0 6
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto clambda_set_physical_bodyB_3;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clambda_set_physical_bodyB_6)
DEFLABEL (clambda_set_physical_bodyB_3)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  (Wrd8.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_8)
  (Wrd8.Obj) = (Rsp [1]);

DEFLABEL (label_7)
DEFLABEL (label_9)
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_6 7
#define LABEL_19_7 9
#define LABEL_19_9 11
#define LABEL_19_11 13
#define LABEL_19_16 15
#define LABEL_19_12 17
#define LABEL_19_13 19
#define LABEL_19_17 21
#define LABEL_19_19 23
#define LABEL_19_23 25
#define LABEL_19_21 27
#define LABEL_19_22 29
#define ENVIRONMENT_LABEL_19_3 52
#define DEBUGGING_LABEL_19_2 51
#define OBJECT_19_7 50
#define OBJECT_19_6 49
#define OBJECT_19_5 48
#define OBJECT_19_4 47
#define OBJECT_19_3 46
#define OBJECT_19_2 45
#define OBJECT_19_1 44
#define OBJECT_19_0 43
#define EXECUTE_CACHE_19_20 31
#define EXECUTE_CACHE_19_18 33
#define EXECUTE_CACHE_19_15 35
#define EXECUTE_CACHE_19_14 37
#define EXECUTE_CACHE_19_10 39
#define EXECUTE_CACHE_19_8 41
#define FREE_REFERENCES_LABEL_19_0 30
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto make_clexpr_24;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_21;

    case 2:
      current_block = (Rpc - LABEL_19_6);
      goto continuation_11;

    case 3:
      current_block = (Rpc - LABEL_19_7);
      goto continuation_10;

    case 4:
      current_block = (Rpc - LABEL_19_9);
      goto continuation_23;

    case 5:
      current_block = (Rpc - LABEL_19_11);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_19_16);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_19_12);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_19_13);
      goto continuation_15;

    case 9:
      current_block = (Rpc - LABEL_19_17);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_19_19);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_19_23);
      goto label_26;

    case 12:
      current_block = (Rpc - LABEL_19_21);
      goto continuation_4;

    case 13:
      current_block = (Rpc - LABEL_19_22);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_clexpr_28)
DEFLABEL (make_clexpr_24)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_8]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_19_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_19_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_19_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_19_4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_14]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_19_13);
  (Wrd9.Obj) = (current_block [OBJECT_19_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_19]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_20]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_19_19);
  (Wrd5.Obj) = Rvl;
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 26))
    goto label_30;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd13.Lng) = ((Wrd14.Lng) + 3L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_30;
  (Wrd11.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_29)
  (Wrd17.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd24.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Rsp [1]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_14]));

DEFLABEL (label_30)
  (Wrd7.Obj) = (current_block [OBJECT_19_7]);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_26)
  (Wrd11.Obj) = Rvl;
  goto label_29;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_19_6);
  (Wrd9.Obj) = (current_block [OBJECT_19_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_12]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd24.Obj) = (current_block [OBJECT_19_2]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_10]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_19_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [8]);
  if ((Wrd8.Obj) == (current_block [OBJECT_19_1]))
    goto label_32;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_17]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_19_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_22]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_19_6]);
  (Wrd15.Obj) = (Rsp [11]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_19_22);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [12]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_19_5]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_19_21);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_19_16);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_31)
  (Wrd16.Obj) = (current_block [OBJECT_19_5]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_15]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_19_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_14]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_19_5);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_19_0]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_10]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_19_9);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_15]));

DEFLABEL (label_32)
  (Wrd15.Obj) = (Rsp [9]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);
  goto label_31;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define TAG_20_6 1
#define LABEL_20_8 7
#define LABEL_20_10 9
#define LABEL_20_12 11
#define LABEL_20_14 13
#define LABEL_20_18 15
#define LABEL_20_15 17
#define LABEL_20_19 19
#define LABEL_20_16 21
#define ENVIRONMENT_LABEL_20_3 41
#define DEBUGGING_LABEL_20_2 40
#define OBJECT_20_2 39
#define OBJECT_20_1 38
#define OBJECT_20_0 37
#define EXECUTE_CACHE_20_21 23
#define EXECUTE_CACHE_20_20 25
#define EXECUTE_CACHE_20_17 27
#define EXECUTE_CACHE_20_13 29
#define EXECUTE_CACHE_20_11 31
#define EXECUTE_CACHE_20_9 33
#define EXECUTE_CACHE_20_7 35
#define FREE_REFERENCES_LABEL_20_0 22
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto clexpr_components_11;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto lambda_17;

    case 2:
      current_block = (Rpc - LABEL_20_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_20_10);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_20_12);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_20_14);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_20_18);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_20_15);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_20_19);
      goto label_14;

    case 9:
      current_block = (Rpc - LABEL_20_16);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clexpr_components_16)
DEFLABEL (clexpr_components_11)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_20_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_20_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_20_5);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_20_12);
  (Rsp [6]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_16]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_20_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_21]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_20_15);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_21;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_20)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_20]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_20_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [6]);
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_19;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [0]);

DEFLABEL (label_18)
  (Wrd15.Obj) = (Rsp [5]);
  (Rsp [2]) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_20_1]);
  (Rsp [4]) = (Wrd16.Obj);
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd17.Obj) = (* (Rsp++));
  (Rsp [5]) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 7);
  }

DEFLABEL (label_19)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_18]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_13)
  (Wrd6.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_2]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_7 7
#define LABEL_21_9 9
#define LABEL_21_10 11
#define LABEL_21_12 13
#define ENVIRONMENT_LABEL_21_3 28
#define DEBUGGING_LABEL_21_2 27
#define EXECUTE_CACHE_21_15 15
#define EXECUTE_CACHE_21_14 17
#define EXECUTE_CACHE_21_13 19
#define EXECUTE_CACHE_21_11 21
#define EXECUTE_CACHE_21_8 23
#define EXECUTE_CACHE_21_6 25
#define FREE_REFERENCES_LABEL_21_0 14
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto clexpr_bound_6;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto lambda_5;

    case 2:
      current_block = (Rpc - LABEL_21_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_21_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_21_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_21_12);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clexpr_bound_9)
DEFLABEL (clexpr_bound_6)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (lambda_10)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_21_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_21_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_21_9);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_21_12);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_15]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define LABEL_22_6 7
#define LABEL_22_8 9
#define LABEL_22_9 11
#define ENVIRONMENT_LABEL_22_3 20
#define DEBUGGING_LABEL_22_2 19
#define EXECUTE_CACHE_22_11 13
#define EXECUTE_CACHE_22_10 15
#define EXECUTE_CACHE_22_7 17
#define FREE_REFERENCES_LABEL_22_0 12
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto clexpr_has_internal_lambdaP_6;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_22_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_22_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_22_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clexpr_has_internal_lambdaP_9)
DEFLABEL (clexpr_has_internal_lambdaP_6)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_22_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_22_8);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = Rvl;
  goto label_10;

DEFLABEL (label_11)
  Rvl = (Rsp [1]);

DEFLABEL (label_10)
DEFLABEL (label_12)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define ENVIRONMENT_LABEL_23_3 12
#define DEBUGGING_LABEL_23_2 11
#define EXECUTE_CACHE_23_7 7
#define EXECUTE_CACHE_23_6 9
#define FREE_REFERENCES_LABEL_23_0 6
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto clexpr_physical_body_1;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clexpr_physical_body_4)
DEFLABEL (clexpr_physical_body_1)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define ENVIRONMENT_LABEL_24_3 12
#define DEBUGGING_LABEL_24_2 11
#define EXECUTE_CACHE_24_7 7
#define EXECUTE_CACHE_24_6 9
#define FREE_REFERENCES_LABEL_24_0 6
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto clexpr_set_physical_bodyB_1;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (clexpr_set_physical_bodyB_4)
DEFLABEL (clexpr_set_physical_bodyB_1)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_5 3
#define LABEL_25_4 5
#define LABEL_25_9 7
#define LABEL_25_6 9
#define LABEL_25_7 11
#define LABEL_25_11 13
#define LABEL_25_12 15
#define LABEL_25_14 17
#define LABEL_25_15 19
#define LABEL_25_20 21
#define LABEL_25_21 23
#define LABEL_25_22 25
#define LABEL_25_23 27
#define ENVIRONMENT_LABEL_25_3 51
#define DEBUGGING_LABEL_25_2 50
#define OBJECT_25_6 49
#define OBJECT_25_5 48
#define OBJECT_25_4 47
#define OBJECT_25_3 46
#define OBJECT_25_2 45
#define OBJECT_25_1 44
#define OBJECT_25_0 43
#define EXECUTE_CACHE_25_19 29
#define EXECUTE_CACHE_25_18 31
#define EXECUTE_CACHE_25_17 33
#define EXECUTE_CACHE_25_16 35
#define EXECUTE_CACHE_25_13 37
#define EXECUTE_CACHE_25_10 39
#define EXECUTE_CACHE_25_8 41
#define FREE_REFERENCES_LABEL_25_0 28
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_25_4);
      goto make_xlambda_17;

    case 2:
      current_block = (Rpc - LABEL_25_9);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_25_6);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_25_7);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_25_11);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_25_12);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_25_14);
      goto continuation_16;

    case 8:
      current_block = (Rpc - LABEL_25_15);
      goto continuation_11;

    case 9:
      current_block = (Rpc - LABEL_25_20);
      goto label_19;

    case 10:
      current_block = (Rpc - LABEL_25_21);
      goto label_20;

    case 11:
      current_block = (Rpc - LABEL_25_22);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_25_23);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_xlambda_23)
DEFLABEL (make_xlambda_17)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  if ((Wrd8.Obj) == (current_block [OBJECT_25_0]))
    goto label_37;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_25_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_25_1]);
  (Wrd15.Obj) = (Rsp [8]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_25_12);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_25_2]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_18]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_25_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_25_5);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_36)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_6]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  if ((Wrd22.Obj) == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd28.Obj) = (current_block [OBJECT_25_0]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  goto label_24;

DEFLABEL (label_25)
  (Wrd31.Obj) = (current_block [OBJECT_25_0]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_24)
DEFLABEL (label_35)
  (Wrd29.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_8]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_25_7);
  (Wrd9.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_13]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_25_6);
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_16]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_25_15);
  (Wrd8.Obj) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd7.Obj) = (current_block [OBJECT_25_5]);
  goto label_26;

DEFLABEL (label_27)
  (Wrd7.Obj) = (current_block [OBJECT_25_4]);

DEFLABEL (label_26)
DEFLABEL (label_34)
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd15.uLng) == 26))
    goto label_33;
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd16.uLng) == 26))
    goto label_33;
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  (Wrd17.Lng) = ((Wrd18.Lng) + (Wrd19.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd17.Lng)))
    goto label_33;
  (Wrd14.Obj) = (LONG_TO_FIXNUM (Wrd17.Lng));

DEFLABEL (label_32)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 26))
    goto label_31;
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (multiply_with_overflow ((Wrd29.Lng), 256, (& (Wrd26.Lng))))
    goto label_31;
  (Wrd30.Obj) = (LONG_TO_FIXNUM (Wrd26.Lng));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_30)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_22]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_25_22);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 26))
    goto label_29;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd13.uLng) == 26))
    goto label_29;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd14.Lng) = ((Wrd15.Lng) + (Wrd16.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd14.Lng)))
    goto label_29;
  (Wrd17.Obj) = (LONG_TO_FIXNUM (Wrd14.Lng));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_28)
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_6]), 1);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_25_14);
  (Rsp [6]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_25_3]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd7.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_19]));

DEFLABEL (label_29)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_23]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd20.Obj) = (current_block [OBJECT_25_5]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_21]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_20]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_19)
  (Wrd14.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_37)
  (Wrd15.Obj) = (Rsp [6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);
  goto label_36;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 8
#define DEBUGGING_LABEL_26_2 7
#define OBJECT_26_2 6
#define OBJECT_26_1 5
#define OBJECT_26_0 4
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto xlambdaP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambdaP_3)
DEFLABEL (xlambdaP_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd5.Obj) = (current_block [OBJECT_26_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 20L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_26_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_5 5
#define LABEL_27_10 7
#define LABEL_27_6 9
#define LABEL_27_7 11
#define LABEL_27_9 13
#define LABEL_27_12 15
#define LABEL_27_13 17
#define LABEL_27_14 19
#define LABEL_27_15 21
#define LABEL_27_18 23
#define LABEL_27_16 25
#define LABEL_27_19 27
#define LABEL_27_20 29
#define LABEL_27_21 31
#define LABEL_27_22 33
#define LABEL_27_23 35
#define LABEL_27_24 37
#define LABEL_27_26 39
#define LABEL_27_27 41
#define LABEL_27_33 43
#define LABEL_27_28 45
#define LABEL_27_30 47
#define LABEL_27_32 49
#define LABEL_27_35 51
#define LABEL_27_37 53
#define ENVIRONMENT_LABEL_27_3 81
#define DEBUGGING_LABEL_27_2 80
#define OBJECT_27_8 79
#define OBJECT_27_7 78
#define OBJECT_27_6 77
#define OBJECT_27_5 76
#define OBJECT_27_4 75
#define OBJECT_27_3 74
#define OBJECT_27_2 73
#define OBJECT_27_1 72
#define OBJECT_27_0 71
#define EXECUTE_CACHE_27_36 55
#define EXECUTE_CACHE_27_34 57
#define EXECUTE_CACHE_27_31 59
#define EXECUTE_CACHE_27_29 61
#define EXECUTE_CACHE_27_25 63
#define EXECUTE_CACHE_27_17 65
#define EXECUTE_CACHE_27_11 67
#define EXECUTE_CACHE_27_8 69
#define FREE_REFERENCES_LABEL_27_0 54
#define NUMBER_OF_LINKER_SECTIONS_27_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd73;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto xlambda_components_29;

    case 1:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_27_10);
      goto label_31;

    case 3:
      current_block = (Rpc - LABEL_27_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_27_7);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_27_9);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_27_12);
      goto label_32;

    case 7:
      current_block = (Rpc - LABEL_27_13);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_27_14);
      goto label_34;

    case 9:
      current_block = (Rpc - LABEL_27_15);
      goto label_35;

    case 10:
      current_block = (Rpc - LABEL_27_18);
      goto continuation_17;

    case 11:
      current_block = (Rpc - LABEL_27_16);
      goto continuation_11;

    case 12:
      current_block = (Rpc - LABEL_27_19);
      goto label_36;

    case 13:
      current_block = (Rpc - LABEL_27_20);
      goto label_37;

    case 14:
      current_block = (Rpc - LABEL_27_21);
      goto label_38;

    case 15:
      current_block = (Rpc - LABEL_27_22);
      goto label_39;

    case 16:
      current_block = (Rpc - LABEL_27_23);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_27_24);
      goto continuation_23;

    case 18:
      current_block = (Rpc - LABEL_27_26);
      goto continuation_22;

    case 19:
      current_block = (Rpc - LABEL_27_27);
      goto continuation_21;

    case 20:
      current_block = (Rpc - LABEL_27_33);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_27_28);
      goto continuation_20;

    case 22:
      current_block = (Rpc - LABEL_27_30);
      goto continuation_14;

    case 23:
      current_block = (Rpc - LABEL_27_32);
      goto continuation_19;

    case 24:
      current_block = (Rpc - LABEL_27_35);
      goto continuation_13;

    case 25:
      current_block = (Rpc - LABEL_27_37);
      goto label_42;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_components_44)
DEFLABEL (xlambda_components_29)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_7]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_7);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_2]), 1);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_27_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 1))
    goto label_70;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_69)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_27_9);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_68;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_67)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd18.uLng) == 26))
    goto label_66;
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd19.Lng) = ((Wrd20.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd19.Lng)))
    goto label_66;
  (Wrd21.Obj) = (LONG_TO_FIXNUM (Wrd19.Lng));
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_65)
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_64;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_63)
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 26))
    goto label_62;
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd38.uLng) == 26))
    goto label_62;
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd39.Lng) = ((Wrd41.Lng) + (Wrd42.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd39.Lng)))
    goto label_62;
  (Wrd43.Obj) = (LONG_TO_FIXNUM (Wrd39.Lng));
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_61)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_16]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_17]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_27_16);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_60;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_59)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_58;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_58;
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd22.Lng) = ((Wrd24.Lng) + (Wrd25.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd22.Lng)))
    goto label_58;
  (Wrd26.Obj) = (LONG_TO_FIXNUM (Wrd22.Lng));
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_57)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_18]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd33.Obj) = (Rsp [5]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_56;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);

DEFLABEL (label_55)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd39.uLng) == 26))
    goto label_54;
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if ((Wrd73.Lng) == 0)
    goto label_53;

DEFLABEL (label_52)
  (Wrd60.Obj) = (Rsp [2]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd61.uLng) == 10))
    goto label_51;
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 26))
    goto label_51;
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [0]);
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  if (! (((unsigned long) (Wrd55.Lng)) < ((unsigned long) (Wrd59.Lng))))
    goto label_51;
  (Wrd48.uLng) = (OBJECT_DATUM (Wrd52.Obj));
  (Wrd51.pObj) = (& ((Wrd57.pObj) [(Wrd48.Lng)]));
  (Wrd46.Obj) = ((Wrd51.pObj) [1]);

DEFLABEL (label_50)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_49)
  (Rsp [5]) = (Wrd46.Obj);
  (Wrd67.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_24]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd71.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd71.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_25]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_27_24);
  (Rsp [8]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_27]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_28]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_29]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_27_28);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_34]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_27_27);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 10))
    goto label_48;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Obj) = (MAKE_OBJECT (26, (Wrd11.uLng)));
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_47)
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_31]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_27_32);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_36]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_27_26);
  (Rsp [7]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_30]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_31]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_27_30);
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_35]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_27_7]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_31]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_27_35);
  (Rsp [4]) = Rvl;
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_46;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd14.Lng))))
    goto label_46;
  (Wrd6.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_45)
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd22.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd22.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 7);
  }

DEFLABEL (label_46)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.Obj) = (current_block [OBJECT_27_8]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_37]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_4]), 2);

DEFLABEL (label_42)
  (Wrd6.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_33]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_6]), 1);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_51)
  (Wrd62.Obj) = (Rsp [2]);
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_23]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_4]), 2);

DEFLABEL (label_40)
  (Wrd46.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd46.Obj) = (current_block [OBJECT_27_5]);
  goto label_50;

DEFLABEL (label_54)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_22]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_39)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_52;
  goto label_53;

DEFLABEL (label_56)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_21]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 1);

DEFLABEL (label_38)
  (Wrd30.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_20]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 1);

DEFLABEL (label_36)
  (Wrd5.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_15]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_14]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_3]), 1);

DEFLABEL (label_34)
  (Wrd22.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_13]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_3]), 1);

DEFLABEL (label_32)
  (Wrd5.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_10]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 1);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_69;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_27_18);
  (Wrd46.Obj) = Rvl;
  goto label_49;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 8
#define DEBUGGING_LABEL_28_2 7
#define EXECUTE_CACHE_28_5 5
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto xlambda_names_vector_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_names_vector_3)
DEFLABEL (xlambda_names_vector_0)
  INTERRUPT_CHECK (26, LABEL_28_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define ENVIRONMENT_LABEL_29_3 12
#define DEBUGGING_LABEL_29_2 11
#define OBJECT_29_1 10
#define OBJECT_29_0 9
#define EXECUTE_CACHE_29_6 7
#define FREE_REFERENCES_LABEL_29_0 6
#define NUMBER_OF_LINKER_SECTIONS_29_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto xlambda_name_1;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_name_4)
DEFLABEL (xlambda_name_1)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_29_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_6 7
#define LABEL_30_11 9
#define LABEL_30_8 11
#define LABEL_30_9 13
#define ENVIRONMENT_LABEL_30_3 28
#define DEBUGGING_LABEL_30_2 27
#define OBJECT_30_1 26
#define OBJECT_30_0 25
#define EXECUTE_CACHE_30_14 15
#define EXECUTE_CACHE_30_13 17
#define EXECUTE_CACHE_30_12 19
#define EXECUTE_CACHE_30_10 21
#define EXECUTE_CACHE_30_7 23
#define FREE_REFERENCES_LABEL_30_0 14
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto xlambda_bound_6;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_30_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_30_11);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_30_8);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_30_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_bound_10)
DEFLABEL (xlambda_bound_6)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_30_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_30_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_12;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd7.Obj) = (MAKE_OBJECT (26, (Wrd11.uLng)));

DEFLABEL (label_11)
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_12]));

DEFLABEL (label_12)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 1);

DEFLABEL (label_8)
  (Wrd7.Obj) = Rvl;
  goto label_11;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_30_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_30_8);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_13]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define ENVIRONMENT_LABEL_31_3 12
#define DEBUGGING_LABEL_31_2 11
#define EXECUTE_CACHE_31_7 7
#define EXECUTE_CACHE_31_6 9
#define FREE_REFERENCES_LABEL_31_0 6
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto xlambda_has_internal_lambdaP_1;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_has_internal_lambdaP_4)
DEFLABEL (xlambda_has_internal_lambdaP_1)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define ENVIRONMENT_LABEL_32_3 14
#define DEBUGGING_LABEL_32_2 13
#define EXECUTE_CACHE_32_8 7
#define EXECUTE_CACHE_32_7 9
#define EXECUTE_CACHE_32_6 11
#define FREE_REFERENCES_LABEL_32_0 6
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto xlambda_physical_body_2;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_physical_body_5)
DEFLABEL (xlambda_physical_body_2)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_6;
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_8]));

DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_5 5
#define ENVIRONMENT_LABEL_33_3 14
#define DEBUGGING_LABEL_33_2 13
#define EXECUTE_CACHE_33_8 7
#define EXECUTE_CACHE_33_7 9
#define EXECUTE_CACHE_33_6 11
#define FREE_REFERENCES_LABEL_33_0 6
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto xlambda_set_physical_bodyB_2;

    case 1:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xlambda_set_physical_bodyB_5)
DEFLABEL (xlambda_set_physical_bodyB_2)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_6;
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_8]));

DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_5 5
#define LABEL_34_6 7
#define ENVIRONMENT_LABEL_34_3 14
#define DEBUGGING_LABEL_34_2 13
#define OBJECT_34_4 12
#define OBJECT_34_3 11
#define OBJECT_34_2 10
#define OBJECT_34_1 9
#define OBJECT_34_0 8
#define FREE_REFERENCES_LABEL_34_0 8
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd24;
  machine_word Wrd13;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd40;
  machine_word Wrd37;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto lambdaP_2;

    case 1:
      current_block = (Rpc - LABEL_34_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_34_6);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambdaP_7)
DEFLABEL (lambdaP_2)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd37.Obj) = (current_block [OBJECT_34_0]);
  (Wrd40.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd40.Lng))))
    goto label_16;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd37.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_9;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_34_4]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd27.Obj) = (current_block [OBJECT_34_2]);
  (Wrd30.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 41L) < ((unsigned long) (Wrd30.Lng))))
    goto label_15;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd27.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_8;

DEFLABEL (label_14)
  (Wrd13.Obj) = (current_block [OBJECT_34_3]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd24.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 20L) < ((unsigned long) (Wrd24.Lng)))
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_10)
  (Wrd16.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd16.Obj) == (Wrd18.Obj))
    goto label_12;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_11;

DEFLABEL (label_12)
  Rvl = (current_block [OBJECT_34_4]);

DEFLABEL (label_11)
DEFLABEL (label_13)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_6]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_4)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  goto label_8;

DEFLABEL (label_16)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_5)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_8 5
#define LABEL_35_12 7
#define LABEL_35_5 9
#define LABEL_35_6 11
#define LABEL_35_15 13
#define LABEL_35_20 15
#define LABEL_35_21 17
#define LABEL_35_13 19
#define LABEL_35_23 21
#define LABEL_35_17 23
#define LABEL_35_11 25
#define LABEL_35_9 27
#define ENVIRONMENT_LABEL_35_3 59
#define DEBUGGING_LABEL_35_2 58
#define OBJECT_35_6 57
#define OBJECT_35_5 56
#define OBJECT_35_4 55
#define OBJECT_35_3 54
#define OBJECT_35_2 53
#define OBJECT_35_1 52
#define OBJECT_35_0 51
#define EXECUTE_CACHE_35_27 29
#define EXECUTE_CACHE_35_26 31
#define EXECUTE_CACHE_35_25 33
#define EXECUTE_CACHE_35_24 35
#define EXECUTE_CACHE_35_22 37
#define EXECUTE_CACHE_35_19 39
#define EXECUTE_CACHE_35_18 41
#define EXECUTE_CACHE_35_16 43
#define EXECUTE_CACHE_35_14 45
#define EXECUTE_CACHE_35_10 47
#define EXECUTE_CACHE_35_7 49
#define FREE_REFERENCES_LABEL_35_0 28
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd6;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto make_lambda_24;

    case 1:
      current_block = (Rpc - LABEL_35_8);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_35_12);
      goto continuation_12;

    case 3:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_35_6);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_35_15);
      goto continuation_13;

    case 6:
      current_block = (Rpc - LABEL_35_20);
      goto continuation_18;

    case 7:
      current_block = (Rpc - LABEL_35_21);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_16;

    case 9:
      current_block = (Rpc - LABEL_35_23);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_35_17);
      goto continuation_4;

    case 11:
      current_block = (Rpc - LABEL_35_11);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_35_9);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_lambda_29)
DEFLABEL (make_lambda_24)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_31;
  (Wrd17.Obj) = (current_block [OBJECT_35_0]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  goto label_30;

DEFLABEL (label_31)
  (Wrd20.Obj) = (current_block [OBJECT_35_0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_30)
DEFLABEL (label_46)
  (Wrd18.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_35_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_35_8);
  (* (--Rsp)) = Rvl;
  (Wrd21.Obj) = (current_block [OBJECT_35_0]);
  if (Rvl == (Wrd21.Obj))
    goto label_32;
  (Wrd22.Obj) = (current_block [OBJECT_35_3]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_11]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_35_2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_35_11);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_27]));

DEFLABEL (label_32)
  (Wrd27.Obj) = (Rsp [1]);
  if ((Wrd27.Obj) == (Wrd21.Obj))
    goto label_33;
  (Wrd29.Obj) = (current_block [OBJECT_35_1]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Rsp [1]) = (Wrd27.Obj);
  (Wrd31.Obj) = (Rsp [5]);
  (Rsp [3]) = (Wrd31.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_35_2]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_35_9);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_27]));

DEFLABEL (label_33)
  Rsp = (& (Rsp [4]));

DEFLABEL (label_45)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  if ((Wrd8.Obj) == (current_block [OBJECT_35_0]))
    goto label_44;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_15]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_35_15);
  (Wrd8.Obj) = (Rsp [7]);
  (Wrd9.Obj) = (current_block [OBJECT_35_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_19]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_35_12);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_43)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_14]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_35_13);
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd6.uLng) == 26))
    goto label_42;
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Rvl));
  if (! ((Wrd7.Lng) < 256L))
    goto label_36;

DEFLABEL (label_41)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_20]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_14]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_35_20);
  (Wrd39.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd39.uLng) == 26))
    goto label_40;
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Rvl));
  if ((Wrd40.Lng) < 256L)
    goto label_37;

DEFLABEL (label_36)
  (Wrd10.Obj) = (Rsp [3]);
  if ((Wrd10.Obj) == (current_block [OBJECT_35_0]))
    goto label_34;
  (Wrd12.Obj) = (current_block [OBJECT_35_5]);
  (Rsp [6]) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_35_6]);
  (Rsp [7]) = (Wrd13.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_26]));

DEFLABEL (label_34)
  (Wrd15.Obj) = (Rsp [4]);
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;
  (Wrd17.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (Rsp [6]) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [0]);
  (Rsp [7]) = (Wrd19.Obj);
  (Rsp [5]) = (Wrd15.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd21.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_25]));

DEFLABEL (label_35)
  (Wrd23.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [5]);
  (Rsp [6]) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [0]);
  (Rsp [7]) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (Rsp [5]) = (Wrd26.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_24]));

DEFLABEL (label_37)
  (Wrd43.Obj) = (Rsp [3]);
  (Wrd44.Obj) = (current_block [OBJECT_35_0]);
  if ((Wrd43.Obj) == (Wrd44.Obj))
    goto label_39;

DEFLABEL (label_38)
  (Wrd45.Obj) = (Rsp [5]);
  (Rsp [6]) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [0]);
  (Rsp [7]) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd50.Obj);
  (Rsp [3]) = (Wrd47.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_22]));

DEFLABEL (label_39)
  (Wrd52.Obj) = (Rsp [4]);
  if (! ((Wrd52.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_38;
  (Wrd54.Obj) = (Rsp [5]);
  if ((Wrd54.Obj) == (Wrd44.Obj))
    goto label_36;
  goto label_38;

DEFLABEL (label_40)
  (Wrd57.Obj) = (current_block [OBJECT_35_4]);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_21]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  goto label_37;

DEFLABEL (label_42)
  (Wrd33.Obj) = (current_block [OBJECT_35_4]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_23]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  goto label_41;

DEFLABEL (label_44)
  (Wrd15.Obj) = (Rsp [7]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);
  goto label_43;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_35_5);
  goto label_45;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define TAG_36_6 1
#define LABEL_36_9 7
#define LABEL_36_8 9
#define LABEL_36_13 11
#define LABEL_36_12 13
#define LABEL_36_16 15
#define LABEL_36_15 17
#define LABEL_36_18 19
#define LABEL_36_19 21
#define ENVIRONMENT_LABEL_36_3 39
#define DEBUGGING_LABEL_36_2 38
#define OBJECT_36_4 37
#define OBJECT_36_3 36
#define OBJECT_36_2 35
#define OBJECT_36_1 34
#define OBJECT_36_0 33
#define EXECUTE_CACHE_36_17 23
#define EXECUTE_CACHE_36_14 25
#define EXECUTE_CACHE_36_11 27
#define EXECUTE_CACHE_36_10 29
#define EXECUTE_CACHE_36_7 31
#define FREE_REFERENCES_LABEL_36_0 22
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto lambda_components_10;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto lambda_18;

    case 2:
      current_block = (Rpc - LABEL_36_9);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_36_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_36_13);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_36_12);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_36_16);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_36_15);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_36_18);
      goto label_14;

    case 9:
      current_block = (Rpc - LABEL_36_19);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_components_17)
DEFLABEL (lambda_components_10)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x707, 2);
  (* (Rhp++)) = (dispatch_base + TAG_36_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_36_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_7]));

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_36_5);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_36_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  (Wrd30.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_36_8);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_29)
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_19;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [2]);
  (Rsp [0]) = (Wrd19.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [6]);
  (Rsp [5]) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_36_0]);
  (Rsp [6]) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 8);
  }

DEFLABEL (label_19)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_28;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_36_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_20;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [2]);
  (Rsp [0]) = (Wrd19.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [6]);
  (Rsp [5]) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_36_0]);
  (Rsp [6]) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 8);
  }

DEFLABEL (label_20)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_26;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_25)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_36_15);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_24;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_23)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_22;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd20.Lng))))
    goto label_22;
  (Wrd15.Obj) = ((Wrd18.pObj) [2]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_21)
  (Wrd27.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [8]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.pObj) = (& (Rsp [16]));
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [8]));
    SCHEME_OBJECT * MFUp2 = (Wrd35.pObj);
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 8);
  }

DEFLABEL (label_22)
  (Wrd23.Obj) = (current_block [OBJECT_36_3]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_19]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_4]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_16]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_2]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_29;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define LABEL_37_8 7
#define LABEL_37_9 9
#define LABEL_37_7 11
#define LABEL_37_11 13
#define LABEL_37_13 15
#define LABEL_37_12 17
#define LABEL_37_14 19
#define LABEL_37_15 21
#define LABEL_37_16 23
#define ENVIRONMENT_LABEL_37_3 33
#define DEBUGGING_LABEL_37_2 32
#define OBJECT_37_2 31
#define OBJECT_37_1 30
#define OBJECT_37_0 29
#define EXECUTE_CACHE_37_10 25
#define EXECUTE_CACHE_37_6 27
#define FREE_REFERENCES_LABEL_37_0 24
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto find_list_duplicates_14;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto loop_12;

    case 2:
      current_block = (Rpc - LABEL_37_8);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_37_9);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_37_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_37_11);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_37_13);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_37_12);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_37_14);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_37_15);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_37_16);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_list_duplicates_24)
DEFLABEL (find_list_duplicates_14)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_37_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto loop_12;

DEFLABEL (loop_25)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_37_5);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_37_0])))
    goto label_26;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (label_26)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_42;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_41)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_40;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_37_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_35;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_34)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_37_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_28;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_27)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_28)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_16]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_20)
  (Wrd7.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_29)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_33;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_32)
  (Wrd28.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Rsp [1]) = (Wrd25.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_31;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_30)
  (Rsp [0]) = (Wrd29.Obj);
  goto loop_12;

DEFLABEL (label_31)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_15]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_22)
  (Wrd29.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_14]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_21)
  (Wrd16.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_13]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (label_36)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_38;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [0]) = (Wrd20.Obj);
  goto loop_12;

DEFLABEL (label_38)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_11]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_19)
  (Wrd20.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_9]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_7 5
#define LABEL_38_5 7
#define TAG_38_6 2
#define LABEL_38_8 9
#define LABEL_38_9 11
#define LABEL_38_10 13
#define ENVIRONMENT_LABEL_38_3 23
#define DEBUGGING_LABEL_38_2 22
#define OBJECT_38_4 21
#define OBJECT_38_3 20
#define OBJECT_38_2 19
#define OBJECT_38_1 18
#define OBJECT_38_0 17
#define EXECUTE_CACHE_38_11 15
#define FREE_REFERENCES_LABEL_38_0 14
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd10;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd26;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto dispatch_0_5;

    case 1:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_38_5);
      goto lambda_12;

    case 3:
      current_block = (Rpc - LABEL_38_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_38_9);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_38_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dispatch_0_11)
DEFLABEL (dispatch_0_5)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_38_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_38_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_38_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_38_0]);
  (Wrd58.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd58.Lng))))
    goto label_23;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd55.Obj));
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd9.Obj) == (Wrd11.Obj))
    goto label_22;

DEFLABEL (label_21)
  (Wrd42.Obj) = (current_block [OBJECT_38_2]);
  (Wrd45.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 41L) < ((unsigned long) (Wrd45.Lng))))
    goto label_20;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd42.Obj));
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd13.Obj) == (Wrd15.Obj))
    goto label_19;

DEFLABEL (label_18)
  (Wrd29.Obj) = (current_block [OBJECT_38_3]);
  (Wrd32.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 20L) < ((unsigned long) (Wrd32.Lng))))
    goto label_17;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd29.Obj));
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_15;

DEFLABEL (label_14)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_38_4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_38_7);
  (Wrd26.Obj) = Rvl;

DEFLABEL (label_13)
  (Rsp [0]) = (Wrd26.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_15)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_16)
  Rsp = (& (Rsp [1]));
  goto label_13;

DEFLABEL (label_17)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_10]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 2);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  goto label_15;

DEFLABEL (label_19)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd26.Obj) = ((Wrd41.pObj) [3]);
  goto label_16;

DEFLABEL (label_20)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 2);

DEFLABEL (label_8)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  goto label_19;

DEFLABEL (label_22)
  (Wrd53.Obj) = (Rsp [1]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd26.Obj) = ((Wrd54.pObj) [4]);
  goto label_16;

DEFLABEL (label_23)
  (Wrd60.Obj) = (Rsp [2]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_8]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 2);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_7 5
#define LABEL_39_5 7
#define TAG_39_6 2
#define LABEL_39_8 9
#define LABEL_39_9 11
#define LABEL_39_10 13
#define ENVIRONMENT_LABEL_39_3 23
#define DEBUGGING_LABEL_39_2 22
#define OBJECT_39_4 21
#define OBJECT_39_3 20
#define OBJECT_39_2 19
#define OBJECT_39_1 18
#define OBJECT_39_0 17
#define EXECUTE_CACHE_39_11 15
#define FREE_REFERENCES_LABEL_39_0 14
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd10;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd26;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto dispatch_1_5;

    case 1:
      current_block = (Rpc - LABEL_39_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_39_5);
      goto lambda_12;

    case 3:
      current_block = (Rpc - LABEL_39_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_39_9);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_39_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dispatch_1_11)
DEFLABEL (dispatch_1_5)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_39_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_39_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_39_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_39_0]);
  (Wrd58.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd58.Lng))))
    goto label_23;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd55.Obj));
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd9.Obj) == (Wrd11.Obj))
    goto label_22;

DEFLABEL (label_21)
  (Wrd42.Obj) = (current_block [OBJECT_39_2]);
  (Wrd45.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 41L) < ((unsigned long) (Wrd45.Lng))))
    goto label_20;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd42.Obj));
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd13.Obj) == (Wrd15.Obj))
    goto label_19;

DEFLABEL (label_18)
  (Wrd29.Obj) = (current_block [OBJECT_39_3]);
  (Wrd32.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 20L) < ((unsigned long) (Wrd32.Lng))))
    goto label_17;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd29.Obj));
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_15;

DEFLABEL (label_14)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_39_4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_39_7);
  (Wrd26.Obj) = Rvl;

DEFLABEL (label_13)
  (Rsp [0]) = (Wrd26.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_15)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_16)
  Rsp = (& (Rsp [1]));
  goto label_13;

DEFLABEL (label_17)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_10]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  goto label_15;

DEFLABEL (label_19)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd26.Obj) = ((Wrd41.pObj) [3]);
  goto label_16;

DEFLABEL (label_20)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_8)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  goto label_19;

DEFLABEL (label_22)
  (Wrd53.Obj) = (Rsp [1]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd26.Obj) = ((Wrd54.pObj) [4]);
  goto label_16;

DEFLABEL (label_23)
  (Wrd60.Obj) = (Rsp [2]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_8]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 5
#define DEBUGGING_LABEL_40_2 4
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define ENVIRONMENT_LABEL_41_3 6
#define DEBUGGING_LABEL_41_2 5
#define OBJECT_41_0 4
#define FREE_REFERENCES_LABEL_41_0 4
#define NUMBER_OF_LINKER_SECTIONS_41_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto make_block_declaration_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_block_declaration_3)
DEFLABEL (make_block_declaration_0)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 2));
  (Wrd12.Obj) = (current_block [OBJECT_41_0]);
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd7.pObj) = (& (Rhp [-3]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define ENVIRONMENT_LABEL_42_3 7
#define DEBUGGING_LABEL_42_2 6
#define OBJECT_42_1 5
#define OBJECT_42_0 4
#define FREE_REFERENCES_LABEL_42_0 4
#define NUMBER_OF_LINKER_SECTIONS_42_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto block_declaration_text_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (block_declaration_text_3)
DEFLABEL (block_declaration_text_0)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_42_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_5 5
#define LABEL_43_6 7
#define LABEL_43_7 9
#define ENVIRONMENT_LABEL_43_3 16
#define DEBUGGING_LABEL_43_2 15
#define OBJECT_43_4 14
#define OBJECT_43_3 13
#define OBJECT_43_2 12
#define OBJECT_43_1 11
#define OBJECT_43_0 10
#define FREE_REFERENCES_LABEL_43_0 10
#define NUMBER_OF_LINKER_SECTIONS_43_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd24;
  machine_word Wrd46;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto block_declarationP_4;

    case 1:
      current_block = (Rpc - LABEL_43_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_43_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_43_7);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (block_declarationP_10)
DEFLABEL (block_declarationP_4)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_13;

DEFLABEL (label_12)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_11)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_13)
  if (! ((Wrd6.uLng) == 10))
    goto label_19;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_18)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_17;
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  if ((Wrd46.Lng) == 0)
    goto label_12;

DEFLABEL (label_16)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_15;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd34.Lng))))
    goto label_15;
  (Wrd26.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_14)
  if (! ((Wrd26.Obj) == (current_block [OBJECT_43_3])))
    goto label_12;
  Rvl = (current_block [OBJECT_43_4]);
  goto label_11;

DEFLABEL (label_15)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (current_block [OBJECT_43_1]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_7]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_2]), 2);

DEFLABEL (label_8)
  (Wrd26.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  goto label_12;

DEFLABEL (label_19)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_6)
  (Wrd9.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define ENVIRONMENT_LABEL_44_3 13
#define DEBUGGING_LABEL_44_2 12
#define OBJECT_44_0 11
#define EXECUTE_CACHE_44_7 7
#define EXECUTE_CACHE_44_6 9
#define FREE_REFERENCES_LABEL_44_0 6
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto make_slambda_2;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_slambda_5)
DEFLABEL (make_slambda_2)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_44_5);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_44_0]);
  (Rsp [0]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define ENVIRONMENT_LABEL_45_3 8
#define DEBUGGING_LABEL_45_2 7
#define OBJECT_45_2 6
#define OBJECT_45_1 5
#define OBJECT_45_0 4
#define FREE_REFERENCES_LABEL_45_0 4
#define NUMBER_OF_LINKER_SECTIONS_45_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto slambdaP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambdaP_3)
DEFLABEL (slambdaP_0)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd5.Obj) = (current_block [OBJECT_45_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 23L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_45_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_7 7
#define LABEL_46_10 9
#define LABEL_46_9 11
#define LABEL_46_12 13
#define ENVIRONMENT_LABEL_46_3 26
#define DEBUGGING_LABEL_46_2 25
#define OBJECT_46_3 24
#define OBJECT_46_2 23
#define OBJECT_46_1 22
#define OBJECT_46_0 21
#define EXECUTE_CACHE_46_11 15
#define EXECUTE_CACHE_46_8 17
#define EXECUTE_CACHE_46_6 19
#define FREE_REFERENCES_LABEL_46_0 14
#define NUMBER_OF_LINKER_SECTIONS_46_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto slambda_components_6;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_46_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_46_10);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_46_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_46_12);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambda_components_11)
DEFLABEL (slambda_components_6)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_46_7);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Obj) = (MAKE_OBJECT (26, (Wrd12.uLng)));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_14)
  (Wrd20.Obj) = (current_block [OBJECT_46_1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_46_9);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_13;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd14.Lng))))
    goto label_13;
  (Wrd6.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_12)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_13)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_46_2]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_9)
  (Wrd6.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_0]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define ENVIRONMENT_LABEL_47_3 8
#define DEBUGGING_LABEL_47_2 7
#define EXECUTE_CACHE_47_5 5
#define FREE_REFERENCES_LABEL_47_0 4
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto slambda_names_vector_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambda_names_vector_3)
DEFLABEL (slambda_names_vector_0)
  INTERRUPT_CHECK (26, LABEL_47_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define ENVIRONMENT_LABEL_48_3 12
#define DEBUGGING_LABEL_48_2 11
#define OBJECT_48_1 10
#define OBJECT_48_0 9
#define EXECUTE_CACHE_48_6 7
#define FREE_REFERENCES_LABEL_48_0 6
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto slambda_name_1;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambda_name_4)
DEFLABEL (slambda_name_1)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_48_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_48_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define LABEL_49_7 7
#define ENVIRONMENT_LABEL_49_3 16
#define DEBUGGING_LABEL_49_2 15
#define OBJECT_49_1 14
#define OBJECT_49_0 13
#define EXECUTE_CACHE_49_8 9
#define EXECUTE_CACHE_49_6 11
#define FREE_REFERENCES_LABEL_49_0 8
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto slambda_auxiliary_3;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_49_7);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambda_auxiliary_7)
DEFLABEL (slambda_auxiliary_3)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_49_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd14.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd14.uLng) == 10))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd8.Obj) = (MAKE_OBJECT (26, (Wrd12.uLng)));

DEFLABEL (label_8)
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_8]));

DEFLABEL (label_9)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 1);

DEFLABEL (label_5)
  (Wrd8.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define ENVIRONMENT_LABEL_50_3 8
#define DEBUGGING_LABEL_50_2 7
#define EXECUTE_CACHE_50_5 5
#define FREE_REFERENCES_LABEL_50_0 4
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto slambda_body_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slambda_body_3)
DEFLABEL (slambda_body_0)
  INTERRUPT_CHECK (26, LABEL_50_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define ENVIRONMENT_LABEL_51_3 8
#define DEBUGGING_LABEL_51_2 7
#define EXECUTE_CACHE_51_5 5
#define FREE_REFERENCES_LABEL_51_0 4
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto set_slambda_bodyB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_slambda_bodyB_3)
DEFLABEL (set_slambda_bodyB_0)
  INTERRUPT_CHECK (26, LABEL_51_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define ENVIRONMENT_LABEL_52_3 13
#define DEBUGGING_LABEL_52_2 12
#define OBJECT_52_0 11
#define EXECUTE_CACHE_52_7 7
#define EXECUTE_CACHE_52_6 9
#define FREE_REFERENCES_LABEL_52_0 6
#define NUMBER_OF_LINKER_SECTIONS_52_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto make_slexpr_2;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_slexpr_5)
DEFLABEL (make_slexpr_2)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_52_0]);
  (Rsp [0]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define ENVIRONMENT_LABEL_53_3 8
#define DEBUGGING_LABEL_53_2 7
#define OBJECT_53_2 6
#define OBJECT_53_1 5
#define OBJECT_53_0 4
#define FREE_REFERENCES_LABEL_53_0 4
#define NUMBER_OF_LINKER_SECTIONS_53_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto slexprP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slexprP_3)
DEFLABEL (slexprP_0)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd5.Obj) = (current_block [OBJECT_53_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 41L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_53_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_7 7
#define LABEL_54_10 9
#define LABEL_54_9 11
#define LABEL_54_12 13
#define ENVIRONMENT_LABEL_54_3 26
#define DEBUGGING_LABEL_54_2 25
#define OBJECT_54_3 24
#define OBJECT_54_2 23
#define OBJECT_54_1 22
#define OBJECT_54_0 21
#define EXECUTE_CACHE_54_11 15
#define EXECUTE_CACHE_54_8 17
#define EXECUTE_CACHE_54_6 19
#define FREE_REFERENCES_LABEL_54_0 14
#define NUMBER_OF_LINKER_SECTIONS_54_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto slexpr_components_6;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_54_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_54_10);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_54_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_54_12);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slexpr_components_11)
DEFLABEL (slexpr_components_6)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_54_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_54_7);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Obj) = (MAKE_OBJECT (26, (Wrd12.uLng)));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_14)
  (Wrd20.Obj) = (current_block [OBJECT_54_1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_54_9);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_13;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd14.Lng))))
    goto label_13;
  (Wrd6.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_12)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_13)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_54_2]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_3]), 2);

DEFLABEL (label_9)
  (Wrd6.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_0]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define ENVIRONMENT_LABEL_55_3 8
#define DEBUGGING_LABEL_55_2 7
#define EXECUTE_CACHE_55_5 5
#define FREE_REFERENCES_LABEL_55_0 4
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto slexpr_names_vector_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slexpr_names_vector_3)
DEFLABEL (slexpr_names_vector_0)
  INTERRUPT_CHECK (26, LABEL_55_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define ENVIRONMENT_LABEL_56_3 12
#define DEBUGGING_LABEL_56_2 11
#define OBJECT_56_1 10
#define OBJECT_56_0 9
#define EXECUTE_CACHE_56_6 7
#define FREE_REFERENCES_LABEL_56_0 6
#define NUMBER_OF_LINKER_SECTIONS_56_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto slexpr_name_1;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slexpr_name_4)
DEFLABEL (slexpr_name_1)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_56_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define ENVIRONMENT_LABEL_57_3 8
#define DEBUGGING_LABEL_57_2 7
#define EXECUTE_CACHE_57_5 5
#define FREE_REFERENCES_LABEL_57_0 4
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto slexpr_body_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (slexpr_body_3)
DEFLABEL (slexpr_body_0)
  INTERRUPT_CHECK (26, LABEL_57_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_5 5
#define ENVIRONMENT_LABEL_58_3 14
#define DEBUGGING_LABEL_58_2 13
#define OBJECT_58_1 12
#define OBJECT_58_0 11
#define EXECUTE_CACHE_58_7 7
#define EXECUTE_CACHE_58_6 9
#define FREE_REFERENCES_LABEL_58_0 6
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto make_internal_lambda_2;

    case 1:
      current_block = (Rpc - LABEL_58_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_internal_lambda_5)
DEFLABEL (make_internal_lambda_2)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd5.Obj) = (current_block [OBJECT_58_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_58_1]);
  (Wrd13.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_58_5);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_5 5
#define ENVIRONMENT_LABEL_59_3 14
#define DEBUGGING_LABEL_59_2 13
#define OBJECT_59_1 12
#define OBJECT_59_0 11
#define EXECUTE_CACHE_59_7 7
#define EXECUTE_CACHE_59_6 9
#define FREE_REFERENCES_LABEL_59_0 6
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto make_internal_lexpr_2;

    case 1:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_internal_lexpr_5)
DEFLABEL (make_internal_lexpr_2)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd5.Obj) = (current_block [OBJECT_59_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_59_1]);
  (Wrd13.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_59_5);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define LABEL_60_6 7
#define LABEL_60_8 9
#define LABEL_60_9 11
#define LABEL_60_10 13
#define ENVIRONMENT_LABEL_60_3 25
#define DEBUGGING_LABEL_60_2 24
#define OBJECT_60_6 23
#define OBJECT_60_5 22
#define OBJECT_60_4 21
#define OBJECT_60_3 20
#define OBJECT_60_2 19
#define OBJECT_60_1 18
#define OBJECT_60_0 17
#define EXECUTE_CACHE_60_7 15
#define FREE_REFERENCES_LABEL_60_0 14
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd15;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto internal_lambdaP_6;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_60_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_60_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_60_9);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_60_10);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (internal_lambdaP_12)
DEFLABEL (internal_lambdaP_6)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd15.Obj) = (current_block [OBJECT_60_0]);
  (Wrd18.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd18.Lng))))
    goto label_23;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd15.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_14;

DEFLABEL (label_13)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_60_6);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_22;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd12.Lng))))
    goto label_22;
  (Wrd6.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_21)
  if (! ((Wrd6.Obj) == (current_block [OBJECT_60_4])))
    goto label_15;
  Rvl = (current_block [OBJECT_60_5]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_60_9);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_20;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd12.Lng))))
    goto label_20;
  (Wrd6.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_19)
  if ((Wrd6.Obj) == (current_block [OBJECT_60_6]))
    goto label_17;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_16;

DEFLABEL (label_17)
  Rvl = (current_block [OBJECT_60_5]);

DEFLABEL (label_16)
DEFLABEL (label_18)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd15.Obj) = (current_block [OBJECT_60_2]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_10]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_3]), 2);

DEFLABEL (label_10)
  (Wrd6.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd15.Obj) = (current_block [OBJECT_60_2]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_3]), 2);

DEFLABEL (label_9)
  (Wrd6.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_1]), 2);

DEFLABEL (label_8)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define ENVIRONMENT_LABEL_61_3 12
#define DEBUGGING_LABEL_61_2 11
#define EXECUTE_CACHE_61_7 7
#define EXECUTE_CACHE_61_6 9
#define FREE_REFERENCES_LABEL_61_0 6
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
lambda_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto make_unassigned_1;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_unassigned_4)
DEFLABEL (make_unassigned_1)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_6]));

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_61_5);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_11 7
#define LABEL_7 9
#define LABEL_8 11
#define LABEL_10 13
#define LABEL_14 15
#define LABEL_15 17
#define LABEL_16 19
#define ENVIRONMENT_LABEL_3 48
#define DEBUGGING_LABEL_2 47
#define PURIFICATION_ROOT 46
#define OBJECT_14 45
#define OBJECT_13 44
#define OBJECT_12 43
#define OBJECT_11 42
#define OBJECT_10 41
#define OBJECT_9 40
#define OBJECT_8 39
#define OBJECT_7 38
#define OBJECT_6 37
#define OBJECT_5 36
#define OBJECT_4 35
#define OBJECT_3 34
#define OBJECT_2 33
#define OBJECT_1 32
#define OBJECT_0 31
#define FREE_REFERENCE_0 21
#define GLOBAL_EXECUTE_CACHE_13 23
#define GLOBAL_EXECUTE_CACHE_12 25
#define GLOBAL_EXECUTE_CACHE_9 27
#define GLOBAL_EXECUTE_CACHE_5 29
#define FREE_REFERENCES_LABEL_0 20
#define NUMBER_OF_LINKER_SECTIONS_1 2

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
lambda_so_8955ad1ce964b4fa (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_11);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_14);
      goto label_11;

    case 7:
      current_block = (Rpc - LABEL_15);
      goto label_12;

    case 8:
      current_block = (Rpc - LABEL_16);
      goto expression_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_7)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_15])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_12)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_11)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	2,
	2,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 61)
      goto label_10;
    blocks = (current_block [OBJECT_14]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_14])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_10)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd17.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_8);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd11.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_14;
  Wrd8 = Wrd12;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd5.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_13]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd9.pObj));

DEFLABEL (label_8)
  (Wrd8.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_lambda_so_8955ad1ce964b4fa [61] =
  {
    { "lambda_so_code_1", 82, lambda_so_code_1 },
    { "lambda_so_code_2", 34, lambda_so_code_2 },
    { "lambda_so_code_3", 2, lambda_so_code_3 },
    { "lambda_so_code_4", 7, lambda_so_code_4 },
    { "lambda_so_code_5", 1, lambda_so_code_5 },
    { "lambda_so_code_6", 1, lambda_so_code_6 },
    { "lambda_so_code_7", 2, lambda_so_code_7 },
    { "lambda_so_code_8", 2, lambda_so_code_8 },
    { "lambda_so_code_9", 2, lambda_so_code_9 },
    { "lambda_so_code_10", 2, lambda_so_code_10 },
    { "lambda_so_code_11", 6, lambda_so_code_11 },
    { "lambda_so_code_12", 4, lambda_so_code_12 },
    { "lambda_so_code_13", 3, lambda_so_code_13 },
    { "lambda_so_code_14", 2, lambda_so_code_14 },
    { "lambda_so_code_15", 4, lambda_so_code_15 },
    { "lambda_so_code_16", 4, lambda_so_code_16 },
    { "lambda_so_code_17", 2, lambda_so_code_17 },
    { "lambda_so_code_18", 2, lambda_so_code_18 },
    { "lambda_so_code_19", 14, lambda_so_code_19 },
    { "lambda_so_code_20", 10, lambda_so_code_20 },
    { "lambda_so_code_21", 6, lambda_so_code_21 },
    { "lambda_so_code_22", 5, lambda_so_code_22 },
    { "lambda_so_code_23", 2, lambda_so_code_23 },
    { "lambda_so_code_24", 2, lambda_so_code_24 },
    { "lambda_so_code_25", 13, lambda_so_code_25 },
    { "lambda_so_code_26", 1, lambda_so_code_26 },
    { "lambda_so_code_27", 26, lambda_so_code_27 },
    { "lambda_so_code_28", 1, lambda_so_code_28 },
    { "lambda_so_code_29", 2, lambda_so_code_29 },
    { "lambda_so_code_30", 6, lambda_so_code_30 },
    { "lambda_so_code_31", 2, lambda_so_code_31 },
    { "lambda_so_code_32", 2, lambda_so_code_32 },
    { "lambda_so_code_33", 2, lambda_so_code_33 },
    { "lambda_so_code_34", 3, lambda_so_code_34 },
    { "lambda_so_code_35", 13, lambda_so_code_35 },
    { "lambda_so_code_36", 10, lambda_so_code_36 },
    { "lambda_so_code_37", 11, lambda_so_code_37 },
    { "lambda_so_code_38", 6, lambda_so_code_38 },
    { "lambda_so_code_39", 6, lambda_so_code_39 },
    { "lambda_so_code_40", 1, lambda_so_code_40 },
    { "lambda_so_code_41", 1, lambda_so_code_41 },
    { "lambda_so_code_42", 1, lambda_so_code_42 },
    { "lambda_so_code_43", 4, lambda_so_code_43 },
    { "lambda_so_code_44", 2, lambda_so_code_44 },
    { "lambda_so_code_45", 1, lambda_so_code_45 },
    { "lambda_so_code_46", 6, lambda_so_code_46 },
    { "lambda_so_code_47", 1, lambda_so_code_47 },
    { "lambda_so_code_48", 2, lambda_so_code_48 },
    { "lambda_so_code_49", 3, lambda_so_code_49 },
    { "lambda_so_code_50", 1, lambda_so_code_50 },
    { "lambda_so_code_51", 1, lambda_so_code_51 },
    { "lambda_so_code_52", 2, lambda_so_code_52 },
    { "lambda_so_code_53", 1, lambda_so_code_53 },
    { "lambda_so_code_54", 6, lambda_so_code_54 },
    { "lambda_so_code_55", 1, lambda_so_code_55 },
    { "lambda_so_code_56", 2, lambda_so_code_56 },
    { "lambda_so_code_57", 1, lambda_so_code_57 },
    { "lambda_so_code_58", 2, lambda_so_code_58 },
    { "lambda_so_code_59", 2, lambda_so_code_59 },
    { "lambda_so_code_60", 6, lambda_so_code_60 },
    { "lambda_so_code_61", 2, lambda_so_code_61 }
  };

int
decl_lambda_so_8955ad1ce964b4fa (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_lambda_so_8955ad1ce964b4fa);
  return (0);
}

DECLARE_COMPILED_CODE ("lambda.so", 9, decl_lambda_so_8955ad1ce964b4fa, lambda_so_8955ad1ce964b4fa)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_lambda_so_data_8955ad1ce964b4fa [7913] =
  "\xfb\x01\x86\x01\xdb\x10\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9"
  "\x0d\xba\x0d\xbb\x0d\xbc\x0d\xbd\x0d\xbe\x0d\xbf\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x1b\xb7\xb6\xb5\xb4\xb3\x0d\x1c\xb2\xb1\x25\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x1b"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\xb1\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x82\x88\x82\xc2\x1c\xc3"
  "\x1c\x1d\x81\x08\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x83\x88\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x84\x88\x07\x1b\x80\xc1\x1c\x1b\x24\x28\x0d\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x85\x88\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d"
  "\xb0\x86\x88\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1d\x82\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x81\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x1d\x81\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x02\x0d\x1c\x08\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x83\x1b\x02\xc1\xc3\x0d\x1c\x08\x02\x28"
  "\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xc1\x1c\x08\xc1\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc1\x02"
  "\x80\x02\x02\x1b\x08\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x07\x02\x22\x29\x21\x9f\x2b\x1c"
  "\x1d\xb0\x02\x88\x80\x81\x1b\x06\x1b\x1b\xc1\x1b\x02\x28\x0d\x28"
  "\x0d\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23"
  "\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x28\x1b\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x07\x02\x02\x1b\x02\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x02\x0c\x0c\x0c\x08\x28\x1b"
  "\x28\x0d\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x1b\x1b\x08\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08\x28\x0d"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x02\x02\x1b\x02\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x02"
  "\x02\x1b\x02\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x1b\x80"
  "\x1b\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x02\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x07\x02\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x80\x81\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x02\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x07\x02\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x81\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29"
  "\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x21\x9f"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x07\x1b\x1b"
  "\x80\x1b\x02\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x28\x0d\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x02\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x02\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\x1b\x0d\x0d\x0d\x0d"
  "\x0d\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x0d\x0d\x0d"
  "\x1b\x0d\x1b\x17\x0d\x0c\x0d\x98\x81\x98\x1b\x2a\xc3\x0d\x1c\x0d"
  "\x1b\x82\xb1\xb2\x1b\xb3\xb4\xb5\xb6\xb7\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b"
  "\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x1b"
  "\x1b\x0d\x1b\x0d\x17\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e"
  "\x1e\x1e\x1e\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x02\x1b\x2a\x1b\x2a\x1e\x1e\x1e\x1e\x1e\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1e\x1e\x1e\x1e\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x0d\x08\x88\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x17\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x24\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x02\x47\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f\x6d"
  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30\x2e"
  "\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6c\x61"
  "\x6d\x62\x64\x61\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
  "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0d\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x62\x6f\x75\x6e\x64\x0c\x6c\x61\x6d\x62"
  "\x64\x61\x2d\x6e\x61\x6d\x65\x11\x73\x65\x74\x2d\x6c\x61\x6d\x62"
  "\x64\x61\x2d\x62\x6f\x64\x79\x21\x0c\x6c\x61\x6d\x62\x64\x61\x2d"
  "\x62\x6f\x64\x79\x14\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72"
  "\x61\x70\x2d\x62\x6f\x64\x79\x21\x1a\x6c\x61\x6d\x62\x64\x61\x2d"
  "\x77\x72\x61\x70\x70\x65\x72\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e"
  "\x74\x73\x12\x6c\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x2d\x62"
  "\x6f\x64\x79\x21\x15\x68\x61\x73\x2d\x69\x6e\x74\x65\x72\x6e\x61"
  "\x6c\x2d\x6c\x61\x6d\x62\x64\x61\x3f\x09\x12\x6c\x61\x6d\x62\x64"
  "\x61\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x0a\x13\x63\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x2d\x62\x6f\x64\x79\x21"
  "\x0b\x1b\x63\x6c\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x70\x65"
  "\x72\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x0c\x15\x63\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72\x61\x70\x2d\x62\x6f\x64"
  "\x79\x21\x0d\x17\x63\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72"
  "\x61\x70\x70\x65\x64\x2d\x62\x6f\x64\x79\x0e\x1c\x73\x65\x74\x2d"
  "\x63\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72\x61\x70\x70\x65"
  "\x64\x2d\x62\x6f\x64\x79\x21\x0f\x12\x63\x6c\x65\x78\x70\x72\x2d"
  "\x77\x72\x61\x70\x2d\x62\x6f\x64\x79\x21\x10\x1a\x63\x6c\x65\x78"
  "\x70\x72\x2d\x77\x72\x61\x70\x70\x65\x72\x2d\x63\x6f\x6d\x70\x6f"
  "\x6e\x65\x6e\x74\x73\x11\x14\x63\x6c\x65\x78\x70\x72\x2d\x75\x6e"
  "\x77\x72\x61\x70\x2d\x62\x6f\x64\x79\x21\x12\x16\x63\x6c\x65\x78"
  "\x70\x72\x2d\x75\x6e\x77\x72\x61\x70\x70\x65\x64\x2d\x62\x6f\x64"
  "\x79\x13\x1b\x73\x65\x74\x2d\x63\x6c\x65\x78\x70\x72\x2d\x75\x6e"
  "\x77\x72\x61\x70\x70\x65\x64\x2d\x62\x6f\x64\x79\x21\x14\x13\x78"
  "\x6c\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x2d\x62\x6f\x64\x79"
  "\x21\x15\x1b\x78\x6c\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x70"
  "\x65\x72\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x16\x15\x78"
  "\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72\x61\x70\x2d\x62\x6f"
  "\x64\x79\x21\x17\x17\x78\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77"
  "\x72\x61\x70\x70\x65\x64\x2d\x62\x6f\x64\x79\x18\x1c\x73\x65\x74"
  "\x2d\x78\x6c\x61\x6d\x62\x64\x61\x2d\x75\x6e\x77\x72\x61\x70\x70"
  "\x65\x64\x2d\x62\x6f\x64\x79\x21\x19\x13\x26\x6c\x61\x6d\x62\x64"
  "\x61\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x1a\x09\x14\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x6e\x61\x6d\x65\x73\x2d\x76\x65\x63\x74"
  "\x6f\x72\x1b\x1a\x1b\x63\x6c\x61\x6d\x62\x64\x61\x2f\x73\x65\x74"
  "\x2d\x70\x68\x79\x73\x69\x63\x61\x6c\x2d\x62\x6f\x64\x79\x21\x1c"
  "\x16\x63\x6c\x61\x6d\x62\x64\x61\x2f\x70\x68\x79\x73\x69\x63\x61"
  "\x6c\x2d\x62\x6f\x64\x79\x1d\x1a\x63\x6c\x65\x78\x70\x72\x2f\x73"
  "\x65\x74\x2d\x70\x68\x79\x73\x69\x63\x61\x6c\x2d\x62\x6f\x64\x79"
  "\x21\x1e\x15\x63\x6c\x65\x78\x70\x72\x2f\x70\x68\x79\x73\x69\x63"
  "\x61\x6c\x2d\x62\x6f\x64\x79\x1f\x0f\x1b\x78\x6c\x61\x6d\x62\x64"
  "\x61\x2f\x73\x65\x74\x2d\x70\x68\x79\x73\x69\x63\x61\x6c\x2d\x62"
  "\x6f\x64\x79\x21\x20\x16\x78\x6c\x61\x6d\x62\x64\x61\x2f\x70\x68"
  "\x79\x73\x69\x63\x61\x6c\x2d\x62\x6f\x64\x79\x21\x14\x13\x78\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73"
  "\x22\x12\x63\x6c\x65\x78\x70\x72\x2d\x63\x6f\x6d\x70\x6f\x6e\x65"
  "\x6e\x74\x73\x23\x13\x63\x6c\x61\x6d\x62\x64\x61\x2d\x63\x6f\x6d"
  "\x70\x6f\x6e\x65\x6e\x74\x73\x24\x19\x1d\x78\x6c\x61\x6d\x62\x64"
  "\x61\x2d\x68\x61\x73\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c"
  "\x61\x6d\x62\x64\x61\x3f\x25\x1c\x63\x6c\x65\x78\x70\x72\x2d\x68"
  "\x61\x73\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x61\x6d\x62"
  "\x64\x61\x3f\x26\x1d\x63\x6c\x61\x6d\x62\x64\x61\x2d\x68\x61\x73"
  "\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x61\x6d\x62\x64\x61"
  "\x3f\x27\x15\x10\x0b\x16\x11\x0c\x17\x12\x0d\x18\x13\x0e\x15\x78"
  "\x6c\x61\x6d\x62\x64\x61\x2d\x6e\x61\x6d\x65\x73\x2d\x76\x65\x63"
  "\x74\x6f\x72\x28\x14\x73\x6c\x65\x78\x70\x72\x2d\x6e\x61\x6d\x65"
  "\x73\x2d\x76\x65\x63\x74\x6f\x72\x29\x15\x73\x6c\x61\x6d\x62\x64"
  "\x61\x2d\x6e\x61\x6d\x65\x73\x2d\x76\x65\x63\x74\x6f\x72\x2a\x0d"
  "\x78\x6c\x61\x6d\x62\x64\x61\x2d\x6e\x61\x6d\x65\x2b\x0c\x73\x6c"
  "\x65\x78\x70\x72\x2d\x6e\x61\x6d\x65\x2c\x0d\x73\x6c\x61\x6d\x62"
  "\x64\x61\x2d\x6e\x61\x6d\x65\x2d\x0e\x78\x6c\x61\x6d\x62\x64\x61"
  "\x2d\x62\x6f\x75\x6e\x64\x2e\x0d\x63\x6c\x65\x78\x70\x72\x2d\x62"
  "\x6f\x75\x6e\x64\x2f\x0e\x63\x6c\x61\x6d\x62\x64\x61\x2d\x62\x6f"
  "\x75\x6e\x64\x30\x26\x05\x17\x6c\x61\x6d\x62\x64\x61\x2d\x62\x6f"
  "\x64\x79\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x31\x06\x0b"
  "\x64\x69\x73\x70\x61\x74\x63\x68\x2d\x31\x32\x06\x0b\x64\x69\x73"
  "\x70\x61\x74\x63\x68\x2d\x30\x33\x04\x5b\xa6\x01\x81\x85\x02\x5a"
  "\xa4\x01\x81\x83\x02\x59\xa2\x01\x81\x81\x02\x58\xa0\x01\x81\x87"
  "\x02\x57\x9e\x01\x81\x85\x02\x56\x9c\x01\x81\x83\x02\x55\x9a\x01"
  "\x81\x81\x02\x54\x98\x01\x81\x81\x02\x53\x96\x01\x81\x87\x02\x52"
  "\x94\x01\x81\x85\x02\x51\x92\x01\x81\x83\x02\x50\x90\x01\x81\x81"
  "\x02\x4f\x8e\x01\x81\x81\x02\x4e\x8c\x01\x81\x87\x02\x4d\x8a\x01"
  "\x81\x85\x02\x4c\x88\x01\x81\x83\x02\x4b\x86\x01\x81\x81\x02\x4a"
  "\x84\x01\x81\x81\x02\x49\x82\x01\x81\x87\x02\x48\x80\x01\x81\x85"
  "\x02\x47\x7e\x81\x83\x02\x46\x7c\x81\x81\x02\x45\x7a\x81\x81\x02"
  "\x44\x78\x81\x87\x02\x43\x76\x81\x85\x02\x42\x74\x81\x83\x02\x41"
  "\x72\x81\x81\x02\x40\x70\x81\x81\x02\x3f\x6e\x81\x87\x02\x3e\x6c"
  "\x81\x85\x02\x3d\x6a\x81\x83\x02\x3c\x68\x81\x81\x02\x3b\x66\x81"
  "\x81\x02\x3a\x64\x81\x87\x02\x39\x62\x81\x85\x02\x38\x60\x81\x83"
  "\x02\x37\x5e\x81\x81\x02\x36\x5c\x81\x81\x02\x35\x5a\x81\x87\x02"
  "\x34\x58\x81\x85\x02\x33\x56\x81\x83\x02\x32\x54\x81\x81\x02\x31"
  "\x52\x81\x81\x02\x30\x50\x81\x87\x02\x2f\x4e\x81\x85\x02\x2e\x4c"
  "\x81\x83\x02\x2d\x4a\x81\x81\x02\x2c\x48\x81\x81\x02\x2b\x46\x81"
  "\x85\x02\x2a\x44\x81\x83\x02\x29\x42\x81\x8b\x02\x28\x40\x81\x8b"
  "\x02\x27\x3e\x81\x8b\x02\x26\x3c\x81\x8b\x02\x25\x3a\x87\x0c\x24"
  "\x38\x81\x87\x02\x23\x36\x81\x85\x02\x22\x34\x81\x83\x02\x21\x32"
  "\x81\x81\x02\x20\x30\x81\x85\x02\x1f\x2e\x81\x83\x02\x1e\x2c\x81"
  "\x8b\x02\x1d\x2a\x81\x8b\x02\x1c\x28\x81\x8b\x02\x1b\x26\x81\x8b"
  "\x02\x1a\x24\x87\x0c\x19\x22\x81\x87\x02\x18\x20\x81\x85\x02\x17"
  "\x1e\x81\x81\x02\x16\x1c\x81\x85\x02\x15\x1a\x81\x83\x02\x14\x18"
  "\x81\x8b\x02\x13\x16\x81\x8b\x02\x12\x14\x81\x8b\x02\x11\x12\x81"
  "\x8b\x02\x10\x10\x87\x0c\x0f\x0e\x81\x87\x02\x0e\x0c\x81\x85\x02"
  "\x0d\x0a\x81\x81\x02\x0c\x08\x81\x87\x02\x0b\x06\x81\x85\x02\x0a"
  "\x04\x82\x02\xa5\x01\xf8\x01\x34\x02\x0b\x76\x65\x63\x74\x6f\x72"
  "\x2d\x72\x65\x66\x35\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74"
  "\x21\x36\x02\x0c\x77\x72\x61\x70\x70\x65\x72\x2d\x74\x61\x67\x37"
  "\x02\x03\x09\x77\x72\x61\x70\x70\x65\x72\x3f\x38\x03\x0d\x63\x6f"
  "\x6d\x6d\x65\x6e\x74\x2d\x74\x65\x78\x74\x39\x03\x13\x63\x6f\x6d"
  "\x6d\x65\x6e\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3a"
  "\x04\x0d\x6d\x61\x6b\x65\x2d\x63\x6f\x6d\x6d\x65\x6e\x74\x3b\x04"
  "\x18\x73\x65\x74\x2d\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x65\x78\x70"
  "\x72\x65\x73\x73\x69\x6f\x6e\x21\x3c\x06\x7d\x46\x81\x87\x02\x7c"
  "\x44\x81\x87\x02\x7b\x42\x81\x87\x02\x7a\x40\x81\x87\x02\x79\x3e"
  "\x81\x89\x02\x78\x3c\x81\x89\x02\x77\x3a\x81\x89\x02\x76\x38\x81"
  "\x87\x02\x75\x36\x81\x87\x02\x74\x34\x81\x83\x02\x73\x32\x81\x8b"
  "\x02\x72\x30\x81\x87\x02\x71\x2e\x81\x89\x02\x70\x2c\x81\x89\x02"
  "\x6f\x2a\x81\x89\x02\x6e\x28\x81\x89\x02\x6d\x26\x81\x87\x02\x6c"
  "\x24\x81\x83\x02\x6b\x22\x81\x89\x02\x6a\x20\x81\x87\x02\x69\x1e"
  "\x81\x89\x02\x68\x1c\x81\x89\x02\x67\x1a\x81\x85\x02\x66\x18\x81"
  "\x85\x02\x65\x16\x81\x89\x02\x64\x14\x81\x87\x02\x63\x12\x81\x87"
  "\x02\x62\x10\x81\x87\x02\x61\x0e\x81\x85\x02\x60\x0c\x81\x85\x02"
  "\x5f\x0a\x81\x87\x02\x5e\x08\x81\x87\x02\x5d\x06\x81\x87\x02\x5c"
  "\x04\x85\x08\x45\x5b\x3d\x02\x37\x02\x04\x3b\x02\x7f\x06\x81\x89"
  "\x02\x7e\x04\x85\x08\x05\x0d\x3b\x02\x35\x0e\x76\x65\x63\x74\x6f"
  "\x72\x2d\x6c\x65\x6e\x67\x74\x68\x3e\x37\x02\x03\x09\x63\x6f\x6d"
  "\x6d\x65\x6e\x74\x3f\x03\x39\x03\x86\x01\x10\x81\x85\x02\x85\x01"
  "\x0e\x81\x83\x02\x84\x01\x0c\x81\x83\x02\x83\x01\x0a\x81\x83\x02"
  "\x82\x01\x08\x81\x83\x02\x81\x01\x06\x81\x83\x02\x80\x01\x04\x83"
  "\x04\x0f\x1d\x3f\x02\x03\x3a\x02\x87\x01\x04\x83\x04\x03\x3a\x02"
  "\x04\x3c\x02\x88\x01\x04\x84\x06\x03\x3c\x02\x08\x35\x03\x39\x02"
  "\x8a\x01\x06\x81\x83\x02\x89\x01\x04\x83\x04\x05\x0d\x40\x02\x09"
  "\x36\x02\x03\x39\x02\x8c\x01\x06\x81\x85\x02\x8b\x01\x04\x84\x06"
  "\x05\x0e\x41\x02\x0a\x35\x03\x39\x02\x8e\x01\x06\x81\x83\x02\x8d"
  "\x01\x04\x83\x04\x05\x0d\x42\x02\x0b\x36\x02\x03\x39\x02\x90\x01"
  "\x06\x81\x85\x02\x8f\x01\x04\x84\x06\x05\x0e\x39\x02\x0c\x18\x13"
  "\x23\x5b\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x61\x6d\x62\x64"
  "\x61\x5d\x36\x03\x0d\x6c\x69\x73\x74\x2d\x3e\x76\x65\x63\x74\x6f"
  "\x72\x43\x03\x10\x6d\x61\x6b\x65\x2d\x75\x6e\x61\x73\x73\x69\x67"
  "\x6e\x65\x64\x44\x05\x11\x26\x74\x79\x70\x65\x64\x2d\x70\x61\x69"
  "\x72\x2d\x63\x6f\x6e\x73\x45\x04\x11\x6d\x61\x6b\x65\x2d\x63\x6f"
  "\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x46\x05\x96\x01\x0e\x81\x8f"
  "\x02\x95\x01\x0c\x81\x8d\x02\x94\x01\x0a\x81\x89\x02\x93\x01\x08"
  "\x81\x8b\x02\x92\x01\x06\x86\x0a\x91\x01\x04\x81\x89\x02\x0d\x1c"
  "\x47\x02\x0d\x04\x13\x73\x6c\x61\x6d\x62\x64\x61\x2d\x63\x6f\x6d"
  "\x70\x6f\x6e\x65\x6e\x74\x73\x48\x03\x16\x6c\x61\x6d\x62\x64\x61"
  "\x2d\x62\x6f\x64\x79\x2d\x61\x75\x78\x69\x6c\x69\x61\x72\x79\x49"
  "\x03\x0e\x04\x9a\x01\x0a\x81\x8f\x02\x99\x01\x08\x81\x8f\x02\x98"
  "\x01\x06\x81\x89\x02\x97\x01\x04\x84\x06\x09\x14\x4a\x02\x0e\x04"
  "\x48\x03\x49\x04\x07\x61\x70\x70\x65\x6e\x64\x4b\x04\x9d\x01\x08"
  "\x81\x87\x02\x9c\x01\x06\x85\x08\x9b\x01\x04\x83\x04\x07\x11\x4c"
  "\x02\x0f\x03\x0a\x26\x70\x61\x69\x72\x2d\x63\x61\x72\x4d\x03\x21"
  "\x6c\x61\x6d\x62\x64\x61\x2d\x62\x6f\x64\x79\x2d\x68\x61\x73\x2d"
  "\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x61\x6d\x62\x64\x61\x3f"
  "\x4e\x03\x9f\x01\x06\x81\x83\x02\x9e\x01\x04\x83\x04\x05\x0d\x4f"
  "\x02\x10\x03\x0d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3f"
  "\x50\x03\x15\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x6f"
  "\x70\x65\x72\x61\x74\x6f\x72\x51\x03\x11\x69\x6e\x74\x65\x72\x6e"
  "\x61\x6c\x2d\x6c\x61\x6d\x62\x64\x61\x3f\x52\x03\x12\x73\x6c\x61"
  "\x6d\x62\x64\x61\x2d\x61\x75\x78\x69\x6c\x69\x61\x72\x79\x53\x05"
  "\xa3\x01\x0a\x81\x83\x02\xa2\x01\x08\x81\x83\x02\xa1\x01\x06\x81"
  "\x83\x02\xa0\x01\x04\x83\x04\x09\x16\x54\x02\x11\x03\x50\x03\x51"
  "\x03\x52\x04\xa7\x01\x0a\x81\x83\x02\xa6\x01\x08\x81\x83\x02\xa5"
  "\x01\x06\x81\x83\x02\xa4\x01\x04\x83\x04\x09\x13\x50\x02\x12\x03"
  "\x27\x03\x4d\x03\xa9\x01\x06\x81\x83\x02\xa8\x01\x04\x83\x04\x05"
  "\x0d\x55\x02\x13\x03\x27\x04\x0f\x26\x70\x61\x69\x72\x2d\x73\x65"
  "\x74\x2d\x63\x61\x72\x21\x56\x03\xab\x01\x06\x81\x85\x02\xaa\x01"
  "\x04\x84\x06\x05\x0d\x57\x02\x14\x36\x18\x13\x73\x79\x73\x74\x65"
  "\x6d\x2d\x76\x65\x63\x74\x6f\x72\x2d\x73\x69\x7a\x65\x19\x73\x79"
  "\x73\x74\x65\x6d\x2d\x73\x75\x62\x76\x65\x63\x74\x6f\x72\x2d\x74"
  "\x6f\x2d\x6c\x69\x73\x74\x12\x23\x5b\x69\x6e\x74\x65\x72\x6e\x61"
  "\x6c\x2d\x6c\x65\x78\x70\x72\x5d\x58\x2a\x02\x15\x6d\x61\x6b\x65"
  "\x2d\x74\x68\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x03\x43\x04\x46\x05\x45\x03\x44\x03\x07\x6c\x65\x6e\x67\x74\x68"
  "\x59\x07\xb9\x01\x1e\x81\x99\x02\xb8\x01\x1c\x81\x97\x02\xb7\x01"
  "\x1a\x81\x87\x02\xb6\x01\x18\x81\x87\x02\xb5\x01\x16\x81\x95\x02"
  "\xb4\x01\x14\x81\x85\x02\xb3\x01\x12\x81\x91\x02\xb2\x01\x10\x81"
  "\x93\x02\xb1\x01\x0e\x81\x8f\x02\xb0\x01\x0c\x81\x8b\x02\xaf\x01"
  "\x0a\x81\x8f\x02\xae\x01\x08\x81\x8d\x02\xad\x01\x06\x81\x8b\x02"
  "\xac\x01\x04\x87\x0c\x1d\x35\x5a\x02\x15\x04\x63\x64\x72\x5b\x04"
  "\x63\x61\x72\x5c\x04\x12\x73\x6c\x65\x78\x70\x72\x2d\x63\x6f\x6d"
  "\x70\x6f\x6e\x65\x6e\x74\x73\x5d\x03\x51\x03\x53\x03\x13\x03\x4d"
  "\x04\x4b\x03\x49\x08\xc3\x01\x16\x81\x93\x02\xc2\x01\x14\x81\x93"
  "\x02\xc1\x01\x12\x81\x91\x02\xc0\x01\x10\x81\x91\x02\xbf\x01\x0e"
  "\x81\x8f\x02\xbe\x01\x0c\x81\x8f\x02\xbd\x01\x0a\x81\x8b\x02\xbc"
  "\x01\x08\x81\x89\x02\xbb\x01\x06\x81\x89\x02\xba\x01\x04\x84\x06"
  "\x15\x2a\x5e\x02\x16\x04\x5d\x03\x51\x03\x4d\x03\x53\x03\x49\x05"
  "\x4b\x07\xc9\x01\x0e\x81\x89\x02\xc8\x01\x0c\x81\x8b\x02\xc7\x01"
  "\x0a\x81\x89\x02\xc6\x01\x08\x81\x87\x02\xc5\x01\x06\x85\x08\xc4"
  "\x01\x04\x83\x04\x0d\x1d\x5f\x02\x17\x03\x4d\x03\x51\x03\x4e\x04"
  "\xce\x01\x0c\x81\x85\x02\xcd\x01\x0a\x81\x83\x02\xcc\x01\x08\x81"
  "\x85\x02\xcb\x01\x06\x81\x83\x02\xca\x01\x04\x83\x04\x0b\x15\x51"
  "\x02\x18\x03\x26\x03\x4d\x03\xd0\x01\x06\x81\x83\x02\xcf\x01\x04"
  "\x83\x04\x05\x0d\x60\x02\x19\x03\x26\x04\x56\x03\xd2\x01\x06\x81"
  "\x85\x02\xd1\x01\x04\x84\x06\x05\x0d\x61\x02\x1a\x18\x6d\x61\x6b"
  "\x65\x2d\x6e\x6f\x6e\x2d\x70\x6f\x69\x6e\x74\x65\x72\x2d\x6f\x62"
  "\x6a\x65\x63\x74\x81\x02\x15\x18\x36\x05\x4b\x03\x44\x03\x43\x03"
  "\x59\x04\x46\x05\x45\x06\x13\x26\x74\x79\x70\x65\x64\x2d\x74\x72"
  "\x69\x70\x6c\x65\x2d\x63\x6f\x6e\x73\x08\xdf\x01\x1c\x81\x91\x02"
  "\xde\x01\x1a\x81\x93\x02\xdd\x01\x18\x81\x91\x02\xdc\x01\x16\x81"
  "\x91\x02\xdb\x01\x14\x81\x91\x02\xda\x01\x12\x81\x8f\x02\xd9\x01"
  "\x10\x81\x93\x02\xd8\x01\x0e\x81\x91\x02\xd7\x01\x0c\x81\x91\x02"
  "\xd6\x01\x0a\x81\x8f\x02\xd5\x01\x08\x81\x8f\x02\xd4\x01\x06\x88"
  "\x0e\xd3\x01\x04\x81\x8d\x02\x1b\x34\x46\x02\x1b\x0d\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x62\x15\xe0\x01\x04\x83\x04"
  "\x03\x63\x02\x1c\x3e\x35\x5b\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x64"
  "\x61\x74\x75\x6d\x5c\x81\x02\x03\x0e\x26\x74\x72\x69\x70\x6c\x65"
  "\x2d\x74\x68\x69\x72\x64\x04\x0f\x69\x6e\x74\x65\x67\x65\x72\x2d"
  "\x64\x69\x76\x69\x64\x65\x03\x0f\x26\x74\x72\x69\x70\x6c\x65\x2d"
  "\x73\x65\x63\x6f\x6e\x64\x64\x03\x18\x03\x0e\x26\x74\x72\x69\x70"
  "\x6c\x65\x2d\x66\x69\x72\x73\x74\x65\x05\x10\x73\x75\x62\x76\x65"
  "\x63\x74\x6f\x72\x2d\x3e\x6c\x69\x73\x74\x66\x03\x49\x04\x4b\x09"
  "\xfa\x01\x36\x81\x93\x02\xf9\x01\x34\x81\x93\x02\xf8\x01\x32\x81"
  "\x97\x02\xf7\x01\x30\x81\x93\x02\xf6\x01\x2e\x81\x97\x02\xf5\x01"
  "\x2c\x81\x99\x02\xf4\x01\x2a\x81\x95\x02\xf3\x01\x28\x81\x93\x02"
  "\xf2\x01\x26\x81\x93\x02\xf1\x01\x24\x81\x93\x02\xf0\x01\x22\x81"
  "\x93\x02\xef\x01\x20\x81\x93\x02\xee\x01\x1e\x81\x8f\x02\xed\x01"
  "\x1c\x81\x8f\x02\xec\x01\x1a\x81\x8d\x02\xeb\x01\x18\x81\x91\x02"
  "\xea\x01\x16\x81\x8b\x02\xe9\x01\x14\x81\x8b\x02\xe8\x01\x12\x81"
  "\x89\x02\xe7\x01\x10\x81\x89\x02\xe6\x01\x0e\x81\x87\x02\xe5\x01"
  "\x0c\x81\x8b\x02\xe4\x01\x0a\x81\x89\x02\xe3\x01\x08\x81\x8b\x02"
  "\xe2\x01\x06\x81\x85\x02\xe1\x01\x04\x84\x06\x35\x52\x67\x02\x1d"
  "\x03\x64\x02\xfb\x01\x04\x83\x04\x03\x68\x02\x1e\x35\x03\x64\x02"
  "\xfd\x01\x06\x81\x83\x02\xfc\x01\x04\x83\x04\x05\x0d\x69\x02\x1f"
  "\x3e\x03\x64\x03\x65\x05\x66\x04\x4b\x03\x49\x06\x83\x02\x0e\x81"
  "\x87\x02\x82\x02\x0c\x81\x85\x02\x81\x02\x0a\x81\x87\x02\x80\x02"
  "\x08\x81\x85\x02\xff\x01\x06\x81\x83\x02\xfe\x01\x04\x83\x04\x0d"
  "\x1d\x64\x02\x20\x03\x65\x03\x4e\x03\x85\x02\x06\x81\x83\x02\x84"
  "\x02\x04\x83\x04\x05\x0d\x6a\x02\x21\x03\x25\x03\x65\x03\x4d\x04"
  "\x87\x02\x06\x81\x83\x02\x86\x02\x04\x83\x04\x05\x0f\x65\x02\x22"
  "\x03\x25\x04\x13\x26\x74\x72\x69\x70\x6c\x65\x2d\x73\x65\x74\x2d"
  "\x66\x69\x72\x73\x74\x21\x04\x56\x04\x89\x02\x06\x81\x85\x02\x88"
  "\x02\x04\x84\x06\x05\x0f\x6b\x02\x23\x15\x2a\x62\x18\x8c\x02\x08"
  "\x81\x83\x02\x8b\x02\x06\x81\x83\x02\x8a\x02\x04\x83\x04\x07\x0f"
  "\x6c\x02\x24\x0c\x6d\x61\x6b\x65\x2d\x6c\x61\x6d\x62\x64\x61\x6d"
  "\x1a\x4f\x70\x74\x69\x6f\x6e\x61\x6c\x73\x20\x6e\x6f\x74\x20\x69"
  "\x6d\x70\x6c\x65\x6d\x65\x6e\x74\x65\x64\x81\x02\x15\x64\x75\x70"
  "\x6c\x69\x63\x61\x74\x65\x20\x70\x61\x72\x61\x6d\x65\x74\x65\x72"
  "\x73\x04\x20\x69\x6e\x23\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x20"
  "\x69\x6e\x74\x65\x72\x6e\x61\x6c\x20\x64\x65\x66\x69\x6e\x69\x74"
  "\x69\x6f\x6e\x73\x20\x66\x6f\x72\x05\x4b\x03\x15\x65\x72\x72\x6f"
  "\x72\x2d\x69\x72\x72\x69\x74\x61\x6e\x74\x2f\x6e\x6f\x69\x73\x65"
  "\x03\x59\x03\x17\x6d\x61\x6b\x65\x2d\x62\x6c\x6f\x63\x6b\x2d\x64"
  "\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x59\x03\x15\x66\x69\x6e"
  "\x64\x2d\x6c\x69\x73\x74\x2d\x64\x75\x70\x6c\x69\x63\x61\x74\x65"
  "\x73\x4b\x03\x0e\x6d\x61\x6b\x65\x2d\x73\x65\x71\x75\x65\x6e\x63"
  "\x65\x6e\x08\x0d\x6d\x61\x6b\x65\x2d\x78\x6c\x61\x6d\x62\x64\x61"
  "\x6f\x06\x0d\x6d\x61\x6b\x65\x2d\x63\x6c\x61\x6d\x62\x64\x61\x70"
  "\x07\x0c\x6d\x61\x6b\x65\x2d\x63\x6c\x65\x78\x70\x72\x71\x04\x06"
  "\x65\x72\x72\x6f\x72\x72\x06\x72\x0c\x99\x02\x1c\x81\x89\x02\x98"
  "\x02\x1a\x81\x89\x02\x97\x02\x18\x81\x83\x02\x96\x02\x16\x81\x91"
  "\x02\x95\x02\x14\x81\x91\x02\x94\x02\x12\x81\x91\x02\x93\x02\x10"
  "\x81\x91\x02\x92\x02\x0e\x81\x91\x02\x91\x02\x0c\x81\x91\x02\x90"
  "\x02\x0a\x81\x8f\x02\x8f\x02\x08\x81\x8f\x02\x8e\x02\x06\x81\x85"
  "\x02\x8d\x02\x04\x89\x10\x1b\x3c\x72\x02\x25\x35\x5b\x5c\x04\x1a"
  "\x03\x0a\x73\x65\x71\x75\x65\x6e\x63\x65\x3f\x03\x11\x73\x65\x71"
  "\x75\x65\x6e\x63\x65\x2d\x61\x63\x74\x69\x6f\x6e\x73\x03\x13\x62"
  "\x6c\x6f\x63\x6b\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e"
  "\x3f\x73\x03\x6e\x06\xa3\x02\x16\x81\x93\x02\xa2\x02\x14\x81\x93"
  "\x02\xa1\x02\x12\x81\x91\x02\xa0\x02\x10\x81\x93\x02\x9f\x02\x0e"
  "\x81\x91\x02\x9e\x02\x0c\x81\x93\x02\x9d\x02\x0a\x81\x8f\x02\x9c"
  "\x02\x08\x81\x91\x02\x9b\x02\x06\x81\x8f\x02\x9a\x02\x04\x84\x06"
  "\x15\x28\x6e\x02\x26\x5c\x5b\x03\x09\x72\x65\x76\x65\x72\x73\x65"
  "\x21\x04\x05\x6d\x65\x6d\x71\x03\xae\x02\x18\x81\x85\x02\xad\x02"
  "\x16\x81\x85\x02\xac\x02\x14\x81\x85\x02\xab\x02\x12\x81\x85\x02"
  "\xaa\x02\x10\x81\x89\x02\xa9\x02\x0e\x81\x85\x02\xa8\x02\x0c\x81"
  "\x85\x02\xa7\x02\x0a\x81\x89\x02\xa6\x02\x08\x81\x87\x02\xa5\x02"
  "\x06\x81\x85\x02\xa4\x02\x04\x83\x04\x17\x22\x5c\x02\x27\x0d\x53"
  "\x43\x6f\x64\x65\x20\x6c\x61\x6d\x62\x64\x61\x15\x2a\x62\x18\x05"
  "\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70"
  "\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x5b\x02\xb4\x02\x0e\x81"
  "\x87\x02\xb3\x02\x0c\x81\x87\x02\xb2\x02\x0a\x81\x87\x02\xb1\x02"
  "\x08\x81\x85\x02\xb0\x02\x06\x81\x85\x02\xaf\x02\x04\x86\x0a\x0d"
  "\x18\x74\x02\x28\x0d\x53\x43\x6f\x64\x65\x20\x6c\x61\x6d\x62\x64"
  "\x61\x15\x2a\x62\x18\x05\x5b\x02\xba\x02\x0e\x81\x89\x02\xb9\x02"
  "\x0c\x81\x89\x02\xb8\x02\x0a\x81\x89\x02\xb7\x02\x08\x81\x87\x02"
  "\xb6\x02\x06\x81\x87\x02\xb5\x02\x04\x86\x0a\x0d\x18\x5b\x02\x29"
  "\xbb\x02\x04\x82\x02\x03\x75\x02\x2a\x15\x23\x5b\x42\x6c\x6f\x63"
  "\x6b\x20\x44\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x5d\x76\xbc"
  "\x02\x04\x83\x04\x03\x77\x02\x2b\x35\xbd\x02\x04\x83\x04\x03\x78"
  "\x02\x2c\x76\x35\x3e\xc1\x02\x0a\x81\x83\x02\xc0\x02\x08\x81\x83"
  "\x02\xbf\x02\x06\x81\x83\x02\xbe\x02\x04\x83\x04\x09\x11\x79\x02"
  "\x2d\x18\x03\x43\x05\x45\x03\xc3\x02\x06\x81\x87\x02\xc2\x02\x04"
  "\x85\x08\x05\x0e\x7a\x02\x2e\x62\x18\xc4\x02\x04\x83\x04\x03\x7b"
  "\x02\x2f\x35\x3e\x03\x0a\x26\x70\x61\x69\x72\x2d\x63\x64\x72\x7c"
  "\x03\x4d\x05\x66\x04\xca\x02\x0e\x81\x89\x02\xc9\x02\x0c\x81\x89"
  "\x02\xc8\x02\x0a\x81\x8b\x02\xc7\x02\x08\x81\x89\x02\xc6\x02\x06"
  "\x81\x85\x02\xc5\x02\x04\x84\x06\x0d\x1b\x7d\x02\x30\x03\x7c\x02"
  "\xcb\x02\x04\x83\x04\x03\x7e\x02\x31\x35\x03\x7c\x02\xcd\x02\x06"
  "\x81\x83\x02\xcc\x02\x04\x83\x04\x05\x0d\x7f\x02\x32\x3e\x03\x7c"
  "\x05\x66\x03\xd0\x02\x08\x81\x87\x02\xcf\x02\x06\x81\x83\x02\xce"
  "\x02\x04\x83\x04\x07\x11\x80\x01\x02\x33\x03\x4d\x02\xd1\x02\x04"
  "\x83\x04\x03\x81\x01\x02\x34\x04\x56\x02\xd2\x02\x04\x84\x06\x03"
  "\x56\x02\x35\x2a\x03\x43\x05\x45\x03\xd4\x02\x06\x81\x87\x02\xd3"
  "\x02\x04\x85\x08\x05\x0e\x82\x01\x02\x36\x62\x2a\xd5\x02\x04\x83"
  "\x04\x03\x83\x01\x02\x37\x35\x3e\x03\x7c\x03\x4d\x05\x66\x04\xdb"
  "\x02\x0e\x81\x89\x02\xda\x02\x0c\x81\x89\x02\xd9\x02\x0a\x81\x8b"
  "\x02\xd8\x02\x08\x81\x89\x02\xd7\x02\x06\x81\x85\x02\xd6\x02\x04"
  "\x84\x06\x0d\x1b\x66\x02\x38\x03\x7c\x02\xdc\x02\x04\x83\x04\x03"
  "\x3e\x02\x39\x35\x03\x7c\x02\xde\x02\x06\x81\x83\x02\xdd\x02\x04"
  "\x83\x04\x05\x0d\x84\x01\x02\x3a\x03\x4d\x02\xdf\x02\x04\x83\x04"
  "\x03\x4d\x02\x3b\x36\x18\x03\x43\x05\x45\x03\xe1\x02\x06\x81\x87"
  "\x02\xe0\x02\x04\x84\x06\x05\x0f\x85\x01\x02\x3c\x58\x18\x03\x43"
  "\x05\x45\x03\xe3\x02\x06\x81\x87\x02\xe2\x02\x04\x84\x06\x05\x0f"
  "\x45\x02\x3d\x58\x36\x35\x62\x18\x03\x7c\x02\xe9\x02\x0e\x81\x83"
  "\x02\xe8\x02\x0c\x81\x83\x02\xe7\x02\x0a\x81\x83\x02\xe6\x02\x08"
  "\x81\x83\x02\xe5\x02\x06\x81\x83\x02\xe4\x02\x04\x83\x04\x0d\x1a"
  "\x7c\x02\x3e\x04\x04\x6d\x61\x70\x02\x1f\x6d\x61\x6b\x65\x2d\x75"
  "\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x72\x65\x66\x65\x72\x65"
  "\x6e\x63\x65\x2d\x74\x72\x61\x70\x03\xeb\x02\x06\x83\x04\xea\x02"
  "\x04\x83\x04\x05\x0d\x62\x3e\x43\x43\x62\x04\x7c\x04\x45\x04\x85"
  "\x01\x04\x58\x36\x4d\x04\x84\x01\x04\x3e\x04\x66\x04\x83\x01\x04"
  "\x82\x01\x04\x2a\x56\x04\x81\x01\x04\x80\x01\x04\x7f\x04\x7e\x04"
  "\x7d\x04\x7b\x04\x7a\x04\x18\x79\x04\x78\x04\x77\x04\x1a\x44\x52"
  "\x14\x6d\x61\x6b\x65\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c"
  "\x65\x78\x70\x72\x15\x6d\x61\x6b\x65\x2d\x69\x6e\x74\x65\x72\x6e"
  "\x61\x6c\x2d\x6c\x61\x6d\x62\x64\x61\x1a\x6c\x61\x6d\x62\x64\x61"
  "\x2d\x74\x61\x67\x3a\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x65"
  "\x78\x70\x72\x1b\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x69"
  "\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6c\x61\x6d\x62\x64\x61\x0c\x73"
  "\x6c\x65\x78\x70\x72\x2d\x62\x6f\x64\x79\x2c\x29\x5d\x08\x73\x6c"
  "\x65\x78\x70\x72\x3f\x0c\x6d\x61\x6b\x65\x2d\x73\x6c\x65\x78\x70"
  "\x72\x0c\x73\x6c\x65\x78\x70\x72\x2d\x74\x79\x70\x65\x12\x73\x65"
  "\x74\x2d\x73\x6c\x61\x6d\x62\x64\x61\x2d\x62\x6f\x64\x79\x21\x0d"
  "\x73\x6c\x61\x6d\x62\x64\x61\x2d\x62\x6f\x64\x79\x53\x2d\x2a\x48"
  "\x09\x73\x6c\x61\x6d\x62\x64\x61\x3f\x0d\x6d\x61\x6b\x65\x2d\x73"
  "\x6c\x61\x6d\x62\x64\x61\x0d\x73\x6c\x61\x6d\x62\x64\x61\x2d\x74"
  "\x79\x70\x65\x73\x17\x62\x6c\x6f\x63\x6b\x2d\x64\x65\x63\x6c\x61"
  "\x72\x61\x74\x69\x6f\x6e\x2d\x74\x65\x78\x74\x59\x1a\x07\x76\x65"
  "\x63\x74\x6f\x72\x12\x62\x6c\x6f\x63\x6b\x2d\x64\x65\x63\x6c\x61"
  "\x72\x61\x74\x69\x6f\x6e\x05\x74\x65\x78\x74\x75\x04\x11\x6c\x6f"
  "\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x16\x72"
  "\x74\x64\x3a\x62\x6c\x6f\x63\x6b\x2d\x64\x65\x63\x6c\x61\x72\x61"
  "\x74\x69\x6f\x6e\x85\x01\x12\x62\x6c\x6f\x63\x6b\x2d\x64\x65\x63"
  "\x6c\x61\x72\x61\x74\x69\x6f\x6e\x76\x1b\x09\x1a\x32\x33\x4b\x0a"
  "\x6d\x08\x6c\x61\x6d\x62\x64\x61\x3f\x20\x21\x19\x18\x17\x16\x15"
  "\x25\x2e\x2b\x28\x22\x09\x78\x6c\x61\x6d\x62\x64\x61\x3f\x6f\x0d"
  "\x78\x6c\x61\x6d\x62\x64\x61\x2d\x74\x79\x70\x65\x1e\x1f\x14\x13"
  "\x12\x11\x10\x26\x2f\x23\x71\x1c\x1d\x0f\x0e\x0d\x0c\x0b\x4e\x49"
  "\x27\x30\x24\x70\x1b\x73\x65\x74\x2d\x77\x72\x61\x70\x70\x65\x72"
  "\x2d\x6f\x72\x69\x67\x69\x6e\x61\x6c\x2d\x62\x6f\x64\x79\x21\x16"
  "\x77\x72\x61\x70\x70\x65\x72\x2d\x6f\x72\x69\x67\x69\x6e\x61\x6c"
  "\x2d\x62\x6f\x64\x79\x13\x73\x65\x74\x2d\x77\x72\x61\x70\x70\x65"
  "\x72\x2d\x73\x74\x61\x74\x65\x21\x0e\x77\x72\x61\x70\x70\x65\x72"
  "\x2d\x73\x74\x61\x74\x65\x12\x73\x65\x74\x2d\x77\x72\x61\x70\x70"
  "\x65\x72\x2d\x62\x6f\x64\x79\x21\x0d\x77\x72\x61\x70\x70\x65\x72"
  "\x2d\x62\x6f\x64\x79\x37\x38\x0d\x6d\x61\x6b\x65\x2d\x77\x72\x61"
  "\x70\x70\x65\x72\x31\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65"
  "\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x43\x5b\x04\x74\x04\x5c\x04"
  "\x6e\x04\x72\x04\x6c\x04\x6b\x04\x65\x04\x6a\x04\x64\x04\x69\x04"
  "\x68\x04\x67\x04\x63\x04\x46\x06\x15\x61\x04\x60\x04\x51\x04\x5f"
  "\x04\x5e\x04\x5a\x04\x57\x04\x55\x04\x50\x04\x54\x04\x4f\x04\x4c"
  "\x04\x4a\x04\x47\x06\x39\x04\x42\x04\x41\x04\x40\x04\x3c\x04\x3a"
  "\x04\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x77\x72\x61\x70\x70\x65\x72"
  "\x3f\x04\x3b\x04\x3d\x04\x34\x04\x43\x05\x10\x64\x65\x66\x69\x6e"
  "\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x04\x19\x73\x74\x61\x6e"
  "\x64\x61\x72\x64\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x6d\x65"
  "\x74\x68\x6f\x64\x04\x25\x6e\x61\x6d\x65\x64\x2d\x73\x74\x72\x75"
  "\x63\x74\x75\x72\x65\x2f\x73\x65\x74\x2d\x74\x61\x67\x2d\x64\x65"
  "\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x21\x0a\x1b\x6d\x61\x6b\x65"
  "\x2d\x64\x65\x66\x69\x6e\x65\x2d\x73\x74\x72\x75\x63\x74\x75\x72"
  "\x65\x2d\x74\x79\x70\x65\x05\x85\x01\x02\x09\x14\x80\x80\x04\x08"
  "\x12\x81\x81\x02\x07\x10\x81\x81\x02\x06\x0e\x81\x83\x02\x05\x0c"
  "\x81\x8b\x02\x04\x0a\x81\x85\x02\x03\x08\x81\x85\x02\x02\x06\x81"
  "\x83\x02\x01\x04\x81\x83\x02\x13\x31";

SCHEME_OBJECT *
lambda_so_data_8955ad1ce964b4fa (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_lambda_so_data_8955ad1ce964b4fa [0]))), (sizeof (prog_lambda_so_data_8955ad1ce964b4fa)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_16]));
}

DECLARE_COMPILED_DATA_NS ("lambda.so", lambda_so_data_8955ad1ce964b4fa)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("lambda.so", "8dcd0d0fe4bbe09a")
