/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:19:56-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 5
#define DEBUGGING_LABEL_1_2 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 5
#define DEBUGGING_LABEL_2_2 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 5
#define DEBUGGING_LABEL_4_2 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 5
#define DEBUGGING_LABEL_5_2 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 8
#define DEBUGGING_LABEL_6_2 7
#define EXECUTE_CACHE_6_5 5
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_7 7
#define ENVIRONMENT_LABEL_7_3 17
#define DEBUGGING_LABEL_7_2 16
#define OBJECT_7_2 15
#define OBJECT_7_1 14
#define OBJECT_7_0 13
#define EXECUTE_CACHE_7_8 9
#define EXECUTE_CACHE_7_6 11
#define FREE_REFERENCES_LABEL_7_0 8
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_7_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_7_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_7)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_7_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 7
#define DEBUGGING_LABEL_8_2 6
#define OBJECT_8_1 5
#define OBJECT_8_0 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto Z__condition_type_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_name_3)
DEFLABEL (Z__condition_type_name_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_8_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 7
#define DEBUGGING_LABEL_9_2 6
#define OBJECT_9_1 5
#define OBJECT_9_0 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto Z__condition_type_generalizations_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_generalizations_3)
DEFLABEL (Z__condition_type_generalizations_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_9_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define ENVIRONMENT_LABEL_10_3 7
#define DEBUGGING_LABEL_10_2 6
#define OBJECT_10_1 5
#define OBJECT_10_0 4
#define FREE_REFERENCES_LABEL_10_0 4
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto Z__condition_type_field_indexes_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_field_indexes_3)
DEFLABEL (Z__condition_type_field_indexes_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_10_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 7
#define DEBUGGING_LABEL_11_2 6
#define OBJECT_11_1 5
#define OBJECT_11_0 4
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto Z__condition_type_number_of_fields_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_number_of_fields_3)
DEFLABEL (Z__condition_type_number_of_fields_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_11_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 7
#define DEBUGGING_LABEL_12_2 6
#define OBJECT_12_1 5
#define OBJECT_12_0 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto Z__condition_type_reporter_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_reporter_3)
DEFLABEL (Z__condition_type_reporter_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_12_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define ENVIRONMENT_LABEL_13_3 7
#define DEBUGGING_LABEL_13_2 6
#define OBJECT_13_1 5
#define OBJECT_13_0 4
#define FREE_REFERENCES_LABEL_13_0 4
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto Z__condition_type_properties_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_properties_3)
DEFLABEL (Z__condition_type_properties_0)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_13_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 8
#define DEBUGGING_LABEL_14_2 7
#define OBJECT_14_2 6
#define OBJECT_14_1 5
#define OBJECT_14_0 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto set__condition_type_generalizationsB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__condition_type_generalizationsB_3)
DEFLABEL (set__condition_type_generalizationsB_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_14_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_14_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define ENVIRONMENT_LABEL_15_3 13
#define DEBUGGING_LABEL_15_2 12
#define OBJECT_15_0 11
#define EXECUTE_CACHE_15_7 7
#define EXECUTE_CACHE_15_6 9
#define FREE_REFERENCES_LABEL_15_0 6
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto guarantee_condition_type_1;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_condition_type_4)
DEFLABEL (guarantee_condition_type_1)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_15_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 11
#define DEBUGGING_LABEL_16_2 10
#define OBJECT_16_2 9
#define OBJECT_16_1 8
#define OBJECT_16_0 7
#define EXECUTE_CACHE_16_5 5
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto error_not_condition_type_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_condition_type_5)
DEFLABEL (error_not_condition_type_2)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_16_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_16_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_16_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define ENVIRONMENT_LABEL_17_3 13
#define DEBUGGING_LABEL_17_2 12
#define OBJECT_17_0 11
#define EXECUTE_CACHE_17_6 7
#define FREE_REFERENCE_17_0 10
#define FREE_REFERENCES_LABEL_17_0 6
#define NUMBER_OF_LINKER_SECTIONS_17_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto guarantee_condition_types_0;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_condition_types_4)
DEFLABEL (guarantee_condition_types_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_17_0]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_5 3
#define LABEL_18_4 5
#define LABEL_18_6 7
#define LABEL_18_14 9
#define LABEL_18_9 11
#define LABEL_18_15 13
#define LABEL_18_16 15
#define LABEL_18_17 17
#define LABEL_18_19 19
#define LABEL_18_21 21
#define LABEL_18_22 23
#define LABEL_18_23 25
#define LABEL_18_10 27
#define TAG_18_11 12
#define LABEL_18_25 29
#define LABEL_18_12 31
#define LABEL_18_26 33
#define TAG_18_27 15
#define LABEL_18_18 35
#define LABEL_18_32 37
#define LABEL_18_33 39
#define ENVIRONMENT_LABEL_18_3 77
#define DEBUGGING_LABEL_18_2 76
#define OBJECT_18_14 75
#define OBJECT_18_13 74
#define OBJECT_18_12 73
#define OBJECT_18_11 72
#define OBJECT_18_10 71
#define OBJECT_18_9 70
#define OBJECT_18_8 69
#define OBJECT_18_7 68
#define OBJECT_18_6 67
#define OBJECT_18_5 66
#define OBJECT_18_4 65
#define OBJECT_18_3 64
#define OBJECT_18_2 63
#define OBJECT_18_1 62
#define OBJECT_18_0 61
#define EXECUTE_CACHE_18_34 41
#define EXECUTE_CACHE_18_31 43
#define EXECUTE_CACHE_18_30 45
#define EXECUTE_CACHE_18_29 47
#define EXECUTE_CACHE_18_28 49
#define EXECUTE_CACHE_18_24 51
#define EXECUTE_CACHE_18_20 53
#define EXECUTE_CACHE_18_13 55
#define EXECUTE_CACHE_18_8 57
#define EXECUTE_CACHE_18_7 59
#define FREE_REFERENCES_LABEL_18_0 40
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd67;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd47;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd28;
  machine_word Wrd32;
  machine_word Wrd80;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd128;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd121;
  machine_word Wrd66;
  machine_word Wrd103;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd42;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_18_4);
      goto make_condition_type_21;

    case 2:
      current_block = (Rpc - LABEL_18_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_18_14);
      goto continuation_17;

    case 4:
      current_block = (Rpc - LABEL_18_9);
      goto continuation_15;

    case 5:
      current_block = (Rpc - LABEL_18_15);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_18_16);
      goto label_24;

    case 7:
      current_block = (Rpc - LABEL_18_17);
      goto continuation_9;

    case 8:
      current_block = (Rpc - LABEL_18_19);
      goto label_26;

    case 9:
      current_block = (Rpc - LABEL_18_21);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_18_22);
      goto continuation_4;

    case 11:
      current_block = (Rpc - LABEL_18_23);
      goto continuation_3;

    case 12:
      current_block = (Rpc - LABEL_18_10);
      goto lambda_30;

    case 13:
      current_block = (Rpc - LABEL_18_25);
      goto label_25;

    case 14:
      current_block = (Rpc - LABEL_18_12);
      goto continuation_16;

    case 15:
      current_block = (Rpc - LABEL_18_26);
      goto lambda_31;

    case 16:
      current_block = (Rpc - LABEL_18_18);
      goto lambda_12;

    case 17:
      current_block = (Rpc - LABEL_18_32);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_18_33);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_condition_type_29)
DEFLABEL (make_condition_type_21)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_5);

DEFLABEL (label_39)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_18_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18_10])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_12]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_13]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_18_12);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_18_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_38;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_37;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_37;
  (Wrd11.Obj) = ((Wrd17.pObj) [3]);

DEFLABEL (label_36)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_35)
  (Wrd30.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd42.uLng) == 62))
    goto label_34;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd40.Lng))))
    goto label_34;
  ((Wrd38.pObj) [3]) = (Wrd27.Obj);

DEFLABEL (label_33)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.Obj) = (current_block [OBJECT_18_2]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_16]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_4]), 3);

DEFLABEL (label_24)
  goto label_33;

DEFLABEL (label_37)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_18_2]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_3]), 2);

DEFLABEL (label_23)
  (Wrd11.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  (Wrd11.Obj) = (current_block [OBJECT_18_1]);
  goto label_36;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_18_14);
  (Wrd11.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_18_10);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 30))
    goto label_48;
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_24]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_18_23);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_47)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_21]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [2]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 30)
    goto label_46;
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_17]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_18_2]);
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_29]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_18_17);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;
  (Wrd90.Obj) = (Rsp [2]);
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd66.Obj) = ((Wrd91.pObj) [2]);

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_40)
  (Wrd67.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd67.Obj);
  (Rsp [3]) = (Wrd66.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_28]));

DEFLABEL (label_42)
  (Wrd92.Obj) = (Rsp [2]);
  (Wrd93.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  (Wrd94.Obj) = ((Wrd93.pObj) [2]);
  if ((Wrd94.Obj) == ((SCHEME_OBJECT) 0))
    goto label_43;
  (Wrd96.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd97.Obj) = (current_block [OBJECT_18_6]);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_20]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_18_21);
  (Wrd66.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd103.Obj) = ((Wrd93.pObj) [3]);
  if ((Wrd103.Obj) == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd121.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd121.uLng) == 62))
    goto label_44;
  (Wrd115.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd116.Obj) = ((Wrd115.pObj) [0]);
  (Wrd117.Lng) = (FIXNUM_TO_LONG (Wrd116.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd117.Lng))))
    goto label_44;
  (Wrd66.Obj) = ((Wrd115.pObj) [6]);
  goto label_41;

DEFLABEL (label_44)
  (Wrd123.Obj) = (Rsp [2]);
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd122.Obj) = ((Wrd124.pObj) [3]);
  (Wrd125.Obj) = (current_block [OBJECT_18_5]);
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_19]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_3]), 2);

DEFLABEL (label_26)
  (Wrd66.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_45)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_18]))));
  goto label_41;

DEFLABEL (label_46)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd61.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_18_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18_26])));
  Rhp += 1;
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd61.pObj)));
  ((Wrd61.pObj) [2]) = (Wrd50.Obj);
  Wrd66 = Wrd60;
  goto label_41;

DEFLABEL (label_48)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_22]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd72.Obj) = (current_block [OBJECT_18_7]);
  (Wrd75.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd75.Lng))))
    goto label_58;
  (Wrd19.uLng) = (OBJECT_DATUM (Wrd72.Obj));
  if ((Wrd19.Obj) == (Wrd11.Obj))
    goto label_57;

DEFLABEL (label_56)
  (Wrd22.Obj) = (current_block [OBJECT_18_5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd32.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd32.Lng)))
    goto label_49;
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_8]), 2);

DEFLABEL (label_49)
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd26.Obj) == (Wrd28.Obj))
    goto label_51;
  (Wrd24.Obj) = (current_block [OBJECT_18_10]);
  goto label_50;

DEFLABEL (label_51)
  (Wrd24.Obj) = (current_block [OBJECT_18_9]);

DEFLABEL (label_50)
DEFLABEL (label_55)
  Rsp = (& (Rsp [3]));
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_53;

DEFLABEL (label_52)
  (Wrd68.Obj) = (Rsp [1]);
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd70.Obj) = ((Wrd69.pObj) [4]);
  (* (--Rsp)) = (Wrd70.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_30]));

DEFLABEL (label_53)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [4]);
  if ((Wrd36.Obj) == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd38.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_18_12]);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_20]));

DEFLABEL (label_54)
  (Wrd44.Obj) = (current_block [OBJECT_18_11]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd44.Obj);
  goto label_47;

DEFLABEL (label_57)
  Rsp = (& (Rsp [2]));
  goto label_52;

DEFLABEL (label_58)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_25]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_8]), 2);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_56;
  goto label_57;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_18_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_53;
  goto label_52;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_18_26);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_31]));

DEFLABEL (lambda_32)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_18_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_18_13]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_31]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_18_32);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_60;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_60;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_59)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_34]));

DEFLABEL (label_60)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_18_14]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_33]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_3]), 2);

DEFLABEL (label_27)
  (Wrd5.Obj) = Rvl;
  goto label_59;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_6 5
#define LABEL_19_7 7
#define LABEL_19_8 9
#define TAG_19_9 3
#define LABEL_19_10 11
#define TAG_19_11 4
#define LABEL_19_5 13
#define LABEL_19_12 15
#define LABEL_19_13 17
#define LABEL_19_15 19
#define LABEL_19_17 21
#define LABEL_19_18 23
#define LABEL_19_19 25
#define LABEL_19_20 27
#define LABEL_19_14 29
#define LABEL_19_23 31
#define LABEL_19_21 33
#define LABEL_19_24 35
#define TAG_19_25 16
#define ENVIRONMENT_LABEL_19_3 49
#define DEBUGGING_LABEL_19_2 48
#define OBJECT_19_6 47
#define OBJECT_19_5 46
#define OBJECT_19_4 45
#define OBJECT_19_3 44
#define OBJECT_19_2 43
#define OBJECT_19_1 42
#define OBJECT_19_0 41
#define EXECUTE_CACHE_19_22 37
#define EXECUTE_CACHE_19_16 39
#define FREE_REFERENCES_LABEL_19_0 36
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd21;
  machine_word Wrd37;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd46;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto compute_field_indexes_31;

    case 1:
      current_block = (Rpc - LABEL_19_6);
      goto label_33;

    case 2:
      current_block = (Rpc - LABEL_19_7);
      goto label_34;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto lambda_43;

    case 4:
      current_block = (Rpc - LABEL_19_10);
      goto lambda_44;

    case 5:
      current_block = (Rpc - LABEL_19_5);
      goto lambda_25;

    case 6:
      current_block = (Rpc - LABEL_19_12);
      goto loop_9;

    case 7:
      current_block = (Rpc - LABEL_19_13);
      goto label_35;

    case 8:
      current_block = (Rpc - LABEL_19_15);
      goto label_36;

    case 9:
      current_block = (Rpc - LABEL_19_17);
      goto loop_21;

    case 10:
      current_block = (Rpc - LABEL_19_18);
      goto label_37;

    case 11:
      current_block = (Rpc - LABEL_19_19);
      goto label_38;

    case 12:
      current_block = (Rpc - LABEL_19_20);
      goto label_39;

    case 13:
      current_block = (Rpc - LABEL_19_14);
      goto continuation_7;

    case 14:
      current_block = (Rpc - LABEL_19_23);
      goto label_40;

    case 15:
      current_block = (Rpc - LABEL_19_21);
      goto continuation_13;

    case 16:
      current_block = (Rpc - LABEL_19_24);
      goto lambda_48;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compute_field_indexes_42)
DEFLABEL (compute_field_indexes_31)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_53;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_53;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_52)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_51;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd31.Lng))))
    goto label_51;
  (Wrd25.Obj) = ((Wrd29.pObj) [5]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_50)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd41.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_8])));
  Rhp += 2;
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd41.pObj)));
  Wrd44 = Wrd41;
  (Wrd45.Obj) = (Rsp [1]);
  ((Wrd44.pObj) [2]) = (Wrd45.Obj);
  (Wrd43.Obj) = (Rsp [0]);
  ((Wrd44.pObj) [3]) = (Wrd43.Obj);
  Wrd46 = Wrd40;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_49)
  (Rsp [0]) = (Wrd46.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd49.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_10])));
  Rhp += 1;
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd49.pObj)));
  Wrd50 = Wrd49;
  (Wrd51.Obj) = (Rsp [1]);
  ((Wrd50.pObj) [2]) = (Wrd51.Obj);
  (Rsp [1]) = (Wrd48.Obj);
  goto pop_return;

DEFLABEL (label_51)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_19_2]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_19_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_54)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  goto label_49;

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_19_8);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  goto lambda_23;

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_19_10);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_19_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_9;

DEFLABEL (lambda_45)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_19_5);
  (Wrd5.Obj) = (current_block [OBJECT_19_4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_19_3]);
  (Rsp [2]) = (Wrd7.Obj);
  goto lambda_23;

DEFLABEL (loop_46)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_19_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_55;
  (Wrd8.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  (Rsp [2]) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_21;

DEFLABEL (label_55)
  if (! ((Wrd6.uLng) == 1))
    goto label_64;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_63)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_62;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_61)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_19_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd8.Obj) = (Rsp [2]);
  goto label_56;

DEFLABEL (label_57)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));

DEFLABEL (label_56)
DEFLABEL (label_60)
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_59;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_58)
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_9;

DEFLABEL (label_59)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_23]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_6]), 1);

DEFLABEL (label_40)
  (Wrd9.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_62)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_15]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_5]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_13]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_5]), 1);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (loop_47)
DEFLABEL (loop_21)
  INTERRUPT_CHECK (26, LABEL_19_17);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_65;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_22]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_19_21);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_24])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_65)
  if (! ((Wrd6.uLng) == 1))
    goto label_71;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_70)
  (Wrd23.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (Wrd27.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (Rsp [2]) = (Wrd24.Obj);
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_69;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_68)
  (Rsp [0]) = (Wrd28.Obj);
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 26))
    goto label_67;
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  (Wrd44.Lng) = ((Wrd46.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd44.Lng)))
    goto label_67;
  (Wrd41.Obj) = (LONG_TO_FIXNUM (Wrd44.Lng));

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd41.Obj);
  goto loop_21;

DEFLABEL (label_67)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_20]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_39)
  (Wrd41.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_19]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_6]), 1);

DEFLABEL (label_38)
  (Wrd28.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_18]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_5]), 1);

DEFLABEL (label_37)
  (Wrd11.Obj) = Rvl;
  goto label_70;

DEFLABEL (lambda_48)
  CLOSURE_HEADER (LABEL_19_24);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_6 5
#define LABEL_20_8 7
#define LABEL_20_5 9
#define ENVIRONMENT_LABEL_20_3 19
#define DEBUGGING_LABEL_20_2 18
#define OBJECT_20_2 17
#define OBJECT_20_1 16
#define OBJECT_20_0 15
#define EXECUTE_CACHE_20_9 11
#define EXECUTE_CACHE_20_7 13
#define FREE_REFERENCES_LABEL_20_0 10
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto Z__condition_type_field_index_4;

    case 1:
      current_block = (Rpc - LABEL_20_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_20_8);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_field_index_8)
DEFLABEL (Z__condition_type_field_index_4)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_12;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_12;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_11)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_20_8);

DEFLABEL (label_10)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_9;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_2]), 1);

DEFLABEL (label_12)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_20_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_7 7
#define LABEL_21_8 9
#define ENVIRONMENT_LABEL_21_3 21
#define DEBUGGING_LABEL_21_2 20
#define OBJECT_21_2 19
#define OBJECT_21_1 18
#define OBJECT_21_0 17
#define EXECUTE_CACHE_21_9 11
#define EXECUTE_CACHE_21_6 13
#define FREE_REFERENCE_21_0 16
#define FREE_REFERENCES_LABEL_21_0 10
#define NUMBER_OF_LINKER_SECTIONS_21_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto condition_type_field_names_2;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_21_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_21_8);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_field_names_7)
DEFLABEL (condition_type_field_names_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_9;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd19.Lng))))
    goto label_9;
  (Wrd11.Obj) = ((Wrd17.pObj) [4]);

DEFLABEL (label_8)
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_9]));

DEFLABEL (label_9)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_21_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_8]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_2]), 2);

DEFLABEL (label_5)
  (Wrd11.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21_7])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define LABEL_22_7 7
#define LABEL_22_8 9
#define ENVIRONMENT_LABEL_22_3 20
#define DEBUGGING_LABEL_22_2 19
#define OBJECT_22_3 18
#define OBJECT_22_2 17
#define OBJECT_22_1 16
#define OBJECT_22_0 15
#define EXECUTE_CACHE_22_9 11
#define EXECUTE_CACHE_22_6 13
#define FREE_REFERENCES_LABEL_22_0 10
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto condition_type_generalizations_3;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_22_7);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_22_8);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_generalizations_8)
DEFLABEL (condition_type_generalizations_3)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_22_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_12;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_12;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_11)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_10;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_9]));

DEFLABEL (label_10)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_3]), 1);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_22_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define ENVIRONMENT_LABEL_23_3 13
#define DEBUGGING_LABEL_23_2 12
#define OBJECT_23_2 11
#define OBJECT_23_1 10
#define OBJECT_23_0 9
#define EXECUTE_CACHE_23_6 7
#define FREE_REFERENCES_LABEL_23_0 6
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto condition_type_properties_1;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_properties_4)
DEFLABEL (condition_type_properties_1)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_23_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define ENVIRONMENT_LABEL_24_3 12
#define DEBUGGING_LABEL_24_2 11
#define EXECUTE_CACHE_24_7 7
#define EXECUTE_CACHE_24_6 9
#define FREE_REFERENCES_LABEL_24_0 6
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto condition_type_putB_1;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_putB_4)
DEFLABEL (condition_type_putB_1)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define ENVIRONMENT_LABEL_25_3 12
#define DEBUGGING_LABEL_25_2 11
#define EXECUTE_CACHE_25_7 7
#define EXECUTE_CACHE_25_6 9
#define FREE_REFERENCES_LABEL_25_0 6
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto condition_type_get_1;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_get_4)
DEFLABEL (condition_type_get_1)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 5
#define DEBUGGING_LABEL_26_2 4
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 5
#define DEBUGGING_LABEL_27_2 4
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_27_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 5
#define DEBUGGING_LABEL_28_2 4
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_28_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define ENVIRONMENT_LABEL_29_3 5
#define DEBUGGING_LABEL_29_2 4
#define FREE_REFERENCES_LABEL_29_0 4
#define NUMBER_OF_LINKER_SECTIONS_29_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define ENVIRONMENT_LABEL_30_3 8
#define DEBUGGING_LABEL_30_2 7
#define EXECUTE_CACHE_30_5 5
#define FREE_REFERENCES_LABEL_30_0 4
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_7 7
#define LABEL_31_8 9
#define ENVIRONMENT_LABEL_31_3 19
#define DEBUGGING_LABEL_31_2 18
#define OBJECT_31_2 17
#define OBJECT_31_1 16
#define OBJECT_31_0 15
#define EXECUTE_CACHE_31_9 11
#define EXECUTE_CACHE_31_6 13
#define FREE_REFERENCES_LABEL_31_0 10
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_31_7);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_31_8);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_8)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_31_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_12;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_12;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_11)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_10;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_10;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_9]));

DEFLABEL (label_10)
  (Wrd30.Obj) = (current_block [OBJECT_31_1]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_2]), 2);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_31_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_2]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define ENVIRONMENT_LABEL_32_3 7
#define DEBUGGING_LABEL_32_2 6
#define OBJECT_32_1 5
#define OBJECT_32_0 4
#define FREE_REFERENCES_LABEL_32_0 4
#define NUMBER_OF_LINKER_SECTIONS_32_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto Z__condition_type_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_3)
DEFLABEL (Z__condition_type_0)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_32_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 7
#define DEBUGGING_LABEL_33_2 6
#define OBJECT_33_1 5
#define OBJECT_33_0 4
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto Z__condition_continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_continuation_3)
DEFLABEL (Z__condition_continuation_0)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_33_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 7
#define DEBUGGING_LABEL_34_2 6
#define OBJECT_34_1 5
#define OBJECT_34_0 4
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto Z__condition_restarts_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_restarts_3)
DEFLABEL (Z__condition_restarts_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_34_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define ENVIRONMENT_LABEL_35_3 7
#define DEBUGGING_LABEL_35_2 6
#define OBJECT_35_1 5
#define OBJECT_35_0 4
#define FREE_REFERENCES_LABEL_35_0 4
#define NUMBER_OF_LINKER_SECTIONS_35_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto Z__condition_field_values_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_field_values_3)
DEFLABEL (Z__condition_field_values_0)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_35_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 7
#define DEBUGGING_LABEL_36_2 6
#define OBJECT_36_1 5
#define OBJECT_36_0 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto Z__condition_properties_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_properties_3)
DEFLABEL (Z__condition_properties_0)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_36_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define ENVIRONMENT_LABEL_37_3 13
#define DEBUGGING_LABEL_37_2 12
#define OBJECT_37_0 11
#define EXECUTE_CACHE_37_7 7
#define EXECUTE_CACHE_37_6 9
#define FREE_REFERENCES_LABEL_37_0 6
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto guarantee_condition_1;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_condition_4)
DEFLABEL (guarantee_condition_1)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_37_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define ENVIRONMENT_LABEL_38_3 11
#define DEBUGGING_LABEL_38_2 10
#define OBJECT_38_2 9
#define OBJECT_38_1 8
#define OBJECT_38_0 7
#define EXECUTE_CACHE_38_5 5
#define FREE_REFERENCES_LABEL_38_0 4
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto error_not_condition_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_condition_5)
DEFLABEL (error_not_condition_2)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_38_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_38_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_38_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_6 5
#define LABEL_39_5 7
#define ENVIRONMENT_LABEL_39_3 16
#define DEBUGGING_LABEL_39_2 15
#define OBJECT_39_1 14
#define OBJECT_39_0 13
#define EXECUTE_CACHE_39_8 9
#define EXECUTE_CACHE_39_7 11
#define FREE_REFERENCES_LABEL_39_0 8
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto Z__make_condition_2;

    case 1:
      current_block = (Rpc - LABEL_39_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__make_condition_6)
DEFLABEL (Z__make_condition_2)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 62))
    goto label_8;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd20.Lng))))
    goto label_8;
  (Wrd14.Obj) = ((Wrd18.pObj) [5]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_7)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_8]));

DEFLABEL (label_8)
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.Obj) = (current_block [OBJECT_39_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_6]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define LABEL_40_7 7
#define LABEL_40_11 9
#define LABEL_40_13 11
#define LABEL_40_15 13
#define LABEL_40_16 15
#define LABEL_40_9 17
#define LABEL_40_18 19
#define LABEL_40_17 21
#define LABEL_40_21 23
#define LABEL_40_22 25
#define LABEL_40_23 27
#define LABEL_40_24 29
#define LABEL_40_26 31
#define LABEL_40_12 33
#define LABEL_40_25 35
#define LABEL_40_29 37
#define LABEL_40_30 39
#define LABEL_40_31 41
#define ENVIRONMENT_LABEL_40_3 72
#define DEBUGGING_LABEL_40_2 71
#define OBJECT_40_8 70
#define OBJECT_40_7 69
#define OBJECT_40_6 68
#define OBJECT_40_5 67
#define OBJECT_40_4 66
#define OBJECT_40_3 65
#define OBJECT_40_2 64
#define OBJECT_40_1 63
#define OBJECT_40_0 62
#define EXECUTE_CACHE_40_28 43
#define EXECUTE_CACHE_40_27 45
#define EXECUTE_CACHE_40_20 47
#define EXECUTE_CACHE_40_19 49
#define EXECUTE_CACHE_40_14 51
#define EXECUTE_CACHE_40_10 53
#define EXECUTE_CACHE_40_8 55
#define EXECUTE_CACHE_40_6 57
#define FREE_REFERENCE_40_1 60
#define FREE_REFERENCE_40_0 61
#define FREE_REFERENCES_LABEL_40_0 42
#define NUMBER_OF_LINKER_SECTIONS_40_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd35;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd30;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto make_condition_23;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_40_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_40_11);
      goto continuation_5;

    case 4:
      current_block = (Rpc - LABEL_40_13);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_40_15);
      goto label_27;

    case 6:
      current_block = (Rpc - LABEL_40_16);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_40_9);
      goto continuation_2;

    case 8:
      current_block = (Rpc - LABEL_40_18);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_40_17);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_40_21);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_40_22);
      goto do_loop_19;

    case 12:
      current_block = (Rpc - LABEL_40_23);
      goto label_29;

    case 13:
      current_block = (Rpc - LABEL_40_24);
      goto label_30;

    case 14:
      current_block = (Rpc - LABEL_40_26);
      goto label_31;

    case 15:
      current_block = (Rpc - LABEL_40_12);
      goto continuation_6;

    case 16:
      current_block = (Rpc - LABEL_40_25);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_40_29);
      goto label_34;

    case 18:
      current_block = (Rpc - LABEL_40_30);
      goto label_32;

    case 19:
      current_block = (Rpc - LABEL_40_31);
      goto label_33;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_condition_36)
DEFLABEL (make_condition_23)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_40_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_40_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  if ((Wrd12.Obj) == (current_block [OBJECT_40_4]))
    goto label_46;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_20]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_40_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_42;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd38.Lng))))
    goto label_42;
  (Wrd30.Obj) = ((Wrd36.pObj) [4]);

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_40)
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_40_17);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 62))
    goto label_39;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_39;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_38)
  (Wrd21.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd21.Obj);
  goto do_loop_19;

DEFLABEL (label_39)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_40_5]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_21]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_3]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_42)
  (Wrd41.Obj) = (Rsp [4]);
  (Wrd42.Obj) = (current_block [OBJECT_40_2]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_15]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_3]), 2);

DEFLABEL (label_27)
  (Wrd30.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_43)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_12]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_40_1]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_45;
  Wrd51 = Wrd55;

DEFLABEL (label_44)
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd57.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_40_12);
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_28]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_40_16);
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (label_45)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_13])), (Wrd52.pObj));

DEFLABEL (label_28)
  (Wrd51.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_48;
  Wrd19 = Wrd23;

DEFLABEL (label_47)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);
  goto label_40;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_18])), (Wrd20.pObj));

DEFLABEL (label_25)
  (Wrd19.Obj) = Rvl;
  goto label_47;

DEFLABEL (do_loop_37)
DEFLABEL (do_loop_19)
  INTERRUPT_CHECK (26, LABEL_40_22);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_49;
  Rsp = (& (Rsp [2]));
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_49)
  if (! ((Wrd6.uLng) == 1))
    goto label_61;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_60)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_59;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_58)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_25]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_57;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_56)
  (Wrd39.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_27]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_40_25);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_55;
  (Wrd27.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd27.uLng) == 26))
    goto label_55;
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) (Wrd28.Lng)) < ((unsigned long) (Wrd32.Lng))))
    goto label_55;
  (Wrd23.uLng) = (OBJECT_DATUM (Rvl));
  (Wrd26.pObj) = (& ((Wrd30.pObj) [(Wrd23.Lng)]));
  ((Wrd26.pObj) [1]) = (Wrd5.Obj);

DEFLABEL (label_54)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_53;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_52)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_51;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_50)
  (Rsp [0]) = (Wrd16.Obj);
  goto do_loop_19;

DEFLABEL (label_51)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_31]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_6]), 1);

DEFLABEL (label_33)
  (Wrd16.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_30]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_6]), 1);

DEFLABEL (label_32)
  (Wrd7.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_29]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_8]), 3);

DEFLABEL (label_34)
  goto label_54;

DEFLABEL (label_57)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_26]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_7]), 1);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_7]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_23]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_6]), 1);

DEFLABEL (label_29)
  (Wrd10.Obj) = Rvl;
  goto label_60;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_9 9
#define LABEL_41_10 11
#define TAG_41_11 4
#define LABEL_41_13 13
#define TAG_41_14 5
#define LABEL_41_18 15
#define LABEL_41_20 17
#define LABEL_41_22 19
#define LABEL_41_23 21
#define LABEL_41_16 23
#define LABEL_41_25 25
#define LABEL_41_24 27
#define LABEL_41_29 29
#define LABEL_41_30 31
#define LABEL_41_31 33
#define LABEL_41_32 35
#define LABEL_41_33 37
#define LABEL_41_34 39
#define LABEL_41_35 41
#define LABEL_41_28 43
#define LABEL_41_19 45
#define LABEL_41_36 47
#define ENVIRONMENT_LABEL_41_3 84
#define DEBUGGING_LABEL_41_2 83
#define OBJECT_41_8 82
#define OBJECT_41_7 81
#define OBJECT_41_6 80
#define OBJECT_41_5 79
#define OBJECT_41_4 78
#define OBJECT_41_3 77
#define OBJECT_41_2 76
#define OBJECT_41_1 75
#define OBJECT_41_0 74
#define EXECUTE_CACHE_41_39 49
#define EXECUTE_CACHE_41_38 51
#define EXECUTE_CACHE_41_37 53
#define EXECUTE_CACHE_41_27 55
#define EXECUTE_CACHE_41_26 57
#define EXECUTE_CACHE_41_21 59
#define EXECUTE_CACHE_41_17 61
#define EXECUTE_CACHE_41_15 63
#define EXECUTE_CACHE_41_12 65
#define EXECUTE_CACHE_41_8 67
#define EXECUTE_CACHE_41_6 69
#define FREE_REFERENCE_41_1 72
#define FREE_REFERENCE_41_0 73
#define FREE_REFERENCES_LABEL_41_0 48
#define NUMBER_OF_LINKER_SECTIONS_41_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd55;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd32;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto condition_constructor_33;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_41_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_41_10);
      goto lambda_46;

    case 5:
      current_block = (Rpc - LABEL_41_13);
      goto lambda_47;

    case 6:
      current_block = (Rpc - LABEL_41_18);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_41_20);
      goto label_38;

    case 8:
      current_block = (Rpc - LABEL_41_22);
      goto label_37;

    case 9:
      current_block = (Rpc - LABEL_41_23);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_41_16);
      goto continuation_4;

    case 11:
      current_block = (Rpc - LABEL_41_25);
      goto label_35;

    case 12:
      current_block = (Rpc - LABEL_41_24);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_41_29);
      goto label_36;

    case 14:
      current_block = (Rpc - LABEL_41_30);
      goto do_loop_26;

    case 15:
      current_block = (Rpc - LABEL_41_31);
      goto label_39;

    case 16:
      current_block = (Rpc - LABEL_41_32);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_41_33);
      goto label_43;

    case 18:
      current_block = (Rpc - LABEL_41_34);
      goto label_41;

    case 19:
      current_block = (Rpc - LABEL_41_35);
      goto label_42;

    case 20:
      current_block = (Rpc - LABEL_41_28);
      goto continuation_11;

    case 21:
      current_block = (Rpc - LABEL_41_19);
      goto continuation_8;

    case 22:
      current_block = (Rpc - LABEL_41_36);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_constructor_45)
DEFLABEL (condition_constructor_33)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_41_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_41_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_41_10])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_41_9);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x3fc, 2);
  (* (Rhp++)) = (dispatch_base + TAG_41_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_41_13])));
  Rhp += 2;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  Wrd11 = Wrd13;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  Rvl = (Wrd14.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_46)
  CLOSURE_HEADER (LABEL_41_10);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_41_0]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_15]));

DEFLABEL (lambda_47)
  CLOSURE_HEADER (LABEL_41_13);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_41_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  if ((Wrd12.Obj) == (current_block [OBJECT_41_4]))
    goto label_57;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_18]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_27]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_41_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd41.Obj) = (Rsp [4]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 62))
    goto label_53;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd40.Lng))))
    goto label_53;
  (Wrd32.Obj) = ((Wrd38.pObj) [4]);

DEFLABEL (label_52)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_51)
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_26]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_41_24);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_50;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_50;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_49)
  (Wrd24.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto do_loop_26;

DEFLABEL (label_50)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_41_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_29]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (label_53)
  (Wrd43.Obj) = (Rsp [4]);
  (Wrd44.Obj) = (current_block [OBJECT_41_2]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_22]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_37)
  (Wrd32.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_54)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_19]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd52.Obj) = (current_block [OBJECT_41_1]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd54.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd57.Obj) = ((Wrd54.pObj) [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if ((Wrd58.uLng) == 50)
    goto label_56;
  Wrd53 = Wrd57;

DEFLABEL (label_55)
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd59.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_21]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_41_19);
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_38]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_41_23);
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_20])), (Wrd54.pObj));

DEFLABEL (label_38)
  (Wrd53.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_59;
  Wrd19 = Wrd23;

DEFLABEL (label_58)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);
  goto label_51;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_25])), (Wrd20.pObj));

DEFLABEL (label_35)
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_41_28);

DEFLABEL (label_60)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (do_loop_48)
DEFLABEL (do_loop_26)
  INTERRUPT_CHECK (26, LABEL_41_30);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_64;

DEFLABEL (label_63)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_62;

DEFLABEL (label_61)
  (Wrd14.Obj) = (Rsp [5]);
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_36]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_37]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_41_36);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd10.Lng) = ((Wrd7.Lng) + 2L);
  (Wrd6.Obj) = (LONG_TO_FIXNUM (Wrd10.Lng));
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (Wrd15.Obj) = (Rsp [8]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd19.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Rsp [2]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_39]));

DEFLABEL (label_62)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 1)
    goto label_61;
  Rsp = (& (Rsp [4]));
  goto label_60;

DEFLABEL (label_64)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_63;
  if (! ((Wrd22.uLng) == 1))
    goto label_74;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_73)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_72;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [0]);

DEFLABEL (label_71)
  (Wrd41.Obj) = (* (Rsp++));
  (Wrd70.Obj) = (Rsp [2]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 10))
    goto label_70;
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd64.uLng) == 26))
    goto label_70;
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
  if (! (((unsigned long) (Wrd65.Lng)) < ((unsigned long) (Wrd69.Lng))))
    goto label_70;
  (Wrd60.uLng) = (OBJECT_DATUM (Wrd32.Obj));
  (Wrd63.pObj) = (& ((Wrd67.pObj) [(Wrd60.Lng)]));
  ((Wrd63.pObj) [1]) = (Wrd41.Obj);

DEFLABEL (label_69)
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_68;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_67)
  (Rsp [0]) = (Wrd42.Obj);
  (Wrd54.Obj) = (Rsp [1]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_66;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd53.pObj) [1]);

DEFLABEL (label_65)
  (Rsp [1]) = (Wrd51.Obj);
  goto do_loop_26;

DEFLABEL (label_66)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_35]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_8]), 1);

DEFLABEL (label_42)
  (Wrd51.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_34]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_8]), 1);

DEFLABEL (label_41)
  (Wrd42.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd72.Obj) = (Rsp [2]);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_33]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_7]), 3);

DEFLABEL (label_43)
  goto label_69;

DEFLABEL (label_72)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_32]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_40)
  (Wrd32.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_31]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_73;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define LABEL_42_6 7
#define LABEL_42_9 9
#define LABEL_42_8 11
#define ENVIRONMENT_LABEL_42_3 27
#define DEBUGGING_LABEL_42_2 26
#define OBJECT_42_3 25
#define OBJECT_42_2 24
#define OBJECT_42_1 23
#define OBJECT_42_0 22
#define EXECUTE_CACHE_42_11 13
#define EXECUTE_CACHE_42_10 15
#define EXECUTE_CACHE_42_7 17
#define FREE_REFERENCE_42_1 20
#define FREE_REFERENCE_42_0 21
#define FREE_REFERENCES_LABEL_42_0 12
#define NUMBER_OF_LINKER_SECTIONS_42_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto Z__restarts_argument_3;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_42_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_42_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_42_8);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restarts_argument_8)
DEFLABEL (Z__restarts_argument_3)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == (current_block [OBJECT_42_0]))
    goto label_14;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_42_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  (Wrd7.Obj) = (current_block [OBJECT_42_2]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_10;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_10)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_9;
  Rvl = ((Wrd15.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_8]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_42_1]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_1]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_13;
  Wrd25 = Wrd29;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_42_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_11]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_9])), (Wrd26.pObj));

DEFLABEL (label_6)
  (Wrd25.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_14)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_16;
  Wrd12 = Wrd16;

DEFLABEL (label_15)
  Rvl = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_5])), (Wrd13.pObj));

DEFLABEL (label_5)
  (Wrd12.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_5 5
#define ENVIRONMENT_LABEL_43_3 13
#define DEBUGGING_LABEL_43_2 12
#define OBJECT_43_0 11
#define EXECUTE_CACHE_43_7 7
#define EXECUTE_CACHE_43_6 9
#define FREE_REFERENCES_LABEL_43_0 6
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto condition_of_typeP_1;

    case 1:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_of_typeP_4)
DEFLABEL (condition_of_typeP_1)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_43_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_43_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_7 7
#define TAG_44_8 2
#define ENVIRONMENT_LABEL_44_3 15
#define DEBUGGING_LABEL_44_2 14
#define OBJECT_44_0 13
#define EXECUTE_CACHE_44_9 9
#define EXECUTE_CACHE_44_6 11
#define FREE_REFERENCES_LABEL_44_0 8
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto condition_predicate_2;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto lambda_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_predicate_5)
DEFLABEL (condition_predicate_2)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_44_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_44_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_44_7])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_44_7);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define LABEL_45_7 7
#define LABEL_45_8 9
#define ENVIRONMENT_LABEL_45_3 19
#define DEBUGGING_LABEL_45_2 18
#define OBJECT_45_2 17
#define OBJECT_45_1 16
#define OBJECT_45_0 15
#define EXECUTE_CACHE_45_9 11
#define EXECUTE_CACHE_45_6 13
#define FREE_REFERENCES_LABEL_45_0 10
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto Z__condition_of_typeP_3;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_45_7);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_45_8);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_of_typeP_8)
DEFLABEL (Z__condition_of_typeP_3)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_45_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd23.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_10)
  (Wrd36.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd36.Obj);
  (Rsp [1]) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_9]));

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_45_2]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_8]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_6)
  (Wrd23.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_45_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_7 7
#define LABEL_46_9 9
#define LABEL_46_11 11
#define LABEL_46_13 13
#define TAG_46_14 5
#define LABEL_46_16 15
#define LABEL_46_15 17
#define LABEL_46_20 19
#define LABEL_46_17 21
#define LABEL_46_18 23
#define ENVIRONMENT_LABEL_46_3 45
#define DEBUGGING_LABEL_46_2 44
#define OBJECT_46_4 43
#define OBJECT_46_3 42
#define OBJECT_46_2 41
#define OBJECT_46_1 40
#define OBJECT_46_0 39
#define EXECUTE_CACHE_46_22 25
#define EXECUTE_CACHE_46_21 27
#define EXECUTE_CACHE_46_19 29
#define EXECUTE_CACHE_46_12 31
#define EXECUTE_CACHE_46_10 33
#define EXECUTE_CACHE_46_8 35
#define EXECUTE_CACHE_46_6 37
#define FREE_REFERENCES_LABEL_46_0 24
#define NUMBER_OF_LINKER_SECTIONS_46_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd43;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto condition_accessor_11;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_46_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_46_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_46_11);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_46_13);
      goto lambda_16;

    case 6:
      current_block = (Rpc - LABEL_46_16);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_46_15);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_46_20);
      goto label_13;

    case 9:
      current_block = (Rpc - LABEL_46_17);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_46_18);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_accessor_15)
DEFLABEL (condition_accessor_11)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_46_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_46_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_46_11);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_13])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  ((Wrd12.pObj) [4]) = Rvl;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_16)
  CLOSURE_HEADER (LABEL_46_13);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_46_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_21;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_16]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_17]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_18]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [2]);
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_19]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_46_18);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_46_4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_22]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_46_17);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_46_16);

DEFLABEL (label_21)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_20;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_20;
  (Wrd10.Obj) = ((Wrd16.pObj) [5]);

DEFLABEL (label_19)
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd26.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd26.Obj);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd43.uLng) == 10)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_18)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd35.uLng) == 26))
    goto label_17;
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) (Wrd37.Lng)) < ((unsigned long) (Wrd41.Lng))))
    goto label_17;
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd26.Obj));
  (Wrd32.pObj) = (& ((Wrd39.pObj) [(Wrd29.Lng)]));
  Rvl = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_46_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_20]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_2]), 2);

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define LABEL_47_8 7
#define LABEL_47_7 9
#define ENVIRONMENT_LABEL_47_3 19
#define DEBUGGING_LABEL_47_2 18
#define OBJECT_47_2 17
#define OBJECT_47_1 16
#define OBJECT_47_0 15
#define EXECUTE_CACHE_47_9 11
#define EXECUTE_CACHE_47_6 13
#define FREE_REFERENCES_LABEL_47_0 10
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto access_condition_3;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_47_8);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_47_7);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (access_condition_7)
DEFLABEL (access_condition_3)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_9;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_9;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_8)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_47_7);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_9)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_47_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_2]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define ENVIRONMENT_LABEL_48_3 13
#define DEBUGGING_LABEL_48_2 12
#define OBJECT_48_2 11
#define OBJECT_48_1 10
#define OBJECT_48_0 9
#define EXECUTE_CACHE_48_6 7
#define FREE_REFERENCES_LABEL_48_0 6
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto condition_type_1;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_4)
DEFLABEL (condition_type_1)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_48_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_48_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define ENVIRONMENT_LABEL_49_3 13
#define DEBUGGING_LABEL_49_2 12
#define OBJECT_49_2 11
#define OBJECT_49_1 10
#define OBJECT_49_0 9
#define EXECUTE_CACHE_49_6 7
#define FREE_REFERENCES_LABEL_49_0 6
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto condition_continuation_1;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_continuation_4)
DEFLABEL (condition_continuation_1)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_49_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define LABEL_50_7 7
#define ENVIRONMENT_LABEL_50_3 17
#define DEBUGGING_LABEL_50_2 16
#define OBJECT_50_2 15
#define OBJECT_50_1 14
#define OBJECT_50_0 13
#define EXECUTE_CACHE_50_8 9
#define EXECUTE_CACHE_50_6 11
#define FREE_REFERENCES_LABEL_50_0 8
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto condition_restarts_2;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_50_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_restarts_6)
DEFLABEL (condition_restarts_2)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_50_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_50_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [4]);

DEFLABEL (label_7)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_50_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define ENVIRONMENT_LABEL_51_3 13
#define DEBUGGING_LABEL_51_2 12
#define OBJECT_51_2 11
#define OBJECT_51_1 10
#define OBJECT_51_0 9
#define EXECUTE_CACHE_51_6 7
#define FREE_REFERENCES_LABEL_51_0 6
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto condition_properties_1;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_properties_4)
DEFLABEL (condition_properties_1)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_51_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_51_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_51_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define ENVIRONMENT_LABEL_52_3 12
#define DEBUGGING_LABEL_52_2 11
#define EXECUTE_CACHE_52_7 7
#define EXECUTE_CACHE_52_6 9
#define FREE_REFERENCES_LABEL_52_0 6
#define NUMBER_OF_LINKER_SECTIONS_52_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto condition_putB_1;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_putB_4)
DEFLABEL (condition_putB_1)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_5 5
#define ENVIRONMENT_LABEL_53_3 12
#define DEBUGGING_LABEL_53_2 11
#define EXECUTE_CACHE_53_7 7
#define EXECUTE_CACHE_53_6 9
#define FREE_REFERENCES_LABEL_53_0 6
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto condition_get_1;

    case 1:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_get_4)
DEFLABEL (condition_get_1)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_53_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_7 7
#define LABEL_54_9 9
#define LABEL_54_10 11
#define LABEL_54_12 13
#define LABEL_54_13 15
#define LABEL_54_14 17
#define LABEL_54_11 19
#define LABEL_54_16 21
#define TAG_54_17 9
#define ENVIRONMENT_LABEL_54_3 39
#define DEBUGGING_LABEL_54_2 38
#define OBJECT_54_4 37
#define OBJECT_54_3 36
#define OBJECT_54_2 35
#define OBJECT_54_1 34
#define OBJECT_54_0 33
#define EXECUTE_CACHE_54_18 23
#define EXECUTE_CACHE_54_15 25
#define EXECUTE_CACHE_54_8 27
#define EXECUTE_CACHE_54_6 29
#define FREE_REFERENCE_54_0 32
#define FREE_REFERENCES_LABEL_54_0 22
#define NUMBER_OF_LINKER_SECTIONS_54_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd66;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd54;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd60;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto write_condition_report_9;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_54_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_54_9);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_54_10);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_54_12);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_54_13);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_54_14);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_54_11);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_54_16);
      goto lambda_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_condition_report_17)
DEFLABEL (write_condition_report_9)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_54_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_54_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_54_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_54_7);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_29;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_29;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_28)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_27;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd27.Lng))))
    goto label_27;
  (Wrd22.Obj) = ((Wrd25.pObj) [6]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_26)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_11]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 62))
    goto label_25;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd45.Lng))))
    goto label_25;
  (Wrd37.Obj) = ((Wrd43.pObj) [2]);

DEFLABEL (label_24)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd60.uLng) == 62))
    goto label_23;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [0]);
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd59.Lng))))
    goto label_23;
  (Wrd54.Obj) = ((Wrd57.pObj) [3]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_22)
  (Wrd67.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_0]));
  (Wrd70.Obj) = ((Wrd67.pObj) [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 50)
    goto label_21;
  Wrd66 = Wrd70;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd66.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_15]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_54_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_54_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_54_16])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_18]));

DEFLABEL (label_19)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_14])), (Wrd67.pObj));

DEFLABEL (label_15)
  (Wrd66.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd62.Obj) = (current_block [OBJECT_54_4]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_13]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_2]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.Obj) = (current_block [OBJECT_54_1]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_12]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_2]), 2);

DEFLABEL (label_13)
  (Wrd37.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd30.Obj) = (current_block [OBJECT_54_3]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_2]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_54_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_2]), 2);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_28;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_54_16);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [2]) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define TAG_55_6 1
#define ENVIRONMENT_LABEL_55_3 12
#define DEBUGGING_LABEL_55_2 11
#define EXECUTE_CACHE_55_8 7
#define EXECUTE_CACHE_55_7 9
#define FREE_REFERENCES_LABEL_55_0 6
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto condition_report_string_1;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_report_string_4)
DEFLABEL (condition_report_string_1)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_55_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_55_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_55_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_8]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define ENVIRONMENT_LABEL_56_3 5
#define DEBUGGING_LABEL_56_2 4
#define FREE_REFERENCES_LABEL_56_0 4
#define NUMBER_OF_LINKER_SECTIONS_56_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_56_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define ENVIRONMENT_LABEL_57_3 5
#define DEBUGGING_LABEL_57_2 4
#define FREE_REFERENCES_LABEL_57_0 4
#define NUMBER_OF_LINKER_SECTIONS_57_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_57_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define ENVIRONMENT_LABEL_58_3 5
#define DEBUGGING_LABEL_58_2 4
#define FREE_REFERENCES_LABEL_58_0 4
#define NUMBER_OF_LINKER_SECTIONS_58_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_58_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define ENVIRONMENT_LABEL_59_3 5
#define DEBUGGING_LABEL_59_2 4
#define FREE_REFERENCES_LABEL_59_0 4
#define NUMBER_OF_LINKER_SECTIONS_59_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_59_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define ENVIRONMENT_LABEL_60_3 8
#define DEBUGGING_LABEL_60_2 7
#define EXECUTE_CACHE_60_5 5
#define FREE_REFERENCES_LABEL_60_0 4
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_60_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define LABEL_61_7 7
#define ENVIRONMENT_LABEL_61_3 20
#define DEBUGGING_LABEL_61_2 19
#define OBJECT_61_3 18
#define OBJECT_61_2 17
#define OBJECT_61_1 16
#define OBJECT_61_0 15
#define EXECUTE_CACHE_61_9 9
#define EXECUTE_CACHE_61_8 11
#define EXECUTE_CACHE_61_6 13
#define FREE_REFERENCES_LABEL_61_0 8
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_61_7);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_61_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_61_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_10;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_10;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_9)
  (Wrd21.Obj) = (Rsp [0]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_8;
  (Rsp [1]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_9]));

DEFLABEL (label_8)
  (Wrd25.Obj) = (current_block [OBJECT_61_3]);
  (Rsp [1]) = (Wrd25.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_8]));

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_61_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_61_2]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define ENVIRONMENT_LABEL_62_3 7
#define DEBUGGING_LABEL_62_2 6
#define OBJECT_62_1 5
#define OBJECT_62_0 4
#define FREE_REFERENCES_LABEL_62_0 4
#define NUMBER_OF_LINKER_SECTIONS_62_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto Z__restart_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restart_name_3)
DEFLABEL (Z__restart_name_0)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define ENVIRONMENT_LABEL_63_3 7
#define DEBUGGING_LABEL_63_2 6
#define OBJECT_63_1 5
#define OBJECT_63_0 4
#define FREE_REFERENCES_LABEL_63_0 4
#define NUMBER_OF_LINKER_SECTIONS_63_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto Z__restart_reporter_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restart_reporter_3)
DEFLABEL (Z__restart_reporter_0)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_63_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define ENVIRONMENT_LABEL_64_3 7
#define DEBUGGING_LABEL_64_2 6
#define OBJECT_64_1 5
#define OBJECT_64_0 4
#define FREE_REFERENCES_LABEL_64_0 4
#define NUMBER_OF_LINKER_SECTIONS_64_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto Z__restart_effector_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restart_effector_3)
DEFLABEL (Z__restart_effector_0)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_64_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define ENVIRONMENT_LABEL_65_3 7
#define DEBUGGING_LABEL_65_2 6
#define OBJECT_65_1 5
#define OBJECT_65_0 4
#define FREE_REFERENCES_LABEL_65_0 4
#define NUMBER_OF_LINKER_SECTIONS_65_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto Z__restart_interactor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restart_interactor_3)
DEFLABEL (Z__restart_interactor_0)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_65_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define ENVIRONMENT_LABEL_66_3 7
#define DEBUGGING_LABEL_66_2 6
#define OBJECT_66_1 5
#define OBJECT_66_0 4
#define FREE_REFERENCES_LABEL_66_0 4
#define NUMBER_OF_LINKER_SECTIONS_66_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto Z__restart_properties_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__restart_properties_3)
DEFLABEL (Z__restart_properties_0)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_66_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define ENVIRONMENT_LABEL_67_3 8
#define DEBUGGING_LABEL_67_2 7
#define OBJECT_67_2 6
#define OBJECT_67_1 5
#define OBJECT_67_0 4
#define FREE_REFERENCES_LABEL_67_0 4
#define NUMBER_OF_LINKER_SECTIONS_67_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto set__restart_interactorB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__restart_interactorB_3)
DEFLABEL (set__restart_interactorB_0)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_67_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_67_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define LABEL_68_5 5
#define ENVIRONMENT_LABEL_68_3 13
#define DEBUGGING_LABEL_68_2 12
#define OBJECT_68_0 11
#define EXECUTE_CACHE_68_7 7
#define EXECUTE_CACHE_68_6 9
#define FREE_REFERENCES_LABEL_68_0 6
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto guarantee_restart_1;

    case 1:
      current_block = (Rpc - LABEL_68_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_restart_4)
DEFLABEL (guarantee_restart_1)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_68_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_68_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_4 3
#define ENVIRONMENT_LABEL_69_3 11
#define DEBUGGING_LABEL_69_2 10
#define OBJECT_69_2 9
#define OBJECT_69_1 8
#define OBJECT_69_0 7
#define EXECUTE_CACHE_69_5 5
#define FREE_REFERENCES_LABEL_69_0 4
#define NUMBER_OF_LINKER_SECTIONS_69_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_4);
      goto error_not_restart_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_restart_5)
DEFLABEL (error_not_restart_2)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_69_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_69_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_69_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_5 5
#define ENVIRONMENT_LABEL_70_3 13
#define DEBUGGING_LABEL_70_2 12
#define OBJECT_70_0 11
#define EXECUTE_CACHE_70_6 7
#define FREE_REFERENCE_70_0 10
#define FREE_REFERENCES_LABEL_70_0 6
#define NUMBER_OF_LINKER_SECTIONS_70_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto guarantee_restarts_0;

    case 1:
      current_block = (Rpc - LABEL_70_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_restarts_4)
DEFLABEL (guarantee_restarts_0)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_70_0]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_5 3
#define LABEL_71_6 5
#define LABEL_71_8 7
#define LABEL_71_4 9
#define LABEL_71_13 11
#define LABEL_71_14 13
#define LABEL_71_15 15
#define LABEL_71_9 17
#define LABEL_71_16 19
#define LABEL_71_17 21
#define LABEL_71_19 23
#define TAG_71_20 10
#define LABEL_71_26 25
#define LABEL_71_27 27
#define LABEL_71_21 29
#define TAG_71_22 13
#define LABEL_71_23 31
#define TAG_71_24 14
#define LABEL_71_28 33
#define LABEL_71_29 35
#define ENVIRONMENT_LABEL_71_3 60
#define DEBUGGING_LABEL_71_2 59
#define OBJECT_71_5 58
#define OBJECT_71_4 57
#define OBJECT_71_3 56
#define OBJECT_71_2 55
#define OBJECT_71_1 54
#define OBJECT_71_0 53
#define EXECUTE_CACHE_71_25 37
#define EXECUTE_CACHE_71_18 39
#define EXECUTE_CACHE_71_12 41
#define EXECUTE_CACHE_71_11 43
#define EXECUTE_CACHE_71_10 45
#define EXECUTE_CACHE_71_7 47
#define FREE_REFERENCE_71_0 50
#define FREE_ASSIGNMENT_71_0 52
#define FREE_REFERENCES_LABEL_71_0 36
#define NUMBER_OF_LINKER_SECTIONS_71_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd6;
  machine_word Wrd32;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_71_6);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_71_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_71_4);
      goto with_restart_26;

    case 4:
      current_block = (Rpc - LABEL_71_13);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_71_14);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_71_15);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_71_9);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_71_16);
      goto label_28;

    case 9:
      current_block = (Rpc - LABEL_71_17);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_71_19);
      goto lambda_35;

    case 11:
      current_block = (Rpc - LABEL_71_26);
      goto label_29;

    case 12:
      current_block = (Rpc - LABEL_71_27);
      goto label_30;

    case 13:
      current_block = (Rpc - LABEL_71_21);
      goto lambda_36;

    case 14:
      current_block = (Rpc - LABEL_71_23);
      goto lambda_37;

    case 15:
      current_block = (Rpc - LABEL_71_28);
      goto label_31;

    case 16:
      current_block = (Rpc - LABEL_71_29);
      goto label_32;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (with_restart_34)
DEFLABEL (with_restart_26)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_44;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_12]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_71_8);

DEFLABEL (label_44)
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 30)
    goto label_42;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_71_2]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_71_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;

DEFLABEL (label_42)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_9]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_71_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_41;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_14]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_71_4]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_71_14);

DEFLABEL (label_41)
  (Wrd7.Obj) = (Rsp [3]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_71_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_40;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_13]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_71_3]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_71_13);

DEFLABEL (label_40)
  (Wrd18.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd14.pObj) = (& (Rhp [-1]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_39;
  Wrd19 = Wrd23;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_17]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_71_17);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd31.pObj) = (& (Rhp [-1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd31.pObj)));
  (Rsp [0]) = (Wrd32.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_71_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_71_19])));
  Rhp += 2;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd15 = Wrd12;
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd15.pObj) [2]) = (Wrd16.Obj);
  ((Wrd15.pObj) [3]) = (Wrd32.Obj);
  (Rsp [4]) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_71_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_71_21])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd20 = Wrd19;
  (Wrd21.Obj) = (Rsp [6]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (Rsp [5]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_71_24);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_71_23])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd27 = Wrd24;
  ((Wrd27.pObj) [2]) = (Wrd16.Obj);
  ((Wrd27.pObj) [3]) = (Wrd32.Obj);
  (Rsp [6]) = (Wrd23.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_25]));

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_16])), (Wrd20.pObj));

DEFLABEL (label_28)
  (Wrd19.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_43)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_5]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_71_1]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_71_5);
  goto label_42;

DEFLABEL (lambda_35)
  CLOSURE_HEADER (LABEL_71_19);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_50;

DEFLABEL (label_49)
  Wrd19 = Wrd23;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_71_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_47;

DEFLABEL (label_46)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_45)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_71_5]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_47)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_46;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_71_27])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_30)
  goto label_45;

DEFLABEL (label_50)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_49;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_71_26])), (Wrd20.pObj));

DEFLABEL (label_29)
  (Wrd19.Obj) = Rvl;
  goto label_48;

DEFLABEL (lambda_36)
  CLOSURE_HEADER (LABEL_71_21);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_37)
  CLOSURE_HEADER (LABEL_71_23);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_56;

DEFLABEL (label_55)
  Wrd19 = Wrd23;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_71_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_53;

DEFLABEL (label_52)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_51)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_71_5]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_53)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_52;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_71_29])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_32)
  goto label_51;

DEFLABEL (label_56)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_55;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_71_28])), (Wrd20.pObj));

DEFLABEL (label_31)
  (Wrd19.Obj) = Rvl;
  goto label_54;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define TAG_72_6 1
#define LABEL_72_10 7
#define LABEL_72_8 9
#define TAG_72_9 3
#define ENVIRONMENT_LABEL_72_3 19
#define DEBUGGING_LABEL_72_2 18
#define OBJECT_72_0 17
#define EXECUTE_CACHE_72_11 11
#define EXECUTE_CACHE_72_7 13
#define FREE_REFERENCE_72_0 16
#define FREE_REFERENCES_LABEL_72_0 10
#define NUMBER_OF_LINKER_SECTIONS_72_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto with_simple_restart_2;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_72_10);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_72_8);
      goto lambda_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (with_simple_restart_6)
DEFLABEL (with_simple_restart_2)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_72_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_8])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = ((Wrd10.pObj) [2]);
  (Rsp [4]) = (Wrd15.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_72_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_10;
  Wrd19 = Wrd23;

DEFLABEL (label_9)
  (Rsp [3]) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_11]));

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_72_10])), (Wrd20.pObj));

DEFLABEL (label_4)
  (Wrd19.Obj) = Rvl;
  goto label_9;

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_72_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_72_0]);
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_5 5
#define ENVIRONMENT_LABEL_73_3 13
#define DEBUGGING_LABEL_73_2 12
#define OBJECT_73_2 11
#define OBJECT_73_1 10
#define OBJECT_73_0 9
#define EXECUTE_CACHE_73_6 7
#define FREE_REFERENCES_LABEL_73_0 6
#define NUMBER_OF_LINKER_SECTIONS_73_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto restart_name_1;

    case 1:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_name_4)
DEFLABEL (restart_name_1)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_73_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_73_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_5 5
#define LABEL_74_7 7
#define LABEL_74_9 9
#define ENVIRONMENT_LABEL_74_3 21
#define DEBUGGING_LABEL_74_2 20
#define OBJECT_74_2 19
#define OBJECT_74_1 18
#define OBJECT_74_0 17
#define EXECUTE_CACHE_74_10 11
#define EXECUTE_CACHE_74_8 13
#define EXECUTE_CACHE_74_6 15
#define FREE_REFERENCES_LABEL_74_0 10
#define NUMBER_OF_LINKER_SECTIONS_74_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto write_restart_report_5;

    case 1:
      current_block = (Rpc - LABEL_74_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_74_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_74_9);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_restart_report_9)
DEFLABEL (write_restart_report_5)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_74_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_74_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_74_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_74_7);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_12;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_12;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_11)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 30)
    goto label_10;
  (Rsp [1]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_10]));

DEFLABEL (label_12)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_74_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define LABEL_75_5 5
#define ENVIRONMENT_LABEL_75_3 13
#define DEBUGGING_LABEL_75_2 12
#define OBJECT_75_2 11
#define OBJECT_75_1 10
#define OBJECT_75_0 9
#define EXECUTE_CACHE_75_6 7
#define FREE_REFERENCES_LABEL_75_0 6
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto restart_effector_1;

    case 1:
      current_block = (Rpc - LABEL_75_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_effector_4)
DEFLABEL (restart_effector_1)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_75_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_75_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_75_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define LABEL_76_5 5
#define ENVIRONMENT_LABEL_76_3 13
#define DEBUGGING_LABEL_76_2 12
#define OBJECT_76_2 11
#define OBJECT_76_1 10
#define OBJECT_76_0 9
#define EXECUTE_CACHE_76_6 7
#define FREE_REFERENCES_LABEL_76_0 6
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto restart_interactor_1;

    case 1:
      current_block = (Rpc - LABEL_76_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_interactor_4)
DEFLABEL (restart_interactor_1)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_76_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_76_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_76_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define LABEL_77_5 5
#define ENVIRONMENT_LABEL_77_3 13
#define DEBUGGING_LABEL_77_2 12
#define OBJECT_77_2 11
#define OBJECT_77_1 10
#define OBJECT_77_0 9
#define EXECUTE_CACHE_77_6 7
#define FREE_REFERENCES_LABEL_77_0 6
#define NUMBER_OF_LINKER_SECTIONS_77_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto restart_properties_1;

    case 1:
      current_block = (Rpc - LABEL_77_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_properties_4)
DEFLABEL (restart_properties_1)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_77_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_77_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_77_1]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_77_2]), 2);

DEFLABEL (label_6)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_5;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_6 5
#define ENVIRONMENT_LABEL_78_3 15
#define DEBUGGING_LABEL_78_2 14
#define OBJECT_78_0 13
#define EXECUTE_CACHE_78_8 7
#define EXECUTE_CACHE_78_7 9
#define EXECUTE_CACHE_78_5 11
#define FREE_REFERENCES_LABEL_78_0 6
#define NUMBER_OF_LINKER_SECTIONS_78_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto restart_get_2;

    case 1:
      current_block = (Rpc - LABEL_78_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_get_5)
DEFLABEL (restart_get_2)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_78_0])))
    goto label_6;
  (Wrd11.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_5]));

DEFLABEL (label_6)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_78_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_8]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define LABEL_79_5 5
#define ENVIRONMENT_LABEL_79_3 16
#define DEBUGGING_LABEL_79_2 15
#define OBJECT_79_3 14
#define OBJECT_79_2 13
#define OBJECT_79_1 12
#define OBJECT_79_0 11
#define EXECUTE_CACHE_79_7 7
#define EXECUTE_CACHE_79_6 9
#define FREE_REFERENCES_LABEL_79_0 6
#define NUMBER_OF_LINKER_SECTIONS_79_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto restart_putB_2;

    case 1:
      current_block = (Rpc - LABEL_79_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restart_putB_5)
DEFLABEL (restart_putB_2)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_79_0]))
    goto label_6;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_79_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_7]));

DEFLABEL (label_6)
  (Wrd11.Obj) = (current_block [OBJECT_79_1]);
  (Rsp [1]) = (Wrd11.Obj);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 62)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_3]), 3);

DEFLABEL (label_8)
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd22.Lng))))
    goto label_7;
  (Wrd15.Obj) = (Rsp [2]);
  ((Wrd20.pObj) [5]) = (Wrd15.Obj);
  Rvl = (current_block [OBJECT_79_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define LABEL_80_5 5
#define TAG_80_6 1
#define LABEL_80_8 7
#define LABEL_80_9 9
#define ENVIRONMENT_LABEL_80_3 17
#define DEBUGGING_LABEL_80_2 16
#define OBJECT_80_0 15
#define EXECUTE_CACHE_80_7 11
#define FREE_REFERENCE_80_0 14
#define FREE_REFERENCES_LABEL_80_0 10
#define NUMBER_OF_LINKER_SECTIONS_80_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto bind_restart_2;

    case 1:
      current_block = (Rpc - LABEL_80_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_80_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_80_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_restart_7)
DEFLABEL (bind_restart_2)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_80_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_80_5])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [4]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Rsp [4]) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd12.Obj);
  (Rsp [3]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_80_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_80_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_12;
  Wrd9 = Wrd13;

DEFLABEL (label_11)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd15.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_9)
  (Rsp [1]) = (Wrd15.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_10)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_9]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_0]), 1);

DEFLABEL (label_5)
  (Wrd15.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_80_8])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define LABEL_81_5 5
#define LABEL_81_7 7
#define ENVIRONMENT_LABEL_81_3 17
#define DEBUGGING_LABEL_81_2 16
#define OBJECT_81_2 15
#define OBJECT_81_1 14
#define OBJECT_81_0 13
#define EXECUTE_CACHE_81_8 9
#define EXECUTE_CACHE_81_6 11
#define FREE_REFERENCES_LABEL_81_0 8
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto invoke_restart_2;

    case 1:
      current_block = (Rpc - LABEL_81_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_81_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (invoke_restart_6)
DEFLABEL (invoke_restart_2)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_81_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_81_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [4]);

DEFLABEL (label_7)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_81_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_7 5
#define LABEL_82_8 7
#define LABEL_82_5 9
#define LABEL_82_9 11
#define LABEL_82_10 13
#define LABEL_82_17 15
#define LABEL_82_18 17
#define LABEL_82_12 19
#define LABEL_82_13 21
#define TAG_82_14 9
#define ENVIRONMENT_LABEL_82_3 44
#define DEBUGGING_LABEL_82_2 43
#define OBJECT_82_7 42
#define OBJECT_82_6 41
#define OBJECT_82_5 40
#define OBJECT_82_4 39
#define OBJECT_82_3 38
#define OBJECT_82_2 37
#define OBJECT_82_1 36
#define OBJECT_82_0 35
#define EXECUTE_CACHE_82_19 23
#define EXECUTE_CACHE_82_16 25
#define EXECUTE_CACHE_82_15 27
#define EXECUTE_CACHE_82_11 29
#define EXECUTE_CACHE_82_6 31
#define FREE_REFERENCE_82_0 34
#define FREE_REFERENCES_LABEL_82_0 22
#define NUMBER_OF_LINKER_SECTIONS_82_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd44;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd64;
  machine_word Wrd65;
  machine_word Wrd63;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd48;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd47;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto invoke_restart_interactively_13;

    case 1:
      current_block = (Rpc - LABEL_82_7);
      goto continuation_8;

    case 2:
      current_block = (Rpc - LABEL_82_8);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_82_9);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_82_10);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_82_17);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_82_18);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_82_12);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_82_13);
      goto lambda_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (invoke_restart_interactively_19)
DEFLABEL (invoke_restart_interactively_13)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_82_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_34;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_34;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_33)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_32;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd32.Lng))))
    goto label_32;
  (Wrd26.Obj) = ((Wrd30.pObj) [5]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_31)
  (Wrd40.Obj) = (Rsp [0]);
  if ((Wrd40.Obj) == ((SCHEME_OBJECT) 0))
    goto label_23;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_17]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_82_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_82_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_22;
  Wrd6 = Wrd10;

DEFLABEL (label_21)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_82_18])), (Wrd7.pObj));

DEFLABEL (label_17)
  (Wrd6.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  (Wrd47.Obj) = (current_block [OBJECT_82_4]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_30)
  (Rsp [1]) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [2]);
  if ((Wrd48.Obj) == (current_block [OBJECT_82_5]))
    goto label_25;
  Wrd50 = Wrd48;
  goto label_24;

DEFLABEL (label_25)
  (Wrd50.Obj) = (current_block [OBJECT_82_6]);

DEFLABEL (label_24)
DEFLABEL (label_29)
  (Rsp [2]) = (Wrd50.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd53.Obj);
  if ((Wrd50.Obj) == ((SCHEME_OBJECT) 0))
    goto label_28;
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_82_7);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_27)
  (Wrd59.Obj) = (Rsp [0]);
  if (! ((Wrd59.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_26;
  (Wrd72.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd72.Obj);
  (Wrd73.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd73.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_11]));

DEFLABEL (label_26)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_12]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd65.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_82_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_82_13])));
  Rhp += 2;
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd65.pObj)));
  Wrd68 = Wrd65;
  (Wrd69.Obj) = (Rsp [3]);
  ((Wrd68.pObj) [2]) = (Wrd69.Obj);
  (Wrd67.Obj) = (Rsp [2]);
  ((Wrd68.pObj) [3]) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd70.Obj) = (current_block [OBJECT_82_7]);
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_15]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_82_12);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_19]));

DEFLABEL (label_28)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_27;

DEFLABEL (label_32)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_82_3]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_10]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_2]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_82_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_2]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_82_8);
  (Wrd47.Obj) = Rvl;
  goto label_30;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_82_13);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_11]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define LABEL_83_5 5
#define LABEL_83_7 7
#define LABEL_83_9 9
#define ENVIRONMENT_LABEL_83_3 19
#define DEBUGGING_LABEL_83_2 18
#define OBJECT_83_0 17
#define EXECUTE_CACHE_83_10 11
#define EXECUTE_CACHE_83_8 13
#define EXECUTE_CACHE_83_6 15
#define FREE_REFERENCES_LABEL_83_0 10
#define NUMBER_OF_LINKER_SECTIONS_83_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto condition_other_thread_5;

    case 1:
      current_block = (Rpc - LABEL_83_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_83_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_83_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_other_thread_8)
DEFLABEL (condition_other_thread_5)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_83_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_83_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_83_7);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_83_9);
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == Rvl)
    goto label_11;
  Rvl = (Wrd6.Obj);
  goto label_10;

DEFLABEL (label_11)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_10)
DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define LABEL_84_5 5
#define LABEL_84_7 7
#define LABEL_84_9 9
#define LABEL_84_8 11
#define LABEL_84_12 13
#define LABEL_84_14 15
#define LABEL_84_11 17
#define LABEL_84_15 19
#define LABEL_84_17 21
#define ENVIRONMENT_LABEL_84_3 37
#define DEBUGGING_LABEL_84_2 36
#define OBJECT_84_4 35
#define OBJECT_84_3 34
#define OBJECT_84_2 33
#define OBJECT_84_1 32
#define OBJECT_84_0 31
#define EXECUTE_CACHE_84_16 23
#define EXECUTE_CACHE_84_13 25
#define EXECUTE_CACHE_84_10 27
#define EXECUTE_CACHE_84_6 29
#define FREE_REFERENCES_LABEL_84_0 22
#define NUMBER_OF_LINKER_SECTIONS_84_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto continue_from_derived_thread_error_14;

    case 1:
      current_block = (Rpc - LABEL_84_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_84_7);
      goto loop_12;

    case 3:
      current_block = (Rpc - LABEL_84_9);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_84_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_84_12);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_84_14);
      goto label_17;

    case 7:
      current_block = (Rpc - LABEL_84_11);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_84_15);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_84_17);
      goto label_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (continue_from_derived_thread_error_22)
DEFLABEL (continue_from_derived_thread_error_14)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_84_5);
  (* (--Rsp)) = Rvl;
  goto loop_12;

DEFLABEL (loop_23)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_84_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  Rvl = (current_block [OBJECT_84_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_36;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_35)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_84_8);
  if (Rvl == (current_block [OBJECT_84_2]))
    goto label_27;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_26;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_26)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_14]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_4]), 1);

DEFLABEL (label_17)
  (Wrd7.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_27)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_11]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_34;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_33)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_13]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_84_11);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd6.Obj) == Rvl)
    goto label_30;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_29;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_29)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_17]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_4]), 1);

DEFLABEL (label_19)
  (Wrd7.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_32;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_31)
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_16]));

DEFLABEL (label_32)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_15]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_20)
  (Wrd16.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_12]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define LABEL_85_5 5
#define LABEL_85_6 7
#define LABEL_85_8 9
#define LABEL_85_7 11
#define LABEL_85_9 13
#define ENVIRONMENT_LABEL_85_3 20
#define DEBUGGING_LABEL_85_2 19
#define OBJECT_85_2 18
#define OBJECT_85_1 17
#define OBJECT_85_0 16
#define FREE_REFERENCE_85_0 15
#define FREE_REFERENCES_LABEL_85_0 14
#define NUMBER_OF_LINKER_SECTIONS_85_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto bound_restarts_7;

    case 1:
      current_block = (Rpc - LABEL_85_5);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_85_6);
      goto loop_5;

    case 3:
      current_block = (Rpc - LABEL_85_8);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_85_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_85_9);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bound_restarts_13)
DEFLABEL (bound_restarts_7)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_85_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_16;
  Wrd5 = Wrd9;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_5;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_85_5])), (Wrd6.pObj));

DEFLABEL (label_9)
  (Wrd5.Obj) = Rvl;
  goto label_15;

DEFLABEL (loop_14)
DEFLABEL (loop_5)
  INTERRUPT_CHECK (26, LABEL_85_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_17;
  Rvl = (current_block [OBJECT_85_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_21;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_20)
  goto loop_5;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_85_7);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_19;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_18)
  (Wrd14.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_2]), 1);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_0]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_5 3
#define LABEL_86_4 5
#define LABEL_86_6 7
#define ENVIRONMENT_LABEL_86_3 15
#define DEBUGGING_LABEL_86_2 14
#define OBJECT_86_0 13
#define EXECUTE_CACHE_86_7 9
#define FREE_REFERENCE_86_0 12
#define FREE_REFERENCES_LABEL_86_0 8
#define NUMBER_OF_LINKER_SECTIONS_86_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_86_4);
      goto first_bound_restart_3;

    case 2:
      current_block = (Rpc - LABEL_86_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (first_bound_restart_7)
DEFLABEL (first_bound_restart_3)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_86_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd12.uLng) == 1)
    goto label_9;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_86_5);

DEFLABEL (label_9)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_8;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_0]), 1);

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_86_6])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define LABEL_87_5 5
#define LABEL_87_6 7
#define LABEL_87_7 9
#define LABEL_87_8 11
#define ENVIRONMENT_LABEL_87_3 17
#define DEBUGGING_LABEL_87_2 16
#define OBJECT_87_3 15
#define OBJECT_87_2 14
#define OBJECT_87_1 13
#define OBJECT_87_0 12
#define FREE_REFERENCES_LABEL_87_0 12
#define NUMBER_OF_LINKER_SECTIONS_87_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto Z__find_restart_8;

    case 1:
      current_block = (Rpc - LABEL_87_5);
      goto loop_6;

    case 2:
      current_block = (Rpc - LABEL_87_6);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_87_7);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_87_8);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__find_restart_14)
DEFLABEL (Z__find_restart_8)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_6;

DEFLABEL (loop_15)
DEFLABEL (loop_6)
  INTERRUPT_CHECK (26, LABEL_87_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_16)
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_23)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_22;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd24.Lng))))
    goto label_22;
  (Wrd18.Obj) = ((Wrd22.pObj) [2]);

DEFLABEL (label_21)
  (Wrd31.Obj) = (Rsp [1]);
  if ((Wrd31.Obj) == (Wrd18.Obj))
    goto label_19;
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_18;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_17)
  (Rsp [0]) = (Wrd32.Obj);
  goto loop_6;

DEFLABEL (label_18)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_8]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_3]), 1);

DEFLABEL (label_12)
  (Wrd32.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  (Wrd41.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd41.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_20;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  Rvl = ((Wrd44.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_20)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_22)
  (Wrd27.Obj) = (current_block [OBJECT_87_1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_7]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_2]), 2);

DEFLABEL (label_11)
  (Wrd18.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_10)
  (Wrd9.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define LABEL_88_5 5
#define LABEL_88_7 7
#define ENVIRONMENT_LABEL_88_3 17
#define DEBUGGING_LABEL_88_2 16
#define OBJECT_88_0 15
#define EXECUTE_CACHE_88_9 9
#define EXECUTE_CACHE_88_8 11
#define EXECUTE_CACHE_88_6 13
#define FREE_REFERENCES_LABEL_88_0 8
#define NUMBER_OF_LINKER_SECTIONS_88_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto find_restart_2;

    case 1:
      current_block = (Rpc - LABEL_88_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_88_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_restart_5)
DEFLABEL (find_restart_2)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_88_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_88_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_88_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_88_7);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define LABEL_89_8 5
#define LABEL_89_5 7
#define LABEL_89_10 9
#define LABEL_89_6 11
#define ENVIRONMENT_LABEL_89_3 23
#define DEBUGGING_LABEL_89_2 22
#define OBJECT_89_2 21
#define OBJECT_89_1 20
#define OBJECT_89_0 19
#define EXECUTE_CACHE_89_11 13
#define EXECUTE_CACHE_89_9 15
#define EXECUTE_CACHE_89_7 17
#define FREE_REFERENCES_LABEL_89_0 12
#define NUMBER_OF_LINKER_SECTIONS_89_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto abort_5;

    case 1:
      current_block = (Rpc - LABEL_89_8);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_89_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_89_10);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_89_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (abort_9)
DEFLABEL (abort_5)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_89_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_89_5);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_8]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_89_8);

DEFLABEL (label_12)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_89_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_2]), 2);

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_4 3
#define LABEL_90_5 5
#define LABEL_90_8 7
#define LABEL_90_6 9
#define ENVIRONMENT_LABEL_90_3 20
#define DEBUGGING_LABEL_90_2 19
#define OBJECT_90_3 18
#define OBJECT_90_2 17
#define OBJECT_90_1 16
#define OBJECT_90_0 15
#define EXECUTE_CACHE_90_9 11
#define EXECUTE_CACHE_90_7 13
#define FREE_REFERENCES_LABEL_90_0 10
#define NUMBER_OF_LINKER_SECTIONS_90_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_4);
      goto continue_4;

    case 1:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_90_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_90_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (continue_8)
DEFLABEL (continue_4)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_90_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_90_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_90_5);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = (current_block [OBJECT_90_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_90_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_3]), 2);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define LABEL_91_8 5
#define LABEL_91_5 7
#define LABEL_91_10 9
#define LABEL_91_6 11
#define ENVIRONMENT_LABEL_91_3 23
#define DEBUGGING_LABEL_91_2 22
#define OBJECT_91_2 21
#define OBJECT_91_1 20
#define OBJECT_91_0 19
#define EXECUTE_CACHE_91_11 13
#define EXECUTE_CACHE_91_9 15
#define EXECUTE_CACHE_91_7 17
#define FREE_REFERENCES_LABEL_91_0 12
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto muffle_warning_5;

    case 1:
      current_block = (Rpc - LABEL_91_8);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_91_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_91_10);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_91_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (muffle_warning_9)
DEFLABEL (muffle_warning_5)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_91_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_91_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_91_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_91_5);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_8]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_91_0]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_91_8);

DEFLABEL (label_12)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_91_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_2]), 2);

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_5 5
#define LABEL_92_8 7
#define LABEL_92_6 9
#define ENVIRONMENT_LABEL_92_3 20
#define DEBUGGING_LABEL_92_2 19
#define OBJECT_92_3 18
#define OBJECT_92_2 17
#define OBJECT_92_1 16
#define OBJECT_92_0 15
#define EXECUTE_CACHE_92_9 11
#define EXECUTE_CACHE_92_7 13
#define FREE_REFERENCES_LABEL_92_0 10
#define NUMBER_OF_LINKER_SECTIONS_92_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto retry_4;

    case 1:
      current_block = (Rpc - LABEL_92_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_92_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_92_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (retry_8)
DEFLABEL (retry_4)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_92_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_92_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_92_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_92_5);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = (current_block [OBJECT_92_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_92_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_3]), 2);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_5 5
#define LABEL_93_8 7
#define LABEL_93_6 9
#define ENVIRONMENT_LABEL_93_3 20
#define DEBUGGING_LABEL_93_2 19
#define OBJECT_93_3 18
#define OBJECT_93_2 17
#define OBJECT_93_1 16
#define OBJECT_93_0 15
#define EXECUTE_CACHE_93_9 11
#define EXECUTE_CACHE_93_7 13
#define FREE_REFERENCES_LABEL_93_0 10
#define NUMBER_OF_LINKER_SECTIONS_93_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto store_value_4;

    case 1:
      current_block = (Rpc - LABEL_93_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_93_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_93_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (store_value_8)
DEFLABEL (store_value_4)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_93_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_93_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_93_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_93_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = (current_block [OBJECT_93_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_93_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_3]), 2);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_5 5
#define LABEL_94_8 7
#define LABEL_94_6 9
#define ENVIRONMENT_LABEL_94_3 20
#define DEBUGGING_LABEL_94_2 19
#define OBJECT_94_3 18
#define OBJECT_94_2 17
#define OBJECT_94_1 16
#define OBJECT_94_0 15
#define EXECUTE_CACHE_94_9 11
#define EXECUTE_CACHE_94_7 13
#define FREE_REFERENCES_LABEL_94_0 10
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto use_value_4;

    case 1:
      current_block = (Rpc - LABEL_94_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_94_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_94_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (use_value_8)
DEFLABEL (use_value_4)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_94_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_94_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_94_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_94_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = (current_block [OBJECT_94_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_11;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_11;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_11)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_94_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_3]), 2);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_5 5
#define LABEL_95_6 7
#define LABEL_95_7 9
#define LABEL_95_10 11
#define LABEL_95_9 13
#define ENVIRONMENT_LABEL_95_3 28
#define DEBUGGING_LABEL_95_2 27
#define OBJECT_95_4 26
#define OBJECT_95_3 25
#define OBJECT_95_2 24
#define OBJECT_95_1 23
#define OBJECT_95_0 22
#define EXECUTE_CACHE_95_11 15
#define EXECUTE_CACHE_95_8 17
#define FREE_REFERENCE_95_1 20
#define FREE_REFERENCE_95_0 21
#define FREE_REFERENCES_LABEL_95_0 14
#define NUMBER_OF_LINKER_SECTIONS_95_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto restarts_default_4;

    case 1:
      current_block = (Rpc - LABEL_95_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_95_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_95_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_95_10);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_95_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restarts_default_10)
DEFLABEL (restarts_default_4)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_95_0]))
    goto label_20;
  if ((Wrd5.Obj) == (current_block [OBJECT_95_1]))
    goto label_16;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_95_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd7.Obj) = (current_block [OBJECT_95_3]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_12;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_4]), 2);

DEFLABEL (label_12)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_11;
  Rvl = ((Wrd15.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_95_2]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_1]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_15;
  Wrd25 = Wrd29;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_95_9);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_10])), (Wrd26.pObj));

DEFLABEL (label_8)
  (Wrd25.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_16)
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_19;
  Wrd14 = Wrd18;

DEFLABEL (label_18)
  Rvl = (Wrd14.Obj);

DEFLABEL (label_17)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_6])), (Wrd15.pObj));

DEFLABEL (label_6)
  (Wrd14.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_20)
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_0]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_22;
  Wrd21 = Wrd25;

DEFLABEL (label_21)
  Rvl = (Wrd21.Obj);
  goto label_17;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_5])), (Wrd22.pObj));

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_6 5
#define LABEL_96_5 7
#define LABEL_96_8 9
#define LABEL_96_10 11
#define LABEL_96_11 13
#define ENVIRONMENT_LABEL_96_3 29
#define DEBUGGING_LABEL_96_2 28
#define OBJECT_96_3 27
#define OBJECT_96_2 26
#define OBJECT_96_1 25
#define OBJECT_96_0 24
#define EXECUTE_CACHE_96_9 15
#define EXECUTE_CACHE_96_7 17
#define FREE_REFERENCE_96_1 20
#define FREE_REFERENCE_96_0 21
#define FREE_ASSIGNMENT_96_0 23
#define FREE_REFERENCES_LABEL_96_0 14
#define NUMBER_OF_LINKER_SECTIONS_96_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto bind_default_condition_handler_4;

    case 1:
      current_block = (Rpc - LABEL_96_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_96_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_96_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_96_10);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_96_11);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_default_condition_handler_10)
DEFLABEL (bind_default_condition_handler_4)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_96_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_96_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_96_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_17;
  Wrd10 = Wrd14;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_96_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_96_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_96_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_96_8);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_96_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_15;
  Wrd6 = Wrd10;

DEFLABEL (label_14)
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_96_0]));
  (Wrd28.Obj) = ((Wrd20.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_13;

DEFLABEL (label_12)
  ((Wrd20.pObj) [0]) = (Wrd17.Obj);

DEFLABEL (label_11)
  Rvl = (current_block [OBJECT_96_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  if ((Wrd28.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_12;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_96_11])), (Wrd20.pObj), (Wrd17.Obj));

DEFLABEL (label_8)
  goto label_11;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96_10])), (Wrd7.pObj));

DEFLABEL (label_7)
  (Wrd6.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96_6])), (Wrd11.pObj));

DEFLABEL (label_6)
  (Wrd10.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define LABEL_97_6 5
#define LABEL_97_5 7
#define LABEL_97_8 9
#define LABEL_97_10 11
#define LABEL_97_11 13
#define TAG_97_12 5
#define LABEL_97_18 15
#define LABEL_97_19 17
#define LABEL_97_13 19
#define TAG_97_14 8
#define LABEL_97_15 21
#define TAG_97_16 9
#define LABEL_97_20 23
#define LABEL_97_21 25
#define ENVIRONMENT_LABEL_97_3 43
#define DEBUGGING_LABEL_97_2 42
#define OBJECT_97_3 41
#define OBJECT_97_2 40
#define OBJECT_97_1 39
#define OBJECT_97_0 38
#define EXECUTE_CACHE_97_17 27
#define EXECUTE_CACHE_97_9 29
#define EXECUTE_CACHE_97_7 31
#define FREE_REFERENCE_97_1 34
#define FREE_REFERENCE_97_0 35
#define FREE_ASSIGNMENT_97_0 37
#define FREE_REFERENCES_LABEL_97_0 26
#define NUMBER_OF_LINKER_SECTIONS_97_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto bind_condition_handler_20;

    case 1:
      current_block = (Rpc - LABEL_97_6);
      goto label_22;

    case 2:
      current_block = (Rpc - LABEL_97_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_97_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_97_10);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_97_11);
      goto lambda_30;

    case 6:
      current_block = (Rpc - LABEL_97_18);
      goto label_24;

    case 7:
      current_block = (Rpc - LABEL_97_19);
      goto label_25;

    case 8:
      current_block = (Rpc - LABEL_97_13);
      goto lambda_31;

    case 9:
      current_block = (Rpc - LABEL_97_15);
      goto lambda_32;

    case 10:
      current_block = (Rpc - LABEL_97_20);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_97_21);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_condition_handler_29)
DEFLABEL (bind_condition_handler_20)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_97_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_97_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_97_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_36;
  Wrd10 = Wrd14;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_97_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_97_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_97_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_97_8);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_97_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_34;
  Wrd12 = Wrd16;

DEFLABEL (label_33)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd47.pObj) = (& (Rhp [-1]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd47.pObj)));
  (Rsp [0]) = (Wrd48.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_97_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_97_11])));
  Rhp += 2;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  Wrd31 = Wrd28;
  (Wrd32.Obj) = (Rsp [1]);
  ((Wrd31.pObj) [2]) = (Wrd32.Obj);
  ((Wrd31.pObj) [3]) = (Wrd48.Obj);
  (Rsp [2]) = (Wrd27.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_97_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_97_13])));
  Rhp += 1;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd36 = Wrd35;
  (Wrd37.Obj) = (Rsp [4]);
  ((Wrd36.pObj) [2]) = (Wrd37.Obj);
  (Rsp [3]) = (Wrd34.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd40.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_97_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_97_15])));
  Rhp += 2;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd40.pObj)));
  Wrd43 = Wrd40;
  ((Wrd43.pObj) [2]) = (Wrd32.Obj);
  ((Wrd43.pObj) [3]) = (Wrd48.Obj);
  (Rsp [4]) = (Wrd39.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_17]));

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_97_10])), (Wrd13.pObj));

DEFLABEL (label_23)
  (Wrd12.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_97_6])), (Wrd11.pObj));

DEFLABEL (label_22)
  (Wrd10.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_97_11);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_97_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_42;

DEFLABEL (label_41)
  Wrd19 = Wrd23;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_97_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_39;

DEFLABEL (label_38)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_37)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_97_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_39)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_38;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_97_19])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_25)
  goto label_37;

DEFLABEL (label_42)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_41;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_97_18])), (Wrd20.pObj));

DEFLABEL (label_24)
  (Wrd19.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_97_13);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_97_15);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_97_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_48;

DEFLABEL (label_47)
  Wrd19 = Wrd23;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_97_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_45;

DEFLABEL (label_44)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_43)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_97_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_44;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_97_21])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_27)
  goto label_43;

DEFLABEL (label_48)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_47;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_97_20])), (Wrd20.pObj));

DEFLABEL (label_26)
  (Wrd19.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_4 3
#define ENVIRONMENT_LABEL_98_3 9
#define DEBUGGING_LABEL_98_2 8
#define OBJECT_98_0 7
#define EXECUTE_CACHE_98_5 5
#define FREE_REFERENCES_LABEL_98_0 4
#define NUMBER_OF_LINKER_SECTIONS_98_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_4);
      goto guarantee_condition_handler_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_condition_handler_3)
DEFLABEL (guarantee_condition_handler_0)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_98_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_4 3
#define LABEL_99_6 5
#define LABEL_99_5 7
#define LABEL_99_8 9
#define ENVIRONMENT_LABEL_99_3 21
#define DEBUGGING_LABEL_99_2 20
#define OBJECT_99_2 19
#define OBJECT_99_1 18
#define OBJECT_99_0 17
#define EXECUTE_CACHE_99_7 11
#define FREE_REFERENCE_99_0 14
#define FREE_ASSIGNMENT_99_0 16
#define FREE_REFERENCES_LABEL_99_0 10
#define NUMBER_OF_LINKER_SECTIONS_99_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_4);
      goto break_on_signals_1;

    case 1:
      current_block = (Rpc - LABEL_99_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_99_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_99_8);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (break_on_signals_6)
DEFLABEL (break_on_signals_1)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_99_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_99_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_99_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_11;
  Wrd10 = Wrd14;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_99_5);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_99_0]));
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_9;

DEFLABEL (label_8)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_99_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_8;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_99_8])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_4)
  goto label_7;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99_6])), (Wrd11.pObj));

DEFLABEL (label_3)
  (Wrd10.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_4 3
#define ENVIRONMENT_LABEL_100_3 5
#define DEBUGGING_LABEL_100_2 4
#define FREE_REFERENCES_LABEL_100_0 4
#define NUMBER_OF_LINKER_SECTIONS_100_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_4);
      goto default_invoke_condition_handler_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (default_invoke_condition_handler_3)
DEFLABEL (default_invoke_condition_handler_0)
  INTERRUPT_CHECK (26, LABEL_100_4);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_4 3
#define LABEL_101_7 5
#define LABEL_101_8 7
#define LABEL_101_5 9
#define LABEL_101_16 11
#define LABEL_101_17 13
#define LABEL_101_20 15
#define LABEL_101_21 17
#define LABEL_101_18 19
#define TAG_101_19 8
#define LABEL_101_24 21
#define LABEL_101_25 23
#define LABEL_101_26 25
#define LABEL_101_27 27
#define LABEL_101_28 29
#define LABEL_101_22 31
#define TAG_101_23 14
#define LABEL_101_29 33
#define LABEL_101_30 35
#define LABEL_101_31 37
#define LABEL_101_38 39
#define LABEL_101_41 41
#define LABEL_101_9 43
#define TAG_101_10 20
#define LABEL_101_42 45
#define LABEL_101_43 47
#define LABEL_101_11 49
#define TAG_101_12 23
#define LABEL_101_44 51
#define LABEL_101_45 53
#define LABEL_101_13 55
#define TAG_101_14 26
#define LABEL_101_47 57
#define LABEL_101_48 59
#define LABEL_101_49 61
#define LABEL_101_39 63
#define TAG_101_40 30
#define LABEL_101_50 65
#define LABEL_101_51 67
#define LABEL_101_52 69
#define LABEL_101_32 71
#define TAG_101_33 34
#define LABEL_101_59 73
#define LABEL_101_60 75
#define LABEL_101_34 77
#define TAG_101_35 37
#define LABEL_101_61 79
#define LABEL_101_62 81
#define LABEL_101_36 83
#define TAG_101_37 40
#define LABEL_101_63 85
#define LABEL_101_64 87
#define LABEL_101_66 89
#define LABEL_101_67 91
#define LABEL_101_68 93
#define LABEL_101_69 95
#define LABEL_101_70 97
#define LABEL_101_53 99
#define TAG_101_54 48
#define LABEL_101_71 101
#define LABEL_101_72 103
#define LABEL_101_73 105
#define LABEL_101_74 107
#define LABEL_101_55 109
#define TAG_101_56 53
#define LABEL_101_75 111
#define LABEL_101_76 113
#define LABEL_101_77 115
#define LABEL_101_78 117
#define LABEL_101_57 119
#define TAG_101_58 58
#define LABEL_101_79 121
#define LABEL_101_80 123
#define ENVIRONMENT_LABEL_101_3 153
#define DEBUGGING_LABEL_101_2 152
#define OBJECT_101_10 151
#define OBJECT_101_9 150
#define OBJECT_101_8 149
#define OBJECT_101_7 148
#define OBJECT_101_6 147
#define OBJECT_101_5 146
#define OBJECT_101_4 145
#define OBJECT_101_3 144
#define OBJECT_101_2 143
#define OBJECT_101_1 142
#define OBJECT_101_0 141
#define EXECUTE_CACHE_101_65 125
#define EXECUTE_CACHE_101_46 127
#define EXECUTE_CACHE_101_15 129
#define EXECUTE_CACHE_101_6 131
#define FREE_REFERENCE_101_2 134
#define FREE_REFERENCE_101_1 135
#define FREE_REFERENCE_101_0 136
#define FREE_ASSIGNMENT_101_2 138
#define FREE_ASSIGNMENT_101_1 139
#define FREE_ASSIGNMENT_101_0 140
#define FREE_REFERENCES_LABEL_101_0 124
#define NUMBER_OF_LINKER_SECTIONS_101_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd76;
  machine_word Wrd60;
  machine_word Wrd10;
  machine_word Wrd86;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd93;
  machine_word Wrd53;
  machine_word Wrd34;
  machine_word Wrd110;
  machine_word Wrd102;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd101;
  machine_word Wrd45;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd85;
  machine_word Wrd79;
  machine_word Wrd71;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd88;
  machine_word Wrd89;
  machine_word Wrd57;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd92;
  machine_word Wrd44;
  machine_word Wrd29;
  machine_word Wrd104;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd61;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd67;
  machine_word Wrd49;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd97;
  machine_word Wrd98;
  machine_word Wrd94;
  machine_word Wrd90;
  machine_word Wrd91;
  machine_word Wrd87;
  machine_word Wrd83;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd82;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd78;
  machine_word Wrd72;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_4);
      goto signal_condition_115;

    case 1:
      current_block = (Rpc - LABEL_101_7);
      goto continuation_22;

    case 2:
      current_block = (Rpc - LABEL_101_8);
      goto continuation_19;

    case 3:
      current_block = (Rpc - LABEL_101_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_101_16);
      goto label_117;

    case 5:
      current_block = (Rpc - LABEL_101_17);
      goto label_118;

    case 6:
      current_block = (Rpc - LABEL_101_20);
      goto label_119;

    case 7:
      current_block = (Rpc - LABEL_101_21);
      goto label_120;

    case 8:
      current_block = (Rpc - LABEL_101_18);
      goto lambda_18;

    case 9:
      current_block = (Rpc - LABEL_101_24);
      goto label_121;

    case 10:
      current_block = (Rpc - LABEL_101_25);
      goto label_122;

    case 11:
      current_block = (Rpc - LABEL_101_26);
      goto continuation_48;

    case 12:
      current_block = (Rpc - LABEL_101_27);
      goto continuation_44;

    case 13:
      current_block = (Rpc - LABEL_101_28);
      goto label_134;

    case 14:
      current_block = (Rpc - LABEL_101_22);
      goto do_loop_68;

    case 15:
      current_block = (Rpc - LABEL_101_29);
      goto label_124;

    case 16:
      current_block = (Rpc - LABEL_101_30);
      goto label_125;

    case 17:
      current_block = (Rpc - LABEL_101_31);
      goto label_126;

    case 18:
      current_block = (Rpc - LABEL_101_38);
      goto label_123;

    case 19:
      current_block = (Rpc - LABEL_101_41);
      goto outer_16;

    case 20:
      current_block = (Rpc - LABEL_101_9);
      goto lambda_158;

    case 21:
      current_block = (Rpc - LABEL_101_42);
      goto label_127;

    case 22:
      current_block = (Rpc - LABEL_101_43);
      goto label_128;

    case 23:
      current_block = (Rpc - LABEL_101_11);
      goto lambda_159;

    case 24:
      current_block = (Rpc - LABEL_101_44);
      goto label_129;

    case 25:
      current_block = (Rpc - LABEL_101_45);
      goto label_130;

    case 26:
      current_block = (Rpc - LABEL_101_13);
      goto lambda_160;

    case 27:
      current_block = (Rpc - LABEL_101_47);
      goto continuation_79;

    case 28:
      current_block = (Rpc - LABEL_101_48);
      goto continuation_75;

    case 29:
      current_block = (Rpc - LABEL_101_49);
      goto label_145;

    case 30:
      current_block = (Rpc - LABEL_101_39);
      goto do_loop_111;

    case 31:
      current_block = (Rpc - LABEL_101_50);
      goto label_131;

    case 32:
      current_block = (Rpc - LABEL_101_51);
      goto label_132;

    case 33:
      current_block = (Rpc - LABEL_101_52);
      goto label_133;

    case 34:
      current_block = (Rpc - LABEL_101_32);
      goto lambda_163;

    case 35:
      current_block = (Rpc - LABEL_101_59);
      goto label_135;

    case 36:
      current_block = (Rpc - LABEL_101_60);
      goto label_136;

    case 37:
      current_block = (Rpc - LABEL_101_34);
      goto lambda_164;

    case 38:
      current_block = (Rpc - LABEL_101_61);
      goto label_137;

    case 39:
      current_block = (Rpc - LABEL_101_62);
      goto label_138;

    case 40:
      current_block = (Rpc - LABEL_101_36);
      goto lambda_165;

    case 41:
      current_block = (Rpc - LABEL_101_63);
      goto label_139;

    case 42:
      current_block = (Rpc - LABEL_101_64);
      goto label_140;

    case 43:
      current_block = (Rpc - LABEL_101_66);
      goto inner_14;

    case 44:
      current_block = (Rpc - LABEL_101_67);
      goto label_143;

    case 45:
      current_block = (Rpc - LABEL_101_68);
      goto label_144;

    case 46:
      current_block = (Rpc - LABEL_101_69);
      goto label_141;

    case 47:
      current_block = (Rpc - LABEL_101_70);
      goto label_142;

    case 48:
      current_block = (Rpc - LABEL_101_53);
      goto lambda_168;

    case 49:
      current_block = (Rpc - LABEL_101_71);
      goto label_146;

    case 50:
      current_block = (Rpc - LABEL_101_72);
      goto label_147;

    case 51:
      current_block = (Rpc - LABEL_101_73);
      goto label_148;

    case 52:
      current_block = (Rpc - LABEL_101_74);
      goto label_149;

    case 53:
      current_block = (Rpc - LABEL_101_55);
      goto lambda_169;

    case 54:
      current_block = (Rpc - LABEL_101_75);
      goto label_150;

    case 55:
      current_block = (Rpc - LABEL_101_76);
      goto label_151;

    case 56:
      current_block = (Rpc - LABEL_101_77);
      goto label_152;

    case 57:
      current_block = (Rpc - LABEL_101_78);
      goto label_153;

    case 58:
      current_block = (Rpc - LABEL_101_57);
      goto lambda_170;

    case 59:
      current_block = (Rpc - LABEL_101_79);
      goto label_154;

    case 60:
      current_block = (Rpc - LABEL_101_80);
      goto label_155;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (signal_condition_157)
DEFLABEL (signal_condition_115)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_101_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_101_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_181;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_181;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_180)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_179;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_179;
  (Wrd22.Obj) = ((Wrd25.pObj) [3]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_178)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd36.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_18])));
  Rhp += 1;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd36.pObj)));
  Wrd37 = Wrd36;
  (Wrd38.Obj) = (Rsp [0]);
  ((Wrd37.pObj) [2]) = (Wrd38.Obj);
  (Rsp [0]) = (Wrd35.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_0]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_177;
  Wrd42 = Wrd46;

DEFLABEL (label_176)
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_172;
  (Wrd67.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd67.Obj);
  goto lambda_18;

DEFLABEL (label_172)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_175)
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_1]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_174;
  Wrd51 = Wrd55;

DEFLABEL (label_173)
  (* (--Rsp)) = (Wrd51.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd65.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_22])));
  Rhp += 2;
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd65.pObj)));
  (* (--Rsp)) = (Wrd66.Obj);
  Wrd63 = Wrd65;
  (Wrd64.Obj) = (Rsp [3]);
  ((Wrd63.pObj) [2]) = (Wrd64.Obj);
  (Wrd61.Obj) = (Rsp [2]);
  ((Wrd63.pObj) [3]) = (Wrd61.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd66.Obj);
  goto do_loop_68;

DEFLABEL (label_174)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101_21])), (Wrd52.pObj));

DEFLABEL (label_120)
  (Wrd51.Obj) = Rvl;
  goto label_173;

DEFLABEL (label_177)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101_20])), (Wrd43.pObj));

DEFLABEL (label_119)
  (Wrd42.Obj) = Rvl;
  goto label_176;

DEFLABEL (label_179)
  (Wrd30.Obj) = (current_block [OBJECT_101_4]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_17]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_3]), 2);

DEFLABEL (label_118)
  (* (--Rsp)) = Rvl;
  goto label_178;

DEFLABEL (label_181)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_101_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_16]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_3]), 2);

DEFLABEL (label_117)
  (Wrd5.Obj) = Rvl;
  goto label_180;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_101_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_175;
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_7]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd78.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd74.pObj) = (& (Rhp [-1]));
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd74.pObj)));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd82.Obj) = (current_block [OBJECT_101_1]);
  (* (Rhp++)) = (Wrd82.Obj);
  (Wrd80.pObj) = (& (Rhp [-1]));
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd80.pObj)));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd84.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_9])));
  Rhp += 2;
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd84.pObj)));
  Wrd87 = Wrd84;
  ((Wrd87.pObj) [2]) = (Wrd75.Obj);
  ((Wrd87.pObj) [3]) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd91.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_11])));
  Rhp += 2;
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd91.pObj)));
  Wrd94 = Wrd91;
  ((Wrd94.pObj) [2]) = (Wrd75.Obj);
  ((Wrd94.pObj) [3]) = (Wrd81.Obj);
  (Rsp [2]) = (Wrd90.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd98.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_13])));
  Rhp += 1;
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd98.pObj)));
  Wrd99 = Wrd98;
  (Wrd100.Obj) = (Rsp [5]);
  ((Wrd99.pObj) [2]) = (Wrd100.Obj);
  (Rsp [1]) = (Wrd97.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_15]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_101_7);
  goto label_175;

DEFLABEL (lambda_161)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_101_18);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_185;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_184)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_183;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_182)
  goto outer_16;

DEFLABEL (label_183)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_25]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_122)
  (* (--Rsp)) = Rvl;
  goto label_182;

DEFLABEL (label_185)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_24]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_121)
  (* (--Rsp)) = Rvl;
  goto label_184;

DEFLABEL (do_loop_162)
DEFLABEL (do_loop_68)
  INTERRUPT_CHECK (26, LABEL_101_22);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_188;
  Rsp = (& (Rsp [2]));
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_2]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_187;
  Wrd8 = Wrd12;

DEFLABEL (label_186)
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_39])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  Wrd20 = Wrd22;
  (Wrd21.Obj) = (Rsp [3]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  ((Wrd20.pObj) [3]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd23.Obj);
  goto do_loop_111;

DEFLABEL (label_187)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101_38])), (Wrd9.pObj));

DEFLABEL (label_123)
  (Wrd8.Obj) = Rvl;
  goto label_186;

DEFLABEL (label_188)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_27]))));
  (* (--Rsp)) = (Wrd26.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_196;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);

DEFLABEL (label_195)
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_194;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_193)
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_189;
  (Wrd90.Obj) = (Rsp [2]);
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [3]);
  (* (--Rsp)) = (Wrd92.Obj);
  goto lambda_18;

DEFLABEL (label_189)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_192)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_26]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd54.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd54.Obj);
  (Wrd50.pObj) = (& (Rhp [-1]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd50.pObj)));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd58.Obj) = (Rsp [3]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_191;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [1]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_190)
  (Wrd89.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd89.Obj);
  (Wrd87.pObj) = (& (Rhp [-1]));
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd87.pObj)));
  (Rsp [0]) = (Wrd88.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd65.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_32])));
  Rhp += 2;
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd65.pObj)));
  Wrd68 = Wrd65;
  (Wrd69.Obj) = (Rsp [1]);
  ((Wrd68.pObj) [2]) = (Wrd69.Obj);
  ((Wrd68.pObj) [3]) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd72.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_34])));
  Rhp += 2;
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd72.pObj)));
  Wrd75 = Wrd72;
  ((Wrd75.pObj) [2]) = (Wrd69.Obj);
  ((Wrd75.pObj) [3]) = (Wrd88.Obj);
  (Rsp [2]) = (Wrd71.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd79.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_37);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_36])));
  Rhp += 2;
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd79.pObj)));
  Wrd82 = Wrd79;
  (Wrd83.Obj) = (Rsp [4]);
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd85.Obj) = ((Wrd84.pObj) [2]);
  ((Wrd82.pObj) [2]) = (Wrd85.Obj);
  (Wrd81.Obj) = (Rsp [5]);
  ((Wrd82.pObj) [3]) = (Wrd81.Obj);
  (Rsp [1]) = (Wrd78.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_15]));

DEFLABEL (label_191)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_31]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_126)
  (* (--Rsp)) = Rvl;
  goto label_190;

DEFLABEL (label_194)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_30]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_125)
  (* (--Rsp)) = Rvl;
  goto label_193;

DEFLABEL (label_196)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_29]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_124)
  (Wrd27.Obj) = Rvl;
  goto label_195;

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_101_26);

DEFLABEL (label_199)
  (Wrd95.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd95.Obj);
  (Wrd99.Obj) = (Rsp [1]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd100.uLng) == 1))
    goto label_198;
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd99.Obj));
  (Wrd96.Obj) = ((Wrd98.pObj) [1]);

DEFLABEL (label_197)
  (Rsp [1]) = (Wrd96.Obj);
  goto do_loop_68;

DEFLABEL (label_198)
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_28]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_134)
  (Wrd96.Obj) = Rvl;
  goto label_197;

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_101_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_199;
  goto label_192;

DEFLABEL (outer_167)
DEFLABEL (outer_16)
  INTERRUPT_CHECK (26, LABEL_101_41);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto inner_14;

DEFLABEL (lambda_158)
  CLOSURE_HEADER (LABEL_101_9);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_205;

DEFLABEL (label_204)
  Wrd19 = Wrd23;

DEFLABEL (label_203)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_202;

DEFLABEL (label_201)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_200)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_202)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_201;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_43])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_128)
  goto label_200;

DEFLABEL (label_205)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_204;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_42])), (Wrd20.pObj));

DEFLABEL (label_127)
  (Wrd19.Obj) = Rvl;
  goto label_203;

DEFLABEL (lambda_159)
  CLOSURE_HEADER (LABEL_101_11);

DEFLABEL (lambda_37)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_211;

DEFLABEL (label_210)
  Wrd19 = Wrd23;

DEFLABEL (label_209)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_208;

DEFLABEL (label_207)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_206)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_208)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_207;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_45])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_130)
  goto label_206;

DEFLABEL (label_211)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_210;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_44])), (Wrd20.pObj));

DEFLABEL (label_129)
  (Wrd19.Obj) = Rvl;
  goto label_209;

DEFLABEL (lambda_160)
  CLOSURE_HEADER (LABEL_101_13);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_101_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_101_9]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_46]));

DEFLABEL (do_loop_166)
DEFLABEL (do_loop_111)
  INTERRUPT_CHECK (26, LABEL_101_39);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_212;
  Rsp = (& (Rsp [2]));
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_212)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_48]))));
  (* (--Rsp)) = (Wrd12.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_220;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_219)
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_218;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_217)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_213;
  (Wrd96.Obj) = (Rsp [2]);
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [3]);
  (* (--Rsp)) = (Wrd98.Obj);
  goto lambda_18;

DEFLABEL (label_213)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_216)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_47]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd40.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd36.pObj) = (& (Rhp [-1]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd42.pObj) = (& (Rhp [-1]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd42.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_101_1]);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd48.pObj) = (& (Rhp [-1]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_215;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [1]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_214)
  (Wrd95.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd95.Obj);
  (Wrd93.pObj) = (& (Rhp [-1]));
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd93.pObj)));
  (Rsp [0]) = (Wrd94.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd62.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_54);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_53])));
  Rhp += 4;
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd62.pObj)));
  Wrd69 = Wrd62;
  (Wrd70.Obj) = (Rsp [3]);
  ((Wrd69.pObj) [2]) = (Wrd70.Obj);
  (Wrd68.Obj) = (Rsp [2]);
  ((Wrd69.pObj) [3]) = (Wrd68.Obj);
  (Wrd66.Obj) = (Rsp [1]);
  ((Wrd69.pObj) [4]) = (Wrd66.Obj);
  ((Wrd69.pObj) [5]) = (Wrd94.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd73.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_56);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_55])));
  Rhp += 4;
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd73.pObj)));
  Wrd80 = Wrd73;
  ((Wrd80.pObj) [2]) = (Wrd70.Obj);
  ((Wrd80.pObj) [3]) = (Wrd68.Obj);
  ((Wrd80.pObj) [4]) = (Wrd66.Obj);
  ((Wrd80.pObj) [5]) = (Wrd94.Obj);
  (Rsp [3]) = (Wrd72.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd84.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_58);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_57])));
  Rhp += 2;
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd84.pObj)));
  Wrd87 = Wrd84;
  (Wrd88.Obj) = (Rsp [5]);
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd90.Obj) = ((Wrd89.pObj) [2]);
  ((Wrd87.pObj) [2]) = (Wrd90.Obj);
  (Wrd86.Obj) = (Rsp [6]);
  ((Wrd87.pObj) [3]) = (Wrd86.Obj);
  (Rsp [2]) = (Wrd83.Obj);
  (Rsp [1]) = (Wrd61.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_15]));

DEFLABEL (label_215)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_52]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_133)
  (* (--Rsp)) = Rvl;
  goto label_214;

DEFLABEL (label_218)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_51]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_132)
  (* (--Rsp)) = Rvl;
  goto label_217;

DEFLABEL (label_220)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_50]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_131)
  (Wrd13.Obj) = Rvl;
  goto label_219;

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_101_47);

DEFLABEL (label_223)
  (Wrd101.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd101.Obj);
  (Wrd105.Obj) = (Rsp [1]);
  (Wrd106.uLng) = (OBJECT_TYPE (Wrd105.Obj));
  if (! ((Wrd106.uLng) == 1))
    goto label_222;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd105.Obj));
  (Wrd102.Obj) = ((Wrd104.pObj) [1]);

DEFLABEL (label_221)
  (Rsp [1]) = (Wrd102.Obj);
  goto do_loop_111;

DEFLABEL (label_222)
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_49]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd105.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_145)
  (Wrd102.Obj) = Rvl;
  goto label_221;

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_101_48);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_223;
  goto label_216;

DEFLABEL (lambda_163)
  CLOSURE_HEADER (LABEL_101_32);

DEFLABEL (lambda_55)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_229;

DEFLABEL (label_228)
  Wrd19 = Wrd23;

DEFLABEL (label_227)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_226;

DEFLABEL (label_225)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_224)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_226)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_225;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_60])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_136)
  goto label_224;

DEFLABEL (label_229)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_228;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_59])), (Wrd20.pObj));

DEFLABEL (label_135)
  (Wrd19.Obj) = Rvl;
  goto label_227;

DEFLABEL (lambda_164)
  CLOSURE_HEADER (LABEL_101_34);

DEFLABEL (lambda_65)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_235;

DEFLABEL (label_234)
  Wrd19 = Wrd23;

DEFLABEL (label_233)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_232;

DEFLABEL (label_231)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_230)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_232)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_231;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_62])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_138)
  goto label_230;

DEFLABEL (label_235)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_234;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_61])), (Wrd20.pObj));

DEFLABEL (label_137)
  (Wrd19.Obj) = Rvl;
  goto label_233;

DEFLABEL (lambda_165)
  CLOSURE_HEADER (LABEL_101_36);

DEFLABEL (lambda_58)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_239;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_238)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_237;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_236)
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_65]));

DEFLABEL (label_237)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_64]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_140)
  (* (--Rsp)) = Rvl;
  goto label_236;

DEFLABEL (label_239)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_63]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_139)
  (Wrd5.Obj) = Rvl;
  goto label_238;

DEFLABEL (inner_171)
DEFLABEL (inner_14)
  INTERRUPT_CHECK (26, LABEL_101_66);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_246;
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_241;
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_240)
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_241)
  if (! ((Wrd8.uLng) == 1))
    goto label_245;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_244)
  (Rsp [1]) = (Wrd11.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_243;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_242)
  (Rsp [2]) = (Wrd20.Obj);
  Rsp = (& (Rsp [1]));
  goto outer_16;

DEFLABEL (label_243)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_70]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_142)
  (Wrd20.Obj) = Rvl;
  goto label_242;

DEFLABEL (label_245)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_69]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_141)
  (Wrd11.Obj) = Rvl;
  goto label_244;

DEFLABEL (label_246)
  if (! ((Wrd6.uLng) == 1))
    goto label_251;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);

DEFLABEL (label_250)
  (Wrd39.Obj) = (Rsp [1]);
  if ((Wrd39.Obj) == (Wrd30.Obj))
    goto label_249;
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_248;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_247)
  (Rsp [0]) = (Wrd40.Obj);
  goto inner_14;

DEFLABEL (label_248)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_68]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_144)
  (Wrd40.Obj) = Rvl;
  goto label_247;

DEFLABEL (label_249)
  Rvl = (current_block [OBJECT_101_10]);
  goto label_240;

DEFLABEL (label_251)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_67]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_143)
  (Wrd30.Obj) = Rvl;
  goto label_250;

DEFLABEL (lambda_168)
  CLOSURE_HEADER (LABEL_101_53);

DEFLABEL (lambda_92)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_263;

DEFLABEL (label_262)
  Wrd19 = Wrd23;

DEFLABEL (label_261)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_260;

DEFLABEL (label_259)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_258)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_257;

DEFLABEL (label_256)
  Wrd63 = Wrd67;

DEFLABEL (label_255)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_254;

DEFLABEL (label_253)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_252)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [2]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_254)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_253;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_74])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_149)
  goto label_252;

DEFLABEL (label_257)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_256;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_73])), (Wrd64.pObj));

DEFLABEL (label_148)
  (Wrd63.Obj) = Rvl;
  goto label_255;

DEFLABEL (label_260)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_259;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_72])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_147)
  goto label_258;

DEFLABEL (label_263)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_262;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_71])), (Wrd20.pObj));

DEFLABEL (label_146)
  (Wrd19.Obj) = Rvl;
  goto label_261;

DEFLABEL (lambda_169)
  CLOSURE_HEADER (LABEL_101_55);

DEFLABEL (lambda_108)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_275;

DEFLABEL (label_274)
  Wrd19 = Wrd23;

DEFLABEL (label_273)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_272;

DEFLABEL (label_271)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_270)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_269;

DEFLABEL (label_268)
  Wrd63 = Wrd67;

DEFLABEL (label_267)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_101_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_266;

DEFLABEL (label_265)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_264)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_101_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_266)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_265;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_78])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_153)
  goto label_264;

DEFLABEL (label_269)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_268;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_77])), (Wrd64.pObj));

DEFLABEL (label_152)
  (Wrd63.Obj) = Rvl;
  goto label_267;

DEFLABEL (label_272)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_271;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_101_76])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_151)
  goto label_270;

DEFLABEL (label_275)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_274;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_101_75])), (Wrd20.pObj));

DEFLABEL (label_150)
  (Wrd19.Obj) = Rvl;
  goto label_273;

DEFLABEL (lambda_170)
  CLOSURE_HEADER (LABEL_101_57);

DEFLABEL (lambda_95)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_279;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_278)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_277;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_276)
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_65]));

DEFLABEL (label_277)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_80]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_5]), 1);

DEFLABEL (label_155)
  (* (--Rsp)) = Rvl;
  goto label_276;

DEFLABEL (label_279)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_79]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_6]), 1);

DEFLABEL (label_154)
  (Wrd5.Obj) = Rvl;
  goto label_278;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_4 3
#define LABEL_102_5 5
#define LABEL_102_6 7
#define ENVIRONMENT_LABEL_102_3 15
#define DEBUGGING_LABEL_102_2 14
#define EXECUTE_CACHE_102_7 9
#define FREE_REFERENCE_102_1 12
#define FREE_REFERENCE_102_0 13
#define FREE_REFERENCES_LABEL_102_0 8
#define NUMBER_OF_LINKER_SECTIONS_102_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_4);
      goto error_0;

    case 1:
      current_block = (Rpc - LABEL_102_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_102_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_5)
DEFLABEL (error_0)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_102_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_9;
  Wrd8 = Wrd12;

DEFLABEL (label_8)
  (Rsp [2]) = (Wrd8.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_102_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_7;
  Wrd15 = Wrd19;

DEFLABEL (label_6)
  (Rsp [3]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_102_6])), (Wrd16.pObj));

DEFLABEL (label_3)
  (Wrd15.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_102_5])), (Wrd9.pObj));

DEFLABEL (label_2)
  (Wrd8.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define LABEL_103_5 5
#define TAG_103_6 1
#define LABEL_103_8 7
#define LABEL_103_9 9
#define ENVIRONMENT_LABEL_103_3 21
#define DEBUGGING_LABEL_103_2 20
#define OBJECT_103_1 19
#define OBJECT_103_0 18
#define EXECUTE_CACHE_103_10 11
#define EXECUTE_CACHE_103_7 13
#define FREE_REFERENCE_103_1 16
#define FREE_REFERENCE_103_0 17
#define FREE_REFERENCES_LABEL_103_0 10
#define NUMBER_OF_LINKER_SECTIONS_103_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto warn_1;

    case 1:
      current_block = (Rpc - LABEL_103_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_103_8);
      goto label_3;

    case 3:
      current_block = (Rpc - LABEL_103_9);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (warn_6)
DEFLABEL (warn_1)
  INTERRUPT_CHECK (26, LABEL_103_4);
  (Wrd5.Obj) = (current_block [OBJECT_103_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_5])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_103_1]);
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_103_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd12.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_1]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_9;
  Wrd18 = Wrd22;

DEFLABEL (label_8)
  (Rsp [3]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_10]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_9])), (Wrd19.pObj));

DEFLABEL (label_4)
  (Wrd18.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_8])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define LABEL_104_5 5
#define LABEL_104_10 7
#define LABEL_104_7 9
#define TAG_104_8 3
#define LABEL_104_12 11
#define LABEL_104_13 13
#define LABEL_104_15 15
#define ENVIRONMENT_LABEL_104_3 29
#define DEBUGGING_LABEL_104_2 28
#define OBJECT_104_0 27
#define EXECUTE_CACHE_104_16 17
#define EXECUTE_CACHE_104_14 19
#define EXECUTE_CACHE_104_11 21
#define EXECUTE_CACHE_104_9 23
#define EXECUTE_CACHE_104_6 25
#define FREE_REFERENCES_LABEL_104_0 16
#define NUMBER_OF_LINKER_SECTIONS_104_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto signal_simple_7;

    case 1:
      current_block = (Rpc - LABEL_104_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_104_10);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_104_7);
      goto lambda_11;

    case 4:
      current_block = (Rpc - LABEL_104_12);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_104_13);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_104_15);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (signal_simple_10)
DEFLABEL (signal_simple_7)
  INTERRUPT_CHECK (26, LABEL_104_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_104_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_104_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_104_7])));
  Rhp += 4;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd20 = Wrd13;
  (Wrd21.Obj) = (Rsp [3]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  ((Wrd20.pObj) [3]) = (Wrd19.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  ((Wrd20.pObj) [4]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [0]);
  ((Wrd20.pObj) [5]) = (Wrd15.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_9]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_104_10);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_104_7);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_104_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_104_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd8.pObj) [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_104_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_104_15);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_13)
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_104_0]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_5 3
#define LABEL_105_4 5
#define LABEL_105_6 7
#define LABEL_105_9 9
#define TAG_105_10 3
#define LABEL_105_16 11
#define LABEL_105_17 13
#define LABEL_105_11 15
#define TAG_105_12 6
#define LABEL_105_13 17
#define TAG_105_14 7
#define LABEL_105_18 19
#define LABEL_105_19 21
#define LABEL_105_7 23
#define ENVIRONMENT_LABEL_105_3 40
#define DEBUGGING_LABEL_105_2 39
#define OBJECT_105_3 38
#define OBJECT_105_2 37
#define OBJECT_105_1 36
#define OBJECT_105_0 35
#define EXECUTE_CACHE_105_20 25
#define EXECUTE_CACHE_105_15 27
#define EXECUTE_CACHE_105_8 29
#define FREE_REFERENCE_105_0 32
#define FREE_ASSIGNMENT_105_0 34
#define FREE_REFERENCES_LABEL_105_0 24
#define NUMBER_OF_LINKER_SECTIONS_105_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_105_4);
      goto standard_error_handler_19;

    case 2:
      current_block = (Rpc - LABEL_105_6);
      goto label_21;

    case 3:
      current_block = (Rpc - LABEL_105_9);
      goto lambda_28;

    case 4:
      current_block = (Rpc - LABEL_105_16);
      goto label_22;

    case 5:
      current_block = (Rpc - LABEL_105_17);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_105_11);
      goto lambda_29;

    case 7:
      current_block = (Rpc - LABEL_105_13);
      goto lambda_30;

    case 8:
      current_block = (Rpc - LABEL_105_18);
      goto label_24;

    case 9:
      current_block = (Rpc - LABEL_105_19);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_105_7);
      goto continuation_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (standard_error_handler_27)
DEFLABEL (standard_error_handler_19)
  INTERRUPT_CHECK (26, LABEL_105_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_34;
  Wrd8 = Wrd12;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd8.Obj);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_31;
  (Wrd21.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd17.pObj) = (& (Rhp [-1]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd23.pObj) = (& (Rhp [-1]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_9])));
  Rhp += 2;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  Wrd31 = Wrd28;
  ((Wrd31.pObj) [2]) = (Wrd18.Obj);
  ((Wrd31.pObj) [3]) = (Wrd24.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_11])));
  Rhp += 2;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd38 = Wrd35;
  (Wrd39.Obj) = (Rsp [4]);
  ((Wrd38.pObj) [2]) = (Wrd39.Obj);
  ((Wrd38.pObj) [3]) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_13])));
  Rhp += 2;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  Wrd45 = Wrd42;
  ((Wrd45.pObj) [2]) = (Wrd18.Obj);
  ((Wrd45.pObj) [3]) = (Wrd24.Obj);
  (Rsp [2]) = (Wrd41.Obj);
  (Rsp [1]) = (Wrd34.Obj);
  (Rsp [0]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_15]));

DEFLABEL (label_31)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_32)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_7]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (current_block [OBJECT_105_0]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd52.Obj) = (current_block [OBJECT_105_1]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (current_block [OBJECT_105_2]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_8]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_105_7);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_20]));

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_6])), (Wrd9.pObj));

DEFLABEL (label_21)
  (Wrd8.Obj) = Rvl;
  goto label_33;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_105_5);
  goto label_32;

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_105_9);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_40;

DEFLABEL (label_39)
  Wrd19 = Wrd23;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_105_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_37;

DEFLABEL (label_36)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_35)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_105_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_37)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_36;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_105_17])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_23)
  goto label_35;

DEFLABEL (label_40)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_39;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_105_16])), (Wrd20.pObj));

DEFLABEL (label_22)
  (Wrd19.Obj) = Rvl;
  goto label_38;

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_105_11);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_105_13);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_46;

DEFLABEL (label_45)
  Wrd19 = Wrd23;

DEFLABEL (label_44)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_105_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_43;

DEFLABEL (label_42)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_41)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_105_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_43)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_42;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_105_19])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_25)
  goto label_41;

DEFLABEL (label_46)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_45;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_105_18])), (Wrd20.pObj));

DEFLABEL (label_24)
  (Wrd19.Obj) = Rvl;
  goto label_44;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define LABEL_106_5 5
#define LABEL_106_8 7
#define TAG_106_9 2
#define LABEL_106_10 9
#define TAG_106_11 3
#define LABEL_106_15 11
#define LABEL_106_16 13
#define LABEL_106_12 15
#define TAG_106_13 6
#define LABEL_106_17 17
#define LABEL_106_18 19
#define LABEL_106_6 21
#define LABEL_106_19 23
#define LABEL_106_21 25
#define LABEL_106_23 27
#define ENVIRONMENT_LABEL_106_3 48
#define DEBUGGING_LABEL_106_2 47
#define OBJECT_106_1 46
#define OBJECT_106_0 45
#define EXECUTE_CACHE_106_25 29
#define EXECUTE_CACHE_106_24 31
#define EXECUTE_CACHE_106_22 33
#define EXECUTE_CACHE_106_20 35
#define EXECUTE_CACHE_106_14 37
#define EXECUTE_CACHE_106_7 39
#define FREE_REFERENCE_106_0 42
#define FREE_ASSIGNMENT_106_0 44
#define FREE_REFERENCES_LABEL_106_0 28
#define NUMBER_OF_LINKER_SECTIONS_106_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd47;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto standard_warning_handler_22;

    case 1:
      current_block = (Rpc - LABEL_106_5);
      goto label_24;

    case 2:
      current_block = (Rpc - LABEL_106_8);
      goto lambda_31;

    case 3:
      current_block = (Rpc - LABEL_106_10);
      goto lambda_32;

    case 4:
      current_block = (Rpc - LABEL_106_15);
      goto label_25;

    case 5:
      current_block = (Rpc - LABEL_106_16);
      goto label_26;

    case 6:
      current_block = (Rpc - LABEL_106_12);
      goto lambda_33;

    case 7:
      current_block = (Rpc - LABEL_106_17);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_106_18);
      goto label_28;

    case 9:
      current_block = (Rpc - LABEL_106_6);
      goto continuation_0;

    case 10:
      current_block = (Rpc - LABEL_106_19);
      goto continuation_1;

    case 11:
      current_block = (Rpc - LABEL_106_21);
      goto continuation_2;

    case 12:
      current_block = (Rpc - LABEL_106_23);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (standard_warning_handler_30)
DEFLABEL (standard_warning_handler_22)
  INTERRUPT_CHECK (26, LABEL_106_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_106_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_36;
  Wrd5 = Wrd9;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd5.Obj);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_34;
  (Wrd18.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd14.pObj) = (& (Rhp [-1]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd20.pObj) = (& (Rhp [-1]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_8])));
  Rhp += 2;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd28 = Wrd25;
  (Wrd29.Obj) = (Rsp [3]);
  ((Wrd28.pObj) [2]) = (Wrd29.Obj);
  ((Wrd28.pObj) [3]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd24.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd32.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_10])));
  Rhp += 2;
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd32.pObj)));
  Wrd35 = Wrd32;
  ((Wrd35.pObj) [2]) = (Wrd15.Obj);
  ((Wrd35.pObj) [3]) = (Wrd21.Obj);
  (Rsp [3]) = (Wrd31.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd39.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_12])));
  Rhp += 2;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd39.pObj)));
  Wrd42 = Wrd39;
  ((Wrd42.pObj) [2]) = (Wrd15.Obj);
  ((Wrd42.pObj) [3]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_14]));

DEFLABEL (label_34)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_6]))));
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_106_6);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_19]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_20]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_106_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_106_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_22]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_106_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_24]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_106_23);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_25]));

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_106_5])), (Wrd6.pObj));

DEFLABEL (label_24)
  (Wrd5.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_106_8);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_106_10);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_106_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_42;

DEFLABEL (label_41)
  Wrd19 = Wrd23;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_106_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_39;

DEFLABEL (label_38)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_37)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_106_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_39)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_38;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_106_16])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_26)
  goto label_37;

DEFLABEL (label_42)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_41;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_106_15])), (Wrd20.pObj));

DEFLABEL (label_25)
  (Wrd19.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_106_12);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_106_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_48;

DEFLABEL (label_47)
  Wrd19 = Wrd23;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_106_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_45;

DEFLABEL (label_44)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_43)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_106_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_44;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_106_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_28)
  goto label_43;

DEFLABEL (label_48)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_47;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_106_17])), (Wrd20.pObj));

DEFLABEL (label_27)
  (Wrd19.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define LABEL_107_5 5
#define LABEL_107_7 7
#define LABEL_107_9 9
#define TAG_107_10 3
#define LABEL_107_11 11
#define TAG_107_12 4
#define LABEL_107_14 13
#define LABEL_107_15 15
#define ENVIRONMENT_LABEL_107_3 30
#define DEBUGGING_LABEL_107_2 29
#define OBJECT_107_3 28
#define OBJECT_107_2 27
#define OBJECT_107_1 26
#define OBJECT_107_0 25
#define EXECUTE_CACHE_107_16 17
#define EXECUTE_CACHE_107_13 19
#define EXECUTE_CACHE_107_8 21
#define EXECUTE_CACHE_107_6 23
#define FREE_REFERENCES_LABEL_107_0 16
#define NUMBER_OF_LINKER_SECTIONS_107_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto condition_signaller_10;

    case 1:
      current_block = (Rpc - LABEL_107_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_107_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_107_9);
      goto lambda_14;

    case 4:
      current_block = (Rpc - LABEL_107_11);
      goto lambda_15;

    case 5:
      current_block = (Rpc - LABEL_107_14);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_107_15);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_signaller_13)
DEFLABEL (condition_signaller_10)
  INTERRUPT_CHECK (26, LABEL_107_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_107_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_107_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_107_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_107_7);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x1fe, 2);
  (* (Rhp++)) = (dispatch_base + TAG_107_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_107_9])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [3]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  ((Wrd10.pObj) [3]) = Rvl;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_107_9);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_107_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_107_11])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_13]));

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_107_11);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_107_2]);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Wrd18.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_3]), 2);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_107_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_107_15);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_108_4 3
#define LABEL_108_5 5
#define LABEL_108_7 7
#define LABEL_108_9 9
#define LABEL_108_11 11
#define TAG_108_12 4
#define LABEL_108_14 13
#define LABEL_108_13 15
#define LABEL_108_15 17
#define TAG_108_16 7
#define LABEL_108_20 19
#define LABEL_108_21 21
#define LABEL_108_19 23
#define LABEL_108_27 25
#define LABEL_108_22 27
#define TAG_108_23 12
#define LABEL_108_28 29
#define LABEL_108_24 31
#define TAG_108_25 14
#define LABEL_108_29 33
#define TAG_108_30 15
#define LABEL_108_31 35
#define TAG_108_32 16
#define LABEL_108_33 37
#define LABEL_108_35 39
#define LABEL_108_37 41
#define LABEL_108_39 43
#define TAG_108_40 20
#define ENVIRONMENT_LABEL_108_3 72
#define DEBUGGING_LABEL_108_2 71
#define OBJECT_108_5 70
#define OBJECT_108_4 69
#define OBJECT_108_3 68
#define OBJECT_108_2 67
#define OBJECT_108_1 66
#define OBJECT_108_0 65
#define EXECUTE_CACHE_108_38 45
#define EXECUTE_CACHE_108_36 47
#define EXECUTE_CACHE_108_34 49
#define EXECUTE_CACHE_108_26 51
#define EXECUTE_CACHE_108_18 53
#define EXECUTE_CACHE_108_17 55
#define EXECUTE_CACHE_108_10 57
#define EXECUTE_CACHE_108_8 59
#define EXECUTE_CACHE_108_6 61
#define FREE_REFERENCE_108_0 64
#define FREE_REFERENCES_LABEL_108_0 44
#define NUMBER_OF_LINKER_SECTIONS_108_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_108 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd59;
  machine_word Wrd60;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd25;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_108_4);
      goto substitutable_value_condition_signaller_31;

    case 1:
      current_block = (Rpc - LABEL_108_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_108_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_108_9);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_108_11);
      goto lambda_36;

    case 5:
      current_block = (Rpc - LABEL_108_14);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_108_13);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_108_15);
      goto lambda_37;

    case 8:
      current_block = (Rpc - LABEL_108_20);
      goto continuation_12;

    case 9:
      current_block = (Rpc - LABEL_108_21);
      goto continuation_10;

    case 10:
      current_block = (Rpc - LABEL_108_19);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_108_27);
      goto continuation_20;

    case 12:
      current_block = (Rpc - LABEL_108_22);
      goto lambda_38;

    case 13:
      current_block = (Rpc - LABEL_108_28);
      goto label_33;

    case 14:
      current_block = (Rpc - LABEL_108_24);
      goto lambda_39;

    case 15:
      current_block = (Rpc - LABEL_108_29);
      goto lambda_40;

    case 16:
      current_block = (Rpc - LABEL_108_31);
      goto lambda_41;

    case 17:
      current_block = (Rpc - LABEL_108_33);
      goto continuation_14;

    case 18:
      current_block = (Rpc - LABEL_108_35);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_108_37);
      goto continuation_23;

    case 20:
      current_block = (Rpc - LABEL_108_39);
      goto lambda_42;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (substitutable_value_condition_signaller_35)
DEFLABEL (substitutable_value_condition_signaller_31)
  INTERRUPT_CHECK (26, LABEL_108_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_108_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_108_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_108_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_108_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_108_9);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 10));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x1fe, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_11])));
  Rhp += 7;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  Wrd26 = Wrd28;
  (Wrd27.Obj) = (Rsp [9]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Wrd24.Obj) = (Rsp [8]);
  ((Wrd26.pObj) [3]) = (Wrd24.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  ((Wrd26.pObj) [4]) = (Wrd21.Obj);
  (Wrd18.Obj) = (Rsp [6]);
  ((Wrd26.pObj) [5]) = (Wrd18.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  ((Wrd26.pObj) [6]) = (Wrd15.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [7]) = (Wrd12.Obj);
  ((Wrd26.pObj) [8]) = Rvl;
  Rvl = (Wrd29.Obj);
  Rsp = (& (Rsp [10]));
  goto pop_return;

DEFLABEL (lambda_36)
  CLOSURE_HEADER (LABEL_108_11);

DEFLABEL (lambda_28)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_108_13);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [7]);
  if (! ((Wrd8.Obj) == Rvl))
    goto label_44;

DEFLABEL (label_43)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 10));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_15])));
  Rhp += 7;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd42 = Wrd19;
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [2]);
  ((Wrd42.pObj) [2]) = (Wrd45.Obj);
  (Wrd41.Obj) = ((Wrd44.pObj) [3]);
  ((Wrd42.pObj) [3]) = (Wrd41.Obj);
  (Wrd37.Obj) = ((Wrd44.pObj) [4]);
  ((Wrd42.pObj) [4]) = (Wrd37.Obj);
  (Wrd33.Obj) = ((Wrd44.pObj) [5]);
  ((Wrd42.pObj) [5]) = (Wrd33.Obj);
  (Wrd29.Obj) = ((Wrd44.pObj) [6]);
  ((Wrd42.pObj) [6]) = (Wrd29.Obj);
  (Wrd25.Obj) = ((Wrd44.pObj) [8]);
  ((Wrd42.pObj) [7]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  ((Wrd42.pObj) [8]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_17]));

DEFLABEL (label_44)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_14]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_108_14);
  goto label_43;

DEFLABEL (lambda_37)
  CLOSURE_HEADER (LABEL_108_15);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_108_2]);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [8]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Wrd18.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = ((Wrd13.pObj) [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_108_3]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_108_19);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 30)
    goto label_48;
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_108_21);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_47)
  (Wrd20.Obj) = (current_block [OBJECT_108_4]);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_22])));
  Rhp += 6;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd39 = Wrd22;
  (Wrd40.Obj) = (Rsp [3]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [2]);
  ((Wrd39.pObj) [2]) = (Wrd42.Obj);
  (Wrd38.Obj) = ((Wrd41.pObj) [5]);
  ((Wrd39.pObj) [3]) = (Wrd38.Obj);
  (Wrd34.Obj) = ((Wrd41.pObj) [6]);
  ((Wrd39.pObj) [4]) = (Wrd34.Obj);
  (Wrd30.Obj) = ((Wrd41.pObj) [8]);
  ((Wrd39.pObj) [5]) = (Wrd30.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd39.pObj) [6]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  ((Wrd39.pObj) [7]) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_20]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd48.Obj) = ((Wrd41.pObj) [4]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if ((Wrd49.uLng) == 30)
    goto label_46;
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_108_20);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_45)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd60.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_24])));
  Rhp += 1;
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd60.pObj)));
  Wrd61 = Wrd60;
  (Wrd62.Obj) = (Rsp [0]);
  ((Wrd61.pObj) [2]) = (Wrd62.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [4]) = (Wrd59.Obj);
  (Wrd64.Obj) = (Rsp [5]);
  (Rsp [3]) = (Wrd64.Obj);
  (Wrd65.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd65.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_26]));

DEFLABEL (label_46)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd48.Obj);
  goto label_45;

DEFLABEL (label_48)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd10.Obj);
  goto label_47;

DEFLABEL (lambda_38)
  CLOSURE_HEADER (LABEL_108_22);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_108_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_52;
  Wrd5 = Wrd9;

DEFLABEL (label_51)
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_29])));
  Rhp += 3;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd21 = Wrd12;
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [3]);
  ((Wrd21.pObj) [2]) = (Wrd24.Obj);
  (Wrd20.Obj) = ((Wrd23.pObj) [5]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd23.pObj) [6]);
  ((Wrd21.pObj) [4]) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_27]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = ((Wrd23.pObj) [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 30)
    goto label_50;
  (Wrd34.Obj) = ((Wrd23.pObj) [7]);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_108_27);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_49)
  (Wrd42.Obj) = (current_block [OBJECT_108_5]);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd45.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_31])));
  Rhp += 2;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd45.pObj)));
  Wrd50 = Wrd45;
  (Wrd51.Obj) = (Rsp [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [4]);
  ((Wrd50.pObj) [2]) = (Wrd53.Obj);
  (Wrd49.Obj) = ((Wrd52.pObj) [7]);
  ((Wrd50.pObj) [3]) = (Wrd49.Obj);
  (Rsp [4]) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_26]));

DEFLABEL (label_50)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_49;

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_108_28])), (Wrd6.pObj));

DEFLABEL (label_33)
  (Wrd5.Obj) = Rvl;
  goto label_51;

DEFLABEL (lambda_39)
  CLOSURE_HEADER (LABEL_108_24);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_34]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_108_33);
  (Rsp [0]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_108_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_108_39])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_40)
  CLOSURE_HEADER (LABEL_108_29);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_35]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_36]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_108_35);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_41)
  CLOSURE_HEADER (LABEL_108_31);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_38]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_108_37);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_42)
  CLOSURE_HEADER (LABEL_108_39);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_109_4 3
#define LABEL_109_5 5
#define LABEL_109_7 7
#define LABEL_109_8 9
#define ENVIRONMENT_LABEL_109_3 21
#define DEBUGGING_LABEL_109_2 20
#define OBJECT_109_2 19
#define OBJECT_109_1 18
#define OBJECT_109_0 17
#define EXECUTE_CACHE_109_9 11
#define EXECUTE_CACHE_109_6 13
#define FREE_REFERENCE_109_0 16
#define FREE_REFERENCES_LABEL_109_0 10
#define NUMBER_OF_LINKER_SECTIONS_109_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_109 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_109_4);
      goto condition_type_errorP_2;

    case 1:
      current_block = (Rpc - LABEL_109_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_109_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_109_8);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_type_errorP_7)
DEFLABEL (condition_type_errorP_2)
  INTERRUPT_CHECK (26, LABEL_109_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_109_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_109_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_109_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_9;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_9;
  (Wrd11.Obj) = ((Wrd17.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_9]));

DEFLABEL (label_9)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_109_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_8]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_109_2]), 2);

DEFLABEL (label_5)
  (Wrd11.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_109_7])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_110_4 3
#define LABEL_110_5 5
#define LABEL_110_7 7
#define LABEL_110_8 9
#define LABEL_110_9 11
#define ENVIRONMENT_LABEL_110_3 24
#define DEBUGGING_LABEL_110_2 23
#define OBJECT_110_3 22
#define OBJECT_110_2 21
#define OBJECT_110_1 20
#define OBJECT_110_0 19
#define EXECUTE_CACHE_110_10 13
#define EXECUTE_CACHE_110_6 15
#define FREE_REFERENCE_110_0 18
#define FREE_REFERENCES_LABEL_110_0 12
#define NUMBER_OF_LINKER_SECTIONS_110_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_110 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_110_4);
      goto condition_errorP_3;

    case 1:
      current_block = (Rpc - LABEL_110_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_110_7);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_110_8);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_110_9);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (condition_errorP_9)
DEFLABEL (condition_errorP_3)
  INTERRUPT_CHECK (26, LABEL_110_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_110_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_110_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_110_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_110_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_15;
  Wrd5 = Wrd9;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_13;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd19.Lng))))
    goto label_13;
  (Wrd11.Obj) = ((Wrd17.pObj) [2]);

DEFLABEL (label_12)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_11;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd33.Lng))))
    goto label_11;
  (Wrd27.Obj) = ((Wrd31.pObj) [3]);

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_110_10]));

DEFLABEL (label_11)
  (Wrd36.Obj) = (current_block [OBJECT_110_3]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_110_2]), 2);

DEFLABEL (label_7)
  (Wrd27.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_110_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_8]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_110_2]), 2);

DEFLABEL (label_6)
  (Wrd11.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_110_7])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_111_4 3
#define LABEL_111_5 5
#define LABEL_111_6 7
#define LABEL_111_7 9
#define ENVIRONMENT_LABEL_111_3 19
#define DEBUGGING_LABEL_111_2 18
#define OBJECT_111_2 17
#define OBJECT_111_1 16
#define OBJECT_111_0 15
#define EXECUTE_CACHE_111_8 11
#define FREE_REFERENCE_111_0 14
#define FREE_REFERENCES_LABEL_111_0 10
#define NUMBER_OF_LINKER_SECTIONS_111_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_111 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_111_4);
      goto Z__condition_errorP_2;

    case 1:
      current_block = (Rpc - LABEL_111_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_111_6);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_111_7);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_errorP_8)
DEFLABEL (Z__condition_errorP_2)
  INTERRUPT_CHECK (26, LABEL_111_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_111_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_14;
  Wrd5 = Wrd9;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_12;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd19.Lng))))
    goto label_12;
  (Wrd11.Obj) = ((Wrd17.pObj) [2]);

DEFLABEL (label_11)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_10;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd33.Lng))))
    goto label_10;
  (Wrd27.Obj) = ((Wrd31.pObj) [3]);

DEFLABEL (label_9)
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_111_8]));

DEFLABEL (label_10)
  (Wrd36.Obj) = (current_block [OBJECT_111_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_1]), 2);

DEFLABEL (label_6)
  (Wrd27.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_111_0]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_1]), 2);

DEFLABEL (label_5)
  (Wrd11.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_111_5])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_112_4 3
#define LABEL_112_5 5
#define LABEL_112_6 7
#define ENVIRONMENT_LABEL_112_3 16
#define DEBUGGING_LABEL_112_2 15
#define OBJECT_112_1 14
#define OBJECT_112_0 13
#define EXECUTE_CACHE_112_7 9
#define FREE_REFERENCE_112_0 12
#define FREE_REFERENCES_LABEL_112_0 8
#define NUMBER_OF_LINKER_SECTIONS_112_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_112 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_112_4);
      goto Z__condition_type_errorP_1;

    case 1:
      current_block = (Rpc - LABEL_112_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_112_6);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__condition_type_errorP_6)
DEFLABEL (Z__condition_type_errorP_1)
  INTERRUPT_CHECK (26, LABEL_112_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_112_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_10;
  Wrd5 = Wrd9;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_8;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_8;
  (Wrd11.Obj) = ((Wrd17.pObj) [3]);

DEFLABEL (label_7)
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_112_7]));

DEFLABEL (label_8)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_112_0]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_112_1]), 2);

DEFLABEL (label_4)
  (Wrd11.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_112_5])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_113_4 3
#define LABEL_113_5 5
#define LABEL_113_6 7
#define LABEL_113_8 9
#define LABEL_113_7 11
#define LABEL_113_9 13
#define LABEL_113_11 15
#define LABEL_113_12 17
#define LABEL_113_13 19
#define LABEL_113_15 21
#define LABEL_113_14 23
#define LABEL_113_16 25
#define LABEL_113_17 27
#define LABEL_113_19 29
#define LABEL_113_21 31
#define LABEL_113_18 33
#define LABEL_113_20 35
#define LABEL_113_24 37
#define LABEL_113_26 39
#define LABEL_113_22 41
#define LABEL_113_25 43
#define LABEL_113_28 45
#define LABEL_113_31 47
#define LABEL_113_27 49
#define LABEL_113_29 51
#define LABEL_113_33 53
#define LABEL_113_36 55
#define LABEL_113_30 57
#define LABEL_113_34 59
#define LABEL_113_39 61
#define LABEL_113_35 63
#define LABEL_113_37 65
#define LABEL_113_40 67
#define LABEL_113_50 69
#define LABEL_113_42 71
#define LABEL_113_43 73
#define LABEL_113_44 75
#define LABEL_113_45 77
#define TAG_113_46 37
#define LABEL_113_47 79
#define LABEL_113_55 81
#define LABEL_113_59 83
#define LABEL_113_48 85
#define TAG_113_49 41
#define LABEL_113_51 87
#define LABEL_113_52 89
#define LABEL_113_54 91
#define LABEL_113_56 93
#define LABEL_113_63 95
#define LABEL_113_66 97
#define LABEL_113_57 99
#define TAG_113_58 48
#define LABEL_113_60 101
#define LABEL_113_70 103
#define LABEL_113_71 105
#define LABEL_113_73 107
#define LABEL_113_75 109
#define LABEL_113_61 111
#define LABEL_113_64 113
#define LABEL_113_77 115
#define LABEL_113_80 117
#define LABEL_113_65 119
#define LABEL_113_67 121
#define LABEL_113_68 123
#define LABEL_113_69 125
#define LABEL_113_78 127
#define LABEL_113_85 129
#define LABEL_113_88 131
#define LABEL_113_79 133
#define LABEL_113_81 135
#define LABEL_113_82 137
#define LABEL_113_83 139
#define LABEL_113_84 141
#define LABEL_113_86 143
#define LABEL_113_94 145
#define LABEL_113_96 147
#define LABEL_113_87 149
#define LABEL_113_89 151
#define LABEL_113_90 153
#define LABEL_113_91 155
#define LABEL_113_92 157
#define LABEL_113_102 159
#define LABEL_113_93 161
#define LABEL_113_72 163
#define LABEL_113_95 165
#define LABEL_113_104 167
#define LABEL_113_107 169
#define LABEL_113_97 171
#define LABEL_113_98 173
#define LABEL_113_99 175
#define LABEL_113_100 177
#define LABEL_113_101 179
#define LABEL_113_103 181
#define LABEL_113_105 183
#define LABEL_113_114 185
#define LABEL_113_106 187
#define LABEL_113_108 189
#define LABEL_113_109 191
#define LABEL_113_110 193
#define LABEL_113_112 195
#define LABEL_113_121 197
#define LABEL_113_122 199
#define LABEL_113_113 201
#define LABEL_113_123 203
#define LABEL_113_115 205
#define LABEL_113_126 207
#define LABEL_113_128 209
#define LABEL_113_129 211
#define LABEL_113_116 213
#define LABEL_113_117 215
#define LABEL_113_118 217
#define LABEL_113_119 219
#define LABEL_113_120 221
#define LABEL_113_139 223
#define LABEL_113_125 225
#define LABEL_113_140 227
#define LABEL_113_127 229
#define LABEL_113_144 231
#define LABEL_113_130 233
#define TAG_113_131 115
#define LABEL_113_132 235
#define LABEL_113_133 237
#define LABEL_113_134 239
#define LABEL_113_135 241
#define LABEL_113_136 243
#define LABEL_113_137 245
#define LABEL_113_141 247
#define LABEL_113_143 249
#define LABEL_113_145 251
#define LABEL_113_151 253
#define LABEL_113_146 255
#define LABEL_113_147 257
#define LABEL_113_148 259
#define LABEL_113_158 261
#define LABEL_113_159 263
#define LABEL_113_150 265
#define LABEL_113_162 267
#define LABEL_113_149 269
#define LABEL_113_152 271
#define LABEL_113_165 273
#define LABEL_113_168 275
#define LABEL_113_153 277
#define LABEL_113_154 279
#define LABEL_113_156 281
#define LABEL_113_160 283
#define LABEL_113_161 285
#define LABEL_113_164 287
#define LABEL_113_166 289
#define LABEL_113_172 291
#define LABEL_113_174 293
#define LABEL_113_167 295
#define LABEL_113_169 297
#define LABEL_113_171 299
#define LABEL_113_173 301
#define LABEL_113_181 303
#define LABEL_113_184 305
#define LABEL_113_176 307
#define LABEL_113_177 309
#define LABEL_113_179 311
#define TAG_113_180 154
#define LABEL_113_182 313
#define LABEL_113_192 315
#define LABEL_113_194 317
#define LABEL_113_183 319
#define LABEL_113_185 321
#define LABEL_113_186 323
#define LABEL_113_189 325
#define LABEL_113_188 327
#define LABEL_113_187 329
#define LABEL_113_200 331
#define LABEL_113_190 333
#define LABEL_113_202 335
#define LABEL_113_203 337
#define LABEL_113_193 339
#define LABEL_113_206 341
#define LABEL_113_209 343
#define LABEL_113_195 345
#define LABEL_113_196 347
#define LABEL_113_197 349
#define LABEL_113_198 351
#define LABEL_113_199 353
#define LABEL_113_215 355
#define LABEL_113_201 357
#define LABEL_113_204 359
#define TAG_113_205 178
#define LABEL_113_207 361
#define LABEL_113_218 363
#define LABEL_113_220 365
#define LABEL_113_208 367
#define LABEL_113_210 369
#define LABEL_113_211 371
#define LABEL_113_212 373
#define LABEL_113_214 375
#define LABEL_113_217 377
#define LABEL_113_226 379
#define LABEL_113_227 381
#define LABEL_113_219 383
#define LABEL_113_230 385
#define LABEL_113_232 387
#define LABEL_113_221 389
#define LABEL_113_222 391
#define LABEL_113_223 393
#define LABEL_113_224 395
#define LABEL_113_225 397
#define LABEL_113_228 399
#define TAG_113_229 198
#define LABEL_113_231 401
#define LABEL_113_239 403
#define LABEL_113_242 405
#define LABEL_113_234 407
#define LABEL_113_235 409
#define LABEL_113_236 411
#define LABEL_113_238 413
#define LABEL_113_246 415
#define LABEL_113_247 417
#define LABEL_113_240 419
#define LABEL_113_248 421
#define LABEL_113_251 423
#define LABEL_113_241 425
#define LABEL_113_243 427
#define LABEL_113_244 429
#define LABEL_113_245 431
#define LABEL_113_249 433
#define LABEL_113_258 435
#define LABEL_113_261 437
#define LABEL_113_250 439
#define LABEL_113_263 441
#define LABEL_113_253 443
#define LABEL_113_254 445
#define LABEL_113_255 447
#define TAG_113_256 222
#define LABEL_113_259 449
#define LABEL_113_271 451
#define LABEL_113_274 453
#define LABEL_113_260 455
#define LABEL_113_262 457
#define LABEL_113_278 459
#define LABEL_113_279 461
#define LABEL_113_264 463
#define LABEL_113_265 465
#define LABEL_113_266 467
#define LABEL_113_268 469
#define LABEL_113_269 471
#define LABEL_113_272 473
#define LABEL_113_289 475
#define LABEL_113_292 477
#define LABEL_113_273 479
#define LABEL_113_275 481
#define LABEL_113_276 483
#define TAG_113_277 240
#define LABEL_113_280 485
#define TAG_113_281 241
#define LABEL_113_282 487
#define TAG_113_283 242
#define LABEL_113_285 489
#define LABEL_113_286 491
#define LABEL_113_287 493
#define LABEL_113_290 495
#define LABEL_113_301 497
#define LABEL_113_304 499
#define LABEL_113_291 501
#define LABEL_113_293 503
#define LABEL_113_294 505
#define LABEL_113_295 507
#define LABEL_113_296 509
#define LABEL_113_297 511
#define LABEL_113_298 513
#define LABEL_113_299 515
#define LABEL_113_300 517
#define LABEL_113_302 519
#define LABEL_113_311 521
#define LABEL_113_303 523
#define LABEL_113_305 525
#define LABEL_113_306 527
#define LABEL_113_308 529
#define LABEL_113_309 531
#define LABEL_113_310 533
#define LABEL_113_312 535
#define LABEL_113_318 537
#define LABEL_113_313 539
#define LABEL_113_321 541
#define LABEL_113_322 543
#define LABEL_113_314 545
#define LABEL_113_315 547
#define LABEL_113_317 549
#define LABEL_113_319 551
#define LABEL_113_329 553
#define LABEL_113_320 555
#define LABEL_113_332 557
#define LABEL_113_323 559
#define TAG_113_324 278
#define LABEL_113_325 561
#define LABEL_113_326 563
#define LABEL_113_327 565
#define LABEL_113_328 567
#define LABEL_113_330 569
#define LABEL_113_336 571
#define LABEL_113_331 573
#define LABEL_113_339 575
#define LABEL_113_333 577
#define LABEL_113_334 579
#define LABEL_113_337 581
#define LABEL_113_343 583
#define LABEL_113_346 585
#define LABEL_113_338 587
#define LABEL_113_347 589
#define LABEL_113_340 591
#define LABEL_113_341 593
#define LABEL_113_342 595
#define LABEL_113_344 597
#define LABEL_113_352 599
#define LABEL_113_354 601
#define LABEL_113_345 603
#define LABEL_113_348 605
#define LABEL_113_350 607
#define LABEL_113_349 609
#define LABEL_113_353 611
#define LABEL_113_357 613
#define LABEL_113_359 615
#define LABEL_113_355 617
#define LABEL_113_356 619
#define LABEL_113_358 621
#define LABEL_113_362 623
#define LABEL_113_364 625
#define LABEL_113_365 627
#define LABEL_113_360 629
#define LABEL_113_361 631
#define LABEL_113_363 633
#define LABEL_113_367 635
#define LABEL_113_369 637
#define LABEL_113_370 639
#define LABEL_113_368 641
#define LABEL_113_371 643
#define LABEL_113_373 645
#define LABEL_113_374 647
#define LABEL_113_372 649
#define LABEL_113_375 651
#define LABEL_113_377 653
#define LABEL_113_378 655
#define LABEL_113_376 657
#define LABEL_113_379 659
#define LABEL_113_381 661
#define LABEL_113_382 663
#define LABEL_113_380 665
#define LABEL_113_383 667
#define LABEL_113_385 669
#define LABEL_113_386 671
#define LABEL_113_384 673
#define LABEL_113_387 675
#define LABEL_113_389 677
#define LABEL_113_390 679
#define LABEL_113_388 681
#define LABEL_113_391 683
#define LABEL_113_393 685
#define LABEL_113_394 687
#define LABEL_113_392 689
#define LABEL_113_395 691
#define LABEL_113_397 693
#define LABEL_113_398 695
#define LABEL_113_396 697
#define LABEL_113_399 699
#define LABEL_113_401 701
#define LABEL_113_402 703
#define LABEL_113_400 705
#define LABEL_113_403 707
#define LABEL_113_405 709
#define LABEL_113_406 711
#define LABEL_113_404 713
#define LABEL_113_407 715
#define LABEL_113_409 717
#define LABEL_113_410 719
#define LABEL_113_408 721
#define LABEL_113_411 723
#define ENVIRONMENT_LABEL_113_3 1039
#define DEBUGGING_LABEL_113_2 1038
#define OBJECT_113_156 1037
#define OBJECT_113_155 1036
#define OBJECT_113_154 1035
#define OBJECT_113_153 1034
#define OBJECT_113_152 1033
#define OBJECT_113_151 1032
#define OBJECT_113_150 1031
#define OBJECT_113_149 1030
#define OBJECT_113_148 1029
#define OBJECT_113_147 1028
#define OBJECT_113_146 1027
#define OBJECT_113_145 1026
#define OBJECT_113_144 1025
#define OBJECT_113_143 1024
#define OBJECT_113_142 1023
#define OBJECT_113_141 1022
#define OBJECT_113_140 1021
#define OBJECT_113_139 1020
#define OBJECT_113_138 1019
#define OBJECT_113_137 1018
#define OBJECT_113_136 1017
#define OBJECT_113_135 1016
#define OBJECT_113_134 1015
#define OBJECT_113_133 1014
#define OBJECT_113_132 1013
#define OBJECT_113_131 1012
#define OBJECT_113_130 1011
#define OBJECT_113_129 1010
#define OBJECT_113_128 1009
#define OBJECT_113_127 1008
#define OBJECT_113_126 1007
#define OBJECT_113_125 1006
#define OBJECT_113_124 1005
#define OBJECT_113_123 1004
#define OBJECT_113_122 1003
#define OBJECT_113_121 1002
#define OBJECT_113_120 1001
#define OBJECT_113_119 1000
#define OBJECT_113_118 999
#define OBJECT_113_117 998
#define OBJECT_113_116 997
#define OBJECT_113_115 996
#define OBJECT_113_114 995
#define OBJECT_113_113 994
#define OBJECT_113_112 993
#define OBJECT_113_111 992
#define OBJECT_113_110 991
#define OBJECT_113_109 990
#define OBJECT_113_108 989
#define OBJECT_113_107 988
#define OBJECT_113_106 987
#define OBJECT_113_105 986
#define OBJECT_113_104 985
#define OBJECT_113_103 984
#define OBJECT_113_102 983
#define OBJECT_113_101 982
#define OBJECT_113_100 981
#define OBJECT_113_99 980
#define OBJECT_113_98 979
#define OBJECT_113_97 978
#define OBJECT_113_96 977
#define OBJECT_113_95 976
#define OBJECT_113_94 975
#define OBJECT_113_93 974
#define OBJECT_113_92 973
#define OBJECT_113_91 972
#define OBJECT_113_90 971
#define OBJECT_113_89 970
#define OBJECT_113_88 969
#define OBJECT_113_87 968
#define OBJECT_113_86 967
#define OBJECT_113_85 966
#define OBJECT_113_84 965
#define OBJECT_113_83 964
#define OBJECT_113_82 963
#define OBJECT_113_81 962
#define OBJECT_113_80 961
#define OBJECT_113_79 960
#define OBJECT_113_78 959
#define OBJECT_113_77 958
#define OBJECT_113_76 957
#define OBJECT_113_75 956
#define OBJECT_113_74 955
#define OBJECT_113_73 954
#define OBJECT_113_72 953
#define OBJECT_113_71 952
#define OBJECT_113_70 951
#define OBJECT_113_69 950
#define OBJECT_113_68 949
#define OBJECT_113_67 948
#define OBJECT_113_66 947
#define OBJECT_113_65 946
#define OBJECT_113_64 945
#define OBJECT_113_63 944
#define OBJECT_113_62 943
#define OBJECT_113_61 942
#define OBJECT_113_60 941
#define OBJECT_113_59 940
#define OBJECT_113_58 939
#define OBJECT_113_57 938
#define OBJECT_113_56 937
#define OBJECT_113_55 936
#define OBJECT_113_54 935
#define OBJECT_113_53 934
#define OBJECT_113_52 933
#define OBJECT_113_51 932
#define OBJECT_113_50 931
#define OBJECT_113_49 930
#define OBJECT_113_48 929
#define OBJECT_113_47 928
#define OBJECT_113_46 927
#define OBJECT_113_45 926
#define OBJECT_113_44 925
#define OBJECT_113_43 924
#define OBJECT_113_42 923
#define OBJECT_113_41 922
#define OBJECT_113_40 921
#define OBJECT_113_39 920
#define OBJECT_113_38 919
#define OBJECT_113_37 918
#define OBJECT_113_36 917
#define OBJECT_113_35 916
#define OBJECT_113_34 915
#define OBJECT_113_33 914
#define OBJECT_113_32 913
#define OBJECT_113_31 912
#define OBJECT_113_30 911
#define OBJECT_113_29 910
#define OBJECT_113_28 909
#define OBJECT_113_27 908
#define OBJECT_113_26 907
#define OBJECT_113_25 906
#define OBJECT_113_24 905
#define OBJECT_113_23 904
#define OBJECT_113_22 903
#define OBJECT_113_21 902
#define OBJECT_113_20 901
#define OBJECT_113_19 900
#define OBJECT_113_18 899
#define OBJECT_113_17 898
#define OBJECT_113_16 897
#define OBJECT_113_15 896
#define OBJECT_113_14 895
#define OBJECT_113_13 894
#define OBJECT_113_12 893
#define OBJECT_113_11 892
#define OBJECT_113_10 891
#define OBJECT_113_9 890
#define OBJECT_113_8 889
#define OBJECT_113_7 888
#define OBJECT_113_6 887
#define OBJECT_113_5 886
#define OBJECT_113_4 885
#define OBJECT_113_3 884
#define OBJECT_113_2 883
#define OBJECT_113_1 882
#define OBJECT_113_0 881
#define EXECUTE_CACHE_113_366 725
#define EXECUTE_CACHE_113_351 727
#define EXECUTE_CACHE_113_335 729
#define EXECUTE_CACHE_113_316 731
#define EXECUTE_CACHE_113_307 733
#define EXECUTE_CACHE_113_288 735
#define EXECUTE_CACHE_113_284 737
#define EXECUTE_CACHE_113_270 739
#define EXECUTE_CACHE_113_267 741
#define EXECUTE_CACHE_113_257 743
#define EXECUTE_CACHE_113_252 745
#define EXECUTE_CACHE_113_237 747
#define EXECUTE_CACHE_113_233 749
#define EXECUTE_CACHE_113_216 751
#define EXECUTE_CACHE_113_213 753
#define EXECUTE_CACHE_113_191 755
#define EXECUTE_CACHE_113_178 757
#define EXECUTE_CACHE_113_175 759
#define EXECUTE_CACHE_113_170 761
#define EXECUTE_CACHE_113_163 763
#define EXECUTE_CACHE_113_157 765
#define EXECUTE_CACHE_113_155 767
#define EXECUTE_CACHE_113_142 769
#define EXECUTE_CACHE_113_138 771
#define EXECUTE_CACHE_113_124 773
#define EXECUTE_CACHE_113_111 775
#define EXECUTE_CACHE_113_76 777
#define EXECUTE_CACHE_113_74 779
#define EXECUTE_CACHE_113_62 781
#define EXECUTE_CACHE_113_53 783
#define EXECUTE_CACHE_113_41 785
#define EXECUTE_CACHE_113_38 787
#define EXECUTE_CACHE_113_32 789
#define EXECUTE_CACHE_113_23 791
#define EXECUTE_CACHE_113_10 793
#define FREE_REFERENCE_113_30 796
#define FREE_REFERENCE_113_29 797
#define FREE_REFERENCE_113_28 798
#define FREE_REFERENCE_113_27 799
#define FREE_REFERENCE_113_26 800
#define FREE_REFERENCE_113_25 801
#define FREE_REFERENCE_113_24 802
#define FREE_REFERENCE_113_23 803
#define FREE_REFERENCE_113_22 804
#define FREE_REFERENCE_113_21 805
#define FREE_REFERENCE_113_20 806
#define FREE_REFERENCE_113_19 807
#define FREE_REFERENCE_113_18 808
#define FREE_REFERENCE_113_17 809
#define FREE_REFERENCE_113_16 810
#define FREE_REFERENCE_113_15 811
#define FREE_REFERENCE_113_14 812
#define FREE_REFERENCE_113_13 813
#define FREE_REFERENCE_113_12 814
#define FREE_REFERENCE_113_11 815
#define FREE_REFERENCE_113_10 816
#define FREE_REFERENCE_113_9 817
#define FREE_REFERENCE_113_8 818
#define FREE_REFERENCE_113_7 819
#define FREE_REFERENCE_113_6 820
#define FREE_REFERENCE_113_5 821
#define FREE_REFERENCE_113_4 822
#define FREE_REFERENCE_113_3 823
#define FREE_REFERENCE_113_2 824
#define FREE_REFERENCE_113_1 825
#define FREE_REFERENCE_113_0 826
#define FREE_ASSIGNMENT_113_52 828
#define FREE_ASSIGNMENT_113_51 829
#define FREE_ASSIGNMENT_113_50 830
#define FREE_ASSIGNMENT_113_49 831
#define FREE_ASSIGNMENT_113_48 832
#define FREE_ASSIGNMENT_113_47 833
#define FREE_ASSIGNMENT_113_46 834
#define FREE_ASSIGNMENT_113_45 835
#define FREE_ASSIGNMENT_113_44 836
#define FREE_ASSIGNMENT_113_43 837
#define FREE_ASSIGNMENT_113_42 838
#define FREE_ASSIGNMENT_113_41 839
#define FREE_ASSIGNMENT_113_40 840
#define FREE_ASSIGNMENT_113_39 841
#define FREE_ASSIGNMENT_113_38 842
#define FREE_ASSIGNMENT_113_37 843
#define FREE_ASSIGNMENT_113_36 844
#define FREE_ASSIGNMENT_113_35 845
#define FREE_ASSIGNMENT_113_34 846
#define FREE_ASSIGNMENT_113_33 847
#define FREE_ASSIGNMENT_113_32 848
#define FREE_ASSIGNMENT_113_31 849
#define FREE_ASSIGNMENT_113_30 850
#define FREE_ASSIGNMENT_113_29 851
#define FREE_ASSIGNMENT_113_28 852
#define FREE_ASSIGNMENT_113_27 853
#define FREE_ASSIGNMENT_113_26 854
#define FREE_ASSIGNMENT_113_25 855
#define FREE_ASSIGNMENT_113_24 856
#define FREE_ASSIGNMENT_113_23 857
#define FREE_ASSIGNMENT_113_22 858
#define FREE_ASSIGNMENT_113_21 859
#define FREE_ASSIGNMENT_113_20 860
#define FREE_ASSIGNMENT_113_19 861
#define FREE_ASSIGNMENT_113_18 862
#define FREE_ASSIGNMENT_113_17 863
#define FREE_ASSIGNMENT_113_16 864
#define FREE_ASSIGNMENT_113_15 865
#define FREE_ASSIGNMENT_113_14 866
#define FREE_ASSIGNMENT_113_13 867
#define FREE_ASSIGNMENT_113_12 868
#define FREE_ASSIGNMENT_113_11 869
#define FREE_ASSIGNMENT_113_10 870
#define FREE_ASSIGNMENT_113_9 871
#define FREE_ASSIGNMENT_113_8 872
#define FREE_ASSIGNMENT_113_7 873
#define FREE_ASSIGNMENT_113_6 874
#define FREE_ASSIGNMENT_113_5 875
#define FREE_ASSIGNMENT_113_4 876
#define FREE_ASSIGNMENT_113_3 877
#define FREE_ASSIGNMENT_113_2 878
#define FREE_ASSIGNMENT_113_1 879
#define FREE_ASSIGNMENT_113_0 880
#define FREE_REFERENCES_LABEL_113_0 724
#define NUMBER_OF_LINKER_SECTIONS_113_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_113 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd35;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd42;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_113_4);
      goto initialize_packageB_281;

    case 1:
      current_block = (Rpc - LABEL_113_5);
      goto label_283;

    case 2:
      current_block = (Rpc - LABEL_113_6);
      goto label_284;

    case 3:
      current_block = (Rpc - LABEL_113_8);
      goto label_285;

    case 4:
      current_block = (Rpc - LABEL_113_7);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_113_9);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_113_11);
      goto label_286;

    case 7:
      current_block = (Rpc - LABEL_113_12);
      goto continuation_2;

    case 8:
      current_block = (Rpc - LABEL_113_13);
      goto label_287;

    case 9:
      current_block = (Rpc - LABEL_113_15);
      goto label_288;

    case 10:
      current_block = (Rpc - LABEL_113_14);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_113_16);
      goto label_289;

    case 12:
      current_block = (Rpc - LABEL_113_17);
      goto continuation_8;

    case 13:
      current_block = (Rpc - LABEL_113_19);
      goto label_290;

    case 14:
      current_block = (Rpc - LABEL_113_21);
      goto label_291;

    case 15:
      current_block = (Rpc - LABEL_113_18);
      goto lambda_6;

    case 16:
      current_block = (Rpc - LABEL_113_20);
      goto continuation_9;

    case 17:
      current_block = (Rpc - LABEL_113_24);
      goto label_292;

    case 18:
      current_block = (Rpc - LABEL_113_26);
      goto label_293;

    case 19:
      current_block = (Rpc - LABEL_113_22);
      goto continuation_4;

    case 20:
      current_block = (Rpc - LABEL_113_25);
      goto continuation_10;

    case 21:
      current_block = (Rpc - LABEL_113_28);
      goto label_294;

    case 22:
      current_block = (Rpc - LABEL_113_31);
      goto label_295;

    case 23:
      current_block = (Rpc - LABEL_113_27);
      goto continuation_5;

    case 24:
      current_block = (Rpc - LABEL_113_29);
      goto continuation_16;

    case 25:
      current_block = (Rpc - LABEL_113_33);
      goto label_296;

    case 26:
      current_block = (Rpc - LABEL_113_36);
      goto label_297;

    case 27:
      current_block = (Rpc - LABEL_113_30);
      goto lambda_15;

    case 28:
      current_block = (Rpc - LABEL_113_34);
      goto continuation_21;

    case 29:
      current_block = (Rpc - LABEL_113_39);
      goto label_298;

    case 30:
      current_block = (Rpc - LABEL_113_35);
      goto lambda_20;

    case 31:
      current_block = (Rpc - LABEL_113_37);
      goto continuation_12;

    case 32:
      current_block = (Rpc - LABEL_113_40);
      goto continuation_22;

    case 33:
      current_block = (Rpc - LABEL_113_50);
      goto label_299;

    case 34:
      current_block = (Rpc - LABEL_113_42);
      goto continuation_17;

    case 35:
      current_block = (Rpc - LABEL_113_43);
      goto continuation_14;

    case 36:
      current_block = (Rpc - LABEL_113_44);
      goto continuation_13;

    case 37:
      current_block = (Rpc - LABEL_113_45);
      goto lambda_34;

    case 38:
      current_block = (Rpc - LABEL_113_47);
      goto continuation_64;

    case 39:
      current_block = (Rpc - LABEL_113_55);
      goto label_300;

    case 40:
      current_block = (Rpc - LABEL_113_59);
      goto label_301;

    case 41:
      current_block = (Rpc - LABEL_113_48);
      goto lambda_417;

    case 42:
      current_block = (Rpc - LABEL_113_51);
      goto continuation_19;

    case 43:
      current_block = (Rpc - LABEL_113_52);
      goto continuation_18;

    case 44:
      current_block = (Rpc - LABEL_113_54);
      goto continuation_24;

    case 45:
      current_block = (Rpc - LABEL_113_56);
      goto continuation_72;

    case 46:
      current_block = (Rpc - LABEL_113_63);
      goto label_302;

    case 47:
      current_block = (Rpc - LABEL_113_66);
      goto label_303;

    case 48:
      current_block = (Rpc - LABEL_113_57);
      goto lambda_418;

    case 49:
      current_block = (Rpc - LABEL_113_60);
      goto continuation_58;

    case 50:
      current_block = (Rpc - LABEL_113_70);
      goto continuation_32;

    case 51:
      current_block = (Rpc - LABEL_113_71);
      goto continuation_28;

    case 52:
      current_block = (Rpc - LABEL_113_73);
      goto label_308;

    case 53:
      current_block = (Rpc - LABEL_113_75);
      goto continuation_27;

    case 54:
      current_block = (Rpc - LABEL_113_61);
      goto continuation_26;

    case 55:
      current_block = (Rpc - LABEL_113_64);
      goto continuation_78;

    case 56:
      current_block = (Rpc - LABEL_113_77);
      goto label_304;

    case 57:
      current_block = (Rpc - LABEL_113_80);
      goto label_305;

    case 58:
      current_block = (Rpc - LABEL_113_65);
      goto lambda_77;

    case 59:
      current_block = (Rpc - LABEL_113_67);
      goto continuation_65;

    case 60:
      current_block = (Rpc - LABEL_113_68);
      goto continuation_60;

    case 61:
      current_block = (Rpc - LABEL_113_69);
      goto continuation_59;

    case 62:
      current_block = (Rpc - LABEL_113_78);
      goto continuation_112;

    case 63:
      current_block = (Rpc - LABEL_113_85);
      goto label_306;

    case 64:
      current_block = (Rpc - LABEL_113_88);
      goto label_307;

    case 65:
      current_block = (Rpc - LABEL_113_79);
      goto lambda_111;

    case 66:
      current_block = (Rpc - LABEL_113_81);
      goto continuation_73;

    case 67:
      current_block = (Rpc - LABEL_113_82);
      goto continuation_67;

    case 68:
      current_block = (Rpc - LABEL_113_83);
      goto continuation_66;

    case 69:
      current_block = (Rpc - LABEL_113_84);
      goto continuation_61;

    case 70:
      current_block = (Rpc - LABEL_113_86);
      goto continuation_120;

    case 71:
      current_block = (Rpc - LABEL_113_94);
      goto label_309;

    case 72:
      current_block = (Rpc - LABEL_113_96);
      goto label_310;

    case 73:
      current_block = (Rpc - LABEL_113_87);
      goto lambda_119;

    case 74:
      current_block = (Rpc - LABEL_113_89);
      goto continuation_83;

    case 75:
      current_block = (Rpc - LABEL_113_90);
      goto continuation_75;

    case 76:
      current_block = (Rpc - LABEL_113_91);
      goto continuation_74;

    case 77:
      current_block = (Rpc - LABEL_113_92);
      goto continuation_68;

    case 78:
      current_block = (Rpc - LABEL_113_102);
      goto lambda_56;

    case 79:
      current_block = (Rpc - LABEL_113_93);
      goto continuation_62;

    case 80:
      current_block = (Rpc - LABEL_113_72);
      goto continuation_30;

    case 81:
      current_block = (Rpc - LABEL_113_95);
      goto continuation_121;

    case 82:
      current_block = (Rpc - LABEL_113_104);
      goto label_311;

    case 83:
      current_block = (Rpc - LABEL_113_107);
      goto label_312;

    case 84:
      current_block = (Rpc - LABEL_113_97);
      goto continuation_113;

    case 85:
      current_block = (Rpc - LABEL_113_98);
      goto continuation_85;

    case 86:
      current_block = (Rpc - LABEL_113_99);
      goto continuation_84;

    case 87:
      current_block = (Rpc - LABEL_113_100);
      goto continuation_76;

    case 88:
      current_block = (Rpc - LABEL_113_101);
      goto continuation_69;

    case 89:
      current_block = (Rpc - LABEL_113_103);
      goto continuation_37;

    case 90:
      current_block = (Rpc - LABEL_113_105);
      goto continuation_126;

    case 91:
      current_block = (Rpc - LABEL_113_114);
      goto label_313;

    case 92:
      current_block = (Rpc - LABEL_113_106);
      goto lambda_125;

    case 93:
      current_block = (Rpc - LABEL_113_108);
      goto continuation_115;

    case 94:
      current_block = (Rpc - LABEL_113_109);
      goto continuation_114;

    case 95:
      current_block = (Rpc - LABEL_113_110);
      goto continuation_86;

    case 96:
      current_block = (Rpc - LABEL_113_112);
      goto continuation_70;

    case 97:
      current_block = (Rpc - LABEL_113_121);
      goto continuation_41;

    case 98:
      current_block = (Rpc - LABEL_113_122);
      goto continuation_38;

    case 99:
      current_block = (Rpc - LABEL_113_113);
      goto continuation_36;

    case 100:
      current_block = (Rpc - LABEL_113_123);
      goto label_314;

    case 101:
      current_block = (Rpc - LABEL_113_115);
      goto continuation_134;

    case 102:
      current_block = (Rpc - LABEL_113_126);
      goto label_315;

    case 103:
      current_block = (Rpc - LABEL_113_128);
      goto lambda_132;

    case 104:
      current_block = (Rpc - LABEL_113_129);
      goto label_316;

    case 105:
      current_block = (Rpc - LABEL_113_116);
      goto continuation_122;

    case 106:
      current_block = (Rpc - LABEL_113_117);
      goto continuation_116;

    case 107:
      current_block = (Rpc - LABEL_113_118);
      goto continuation_89;

    case 108:
      current_block = (Rpc - LABEL_113_119);
      goto continuation_88;

    case 109:
      current_block = (Rpc - LABEL_113_120);
      goto continuation_87;

    case 110:
      current_block = (Rpc - LABEL_113_139);
      goto continuation_43;

    case 111:
      current_block = (Rpc - LABEL_113_125);
      goto continuation_42;

    case 112:
      current_block = (Rpc - LABEL_113_140);
      goto label_317;

    case 113:
      current_block = (Rpc - LABEL_113_127);
      goto continuation_135;

    case 114:
      current_block = (Rpc - LABEL_113_144);
      goto label_318;

    case 115:
      current_block = (Rpc - LABEL_113_130);
      goto lambda_425;

    case 116:
      current_block = (Rpc - LABEL_113_132);
      goto continuation_124;

    case 117:
      current_block = (Rpc - LABEL_113_133);
      goto continuation_123;

    case 118:
      current_block = (Rpc - LABEL_113_134);
      goto continuation_118;

    case 119:
      current_block = (Rpc - LABEL_113_135);
      goto continuation_117;

    case 120:
      current_block = (Rpc - LABEL_113_136);
      goto continuation_92;

    case 121:
      current_block = (Rpc - LABEL_113_137);
      goto continuation_90;

    case 122:
      current_block = (Rpc - LABEL_113_141);
      goto continuation_46;

    case 123:
      current_block = (Rpc - LABEL_113_143);
      goto continuation_52;

    case 124:
      current_block = (Rpc - LABEL_113_145);
      goto continuation_136;

    case 125:
      current_block = (Rpc - LABEL_113_151);
      goto label_319;

    case 126:
      current_block = (Rpc - LABEL_113_146);
      goto continuation_128;

    case 127:
      current_block = (Rpc - LABEL_113_147);
      goto continuation_94;

    case 128:
      current_block = (Rpc - LABEL_113_148);
      goto continuation_93;

    case 129:
      current_block = (Rpc - LABEL_113_158);
      goto lambda_82;

    case 130:
      current_block = (Rpc - LABEL_113_159);
      goto label_320;

    case 131:
      current_block = (Rpc - LABEL_113_150);
      goto continuation_48;

    case 132:
      current_block = (Rpc - LABEL_113_162);
      goto label_321;

    case 133:
      current_block = (Rpc - LABEL_113_149);
      goto continuation_47;

    case 134:
      current_block = (Rpc - LABEL_113_152);
      goto continuation_137;

    case 135:
      current_block = (Rpc - LABEL_113_165);
      goto label_322;

    case 136:
      current_block = (Rpc - LABEL_113_168);
      goto label_323;

    case 137:
      current_block = (Rpc - LABEL_113_153);
      goto continuation_130;

    case 138:
      current_block = (Rpc - LABEL_113_154);
      goto continuation_129;

    case 139:
      current_block = (Rpc - LABEL_113_156);
      goto continuation_96;

    case 140:
      current_block = (Rpc - LABEL_113_160);
      goto continuation_51;

    case 141:
      current_block = (Rpc - LABEL_113_161);
      goto continuation_50;

    case 142:
      current_block = (Rpc - LABEL_113_164);
      goto continuation_53;

    case 143:
      current_block = (Rpc - LABEL_113_166);
      goto continuation_146;

    case 144:
      current_block = (Rpc - LABEL_113_172);
      goto label_324;

    case 145:
      current_block = (Rpc - LABEL_113_174);
      goto label_325;

    case 146:
      current_block = (Rpc - LABEL_113_167);
      goto lambda_145;

    case 147:
      current_block = (Rpc - LABEL_113_169);
      goto continuation_95;

    case 148:
      current_block = (Rpc - LABEL_113_171);
      goto continuation_54;

    case 149:
      current_block = (Rpc - LABEL_113_173);
      goto continuation_147;

    case 150:
      current_block = (Rpc - LABEL_113_181);
      goto label_326;

    case 151:
      current_block = (Rpc - LABEL_113_184);
      goto label_327;

    case 152:
      current_block = (Rpc - LABEL_113_176);
      goto continuation_139;

    case 153:
      current_block = (Rpc - LABEL_113_177);
      goto continuation_97;

    case 154:
      current_block = (Rpc - LABEL_113_179);
      goto lambda_428;

    case 155:
      current_block = (Rpc - LABEL_113_182);
      goto continuation_162;

    case 156:
      current_block = (Rpc - LABEL_113_192);
      goto label_328;

    case 157:
      current_block = (Rpc - LABEL_113_194);
      goto label_329;

    case 158:
      current_block = (Rpc - LABEL_113_183);
      goto lambda_161;

    case 159:
      current_block = (Rpc - LABEL_113_185);
      goto continuation_141;

    case 160:
      current_block = (Rpc - LABEL_113_186);
      goto continuation_140;

    case 161:
      current_block = (Rpc - LABEL_113_189);
      goto continuation_106;

    case 162:
      current_block = (Rpc - LABEL_113_188);
      goto continuation_102;

    case 163:
      current_block = (Rpc - LABEL_113_187);
      goto continuation_98;

    case 164:
      current_block = (Rpc - LABEL_113_200);
      goto label_330;

    case 165:
      current_block = (Rpc - LABEL_113_190);
      goto continuation_149;

    case 166:
      current_block = (Rpc - LABEL_113_202);
      goto label_331;

    case 167:
      current_block = (Rpc - LABEL_113_203);
      goto label_332;

    case 168:
      current_block = (Rpc - LABEL_113_193);
      goto continuation_163;

    case 169:
      current_block = (Rpc - LABEL_113_206);
      goto label_333;

    case 170:
      current_block = (Rpc - LABEL_113_209);
      goto label_334;

    case 171:
      current_block = (Rpc - LABEL_113_195);
      goto continuation_155;

    case 172:
      current_block = (Rpc - LABEL_113_196);
      goto continuation_142;

    case 173:
      current_block = (Rpc - LABEL_113_197);
      goto continuation_107;

    case 174:
      current_block = (Rpc - LABEL_113_198);
      goto continuation_103;

    case 175:
      current_block = (Rpc - LABEL_113_199);
      goto continuation_100;

    case 176:
      current_block = (Rpc - LABEL_113_215);
      goto label_335;

    case 177:
      current_block = (Rpc - LABEL_113_201);
      goto continuation_152;

    case 178:
      current_block = (Rpc - LABEL_113_204);
      goto lambda_430;

    case 179:
      current_block = (Rpc - LABEL_113_207);
      goto continuation_183;

    case 180:
      current_block = (Rpc - LABEL_113_218);
      goto label_336;

    case 181:
      current_block = (Rpc - LABEL_113_220);
      goto label_337;

    case 182:
      current_block = (Rpc - LABEL_113_208);
      goto lambda_182;

    case 183:
      current_block = (Rpc - LABEL_113_210);
      goto continuation_157;

    case 184:
      current_block = (Rpc - LABEL_113_211);
      goto continuation_156;

    case 185:
      current_block = (Rpc - LABEL_113_212);
      goto continuation_143;

    case 186:
      current_block = (Rpc - LABEL_113_214);
      goto continuation_104;

    case 187:
      current_block = (Rpc - LABEL_113_217);
      goto continuation_165;

    case 188:
      current_block = (Rpc - LABEL_113_226);
      goto label_338;

    case 189:
      current_block = (Rpc - LABEL_113_227);
      goto label_339;

    case 190:
      current_block = (Rpc - LABEL_113_219);
      goto continuation_184;

    case 191:
      current_block = (Rpc - LABEL_113_230);
      goto label_340;

    case 192:
      current_block = (Rpc - LABEL_113_232);
      goto label_341;

    case 193:
      current_block = (Rpc - LABEL_113_221);
      goto continuation_171;

    case 194:
      current_block = (Rpc - LABEL_113_222);
      goto continuation_158;

    case 195:
      current_block = (Rpc - LABEL_113_223);
      goto continuation_144;

    case 196:
      current_block = (Rpc - LABEL_113_224);
      goto continuation_105;

    case 197:
      current_block = (Rpc - LABEL_113_225);
      goto continuation_168;

    case 198:
      current_block = (Rpc - LABEL_113_228);
      goto lambda_432;

    case 199:
      current_block = (Rpc - LABEL_113_231);
      goto continuation_196;

    case 200:
      current_block = (Rpc - LABEL_113_239);
      goto label_342;

    case 201:
      current_block = (Rpc - LABEL_113_242);
      goto label_343;

    case 202:
      current_block = (Rpc - LABEL_113_234);
      goto continuation_173;

    case 203:
      current_block = (Rpc - LABEL_113_235);
      goto continuation_172;

    case 204:
      current_block = (Rpc - LABEL_113_236);
      goto continuation_159;

    case 205:
      current_block = (Rpc - LABEL_113_238);
      goto continuation_186;

    case 206:
      current_block = (Rpc - LABEL_113_246);
      goto label_344;

    case 207:
      current_block = (Rpc - LABEL_113_247);
      goto label_345;

    case 208:
      current_block = (Rpc - LABEL_113_240);
      goto continuation_215;

    case 209:
      current_block = (Rpc - LABEL_113_248);
      goto label_346;

    case 210:
      current_block = (Rpc - LABEL_113_251);
      goto label_347;

    case 211:
      current_block = (Rpc - LABEL_113_241);
      goto lambda_214;

    case 212:
      current_block = (Rpc - LABEL_113_243);
      goto continuation_174;

    case 213:
      current_block = (Rpc - LABEL_113_244);
      goto continuation_160;

    case 214:
      current_block = (Rpc - LABEL_113_245);
      goto continuation_189;

    case 215:
      current_block = (Rpc - LABEL_113_249);
      goto continuation_218;

    case 216:
      current_block = (Rpc - LABEL_113_258);
      goto label_348;

    case 217:
      current_block = (Rpc - LABEL_113_261);
      goto label_349;

    case 218:
      current_block = (Rpc - LABEL_113_250);
      goto continuation_217;

    case 219:
      current_block = (Rpc - LABEL_113_263);
      goto label_350;

    case 220:
      current_block = (Rpc - LABEL_113_253);
      goto continuation_197;

    case 221:
      current_block = (Rpc - LABEL_113_254);
      goto continuation_175;

    case 222:
      current_block = (Rpc - LABEL_113_255);
      goto lambda_434;

    case 223:
      current_block = (Rpc - LABEL_113_259);
      goto continuation_232;

    case 224:
      current_block = (Rpc - LABEL_113_271);
      goto label_351;

    case 225:
      current_block = (Rpc - LABEL_113_274);
      goto label_352;

    case 226:
      current_block = (Rpc - LABEL_113_260);
      goto lambda_231;

    case 227:
      current_block = (Rpc - LABEL_113_262);
      goto continuation_216;

    case 228:
      current_block = (Rpc - LABEL_113_278);
      goto label_353;

    case 229:
      current_block = (Rpc - LABEL_113_279);
      goto label_354;

    case 230:
      current_block = (Rpc - LABEL_113_264);
      goto continuation_198;

    case 231:
      current_block = (Rpc - LABEL_113_265);
      goto continuation_178;

    case 232:
      current_block = (Rpc - LABEL_113_266);
      goto continuation_176;

    case 233:
      current_block = (Rpc - LABEL_113_268);
      goto continuation_191;

    case 234:
      current_block = (Rpc - LABEL_113_269);
      goto continuation_190;

    case 235:
      current_block = (Rpc - LABEL_113_272);
      goto continuation_236;

    case 236:
      current_block = (Rpc - LABEL_113_289);
      goto label_355;

    case 237:
      current_block = (Rpc - LABEL_113_292);
      goto label_356;

    case 238:
      current_block = (Rpc - LABEL_113_273);
      goto lambda_235;

    case 239:
      current_block = (Rpc - LABEL_113_275);
      goto continuation_228;

    case 240:
      current_block = (Rpc - LABEL_113_276);
      goto lambda_436;

    case 241:
      current_block = (Rpc - LABEL_113_280);
      goto lambda_437;

    case 242:
      current_block = (Rpc - LABEL_113_282);
      goto lambda_438;

    case 243:
      current_block = (Rpc - LABEL_113_285);
      goto continuation_200;

    case 244:
      current_block = (Rpc - LABEL_113_286);
      goto continuation_199;

    case 245:
      current_block = (Rpc - LABEL_113_287);
      goto continuation_179;

    case 246:
      current_block = (Rpc - LABEL_113_290);
      goto continuation_240;

    case 247:
      current_block = (Rpc - LABEL_113_301);
      goto label_357;

    case 248:
      current_block = (Rpc - LABEL_113_304);
      goto label_358;

    case 249:
      current_block = (Rpc - LABEL_113_291);
      goto lambda_239;

    case 250:
      current_block = (Rpc - LABEL_113_293);
      goto continuation_233;

    case 251:
      current_block = (Rpc - LABEL_113_294);
      goto continuation_230;

    case 252:
      current_block = (Rpc - LABEL_113_295);
      goto continuation_229;

    case 253:
      current_block = (Rpc - LABEL_113_296);
      goto continuation_219;

    case 254:
      current_block = (Rpc - LABEL_113_297);
      goto continuation_224;

    case 255:
      current_block = (Rpc - LABEL_113_298);
      goto continuation_221;

    case 256:
      current_block = (Rpc - LABEL_113_299);
      goto continuation_201;

    case 257:
      current_block = (Rpc - LABEL_113_300);
      goto continuation_180;

    case 258:
      current_block = (Rpc - LABEL_113_302);
      goto continuation_244;

    case 259:
      current_block = (Rpc - LABEL_113_311);
      goto label_359;

    case 260:
      current_block = (Rpc - LABEL_113_303);
      goto lambda_243;

    case 261:
      current_block = (Rpc - LABEL_113_305);
      goto continuation_237;

    case 262:
      current_block = (Rpc - LABEL_113_306);
      goto continuation_234;

    case 263:
      current_block = (Rpc - LABEL_113_308);
      goto continuation_225;

    case 264:
      current_block = (Rpc - LABEL_113_309);
      goto continuation_222;

    case 265:
      current_block = (Rpc - LABEL_113_310);
      goto continuation_202;

    case 266:
      current_block = (Rpc - LABEL_113_312);
      goto continuation_254;

    case 267:
      current_block = (Rpc - LABEL_113_318);
      goto label_360;

    case 268:
      current_block = (Rpc - LABEL_113_313);
      goto continuation_253;

    case 269:
      current_block = (Rpc - LABEL_113_321);
      goto label_361;

    case 270:
      current_block = (Rpc - LABEL_113_322);
      goto lambda_251;

    case 271:
      current_block = (Rpc - LABEL_113_314);
      goto continuation_241;

    case 272:
      current_block = (Rpc - LABEL_113_315);
      goto continuation_238;

    case 273:
      current_block = (Rpc - LABEL_113_317);
      goto continuation_203;

    case 274:
      current_block = (Rpc - LABEL_113_319);
      goto continuation_256;

    case 275:
      current_block = (Rpc - LABEL_113_329);
      goto label_362;

    case 276:
      current_block = (Rpc - LABEL_113_320);
      goto continuation_255;

    case 277:
      current_block = (Rpc - LABEL_113_332);
      goto label_363;

    case 278:
      current_block = (Rpc - LABEL_113_323);
      goto lambda_443;

    case 279:
      current_block = (Rpc - LABEL_113_325);
      goto continuation_242;

    case 280:
      current_block = (Rpc - LABEL_113_326);
      goto continuation_206;

    case 281:
      current_block = (Rpc - LABEL_113_327);
      goto continuation_205;

    case 282:
      current_block = (Rpc - LABEL_113_328);
      goto continuation_204;

    case 283:
      current_block = (Rpc - LABEL_113_330);
      goto continuation_258;

    case 284:
      current_block = (Rpc - LABEL_113_336);
      goto label_364;

    case 285:
      current_block = (Rpc - LABEL_113_331);
      goto continuation_257;

    case 286:
      current_block = (Rpc - LABEL_113_339);
      goto label_365;

    case 287:
      current_block = (Rpc - LABEL_113_333);
      goto continuation_245;

    case 288:
      current_block = (Rpc - LABEL_113_334);
      goto continuation_207;

    case 289:
      current_block = (Rpc - LABEL_113_337);
      goto continuation_260;

    case 290:
      current_block = (Rpc - LABEL_113_343);
      goto label_366;

    case 291:
      current_block = (Rpc - LABEL_113_346);
      goto label_367;

    case 292:
      current_block = (Rpc - LABEL_113_338);
      goto continuation_259;

    case 293:
      current_block = (Rpc - LABEL_113_347);
      goto label_368;

    case 294:
      current_block = (Rpc - LABEL_113_340);
      goto continuation_246;

    case 295:
      current_block = (Rpc - LABEL_113_341);
      goto continuation_209;

    case 296:
      current_block = (Rpc - LABEL_113_342);
      goto continuation_208;

    case 297:
      current_block = (Rpc - LABEL_113_344);
      goto continuation_266;

    case 298:
      current_block = (Rpc - LABEL_113_352);
      goto label_369;

    case 299:
      current_block = (Rpc - LABEL_113_354);
      goto label_370;

    case 300:
      current_block = (Rpc - LABEL_113_345);
      goto lambda_265;

    case 301:
      current_block = (Rpc - LABEL_113_348);
      goto continuation_247;

    case 302:
      current_block = (Rpc - LABEL_113_350);
      goto continuation_211;

    case 303:
      current_block = (Rpc - LABEL_113_349);
      goto continuation_210;

    case 304:
      current_block = (Rpc - LABEL_113_353);
      goto continuation_267;

    case 305:
      current_block = (Rpc - LABEL_113_357);
      goto label_371;

    case 306:
      current_block = (Rpc - LABEL_113_359);
      goto label_372;

    case 307:
      current_block = (Rpc - LABEL_113_355);
      goto continuation_262;

    case 308:
      current_block = (Rpc - LABEL_113_356);
      goto continuation_248;

    case 309:
      current_block = (Rpc - LABEL_113_358);
      goto continuation_268;

    case 310:
      current_block = (Rpc - LABEL_113_362);
      goto label_373;

    case 311:
      current_block = (Rpc - LABEL_113_364);
      goto label_374;

    case 312:
      current_block = (Rpc - LABEL_113_365);
      goto label_375;

    case 313:
      current_block = (Rpc - LABEL_113_360);
      goto continuation_264;

    case 314:
      current_block = (Rpc - LABEL_113_361);
      goto continuation_263;

    case 315:
      current_block = (Rpc - LABEL_113_363);
      goto continuation_269;

    case 316:
      current_block = (Rpc - LABEL_113_367);
      goto label_376;

    case 317:
      current_block = (Rpc - LABEL_113_369);
      goto label_377;

    case 318:
      current_block = (Rpc - LABEL_113_370);
      goto label_378;

    case 319:
      current_block = (Rpc - LABEL_113_368);
      goto continuation_270;

    case 320:
      current_block = (Rpc - LABEL_113_371);
      goto label_379;

    case 321:
      current_block = (Rpc - LABEL_113_373);
      goto label_380;

    case 322:
      current_block = (Rpc - LABEL_113_374);
      goto label_381;

    case 323:
      current_block = (Rpc - LABEL_113_372);
      goto continuation_271;

    case 324:
      current_block = (Rpc - LABEL_113_375);
      goto label_382;

    case 325:
      current_block = (Rpc - LABEL_113_377);
      goto label_383;

    case 326:
      current_block = (Rpc - LABEL_113_378);
      goto label_384;

    case 327:
      current_block = (Rpc - LABEL_113_376);
      goto continuation_272;

    case 328:
      current_block = (Rpc - LABEL_113_379);
      goto label_385;

    case 329:
      current_block = (Rpc - LABEL_113_381);
      goto label_386;

    case 330:
      current_block = (Rpc - LABEL_113_382);
      goto label_387;

    case 331:
      current_block = (Rpc - LABEL_113_380);
      goto continuation_273;

    case 332:
      current_block = (Rpc - LABEL_113_383);
      goto label_388;

    case 333:
      current_block = (Rpc - LABEL_113_385);
      goto label_389;

    case 334:
      current_block = (Rpc - LABEL_113_386);
      goto label_390;

    case 335:
      current_block = (Rpc - LABEL_113_384);
      goto continuation_274;

    case 336:
      current_block = (Rpc - LABEL_113_387);
      goto label_391;

    case 337:
      current_block = (Rpc - LABEL_113_389);
      goto label_392;

    case 338:
      current_block = (Rpc - LABEL_113_390);
      goto label_393;

    case 339:
      current_block = (Rpc - LABEL_113_388);
      goto continuation_275;

    case 340:
      current_block = (Rpc - LABEL_113_391);
      goto label_394;

    case 341:
      current_block = (Rpc - LABEL_113_393);
      goto label_395;

    case 342:
      current_block = (Rpc - LABEL_113_394);
      goto label_396;

    case 343:
      current_block = (Rpc - LABEL_113_392);
      goto continuation_276;

    case 344:
      current_block = (Rpc - LABEL_113_395);
      goto label_397;

    case 345:
      current_block = (Rpc - LABEL_113_397);
      goto label_398;

    case 346:
      current_block = (Rpc - LABEL_113_398);
      goto label_399;

    case 347:
      current_block = (Rpc - LABEL_113_396);
      goto continuation_277;

    case 348:
      current_block = (Rpc - LABEL_113_399);
      goto label_400;

    case 349:
      current_block = (Rpc - LABEL_113_401);
      goto label_401;

    case 350:
      current_block = (Rpc - LABEL_113_402);
      goto label_402;

    case 351:
      current_block = (Rpc - LABEL_113_400);
      goto continuation_278;

    case 352:
      current_block = (Rpc - LABEL_113_403);
      goto label_403;

    case 353:
      current_block = (Rpc - LABEL_113_405);
      goto label_404;

    case 354:
      current_block = (Rpc - LABEL_113_406);
      goto label_405;

    case 355:
      current_block = (Rpc - LABEL_113_404);
      goto continuation_279;

    case 356:
      current_block = (Rpc - LABEL_113_407);
      goto label_406;

    case 357:
      current_block = (Rpc - LABEL_113_409);
      goto label_407;

    case 358:
      current_block = (Rpc - LABEL_113_410);
      goto label_408;

    case 359:
      current_block = (Rpc - LABEL_113_408);
      goto continuation_280;

    case 360:
      current_block = (Rpc - LABEL_113_411);
      goto label_409;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_411)
DEFLABEL (initialize_packageB_281)
  INTERRUPT_CHECK (26, LABEL_113_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_581;
  Wrd5 = Wrd9;

DEFLABEL (label_580)
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_0]));
  (Wrd19.Obj) = ((Wrd11.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_579;

DEFLABEL (label_578)
  ((Wrd11.pObj) [0]) = (Wrd5.Obj);

DEFLABEL (label_577)
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_1]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_7]))));
  (Wrd32.Obj) = ((Wrd23.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_576;

DEFLABEL (label_575)
  ((Wrd23.pObj) [0]) = (Wrd24.Obj);

DEFLABEL (label_574)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_9]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd40.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd42.Obj) = (current_block [OBJECT_113_1]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_113_9);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_2]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_573;

DEFLABEL (label_572)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_571)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_12]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd24.Obj) = (current_block [OBJECT_113_3]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_113_12);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_3]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_570;

DEFLABEL (label_569)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_568)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_14]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_1]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_567;
  Wrd23 = Wrd27;

DEFLABEL (label_566)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_113_4]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_113_14);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_4]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_565;

DEFLABEL (label_564)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_563)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_17]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_5]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd25.Obj) = (current_block [OBJECT_113_6]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_113_17);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_5]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_562;

DEFLABEL (label_561)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_560)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_20]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_5]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_559;
  Wrd24 = Wrd28;

DEFLABEL (label_558)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_7]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_113_20);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_6]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_557;

DEFLABEL (label_556)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_555)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_25]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_5]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_3]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_554;
  Wrd24 = Wrd28;

DEFLABEL (label_553)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_9]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_113_25);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_7]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_552;

DEFLABEL (label_551)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_550)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_29]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_30]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_11]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_549;
  Wrd24 = Wrd28;

DEFLABEL (label_548)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_12]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_113_29);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_8]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_547;

DEFLABEL (label_546)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_545)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_35]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_4]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_544;
  Wrd24 = Wrd28;

DEFLABEL (label_543)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_13]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_113_34);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_9]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_542;

DEFLABEL (label_541)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_540)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_40]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_15]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_16]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_17]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_18]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_113_19]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_113_20]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_21]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_113_22]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_113_23]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_24]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_41]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_113_40);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_46);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_45])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_47]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_49);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_48])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  ((Wrd15.pObj) [2]) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_113_26]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_4]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_539;
  Wrd19 = Wrd23;

DEFLABEL (label_538)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_113_27]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_113_47);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_10]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_537;

DEFLABEL (label_536)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_535)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_56]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_58);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_57])));
  Rhp += 1;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd23 = Wrd22;
  (Wrd24.Obj) = (Rsp [1]);
  ((Wrd23.pObj) [2]) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_113_30]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_5]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_534;
  Wrd26 = Wrd30;

DEFLABEL (label_533)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_113_31]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_113_56);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_11]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_532;

DEFLABEL (label_531)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_530)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_64]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_65]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_30]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_6]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_529;
  Wrd24 = Wrd28;

DEFLABEL (label_528)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_34]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_78)
  INTERRUPT_CHECK (27, LABEL_113_64);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_12]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_527;

DEFLABEL (label_526)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_525)
  Rsp = (& (Rsp [1]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_78]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_79]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_39]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_5]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_524;
  Wrd25 = Wrd29;

DEFLABEL (label_523)
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_113_40]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_112)
  INTERRUPT_CHECK (27, LABEL_113_78);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_13]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_522;

DEFLABEL (label_521)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_520)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_86]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_87]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_5]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_519;
  Wrd24 = Wrd28;

DEFLABEL (label_518)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_42]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_120)
  INTERRUPT_CHECK (27, LABEL_113_86);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_14]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_517;

DEFLABEL (label_516)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_515)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_95]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_44]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_514;
  Wrd23 = Wrd27;

DEFLABEL (label_513)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_113_45]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_121)
  INTERRUPT_CHECK (27, LABEL_113_95);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_15]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_512;

DEFLABEL (label_511)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_510)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_105]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_106]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_48]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_7]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_509;
  Wrd24 = Wrd28;

DEFLABEL (label_508)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_49]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_126)
  INTERRUPT_CHECK (27, LABEL_113_105);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_16]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_507;

DEFLABEL (label_506)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_505)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_115]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_52]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_53]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_132;

DEFLABEL (continuation_134)
  INTERRUPT_CHECK (27, LABEL_113_115);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_17]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_504;

DEFLABEL (label_503)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_502)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_127]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_64]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_65]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_132;

DEFLABEL (continuation_135)
  INTERRUPT_CHECK (27, LABEL_113_127);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_18]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_501;

DEFLABEL (label_500)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_499)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_145]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_69]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_70]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_132;

DEFLABEL (continuation_136)
  INTERRUPT_CHECK (27, LABEL_113_145);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_19]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_498;

DEFLABEL (label_497)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_496)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_152]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_75]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_113_76]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_132;

DEFLABEL (continuation_137)
  INTERRUPT_CHECK (27, LABEL_113_152);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_20]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_495;

DEFLABEL (label_494)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_493)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_166]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_167]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_82]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_8]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_492;
  Wrd24 = Wrd28;

DEFLABEL (label_491)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_83]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_146)
  INTERRUPT_CHECK (27, LABEL_113_166);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_21]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_490;

DEFLABEL (label_489)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_488)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_173]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_84]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_9]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_487;
  Wrd22 = Wrd26;

DEFLABEL (label_486)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_175]));

DEFLABEL (continuation_147)
  INTERRUPT_CHECK (27, LABEL_113_173);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_180);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_179])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_22]));
  (Wrd19.Obj) = ((Wrd11.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_485;

DEFLABEL (label_484)
  ((Wrd11.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_483)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_182]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_183]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_113_82]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_10]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_482;
  Wrd29 = Wrd33;

DEFLABEL (label_481)
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_113_87]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_113_182);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_23]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_480;

DEFLABEL (label_479)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_478)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_193]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_92]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_11]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_477;
  Wrd22 = Wrd26;

DEFLABEL (label_476)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_175]));

DEFLABEL (continuation_163)
  INTERRUPT_CHECK (27, LABEL_113_193);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_205);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_204])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_24]));
  (Wrd19.Obj) = ((Wrd11.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_475;

DEFLABEL (label_474)
  ((Wrd11.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_473)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_207]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_208]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_113_82]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_12]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_472;
  Wrd29 = Wrd33;

DEFLABEL (label_471)
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_113_99]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_113_207);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_25]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_470;

DEFLABEL (label_469)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_468)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_219]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_102]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_13]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_467;
  Wrd22 = Wrd26;

DEFLABEL (label_466)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_175]));

DEFLABEL (continuation_184)
  INTERRUPT_CHECK (27, LABEL_113_219);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_229);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_228])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_26]));
  (Wrd19.Obj) = ((Wrd11.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_465;

DEFLABEL (label_464)
  ((Wrd11.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_463)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_231]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_13]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_462;
  Wrd26 = Wrd30;

DEFLABEL (label_461)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_233]));

DEFLABEL (continuation_196)
  INTERRUPT_CHECK (27, LABEL_113_231);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_27]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_460;

DEFLABEL (label_459)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_458)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_240]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_241]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_106]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_10]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_457;
  Wrd24 = Wrd28;

DEFLABEL (label_456)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_107]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_215)
  INTERRUPT_CHECK (27, LABEL_113_240);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_28]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_455;

DEFLABEL (label_454)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_453)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_249]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_250]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_109]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_14]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_452;
  Wrd25 = Wrd29;

DEFLABEL (label_451)
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_252]));

DEFLABEL (continuation_217)
  INTERRUPT_CHECK (27, LABEL_113_250);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_262]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_114]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_14]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_450;
  Wrd9 = Wrd13;

DEFLABEL (label_449)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_252]));

DEFLABEL (continuation_216)
  INTERRUPT_CHECK (27, LABEL_113_262);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_277);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_276])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_35]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_448;
  Wrd10 = Wrd14;

DEFLABEL (label_447)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_113_119]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_14]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_446;
  Wrd17 = Wrd21;

DEFLABEL (label_445)
  (* (--Rsp)) = (Wrd17.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_281);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_280])));
  Rhp += 2;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd28 = Wrd25;
  (Wrd29.Obj) = (Rsp [6]);
  ((Wrd28.pObj) [2]) = (Wrd29.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  ((Wrd28.pObj) [3]) = (Wrd27.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd32.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_283);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_282])));
  Rhp += 2;
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd32.pObj)));
  Wrd35 = Wrd32;
  ((Wrd35.pObj) [2]) = (Wrd29.Obj);
  ((Wrd35.pObj) [3]) = (Wrd27.Obj);
  (Rsp [5]) = (Wrd31.Obj);
  (Rsp [6]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_284]));

DEFLABEL (label_446)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_279])), (Wrd18.pObj));

DEFLABEL (label_354)
  (Wrd17.Obj) = Rvl;
  goto label_445;

DEFLABEL (label_448)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_278])), (Wrd11.pObj));

DEFLABEL (label_353)
  (Wrd10.Obj) = Rvl;
  goto label_447;

DEFLABEL (label_450)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_263])), (Wrd10.pObj));

DEFLABEL (label_350)
  (Wrd9.Obj) = Rvl;
  goto label_449;

DEFLABEL (label_452)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_251])), (Wrd26.pObj));

DEFLABEL (label_347)
  (Wrd25.Obj) = Rvl;
  goto label_451;

DEFLABEL (label_455)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_454;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_248])), (Wrd6.pObj), Rvl);

DEFLABEL (label_346)
  goto label_453;

DEFLABEL (label_457)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_242])), (Wrd25.pObj));

DEFLABEL (label_343)
  (Wrd24.Obj) = Rvl;
  goto label_456;

DEFLABEL (label_460)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_459;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_239])), (Wrd6.pObj), Rvl);

DEFLABEL (label_342)
  goto label_458;

DEFLABEL (label_462)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_232])), (Wrd27.pObj));

DEFLABEL (label_341)
  (Wrd26.Obj) = Rvl;
  goto label_461;

DEFLABEL (label_465)
  if ((Wrd19.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_464;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_230])), (Wrd11.pObj), (Wrd6.Obj));

DEFLABEL (label_340)
  goto label_463;

DEFLABEL (label_467)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_220])), (Wrd23.pObj));

DEFLABEL (label_337)
  (Wrd22.Obj) = Rvl;
  goto label_466;

DEFLABEL (label_470)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_469;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_218])), (Wrd6.pObj), Rvl);

DEFLABEL (label_336)
  goto label_468;

DEFLABEL (label_472)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_209])), (Wrd30.pObj));

DEFLABEL (label_334)
  (Wrd29.Obj) = Rvl;
  goto label_471;

DEFLABEL (label_475)
  if ((Wrd19.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_474;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_206])), (Wrd11.pObj), (Wrd6.Obj));

DEFLABEL (label_333)
  goto label_473;

DEFLABEL (label_477)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_194])), (Wrd23.pObj));

DEFLABEL (label_329)
  (Wrd22.Obj) = Rvl;
  goto label_476;

DEFLABEL (label_480)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_479;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_192])), (Wrd6.pObj), Rvl);

DEFLABEL (label_328)
  goto label_478;

DEFLABEL (label_482)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_184])), (Wrd30.pObj));

DEFLABEL (label_327)
  (Wrd29.Obj) = Rvl;
  goto label_481;

DEFLABEL (label_485)
  if ((Wrd19.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_484;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_181])), (Wrd11.pObj), (Wrd6.Obj));

DEFLABEL (label_326)
  goto label_483;

DEFLABEL (label_487)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_174])), (Wrd23.pObj));

DEFLABEL (label_325)
  (Wrd22.Obj) = Rvl;
  goto label_486;

DEFLABEL (label_490)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_489;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_172])), (Wrd6.pObj), Rvl);

DEFLABEL (label_324)
  goto label_488;

DEFLABEL (label_492)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_168])), (Wrd25.pObj));

DEFLABEL (label_323)
  (Wrd24.Obj) = Rvl;
  goto label_491;

DEFLABEL (label_495)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_494;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_165])), (Wrd6.pObj), Rvl);

DEFLABEL (label_322)
  goto label_493;

DEFLABEL (label_498)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_497;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_151])), (Wrd6.pObj), Rvl);

DEFLABEL (label_319)
  goto label_496;

DEFLABEL (label_501)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_500;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_144])), (Wrd6.pObj), Rvl);

DEFLABEL (label_318)
  goto label_499;

DEFLABEL (label_504)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_503;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_126])), (Wrd6.pObj), Rvl);

DEFLABEL (label_315)
  goto label_502;

DEFLABEL (label_507)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_506;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_114])), (Wrd6.pObj), Rvl);

DEFLABEL (label_313)
  goto label_505;

DEFLABEL (label_509)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_107])), (Wrd25.pObj));

DEFLABEL (label_312)
  (Wrd24.Obj) = Rvl;
  goto label_508;

DEFLABEL (label_512)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_511;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_104])), (Wrd6.pObj), Rvl);

DEFLABEL (label_311)
  goto label_510;

DEFLABEL (label_514)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_96])), (Wrd24.pObj));

DEFLABEL (label_310)
  (Wrd23.Obj) = Rvl;
  goto label_513;

DEFLABEL (label_517)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_516;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_94])), (Wrd6.pObj), Rvl);

DEFLABEL (label_309)
  goto label_515;

DEFLABEL (label_519)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_88])), (Wrd25.pObj));

DEFLABEL (label_307)
  (Wrd24.Obj) = Rvl;
  goto label_518;

DEFLABEL (label_522)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_521;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_85])), (Wrd6.pObj), Rvl);

DEFLABEL (label_306)
  goto label_520;

DEFLABEL (label_524)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_80])), (Wrd26.pObj));

DEFLABEL (label_305)
  (Wrd25.Obj) = Rvl;
  goto label_523;

DEFLABEL (label_527)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_526;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_77])), (Wrd6.pObj), Rvl);

DEFLABEL (label_304)
  goto label_525;

DEFLABEL (label_529)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_66])), (Wrd25.pObj));

DEFLABEL (label_303)
  (Wrd24.Obj) = Rvl;
  goto label_528;

DEFLABEL (label_532)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_531;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_63])), (Wrd6.pObj), Rvl);

DEFLABEL (label_302)
  goto label_530;

DEFLABEL (label_534)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_59])), (Wrd27.pObj));

DEFLABEL (label_301)
  (Wrd26.Obj) = Rvl;
  goto label_533;

DEFLABEL (label_537)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_536;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_55])), (Wrd6.pObj), Rvl);

DEFLABEL (label_300)
  goto label_535;

DEFLABEL (label_539)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_50])), (Wrd20.pObj));

DEFLABEL (label_299)
  (Wrd19.Obj) = Rvl;
  goto label_538;

DEFLABEL (label_542)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_541;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_39])), (Wrd6.pObj), Rvl);

DEFLABEL (label_298)
  goto label_540;

DEFLABEL (label_544)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_36])), (Wrd25.pObj));

DEFLABEL (label_297)
  (Wrd24.Obj) = Rvl;
  goto label_543;

DEFLABEL (label_547)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_546;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_33])), (Wrd6.pObj), Rvl);

DEFLABEL (label_296)
  goto label_545;

DEFLABEL (label_549)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_31])), (Wrd25.pObj));

DEFLABEL (label_295)
  (Wrd24.Obj) = Rvl;
  goto label_548;

DEFLABEL (label_552)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_551;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_28])), (Wrd6.pObj), Rvl);

DEFLABEL (label_294)
  goto label_550;

DEFLABEL (label_554)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_26])), (Wrd25.pObj));

DEFLABEL (label_293)
  (Wrd24.Obj) = Rvl;
  goto label_553;

DEFLABEL (label_557)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_556;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_24])), (Wrd6.pObj), Rvl);

DEFLABEL (label_292)
  goto label_555;

DEFLABEL (label_559)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_21])), (Wrd25.pObj));

DEFLABEL (label_291)
  (Wrd24.Obj) = Rvl;
  goto label_558;

DEFLABEL (label_562)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_561;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_19])), (Wrd6.pObj), Rvl);

DEFLABEL (label_290)
  goto label_560;

DEFLABEL (label_565)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_564;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_16])), (Wrd6.pObj), Rvl);

DEFLABEL (label_289)
  goto label_563;

DEFLABEL (label_567)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_15])), (Wrd24.pObj));

DEFLABEL (label_288)
  (Wrd23.Obj) = Rvl;
  goto label_566;

DEFLABEL (label_570)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_569;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_13])), (Wrd6.pObj), Rvl);

DEFLABEL (label_287)
  goto label_568;

DEFLABEL (label_573)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_572;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_11])), (Wrd6.pObj), Rvl);

DEFLABEL (label_286)
  goto label_571;

DEFLABEL (label_576)
  if ((Wrd32.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_575;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_8])), (Wrd23.pObj), (Wrd24.Obj));

DEFLABEL (label_285)
  goto label_574;

DEFLABEL (label_579)
  if ((Wrd19.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_578;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_6])), (Wrd11.pObj), (Wrd5.Obj));

DEFLABEL (label_284)
  goto label_577;

DEFLABEL (label_581)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_5])), (Wrd6.pObj));

DEFLABEL (label_283)
  (Wrd5.Obj) = Rvl;
  goto label_580;

DEFLABEL (continuation_218)
  INTERRUPT_CHECK (27, LABEL_113_249);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_29]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_723;

DEFLABEL (label_722)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_721)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_259]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_260]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_112]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_15]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_720;
  Wrd24 = Wrd28;

DEFLABEL (label_719)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_113]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_232)
  INTERRUPT_CHECK (27, LABEL_113_259);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_30]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_718;

DEFLABEL (label_717)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_716)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_272]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_273]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_16]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_715;
  Wrd24 = Wrd28;

DEFLABEL (label_714)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_117]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_236)
  INTERRUPT_CHECK (27, LABEL_113_272);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_31]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_713;

DEFLABEL (label_712)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_711)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_290]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_291]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_16]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_710;
  Wrd24 = Wrd28;

DEFLABEL (label_709)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_123]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_240)
  INTERRUPT_CHECK (27, LABEL_113_290);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_32]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_708;

DEFLABEL (label_707)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_706)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_302]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_303]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_16]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_705;
  Wrd24 = Wrd28;

DEFLABEL (label_704)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_129]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_244)
  INTERRUPT_CHECK (27, LABEL_113_302);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_33]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_703;

DEFLABEL (label_702)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_701)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_312]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_313]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_133]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto lambda_251;

DEFLABEL (continuation_253)
  INTERRUPT_CHECK (27, LABEL_113_313);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_137]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_700;
  Wrd6 = Wrd10;

DEFLABEL (label_699)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_138]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_254)
  INTERRUPT_CHECK (27, LABEL_113_312);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_34]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_698;

DEFLABEL (label_697)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_696)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_319]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_320]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_136]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto lambda_251;

DEFLABEL (continuation_255)
  INTERRUPT_CHECK (27, LABEL_113_320);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_18]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_695;
  Wrd6 = Wrd10;

DEFLABEL (label_694)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_140]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_256)
  INTERRUPT_CHECK (27, LABEL_113_319);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_35]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_693;

DEFLABEL (label_692)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_691)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_330]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_331]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_139]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto lambda_251;

DEFLABEL (continuation_257)
  INTERRUPT_CHECK (27, LABEL_113_331);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_18]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_690;
  Wrd6 = Wrd10;

DEFLABEL (label_689)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_143]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_258)
  INTERRUPT_CHECK (27, LABEL_113_330);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_36]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_688;

DEFLABEL (label_687)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_686)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_337]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_338]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_113_142]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto lambda_251;

DEFLABEL (continuation_259)
  INTERRUPT_CHECK (27, LABEL_113_338);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_18]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_685;
  Wrd6 = Wrd10;

DEFLABEL (label_684)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_147]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_260)
  INTERRUPT_CHECK (27, LABEL_113_337);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_37]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_683;

DEFLABEL (label_682)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_681)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_344]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_345]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_145]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_680;
  Wrd24 = Wrd28;

DEFLABEL (label_679)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_113_146]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (continuation_266)
  INTERRUPT_CHECK (27, LABEL_113_344);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_38]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_678;

DEFLABEL (label_677)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_676)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_353]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_5]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_19]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_675;
  Wrd22 = Wrd26;

DEFLABEL (label_674)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_175]));

DEFLABEL (continuation_267)
  INTERRUPT_CHECK (27, LABEL_113_353);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_39]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_673;

DEFLABEL (label_672)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_671)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_358]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_113_5]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_20]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_670;
  Wrd22 = Wrd26;

DEFLABEL (label_669)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_175]));

DEFLABEL (continuation_268)
  INTERRUPT_CHECK (27, LABEL_113_358);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_40]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_668;

DEFLABEL (label_667)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_666)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_363]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_665;
  Wrd21 = Wrd25;

DEFLABEL (label_664)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_152]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_5]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_663;
  Wrd28 = Wrd32;

DEFLABEL (label_662)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_269)
  INTERRUPT_CHECK (27, LABEL_113_363);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_41]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_661;

DEFLABEL (label_660)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_659)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_368]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_658;
  Wrd21 = Wrd25;

DEFLABEL (label_657)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_11]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_6]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_656;
  Wrd28 = Wrd32;

DEFLABEL (label_655)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_270)
  INTERRUPT_CHECK (27, LABEL_113_368);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_42]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_654;

DEFLABEL (label_653)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_652)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_372]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_651;
  Wrd21 = Wrd25;

DEFLABEL (label_650)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_153]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_21]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_649;
  Wrd28 = Wrd32;

DEFLABEL (label_648)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_271)
  INTERRUPT_CHECK (27, LABEL_113_372);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_43]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_647;

DEFLABEL (label_646)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_645)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_376]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_644;
  Wrd21 = Wrd25;

DEFLABEL (label_643)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_154]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_22]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_642;
  Wrd28 = Wrd32;

DEFLABEL (label_641)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_272)
  INTERRUPT_CHECK (27, LABEL_113_376);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_44]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_640;

DEFLABEL (label_639)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_638)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_380]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_637;
  Wrd21 = Wrd25;

DEFLABEL (label_636)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_155]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_23]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_635;
  Wrd28 = Wrd32;

DEFLABEL (label_634)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_273)
  INTERRUPT_CHECK (27, LABEL_113_380);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_45]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_633;

DEFLABEL (label_632)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_631)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_384]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_630;
  Wrd21 = Wrd25;

DEFLABEL (label_629)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_152]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_24]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_628;
  Wrd28 = Wrd32;

DEFLABEL (label_627)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_274)
  INTERRUPT_CHECK (27, LABEL_113_384);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_46]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_626;

DEFLABEL (label_625)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_624)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_388]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_623;
  Wrd21 = Wrd25;

DEFLABEL (label_622)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_137]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_25]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_621;
  Wrd28 = Wrd32;

DEFLABEL (label_620)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_275)
  INTERRUPT_CHECK (27, LABEL_113_388);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_47]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_619;

DEFLABEL (label_618)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_617)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_392]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_616;
  Wrd21 = Wrd25;

DEFLABEL (label_615)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_48]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_26]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_614;
  Wrd28 = Wrd32;

DEFLABEL (label_613)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_276)
  INTERRUPT_CHECK (27, LABEL_113_392);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_48]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_612;

DEFLABEL (label_611)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_610)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_396]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_609;
  Wrd21 = Wrd25;

DEFLABEL (label_608)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_156]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_27]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_607;
  Wrd28 = Wrd32;

DEFLABEL (label_606)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_277)
  INTERRUPT_CHECK (27, LABEL_113_396);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_49]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_605;

DEFLABEL (label_604)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_603)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_400]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_602;
  Wrd21 = Wrd25;

DEFLABEL (label_601)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_156]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_28]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_600;
  Wrd28 = Wrd32;

DEFLABEL (label_599)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_278)
  INTERRUPT_CHECK (27, LABEL_113_400);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_50]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_598;

DEFLABEL (label_597)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_596)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_404]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_595;
  Wrd21 = Wrd25;

DEFLABEL (label_594)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_156]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_29]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_593;
  Wrd28 = Wrd32;

DEFLABEL (label_592)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_279)
  INTERRUPT_CHECK (27, LABEL_113_404);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_51]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_591;

DEFLABEL (label_590)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_589)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_408]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_17]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_588;
  Wrd21 = Wrd25;

DEFLABEL (label_587)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_113_145]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_30]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_586;
  Wrd28 = Wrd32;

DEFLABEL (label_585)
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_366]));

DEFLABEL (continuation_280)
  INTERRUPT_CHECK (27, LABEL_113_408);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_113_52]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_584;

DEFLABEL (label_583)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_582)
  Rvl = (current_block [OBJECT_113_57]);
  goto pop_return;

DEFLABEL (label_584)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_583;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_411])), (Wrd6.pObj), Rvl);

DEFLABEL (label_409)
  goto label_582;

DEFLABEL (label_586)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_410])), (Wrd29.pObj));

DEFLABEL (label_408)
  (Wrd28.Obj) = Rvl;
  goto label_585;

DEFLABEL (label_588)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_409])), (Wrd22.pObj));

DEFLABEL (label_407)
  (Wrd21.Obj) = Rvl;
  goto label_587;

DEFLABEL (label_591)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_590;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_407])), (Wrd6.pObj), Rvl);

DEFLABEL (label_406)
  goto label_589;

DEFLABEL (label_593)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_406])), (Wrd29.pObj));

DEFLABEL (label_405)
  (Wrd28.Obj) = Rvl;
  goto label_592;

DEFLABEL (label_595)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_405])), (Wrd22.pObj));

DEFLABEL (label_404)
  (Wrd21.Obj) = Rvl;
  goto label_594;

DEFLABEL (label_598)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_597;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_403])), (Wrd6.pObj), Rvl);

DEFLABEL (label_403)
  goto label_596;

DEFLABEL (label_600)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_402])), (Wrd29.pObj));

DEFLABEL (label_402)
  (Wrd28.Obj) = Rvl;
  goto label_599;

DEFLABEL (label_602)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_401])), (Wrd22.pObj));

DEFLABEL (label_401)
  (Wrd21.Obj) = Rvl;
  goto label_601;

DEFLABEL (label_605)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_604;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_399])), (Wrd6.pObj), Rvl);

DEFLABEL (label_400)
  goto label_603;

DEFLABEL (label_607)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_398])), (Wrd29.pObj));

DEFLABEL (label_399)
  (Wrd28.Obj) = Rvl;
  goto label_606;

DEFLABEL (label_609)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_397])), (Wrd22.pObj));

DEFLABEL (label_398)
  (Wrd21.Obj) = Rvl;
  goto label_608;

DEFLABEL (label_612)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_611;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_395])), (Wrd6.pObj), Rvl);

DEFLABEL (label_397)
  goto label_610;

DEFLABEL (label_614)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_394])), (Wrd29.pObj));

DEFLABEL (label_396)
  (Wrd28.Obj) = Rvl;
  goto label_613;

DEFLABEL (label_616)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_393])), (Wrd22.pObj));

DEFLABEL (label_395)
  (Wrd21.Obj) = Rvl;
  goto label_615;

DEFLABEL (label_619)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_618;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_391])), (Wrd6.pObj), Rvl);

DEFLABEL (label_394)
  goto label_617;

DEFLABEL (label_621)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_390])), (Wrd29.pObj));

DEFLABEL (label_393)
  (Wrd28.Obj) = Rvl;
  goto label_620;

DEFLABEL (label_623)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_389])), (Wrd22.pObj));

DEFLABEL (label_392)
  (Wrd21.Obj) = Rvl;
  goto label_622;

DEFLABEL (label_626)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_625;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_387])), (Wrd6.pObj), Rvl);

DEFLABEL (label_391)
  goto label_624;

DEFLABEL (label_628)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_386])), (Wrd29.pObj));

DEFLABEL (label_390)
  (Wrd28.Obj) = Rvl;
  goto label_627;

DEFLABEL (label_630)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_385])), (Wrd22.pObj));

DEFLABEL (label_389)
  (Wrd21.Obj) = Rvl;
  goto label_629;

DEFLABEL (label_633)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_632;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_383])), (Wrd6.pObj), Rvl);

DEFLABEL (label_388)
  goto label_631;

DEFLABEL (label_635)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_382])), (Wrd29.pObj));

DEFLABEL (label_387)
  (Wrd28.Obj) = Rvl;
  goto label_634;

DEFLABEL (label_637)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_381])), (Wrd22.pObj));

DEFLABEL (label_386)
  (Wrd21.Obj) = Rvl;
  goto label_636;

DEFLABEL (label_640)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_639;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_379])), (Wrd6.pObj), Rvl);

DEFLABEL (label_385)
  goto label_638;

DEFLABEL (label_642)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_378])), (Wrd29.pObj));

DEFLABEL (label_384)
  (Wrd28.Obj) = Rvl;
  goto label_641;

DEFLABEL (label_644)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_377])), (Wrd22.pObj));

DEFLABEL (label_383)
  (Wrd21.Obj) = Rvl;
  goto label_643;

DEFLABEL (label_647)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_646;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_375])), (Wrd6.pObj), Rvl);

DEFLABEL (label_382)
  goto label_645;

DEFLABEL (label_649)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_374])), (Wrd29.pObj));

DEFLABEL (label_381)
  (Wrd28.Obj) = Rvl;
  goto label_648;

DEFLABEL (label_651)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_373])), (Wrd22.pObj));

DEFLABEL (label_380)
  (Wrd21.Obj) = Rvl;
  goto label_650;

DEFLABEL (label_654)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_653;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_371])), (Wrd6.pObj), Rvl);

DEFLABEL (label_379)
  goto label_652;

DEFLABEL (label_656)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_370])), (Wrd29.pObj));

DEFLABEL (label_378)
  (Wrd28.Obj) = Rvl;
  goto label_655;

DEFLABEL (label_658)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_369])), (Wrd22.pObj));

DEFLABEL (label_377)
  (Wrd21.Obj) = Rvl;
  goto label_657;

DEFLABEL (label_661)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_660;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_367])), (Wrd6.pObj), Rvl);

DEFLABEL (label_376)
  goto label_659;

DEFLABEL (label_663)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_365])), (Wrd29.pObj));

DEFLABEL (label_375)
  (Wrd28.Obj) = Rvl;
  goto label_662;

DEFLABEL (label_665)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_364])), (Wrd22.pObj));

DEFLABEL (label_374)
  (Wrd21.Obj) = Rvl;
  goto label_664;

DEFLABEL (label_668)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_667;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_362])), (Wrd6.pObj), Rvl);

DEFLABEL (label_373)
  goto label_666;

DEFLABEL (label_670)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_359])), (Wrd23.pObj));

DEFLABEL (label_372)
  (Wrd22.Obj) = Rvl;
  goto label_669;

DEFLABEL (label_673)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_672;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_357])), (Wrd6.pObj), Rvl);

DEFLABEL (label_371)
  goto label_671;

DEFLABEL (label_675)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_354])), (Wrd23.pObj));

DEFLABEL (label_370)
  (Wrd22.Obj) = Rvl;
  goto label_674;

DEFLABEL (label_678)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_677;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_352])), (Wrd6.pObj), Rvl);

DEFLABEL (label_369)
  goto label_676;

DEFLABEL (label_680)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_346])), (Wrd25.pObj));

DEFLABEL (label_367)
  (Wrd24.Obj) = Rvl;
  goto label_679;

DEFLABEL (label_683)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_682;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_343])), (Wrd6.pObj), Rvl);

DEFLABEL (label_366)
  goto label_681;

DEFLABEL (label_685)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_347])), (Wrd7.pObj));

DEFLABEL (label_368)
  (Wrd6.Obj) = Rvl;
  goto label_684;

DEFLABEL (label_688)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_687;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_336])), (Wrd6.pObj), Rvl);

DEFLABEL (label_364)
  goto label_686;

DEFLABEL (label_690)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_339])), (Wrd7.pObj));

DEFLABEL (label_365)
  (Wrd6.Obj) = Rvl;
  goto label_689;

DEFLABEL (label_693)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_692;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_329])), (Wrd6.pObj), Rvl);

DEFLABEL (label_362)
  goto label_691;

DEFLABEL (label_695)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_332])), (Wrd7.pObj));

DEFLABEL (label_363)
  (Wrd6.Obj) = Rvl;
  goto label_694;

DEFLABEL (label_698)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_697;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_318])), (Wrd6.pObj), Rvl);

DEFLABEL (label_360)
  goto label_696;

DEFLABEL (label_700)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_321])), (Wrd7.pObj));

DEFLABEL (label_361)
  (Wrd6.Obj) = Rvl;
  goto label_699;

DEFLABEL (label_703)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_702;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_311])), (Wrd6.pObj), Rvl);

DEFLABEL (label_359)
  goto label_701;

DEFLABEL (label_705)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_304])), (Wrd25.pObj));

DEFLABEL (label_358)
  (Wrd24.Obj) = Rvl;
  goto label_704;

DEFLABEL (label_708)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_707;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_301])), (Wrd6.pObj), Rvl);

DEFLABEL (label_357)
  goto label_706;

DEFLABEL (label_710)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_292])), (Wrd25.pObj));

DEFLABEL (label_356)
  (Wrd24.Obj) = Rvl;
  goto label_709;

DEFLABEL (label_713)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_712;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_289])), (Wrd6.pObj), Rvl);

DEFLABEL (label_355)
  goto label_711;

DEFLABEL (label_715)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_274])), (Wrd25.pObj));

DEFLABEL (label_352)
  (Wrd24.Obj) = Rvl;
  goto label_714;

DEFLABEL (label_718)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_717;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_271])), (Wrd6.pObj), Rvl);

DEFLABEL (label_351)
  goto label_716;

DEFLABEL (label_720)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_261])), (Wrd25.pObj));

DEFLABEL (label_349)
  (Wrd24.Obj) = Rvl;
  goto label_719;

DEFLABEL (label_723)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_722;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_113_258])), (Wrd6.pObj), Rvl);

DEFLABEL (label_348)
  goto label_721;

DEFLABEL (lambda_412)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_113_7);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_2]), 2);

DEFLABEL (lambda_413)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_113_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_113_22);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_10]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_113_27);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_32]));

DEFLABEL (lambda_414)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_113_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_113_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_44]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_113_44);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_113_43);
  (Wrd5.Obj) = (current_block [OBJECT_113_28]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_415)
DEFLABEL (lambda_20)
  INTERRUPT_CHECK (26, LABEL_113_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_113_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_52]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_113_52);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_113_51);
  (Wrd5.Obj) = (current_block [OBJECT_113_32]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_416)
DEFLABEL (lambda_34)
  INTERRUPT_CHECK (26, LABEL_113_45);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_29]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_113_54);
  (* (--Rsp)) = Rvl;
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 30)
    goto label_724;
  (Wrd7.Obj) = (current_block [OBJECT_113_33]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_724)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_61]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_62]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_113_61);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_726;

DEFLABEL (label_725)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_726)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_75]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_113_38]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_76]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_113_75);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_725;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_71]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_113_37]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_76]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_113_71);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_725;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_70]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_72]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd41.Obj) = (Rsp [3]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 30))
    goto label_731;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd40.Lng))))
    goto label_731;
  (Wrd33.uLng) = ((unsigned long) (((unsigned char *) (Wrd38.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd34.Obj) = (MAKE_OBJECT (2, (Wrd33.uLng)));
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_730)
  (Wrd48.Obj) = (Rsp [5]);
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [2]);
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_74]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_113_72);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_728;
  (Wrd7.Obj) = (current_block [OBJECT_113_37]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto label_727;

DEFLABEL (label_728)
  (Wrd8.Obj) = (current_block [OBJECT_113_38]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_727)
DEFLABEL (label_729)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_113_70);
  goto label_725;

DEFLABEL (label_731)
  (Wrd43.Obj) = (Rsp [3]);
  (Wrd44.Obj) = (current_block [OBJECT_113_35]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_73]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_36]), 2);

DEFLABEL (label_308)
  (* (--Rsp)) = Rvl;
  goto label_730;

DEFLABEL (lambda_417)
  CLOSURE_HEADER (LABEL_113_48);

DEFLABEL (lambda_63)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_60]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_113_60);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_68]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_69]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_113_69);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_113_68);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_84]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_41]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_113_84);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_93]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto lambda_34;

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_113_93);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_418)
  CLOSURE_HEADER (LABEL_113_57);

DEFLABEL (lambda_71)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_67]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_113_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_83]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_113_83);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_113_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_92]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_56;

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_113_92);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_101]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_41]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_113_101);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_112]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto lambda_34;

DEFLABEL (continuation_70)
  INTERRUPT_CHECK (27, LABEL_113_112);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_419)
DEFLABEL (lambda_77)
  INTERRUPT_CHECK (26, LABEL_113_65);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_81]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_113_81);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_90]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_91]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_113_91);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_113_90);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_100]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_56;

DEFLABEL (continuation_76)
  INTERRUPT_CHECK (27, LABEL_113_100);
  (Wrd5.Obj) = (current_block [OBJECT_113_32]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_420)
DEFLABEL (lambda_111)
  INTERRUPT_CHECK (26, LABEL_113_79);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_43]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_83)
  INTERRUPT_CHECK (27, LABEL_113_89);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_99]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_113_99);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_111]));

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_113_98);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_50]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_113_110);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_119]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_120]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_113_56]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_87)
  INTERRUPT_CHECK (27, LABEL_113_120);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_138]));

DEFLABEL (continuation_88)
  INTERRUPT_CHECK (27, LABEL_113_119);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_137]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_113_137);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = (& (Rsp [3]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd7.pObj)));
  (Rsp [1]) = (Wrd9.Obj);
  goto lambda_82;

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_113_118);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_136]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_67]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_92)
  INTERRUPT_CHECK (27, LABEL_113_136);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_147]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_148]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_29]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_93)
  INTERRUPT_CHECK (27, LABEL_113_148);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_156]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_157]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_113_156);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_169]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_170]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_113_169);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_177]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_178]));

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_113_177);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_732;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_189]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_90]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_106)
  INTERRUPT_CHECK (27, LABEL_113_189);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_197]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_107)
  INTERRUPT_CHECK (27, LABEL_113_197);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd7.pObj) = (& (Rsp [4]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_82;

DEFLABEL (label_732)
  (Wrd12.Obj) = (Rsp [1]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_733;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_188]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_113_89]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_102)
  INTERRUPT_CHECK (27, LABEL_113_188);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_198]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_113_198);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_214]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_100]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_104)
  INTERRUPT_CHECK (27, LABEL_113_214);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_224]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_113_224);
  (Wrd5.Obj) = (current_block [OBJECT_113_79]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [5]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_733)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_187]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_113_88]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_113_187);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_199]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_737;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_736)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_113_199);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_735;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_734)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd15.pObj) = (& (Rsp [4]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (Rsp [2]) = (Wrd17.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_82;

DEFLABEL (label_735)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_215]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_95]), 1);

DEFLABEL (label_335)
  (Wrd5.Obj) = Rvl;
  goto label_734;

DEFLABEL (label_737)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_200]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_95]), 1);

DEFLABEL (label_330)
  (* (--Rsp)) = Rvl;
  goto label_736;

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_113_147);
  (Wrd5.Obj) = (current_block [OBJECT_113_77]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_155]));

DEFLABEL (lambda_421)
DEFLABEL (lambda_119)
  INTERRUPT_CHECK (26, LABEL_113_87);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_97]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_113)
  INTERRUPT_CHECK (27, LABEL_113_97);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_108]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_109]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_25]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_114)
  INTERRUPT_CHECK (27, LABEL_113_109);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_113_108);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_117]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_55]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_113_117);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_134]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_135]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_29]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_113_135);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_118)
  INTERRUPT_CHECK (27, LABEL_113_134);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_422)
DEFLABEL (lambda_56)
  INTERRUPT_CHECK (26, LABEL_113_102);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_103]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_46]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_113_103);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_113]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_51]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_113_113);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_122]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd35.Obj) = (current_block [OBJECT_113_58]);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd38.Lng))))
    goto label_758;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd35.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_757;

DEFLABEL (label_756)
  (Wrd13.Obj) = (current_block [OBJECT_113_60]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd23.Lng)))
    goto label_738;
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_59]), 2);

DEFLABEL (label_738)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_740;
  (Wrd15.Obj) = (current_block [OBJECT_113_62]);
  goto label_739;

DEFLABEL (label_740)
  (Wrd15.Obj) = (current_block [OBJECT_113_61]);

DEFLABEL (label_739)
DEFLABEL (label_755)
  Rsp = (& (Rsp [3]));
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_754;

DEFLABEL (label_753)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_125]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_113_63]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_113_125);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_139]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_113_58]);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd38.Lng))))
    goto label_752;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd35.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_751;

DEFLABEL (label_750)
  (Wrd13.Obj) = (current_block [OBJECT_113_60]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd23.Lng)))
    goto label_741;
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_59]), 2);

DEFLABEL (label_741)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_743;
  (Wrd15.Obj) = (current_block [OBJECT_113_62]);
  goto label_742;

DEFLABEL (label_743)
  (Wrd15.Obj) = (current_block [OBJECT_113_61]);

DEFLABEL (label_742)
DEFLABEL (label_749)
  Rsp = (& (Rsp [3]));
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_745;

DEFLABEL (label_744)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_143]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_113_68]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_113_143);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_149]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_113_149);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_164]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_81]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_113_164);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_171]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_111]));

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_113_171);
  (Wrd5.Obj) = (current_block [OBJECT_113_86]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_745)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_141]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_142]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_113_141);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_748;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_150]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_74]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_113_150);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_160]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_161]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_747;
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd18.Lng) = ((Wrd20.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd18.Lng)))
    goto label_747;
  (Wrd21.Obj) = (LONG_TO_FIXNUM (Wrd18.Lng));
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_746)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_163]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_113_161);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_113_160);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_149]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_80]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_747)
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_162]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_321)
  (* (--Rsp)) = Rvl;
  goto label_746;

DEFLABEL (label_748)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_149]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_113_73]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_751)
  Rsp = (& (Rsp [2]));
  goto label_744;

DEFLABEL (label_752)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_140]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_59]), 2);

DEFLABEL (label_317)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_750;
  goto label_751;

DEFLABEL (label_754)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_121]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_124]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_113_121);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_753;
  Rvl = (current_block [OBJECT_113_57]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_757)
  Rsp = (& (Rsp [2]));
  goto label_753;

DEFLABEL (label_758)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_123]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_59]), 2);

DEFLABEL (label_314)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_756;
  goto label_757;

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_113_139);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_745;
  goto label_744;

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_113_122);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_754;
  goto label_753;

DEFLABEL (lambda_423)
DEFLABEL (lambda_125)
  INTERRUPT_CHECK (26, LABEL_113_106);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_116]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_54]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_122)
  INTERRUPT_CHECK (27, LABEL_113_116);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_132]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_133]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_66]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_123)
  INTERRUPT_CHECK (27, LABEL_113_133);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_124)
  INTERRUPT_CHECK (27, LABEL_113_132);
  (Wrd5.Obj) = (current_block [OBJECT_113_72]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_424)
DEFLABEL (lambda_132)
  INTERRUPT_CHECK (26, LABEL_113_128);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_113_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_760;
  Wrd5 = Wrd9;

DEFLABEL (label_759)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.Obj) = (current_block [OBJECT_113_0]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_131);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_130])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  ((Wrd19.pObj) [2]) = (Wrd15.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_10]));

DEFLABEL (label_760)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113_129])), (Wrd6.pObj));

DEFLABEL (label_316)
  (Wrd5.Obj) = Rvl;
  goto label_759;

DEFLABEL (lambda_425)
  CLOSURE_HEADER (LABEL_113_130);

DEFLABEL (lambda_131)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_146]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_71]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_128)
  INTERRUPT_CHECK (27, LABEL_113_146);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_153]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_154]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_129)
  INTERRUPT_CHECK (27, LABEL_113_154);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_130)
  INTERRUPT_CHECK (27, LABEL_113_153);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_426)
DEFLABEL (lambda_82)
  INTERRUPT_CHECK (26, LABEL_113_158);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_765;
  if ((Wrd5.Obj) == (current_block [OBJECT_113_78]))
    goto label_762;

DEFLABEL (label_763)
  (Wrd9.Obj) = (current_block [OBJECT_113_79]);
  goto label_761;

DEFLABEL (label_762)
  (Wrd9.Obj) = (current_block [OBJECT_113_80]);

DEFLABEL (label_761)
DEFLABEL (label_764)
  (Rsp [0]) = (Wrd9.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_765)
  (Wrd14.Obj) = (current_block [OBJECT_113_78]);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_159]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_320)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_763;
  goto label_762;

DEFLABEL (lambda_427)
DEFLABEL (lambda_145)
  INTERRUPT_CHECK (26, LABEL_113_167);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_176]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_85]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_139)
  INTERRUPT_CHECK (27, LABEL_113_176);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_185]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_186]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_52]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_140)
  INTERRUPT_CHECK (27, LABEL_113_186);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_141)
  INTERRUPT_CHECK (27, LABEL_113_185);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_196]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_94]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_113_196);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_212]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_213]));

DEFLABEL (continuation_143)
  INTERRUPT_CHECK (27, LABEL_113_212);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_223]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_104]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_144)
  INTERRUPT_CHECK (27, LABEL_113_223);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_237]));

DEFLABEL (lambda_428)
  CLOSURE_HEADER (LABEL_113_179);

DEFLABEL (lambda_153)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_190]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_91]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_191]));

DEFLABEL (continuation_149)
  INTERRUPT_CHECK (27, LABEL_113_190);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_201]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_769;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_769;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_768)
  (Wrd35.Obj) = (Rsp [6]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_767;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_767;
  (Wrd28.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_766)
  (Wrd42.Obj) = (Rsp [5]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (continuation_152)
  INTERRUPT_CHECK (27, LABEL_113_201);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_216]));

DEFLABEL (label_767)
  (Wrd37.Obj) = (Rsp [6]);
  (Wrd38.Obj) = (current_block [OBJECT_113_98]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_203]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_332)
  (* (--Rsp)) = Rvl;
  goto label_766;

DEFLABEL (label_769)
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.Obj) = (current_block [OBJECT_113_96]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_202]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_331)
  (* (--Rsp)) = Rvl;
  goto label_768;

DEFLABEL (lambda_429)
DEFLABEL (lambda_161)
  INTERRUPT_CHECK (26, LABEL_113_183);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_195]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_93]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_155)
  INTERRUPT_CHECK (27, LABEL_113_195);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_210]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_211]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_64]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_156)
  INTERRUPT_CHECK (27, LABEL_113_211);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_113_210);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_222]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_94]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_158)
  INTERRUPT_CHECK (27, LABEL_113_222);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_236]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_213]));

DEFLABEL (continuation_159)
  INTERRUPT_CHECK (27, LABEL_113_236);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_244]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_104]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_160)
  INTERRUPT_CHECK (27, LABEL_113_244);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_237]));

DEFLABEL (lambda_430)
  CLOSURE_HEADER (LABEL_113_204);

DEFLABEL (lambda_169)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_217]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_101]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_191]));

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_113_217);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_225]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_773;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_773;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_772)
  (Wrd35.Obj) = (Rsp [6]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_771;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_771;
  (Wrd28.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_770)
  (Wrd42.Obj) = (Rsp [5]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (continuation_168)
  INTERRUPT_CHECK (27, LABEL_113_225);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_216]));

DEFLABEL (label_771)
  (Wrd37.Obj) = (Rsp [6]);
  (Wrd38.Obj) = (current_block [OBJECT_113_98]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_227]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_339)
  (* (--Rsp)) = Rvl;
  goto label_770;

DEFLABEL (label_773)
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.Obj) = (current_block [OBJECT_113_96]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_226]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_338)
  (* (--Rsp)) = Rvl;
  goto label_772;

DEFLABEL (lambda_431)
DEFLABEL (lambda_182)
  INTERRUPT_CHECK (26, LABEL_113_208);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_221]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_103]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_171)
  INTERRUPT_CHECK (27, LABEL_113_221);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_234]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_235]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_75]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_172)
  INTERRUPT_CHECK (27, LABEL_113_235);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_173)
  INTERRUPT_CHECK (27, LABEL_113_234);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_243]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_108]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_174)
  INTERRUPT_CHECK (27, LABEL_113_243);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_254]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_104]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_175)
  INTERRUPT_CHECK (27, LABEL_113_254);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_265]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_266]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_267]));

DEFLABEL (continuation_176)
  INTERRUPT_CHECK (27, LABEL_113_266);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_775;
  (Wrd7.Obj) = (current_block [OBJECT_113_122]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto label_774;

DEFLABEL (label_775)
  (Wrd8.Obj) = (current_block [OBJECT_113_121]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_774)
DEFLABEL (label_776)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_178)
  INTERRUPT_CHECK (27, LABEL_113_265);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_287]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_120]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_179)
  INTERRUPT_CHECK (27, LABEL_113_287);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_300]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_213]));

DEFLABEL (continuation_180)
  INTERRUPT_CHECK (27, LABEL_113_300);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_237]));

DEFLABEL (lambda_432)
  CLOSURE_HEADER (LABEL_113_228);

DEFLABEL (lambda_194)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_238]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_105]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_191]));

DEFLABEL (continuation_186)
  INTERRUPT_CHECK (27, LABEL_113_238);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_245]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_780;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_780;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_779)
  (Wrd35.Obj) = (Rsp [6]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_778;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_778;
  (Wrd28.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_777)
  (Wrd42.Obj) = (Rsp [5]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (continuation_189)
  INTERRUPT_CHECK (27, LABEL_113_245);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd6.Obj) = (current_block [OBJECT_113_110]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_113_111]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_256);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_255])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_257]));

DEFLABEL (label_778)
  (Wrd37.Obj) = (Rsp [6]);
  (Wrd38.Obj) = (current_block [OBJECT_113_98]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_247]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_345)
  (* (--Rsp)) = Rvl;
  goto label_777;

DEFLABEL (label_780)
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.Obj) = (current_block [OBJECT_113_96]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_246]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_97]), 2);

DEFLABEL (label_344)
  (* (--Rsp)) = Rvl;
  goto label_779;

DEFLABEL (lambda_433)
DEFLABEL (lambda_214)
  INTERRUPT_CHECK (26, LABEL_113_241);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_253]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_109]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_197)
  INTERRUPT_CHECK (27, LABEL_113_253);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_264]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_115]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_198)
  INTERRUPT_CHECK (27, LABEL_113_264);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_285]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_286]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_114]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_199)
  INTERRUPT_CHECK (27, LABEL_113_286);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_200)
  INTERRUPT_CHECK (27, LABEL_113_285);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_299]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_128]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_201)
  INTERRUPT_CHECK (27, LABEL_113_299);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_310]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_202)
  INTERRUPT_CHECK (27, LABEL_113_310);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_317]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_128]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_203)
  INTERRUPT_CHECK (27, LABEL_113_317);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_326]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_327]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_328]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_113_64]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_204)
  INTERRUPT_CHECK (27, LABEL_113_328);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_335]));

DEFLABEL (continuation_205)
  INTERRUPT_CHECK (27, LABEL_113_327);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_206)
  INTERRUPT_CHECK (27, LABEL_113_326);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_334]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_141]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_207)
  INTERRUPT_CHECK (27, LABEL_113_334);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_341]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_342]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_144]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_208)
  INTERRUPT_CHECK (27, LABEL_113_342);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_781;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_350]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_351]));

DEFLABEL (continuation_211)
  INTERRUPT_CHECK (27, LABEL_113_350);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (label_781)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_349]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_113_149]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_210)
  INTERRUPT_CHECK (27, LABEL_113_349);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [5]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_209)
  INTERRUPT_CHECK (27, LABEL_113_341);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_434)
  CLOSURE_HEADER (LABEL_113_255);

DEFLABEL (lambda_192)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_268]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_116]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_269]))));
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_270]));

DEFLABEL (continuation_190)
  INTERRUPT_CHECK (27, LABEL_113_269);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_288]));

DEFLABEL (continuation_191)
  INTERRUPT_CHECK (27, LABEL_113_268);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_216]));

DEFLABEL (lambda_435)
DEFLABEL (lambda_231)
  INTERRUPT_CHECK (26, LABEL_113_260);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_275]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_118]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_228)
  INTERRUPT_CHECK (27, LABEL_113_275);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_294]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_295]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_69]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_113_295);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_230)
  INTERRUPT_CHECK (27, LABEL_113_294);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_439)
DEFLABEL (lambda_235)
  INTERRUPT_CHECK (26, LABEL_113_273);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_293]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_124]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_233)
  INTERRUPT_CHECK (27, LABEL_113_293);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_306]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_69]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_234)
  INTERRUPT_CHECK (27, LABEL_113_306);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (lambda_436)
  CLOSURE_HEADER (LABEL_113_276);

DEFLABEL (lambda_220)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_113_125]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_296]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_219)
  INTERRUPT_CHECK (27, LABEL_113_296);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_113_131]);
  (Rsp [2]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_307]));

DEFLABEL (lambda_437)
  CLOSURE_HEADER (LABEL_113_280);

DEFLABEL (lambda_226)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_113_126]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_297]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_224)
  INTERRUPT_CHECK (27, LABEL_113_297);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_132]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_308]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_113_308);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_113_135]);
  (Rsp [4]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_316]));

DEFLABEL (lambda_438)
  CLOSURE_HEADER (LABEL_113_282);

DEFLABEL (lambda_223)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_113_127]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_298]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_221)
  INTERRUPT_CHECK (27, LABEL_113_298);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_113_132]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_309]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_222)
  INTERRUPT_CHECK (27, LABEL_113_309);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [4]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_316]));

DEFLABEL (lambda_440)
DEFLABEL (lambda_239)
  INTERRUPT_CHECK (26, LABEL_113_291);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_305]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_130]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_237)
  INTERRUPT_CHECK (27, LABEL_113_305);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_315]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_69]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_238)
  INTERRUPT_CHECK (27, LABEL_113_315);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (lambda_441)
DEFLABEL (lambda_243)
  INTERRUPT_CHECK (26, LABEL_113_303);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_314]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_134]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_241)
  INTERRUPT_CHECK (27, LABEL_113_314);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_325]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_69]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_242)
  INTERRUPT_CHECK (27, LABEL_113_325);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (lambda_442)
DEFLABEL (lambda_251)
  INTERRUPT_CHECK (26, LABEL_113_322);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_113_324);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_113_323])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_443)
  CLOSURE_HEADER (LABEL_113_323);

DEFLABEL (lambda_250)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_333]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_245)
  INTERRUPT_CHECK (27, LABEL_113_333);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_340]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_113_51]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_246)
  INTERRUPT_CHECK (27, LABEL_113_340);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_782;
  Rvl = (current_block [OBJECT_113_57]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_782)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_348]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_113_148]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_247)
  INTERRUPT_CHECK (27, LABEL_113_348);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_356]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_111]));

DEFLABEL (continuation_248)
  INTERRUPT_CHECK (27, LABEL_113_356);
  (Wrd5.Obj) = (current_block [OBJECT_113_47]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (lambda_444)
DEFLABEL (lambda_265)
  INTERRUPT_CHECK (26, LABEL_113_345);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_355]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113_150]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_38]));

DEFLABEL (continuation_262)
  INTERRUPT_CHECK (27, LABEL_113_355);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_360]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_361]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_113_151]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_23]));

DEFLABEL (continuation_263)
  INTERRUPT_CHECK (27, LABEL_113_361);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_53]));

DEFLABEL (continuation_264)
  INTERRUPT_CHECK (27, LABEL_113_360);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_213]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_114_4 3
#define LABEL_114_8 5
#define LABEL_114_12 7
#define LABEL_114_5 9
#define TAG_114_6 3
#define LABEL_114_13 11
#define LABEL_114_15 13
#define LABEL_114_10 15
#define TAG_114_11 6
#define LABEL_114_18 17
#define ENVIRONMENT_LABEL_114_3 37
#define DEBUGGING_LABEL_114_2 36
#define OBJECT_114_4 35
#define OBJECT_114_3 34
#define OBJECT_114_2 33
#define OBJECT_114_1 32
#define OBJECT_114_0 31
#define EXECUTE_CACHE_114_17 19
#define EXECUTE_CACHE_114_16 21
#define EXECUTE_CACHE_114_14 23
#define EXECUTE_CACHE_114_9 25
#define EXECUTE_CACHE_114_7 27
#define FREE_REFERENCE_114_0 30
#define FREE_REFERENCES_LABEL_114_0 18
#define NUMBER_OF_LINKER_SECTIONS_114_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_114 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd32;
  machine_word Wrd38;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd37;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_114_4);
      goto ignore_errors_8;

    case 1:
      current_block = (Rpc - LABEL_114_8);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_114_12);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_114_5);
      goto lambda_13;

    case 4:
      current_block = (Rpc - LABEL_114_13);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_114_15);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_114_10);
      goto lambda_14;

    case 7:
      current_block = (Rpc - LABEL_114_18);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ignore_errors_12)
DEFLABEL (ignore_errors_8)
  INTERRUPT_CHECK (26, LABEL_114_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_114_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_114_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_7]));

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_114_5);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_114_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_21;
  Wrd6 = Wrd10;

DEFLABEL (label_20)
  (Wrd15.Obj) = (current_block [OBJECT_114_2]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = ((Wrd17.pObj) [2]);
  if ((Wrd24.Obj) == (current_block [OBJECT_114_3]))
    goto label_19;
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_15]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_114_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd14.Obj) = (current_block [OBJECT_114_0]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_114_1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_114_12);
  (Wrd37.Obj) = Rvl;

DEFLABEL (label_15)
  (Rsp [2]) = (Wrd37.Obj);
  (Wrd38.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_14]));

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_114_4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_114_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_17;
  (Wrd51.Obj) = (current_block [OBJECT_114_0]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd52.Obj) = (current_block [OBJECT_114_1]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (Rsp [5]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [2]);
  (* (--Rsp)) = (Wrd55.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_9]));

DEFLABEL (label_17)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd44.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_114_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_114_10])));
  Rhp += 2;
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd44.pObj)));
  Wrd47 = Wrd44;
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [2]);
  ((Wrd47.pObj) [2]) = (Wrd50.Obj);
  (Wrd46.Obj) = (Rsp [4]);
  ((Wrd47.pObj) [3]) = (Wrd46.Obj);
  Wrd37 = Wrd43;

DEFLABEL (label_18)
  Rsp = (& (Rsp [1]));
  goto label_15;

DEFLABEL (label_19)
  (Wrd37.Obj) = (Rsp [4]);
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_114_13])), (Wrd7.pObj));

DEFLABEL (label_10)
  (Wrd6.Obj) = Rvl;
  goto label_20;

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_114_10);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_114_18);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_115_4 3
#define LABEL_115_5 5
#define TAG_115_6 1
#define LABEL_115_14 7
#define LABEL_115_7 9
#define TAG_115_8 3
#define LABEL_115_16 11
#define LABEL_115_17 13
#define LABEL_115_18 15
#define LABEL_115_19 17
#define LABEL_115_9 19
#define TAG_115_10 8
#define LABEL_115_20 21
#define LABEL_115_21 23
#define LABEL_115_22 25
#define LABEL_115_23 27
#define LABEL_115_12 29
#define TAG_115_13 13
#define LABEL_115_24 31
#define LABEL_115_25 33
#define LABEL_115_26 35
#define LABEL_115_29 37
#define LABEL_115_28 39
#define ENVIRONMENT_LABEL_115_3 65
#define DEBUGGING_LABEL_115_2 64
#define OBJECT_115_5 63
#define OBJECT_115_4 62
#define OBJECT_115_3 61
#define OBJECT_115_2 60
#define OBJECT_115_1 59
#define OBJECT_115_0 58
#define EXECUTE_CACHE_115_31 41
#define EXECUTE_CACHE_115_30 43
#define EXECUTE_CACHE_115_27 45
#define EXECUTE_CACHE_115_15 47
#define EXECUTE_CACHE_115_11 49
#define FREE_REFERENCE_115_2 52
#define FREE_REFERENCE_115_1 53
#define FREE_REFERENCE_115_0 54
#define FREE_ASSIGNMENT_115_1 56
#define FREE_ASSIGNMENT_115_0 57
#define FREE_REFERENCES_LABEL_115_0 40
#define NUMBER_OF_LINKER_SECTIONS_115_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_115 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd28;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_115_4);
      goto format_error_message_38;

    case 1:
      current_block = (Rpc - LABEL_115_5);
      goto lambda_54;

    case 2:
      current_block = (Rpc - LABEL_115_14);
      goto label_40;

    case 3:
      current_block = (Rpc - LABEL_115_7);
      goto lambda_55;

    case 4:
      current_block = (Rpc - LABEL_115_16);
      goto label_41;

    case 5:
      current_block = (Rpc - LABEL_115_17);
      goto label_42;

    case 6:
      current_block = (Rpc - LABEL_115_18);
      goto label_43;

    case 7:
      current_block = (Rpc - LABEL_115_19);
      goto label_44;

    case 8:
      current_block = (Rpc - LABEL_115_9);
      goto lambda_56;

    case 9:
      current_block = (Rpc - LABEL_115_20);
      goto label_45;

    case 10:
      current_block = (Rpc - LABEL_115_21);
      goto label_46;

    case 11:
      current_block = (Rpc - LABEL_115_22);
      goto label_47;

    case 12:
      current_block = (Rpc - LABEL_115_23);
      goto label_48;

    case 13:
      current_block = (Rpc - LABEL_115_12);
      goto lambda_57;

    case 14:
      current_block = (Rpc - LABEL_115_24);
      goto label_49;

    case 15:
      current_block = (Rpc - LABEL_115_25);
      goto label_50;

    case 16:
      current_block = (Rpc - LABEL_115_26);
      goto label_51;

    case 17:
      current_block = (Rpc - LABEL_115_29);
      goto continuation_14;

    case 18:
      current_block = (Rpc - LABEL_115_28);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (format_error_message_53)
DEFLABEL (format_error_message_38)
  INTERRUPT_CHECK (26, LABEL_115_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_115_0]);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_115_1]);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd22.pObj) = (& (Rhp [-1]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd27.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_115_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_115_5])));
  Rhp += 3;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd27.pObj)));
  Wrd32 = Wrd27;
  (Wrd33.Obj) = (Rsp [6]);
  ((Wrd32.pObj) [2]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [5]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (Wrd29.Obj) = (Rsp [4]);
  ((Wrd32.pObj) [4]) = (Wrd29.Obj);
  (Rsp [5]) = (Wrd26.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd36.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_115_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_115_7])));
  Rhp += 4;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd36.pObj)));
  Wrd43 = Wrd36;
  ((Wrd43.pObj) [2]) = (Wrd7.Obj);
  ((Wrd43.pObj) [3]) = (Wrd13.Obj);
  ((Wrd43.pObj) [4]) = (Wrd19.Obj);
  ((Wrd43.pObj) [5]) = (Wrd23.Obj);
  (Rsp [4]) = (Wrd35.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_115_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_115_9])));
  Rhp += 4;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  Wrd54 = Wrd47;
  ((Wrd54.pObj) [2]) = (Wrd7.Obj);
  ((Wrd54.pObj) [3]) = (Wrd13.Obj);
  ((Wrd54.pObj) [4]) = (Wrd19.Obj);
  ((Wrd54.pObj) [5]) = (Wrd23.Obj);
  (Rsp [6]) = (Wrd46.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_11]));

DEFLABEL (lambda_54)
  CLOSURE_HEADER (LABEL_115_5);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_115_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_115_12])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  ((Wrd7.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [4]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 30)
    goto label_59;
  Wrd15 = Wrd13;

DEFLABEL (label_58)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Rsp [1]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_15]));

DEFLABEL (label_59)
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_0]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_61;
  Wrd25 = Wrd29;

DEFLABEL (label_60)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [4]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd35.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_115_14])), (Wrd26.pObj));

DEFLABEL (label_40)
  (Wrd25.Obj) = Rvl;
  goto label_60;

DEFLABEL (lambda_55)
  CLOSURE_HEADER (LABEL_115_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_73;

DEFLABEL (label_72)
  Wrd19 = Wrd23;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_115_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_70;

DEFLABEL (label_69)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_68)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_67;

DEFLABEL (label_66)
  Wrd63 = Wrd67;

DEFLABEL (label_65)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_115_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_64;

DEFLABEL (label_63)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_62)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [2]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_115_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_64)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_63;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_115_19])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_44)
  goto label_62;

DEFLABEL (label_67)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_66;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_115_18])), (Wrd64.pObj));

DEFLABEL (label_43)
  (Wrd63.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_70)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_69;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_115_17])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_42)
  goto label_68;

DEFLABEL (label_73)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_72;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_115_16])), (Wrd20.pObj));

DEFLABEL (label_41)
  (Wrd19.Obj) = Rvl;
  goto label_71;

DEFLABEL (lambda_56)
  CLOSURE_HEADER (LABEL_115_9);

DEFLABEL (lambda_36)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_85;

DEFLABEL (label_84)
  Wrd19 = Wrd23;

DEFLABEL (label_83)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_115_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_82;

DEFLABEL (label_81)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_80)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_79;

DEFLABEL (label_78)
  Wrd63 = Wrd67;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_115_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_76;

DEFLABEL (label_75)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_74)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_115_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_76)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_75;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_115_23])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_48)
  goto label_74;

DEFLABEL (label_79)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_78;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_115_22])), (Wrd64.pObj));

DEFLABEL (label_47)
  (Wrd63.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_82)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_81;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_115_21])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_46)
  goto label_80;

DEFLABEL (label_85)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_84;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_115_20])), (Wrd20.pObj));

DEFLABEL (label_45)
  (Wrd19.Obj) = Rvl;
  goto label_83;

DEFLABEL (lambda_57)
  CLOSURE_HEADER (LABEL_115_12);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_87;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_29]))));
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_86)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_115_5]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_30]));

DEFLABEL (label_87)
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_115_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_94;
  Wrd14 = Wrd18;

DEFLABEL (label_93)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_92;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_91)
  (Wrd29.Obj) = (* (Rsp++));
  if ((Wrd20.Obj) == (Wrd29.Obj))
    goto label_88;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_28]))));
  (* (--Rsp)) = (Wrd32.Obj);
  goto label_86;

DEFLABEL (label_88)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [2]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_90;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_89)
  (Rsp [1]) = (Wrd40.Obj);
  (Wrd49.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_27]));

DEFLABEL (label_90)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_26]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_4]), 1);

DEFLABEL (label_51)
  (Wrd40.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_25]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_3]), 1);

DEFLABEL (label_50)
  (Wrd20.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_94)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_115_24])), (Wrd15.pObj));

DEFLABEL (label_49)
  (Wrd14.Obj) = Rvl;
  goto label_93;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_115_29);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_31]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_115_28);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_31]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_116_4 3
#define LABEL_116_5 5
#define ENVIRONMENT_LABEL_116_3 9
#define DEBUGGING_LABEL_116_2 8
#define FREE_REFERENCE_116_0 7
#define FREE_REFERENCES_LABEL_116_0 6
#define NUMBER_OF_LINKER_SECTIONS_116_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_116 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_116_4);
      goto error_irritant_noise_0;

    case 1:
      current_block = (Rpc - LABEL_116_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_irritant_noise_4)
DEFLABEL (error_irritant_noise_0)
  INTERRUPT_CHECK (26, LABEL_116_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_116_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_6;
  Wrd6 = Wrd10;

DEFLABEL (label_5)
  (Wrd16.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_116_5])), (Wrd7.pObj));

DEFLABEL (label_2)
  (Wrd6.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_117_4 3
#define LABEL_117_7 5
#define LABEL_117_5 7
#define LABEL_117_8 9
#define LABEL_117_10 11
#define LABEL_117_11 13
#define LABEL_117_14 15
#define LABEL_117_12 17
#define LABEL_117_15 19
#define LABEL_117_17 21
#define LABEL_117_18 23
#define LABEL_117_20 25
#define LABEL_117_22 27
#define LABEL_117_23 29
#define LABEL_117_19 31
#define ENVIRONMENT_LABEL_117_3 58
#define DEBUGGING_LABEL_117_2 57
#define OBJECT_117_11 56
#define OBJECT_117_10 55
#define OBJECT_117_9 54
#define OBJECT_117_8 53
#define OBJECT_117_7 52
#define OBJECT_117_6 51
#define OBJECT_117_5 50
#define OBJECT_117_4 49
#define OBJECT_117_3 48
#define OBJECT_117_2 47
#define OBJECT_117_1 46
#define OBJECT_117_0 45
#define EXECUTE_CACHE_117_24 33
#define EXECUTE_CACHE_117_21 35
#define EXECUTE_CACHE_117_16 37
#define EXECUTE_CACHE_117_13 39
#define EXECUTE_CACHE_117_9 41
#define EXECUTE_CACHE_117_6 43
#define FREE_REFERENCES_LABEL_117_0 32
#define NUMBER_OF_LINKER_SECTIONS_117_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_117 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd77;
  machine_word Wrd74;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd82;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd71;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd58;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd42;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_117_4);
      goto ordinal_number_string_17;

    case 1:
      current_block = (Rpc - LABEL_117_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_117_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_117_8);
      goto label_22;

    case 4:
      current_block = (Rpc - LABEL_117_10);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_117_11);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_117_14);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_117_12);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_117_15);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_117_17);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_117_18);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_117_20);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_117_22);
      goto label_25;

    case 13:
      current_block = (Rpc - LABEL_117_23);
      goto label_26;

    case 14:
      current_block = (Rpc - LABEL_117_19);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ordinal_number_string_28)
DEFLABEL (ordinal_number_string_17)
  INTERRUPT_CHECK (26, LABEL_117_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_117_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_52;

DEFLABEL (label_51)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_117_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_117_2]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_117_7);

DEFLABEL (label_50)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_49;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if ((Wrd22.Lng) < 10L)
    goto label_48;

DEFLABEL (label_47)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 26))
    goto label_46;
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if ((Wrd28.Lng) < 20L)
    goto label_40;

DEFLABEL (label_39)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_12]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_117_3]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_117_12);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_117_15);
  (Wrd5.Obj) = Rvl;
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 26))
    goto label_38;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd13.Lng) = ((Wrd14.Lng) - 2L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_38;
  (Wrd11.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_37)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_36;
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd24.Obj) = (current_block [OBJECT_117_9]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) (Wrd23.Lng)) < ((unsigned long) (Wrd27.Lng))))
    goto label_36;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd11.Obj));
  (Wrd20.pObj) = (& ((Wrd25.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_35)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_19]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_20]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_21]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_117_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd7.uLng) == 26))
    goto label_34;
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Rvl));
  if ((Wrd35.Lng) == 0)
    goto label_32;

DEFLABEL (label_31)
  (Wrd13.Obj) = (current_block [OBJECT_117_10]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_30;
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  (Wrd24.Obj) = (current_block [OBJECT_117_6]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) (Wrd23.Lng)) < ((unsigned long) (Wrd27.Lng))))
    goto label_30;
  (Wrd16.uLng) = (OBJECT_DATUM (Wrd20.Obj));
  (Wrd19.pObj) = (& ((Wrd25.pObj) [(Wrd16.Lng)]));
  (Wrd14.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_24]));

DEFLABEL (label_30)
  (Wrd28.Obj) = (current_block [OBJECT_117_6]);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_23]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_7]), 2);

DEFLABEL (label_26)
  (Wrd14.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd5.Obj) = (current_block [OBJECT_117_11]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_33)
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_24]));

DEFLABEL (label_34)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_22]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_32;

DEFLABEL (label_36)
  (Wrd28.Obj) = (current_block [OBJECT_117_9]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_18]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_7]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd7.Obj) = (current_block [OBJECT_117_8]);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_23)
  (Wrd11.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd36.Obj) = (current_block [OBJECT_117_5]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 26))
    goto label_45;
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  (Wrd45.Lng) = ((Wrd47.Lng) - 10L);
  if (! (LONG_TO_FIXNUM_P (Wrd45.Lng)))
    goto label_45;
  (Wrd42.Obj) = (LONG_TO_FIXNUM (Wrd45.Lng));

DEFLABEL (label_44)
  (Rsp [1]) = (Wrd42.Obj);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if ((Wrd58.uLng) == 26)
    goto label_42;

DEFLABEL (label_41)
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_7]), 2);

DEFLABEL (label_42)
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  (Wrd61.Obj) = (current_block [OBJECT_117_5]);
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) (Wrd60.Lng)) < ((unsigned long) (Wrd64.Lng))))
    goto label_41;
  (Wrd52.uLng) = (OBJECT_DATUM (Wrd42.Obj));
  (Wrd55.pObj) = (& ((Wrd62.pObj) [(Wrd52.Lng)]));
  Rvl = ((Wrd55.pObj) [1]);

DEFLABEL (label_43)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_45)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (current_block [OBJECT_117_3]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_14]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_19)
  (Wrd42.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  (Wrd66.Obj) = (current_block [OBJECT_117_4]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_11]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_20)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  goto label_40;

DEFLABEL (label_48)
  (Wrd71.Obj) = (current_block [OBJECT_117_6]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd79.Obj) = (Rsp [1]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd80.uLng) == 26))
    goto label_41;
  (Wrd82.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd85.Obj) = ((Wrd84.pObj) [0]);
  (Wrd86.Lng) = (FIXNUM_TO_LONG (Wrd85.Obj));
  if (! (((unsigned long) (Wrd82.Lng)) < ((unsigned long) (Wrd86.Lng))))
    goto label_41;
  (Wrd74.uLng) = (OBJECT_DATUM (Wrd79.Obj));
  (Wrd77.pObj) = (& ((Wrd84.pObj) [(Wrd74.Lng)]));
  Rvl = ((Wrd77.pObj) [1]);
  goto label_43;

DEFLABEL (label_49)
  (Wrd88.Obj) = (current_block [OBJECT_117_3]);
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_10]))));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_21)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  goto label_48;

DEFLABEL (label_52)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_53;
  (Wrd10.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd10.Lng) < 100L)
    goto label_50;
  goto label_51;

DEFLABEL (label_53)
  (Wrd94.Obj) = (current_block [OBJECT_117_0]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_8]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  goto label_50;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_117_19);
  (Wrd5.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_118_4 3
#define LABEL_118_6 5
#define LABEL_118_5 7
#define ENVIRONMENT_LABEL_118_3 16
#define DEBUGGING_LABEL_118_2 15
#define EXECUTE_CACHE_118_9 9
#define EXECUTE_CACHE_118_8 11
#define EXECUTE_CACHE_118_7 13
#define FREE_REFERENCES_LABEL_118_0 8
#define NUMBER_OF_LINKER_SECTIONS_118_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
error_so_code_118 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_118_4);
      goto write_operator_2;

    case 1:
      current_block = (Rpc - LABEL_118_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_118_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_operator_5)
DEFLABEL (write_operator_2)
  INTERRUPT_CHECK (26, LABEL_118_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_118_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_118_5);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_9]));

DEFLABEL (label_7)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [1]));
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_10 5
#define LABEL_5 7
#define LABEL_6 9
#define LABEL_8 11
#define LABEL_9 13
#define LABEL_13 15
#define LABEL_19 17
#define LABEL_15 19
#define TAG_16 8
#define LABEL_21 21
#define LABEL_17 23
#define LABEL_18 25
#define LABEL_20 27
#define LABEL_23 29
#define LABEL_24 31
#define TAG_25 14
#define LABEL_29 33
#define LABEL_26 35
#define LABEL_32 37
#define LABEL_27 39
#define LABEL_28 41
#define LABEL_30 43
#define LABEL_31 45
#define LABEL_33 47
#define LABEL_38 49
#define LABEL_34 51
#define TAG_35 24
#define LABEL_40 53
#define LABEL_36 55
#define LABEL_37 57
#define LABEL_39 59
#define LABEL_41 61
#define LABEL_42 63
#define TAG_43 30
#define LABEL_47 65
#define LABEL_44 67
#define LABEL_50 69
#define LABEL_45 71
#define LABEL_46 73
#define LABEL_48 75
#define LABEL_49 77
#define LABEL_51 79
#define LABEL_56 81
#define LABEL_52 83
#define TAG_53 40
#define LABEL_58 85
#define LABEL_54 87
#define LABEL_55 89
#define LABEL_57 91
#define LABEL_59 93
#define TAG_60 45
#define LABEL_61 95
#define LABEL_62 97
#define LABEL_63 99
#define LABEL_64 101
#define ENVIRONMENT_LABEL_3 177
#define DEBUGGING_LABEL_2 176
#define PURIFICATION_ROOT 175
#define OBJECT_56 174
#define OBJECT_55 173
#define OBJECT_54 172
#define OBJECT_53 171
#define OBJECT_52 170
#define OBJECT_51 169
#define OBJECT_50 168
#define OBJECT_49 167
#define OBJECT_48 166
#define OBJECT_47 165
#define OBJECT_46 164
#define OBJECT_45 163
#define OBJECT_44 162
#define OBJECT_43 161
#define OBJECT_42 160
#define OBJECT_41 159
#define OBJECT_40 158
#define OBJECT_39 157
#define OBJECT_38 156
#define OBJECT_37 155
#define OBJECT_36 154
#define OBJECT_35 153
#define OBJECT_34 152
#define OBJECT_33 151
#define OBJECT_32 150
#define OBJECT_31 149
#define OBJECT_30 148
#define OBJECT_29 147
#define OBJECT_28 146
#define OBJECT_27 145
#define OBJECT_26 144
#define OBJECT_25 143
#define OBJECT_24 142
#define OBJECT_23 141
#define OBJECT_22 140
#define OBJECT_21 139
#define OBJECT_20 138
#define OBJECT_19 137
#define OBJECT_18 136
#define OBJECT_17 135
#define OBJECT_16 134
#define OBJECT_15 133
#define OBJECT_14 132
#define OBJECT_13 131
#define OBJECT_12 130
#define OBJECT_11 129
#define OBJECT_10 128
#define OBJECT_9 127
#define OBJECT_8 126
#define OBJECT_7 125
#define OBJECT_6 124
#define OBJECT_5 123
#define OBJECT_4 122
#define OBJECT_3 121
#define OBJECT_2 120
#define OBJECT_1 119
#define OBJECT_0 118
#define EXECUTE_CACHE_7 103
#define FREE_REFERENCE_2 106
#define FREE_REFERENCE_1 107
#define FREE_REFERENCE_0 108
#define GLOBAL_EXECUTE_CACHE_22 110
#define GLOBAL_EXECUTE_CACHE_14 112
#define GLOBAL_EXECUTE_CACHE_12 114
#define GLOBAL_EXECUTE_CACHE_11 116
#define FREE_REFERENCES_LABEL_0 102
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
error_so_5fc8fc217ca49f46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_8;

    case 1:
      current_block = (Rpc - LABEL_10);
      goto label_71;

    case 2:
      current_block = (Rpc - LABEL_5);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_6);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_14;

    case 5:
      current_block = (Rpc - LABEL_9);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto continuation_15;

    case 7:
      current_block = (Rpc - LABEL_19);
      goto label_72;

    case 8:
      current_block = (Rpc - LABEL_15);
      goto Z__make_condition_type_84;

    case 9:
      current_block = (Rpc - LABEL_21);
      goto label_73;

    case 10:
      current_block = (Rpc - LABEL_17);
      goto continuation_22;

    case 11:
      current_block = (Rpc - LABEL_18);
      goto continuation_16;

    case 12:
      current_block = (Rpc - LABEL_20);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_23);
      goto continuation_23;

    case 14:
      current_block = (Rpc - LABEL_24);
      goto condition_typeP_85;

    case 15:
      current_block = (Rpc - LABEL_29);
      goto label_74;

    case 16:
      current_block = (Rpc - LABEL_26);
      goto continuation_31;

    case 17:
      current_block = (Rpc - LABEL_32);
      goto label_75;

    case 18:
      current_block = (Rpc - LABEL_27);
      goto continuation_30;

    case 19:
      current_block = (Rpc - LABEL_28);
      goto continuation_29;

    case 20:
      current_block = (Rpc - LABEL_30);
      goto continuation_37;

    case 21:
      current_block = (Rpc - LABEL_31);
      goto continuation_32;

    case 22:
      current_block = (Rpc - LABEL_33);
      goto continuation_38;

    case 23:
      current_block = (Rpc - LABEL_38);
      goto label_76;

    case 24:
      current_block = (Rpc - LABEL_34);
      goto Z___make_condition_86;

    case 25:
      current_block = (Rpc - LABEL_40);
      goto label_77;

    case 26:
      current_block = (Rpc - LABEL_36);
      goto continuation_45;

    case 27:
      current_block = (Rpc - LABEL_37);
      goto continuation_39;

    case 28:
      current_block = (Rpc - LABEL_39);
      goto continuation_34;

    case 29:
      current_block = (Rpc - LABEL_41);
      goto continuation_46;

    case 30:
      current_block = (Rpc - LABEL_42);
      goto conditionP_87;

    case 31:
      current_block = (Rpc - LABEL_47);
      goto label_78;

    case 32:
      current_block = (Rpc - LABEL_44);
      goto continuation_54;

    case 33:
      current_block = (Rpc - LABEL_50);
      goto label_79;

    case 34:
      current_block = (Rpc - LABEL_45);
      goto continuation_53;

    case 35:
      current_block = (Rpc - LABEL_46);
      goto continuation_52;

    case 36:
      current_block = (Rpc - LABEL_48);
      goto continuation_60;

    case 37:
      current_block = (Rpc - LABEL_49);
      goto continuation_55;

    case 38:
      current_block = (Rpc - LABEL_51);
      goto continuation_61;

    case 39:
      current_block = (Rpc - LABEL_56);
      goto label_80;

    case 40:
      current_block = (Rpc - LABEL_52);
      goto Z__make_restart_88;

    case 41:
      current_block = (Rpc - LABEL_58);
      goto label_81;

    case 42:
      current_block = (Rpc - LABEL_54);
      goto continuation_68;

    case 43:
      current_block = (Rpc - LABEL_55);
      goto continuation_62;

    case 44:
      current_block = (Rpc - LABEL_57);
      goto continuation_57;

    case 45:
      current_block = (Rpc - LABEL_59);
      goto restartP_89;

    case 46:
      current_block = (Rpc - LABEL_61);
      goto label_82;

    case 47:
      current_block = (Rpc - LABEL_62);
      goto label_91;

    case 48:
      current_block = (Rpc - LABEL_63);
      goto label_92;

    case 49:
      current_block = (Rpc - LABEL_64);
      goto expression_70;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_70)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_63])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_92)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_91)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	3,
	2,
	3,
	2,
	2,
	2,
	2,
	2,
	1,
	3,
	3,
	1,
	2,
	2,
	3,
	0,
	3,
	1,
	3,
	3,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	2,
	1,
	1,
	1,
	2,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	3,
	2,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	0,
	0,
	0,
	0,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	2,
	2,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	0,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 118)
      goto label_90;
    blocks = (current_block [OBJECT_56]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_62])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_90)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_6);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_4]);
  (Wrd9.Obj) = (current_block [OBJECT_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_6]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_8]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_9]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (Wrd29.Obj) = (current_block [OBJECT_10]);
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_104;
  Wrd11 = Wrd15;

DEFLABEL (label_103)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_9);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_15])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_102;
  Wrd11 = Wrd15;

DEFLABEL (label_101)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_18);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_28);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_26]);
  (Wrd9.Obj) = (current_block [OBJECT_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_27]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_28]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_29]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_30]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_27);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_100;
  Wrd11 = Wrd15;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_31);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_34])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_98;
  Wrd11 = Wrd15;

DEFLABEL (label_97)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_37);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_43);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_42])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_46);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_43]);
  (Wrd9.Obj) = (current_block [OBJECT_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_44]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_45]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_46]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_47]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_45);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_96;
  Wrd11 = Wrd15;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_49);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_53);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_52])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_94;
  Wrd11 = Wrd15;

DEFLABEL (label_93)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_55);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_60);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_59])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_54);
  (Wrd5.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_54]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (label_94)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd12.pObj));

DEFLABEL (label_80)
  (Wrd11.Obj) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50])), (Wrd12.pObj));

DEFLABEL (label_79)
  (Wrd11.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38])), (Wrd12.pObj));

DEFLABEL (label_76)
  (Wrd11.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32])), (Wrd12.pObj));

DEFLABEL (label_75)
  (Wrd11.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19])), (Wrd12.pObj));

DEFLABEL (label_72)
  (Wrd11.Obj) = Rvl;
  goto label_101;

DEFLABEL (label_104)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10])), (Wrd12.pObj));

DEFLABEL (label_71)
  (Wrd11.Obj) = Rvl;
  goto label_103;

DEFLABEL (Z__make_condition_type_84)
  CLOSURE_HEADER (LABEL_15);

DEFLABEL (Z__make_condition_type_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_106;
  Wrd9 = Wrd13;

DEFLABEL (label_105)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_22]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd15.Obj) = (MAKE_OBJECT (0, 7));
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [2]);
  (Wrd19.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-8]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd8.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_106)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21])), (Wrd10.pObj));

DEFLABEL (label_73)
  (Wrd9.Obj) = Rvl;
  goto label_105;

DEFLABEL (condition_typeP_85)
  CLOSURE_HEADER (LABEL_24);

DEFLABEL (condition_typeP_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_109;

DEFLABEL (label_108)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_107)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_109)
  if (! ((Wrd6.uLng) == 62))
    goto label_111;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_111;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_110)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_108;
  Rvl = (current_block [OBJECT_24]);
  goto label_107;

DEFLABEL (label_111)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_22]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23]), 2);

DEFLABEL (label_74)
  (Wrd9.Obj) = Rvl;
  goto label_110;

DEFLABEL (Z___make_condition_86)
  CLOSURE_HEADER (LABEL_34);

DEFLABEL (Z___make_condition_35)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_113;
  Wrd9 = Wrd13;

DEFLABEL (label_112)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_22]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_39);
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd8.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_113)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40])), (Wrd10.pObj));

DEFLABEL (label_77)
  (Wrd9.Obj) = Rvl;
  goto label_112;

DEFLABEL (conditionP_87)
  CLOSURE_HEADER (LABEL_42);

DEFLABEL (conditionP_43)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_116;

DEFLABEL (label_115)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_114)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_116)
  if (! ((Wrd6.uLng) == 62))
    goto label_118;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_118;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_117)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_115;
  Rvl = (current_block [OBJECT_24]);
  goto label_114;

DEFLABEL (label_118)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_22]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23]), 2);

DEFLABEL (label_78)
  (Wrd9.Obj) = Rvl;
  goto label_117;

DEFLABEL (Z__make_restart_88)
  CLOSURE_HEADER (LABEL_52);

DEFLABEL (Z__make_restart_58)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_120;
  Wrd9 = Wrd13;

DEFLABEL (label_119)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_22]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_57);
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd8.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_120)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58])), (Wrd10.pObj));

DEFLABEL (label_81)
  (Wrd9.Obj) = Rvl;
  goto label_119;

DEFLABEL (restartP_89)
  CLOSURE_HEADER (LABEL_59);

DEFLABEL (restartP_66)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_123;

DEFLABEL (label_122)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_121)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_123)
  if (! ((Wrd6.uLng) == 62))
    goto label_125;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_125;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_124)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_122;
  Rvl = (current_block [OBJECT_24]);
  goto label_121;

DEFLABEL (label_125)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_22]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23]), 2);

DEFLABEL (label_82)
  (Wrd9.Obj) = Rvl;
  goto label_124;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_error_so_5fc8fc217ca49f46 [118] =
  {
    { "error_so_code_1", 1, error_so_code_1 },
    { "error_so_code_2", 1, error_so_code_2 },
    { "error_so_code_3", 1, error_so_code_3 },
    { "error_so_code_4", 1, error_so_code_4 },
    { "error_so_code_5", 1, error_so_code_5 },
    { "error_so_code_6", 1, error_so_code_6 },
    { "error_so_code_7", 3, error_so_code_7 },
    { "error_so_code_8", 1, error_so_code_8 },
    { "error_so_code_9", 1, error_so_code_9 },
    { "error_so_code_10", 1, error_so_code_10 },
    { "error_so_code_11", 1, error_so_code_11 },
    { "error_so_code_12", 1, error_so_code_12 },
    { "error_so_code_13", 1, error_so_code_13 },
    { "error_so_code_14", 1, error_so_code_14 },
    { "error_so_code_15", 2, error_so_code_15 },
    { "error_so_code_16", 1, error_so_code_16 },
    { "error_so_code_17", 2, error_so_code_17 },
    { "error_so_code_18", 19, error_so_code_18 },
    { "error_so_code_19", 17, error_so_code_19 },
    { "error_so_code_20", 4, error_so_code_20 },
    { "error_so_code_21", 4, error_so_code_21 },
    { "error_so_code_22", 4, error_so_code_22 },
    { "error_so_code_23", 2, error_so_code_23 },
    { "error_so_code_24", 2, error_so_code_24 },
    { "error_so_code_25", 2, error_so_code_25 },
    { "error_so_code_26", 1, error_so_code_26 },
    { "error_so_code_27", 1, error_so_code_27 },
    { "error_so_code_28", 1, error_so_code_28 },
    { "error_so_code_29", 1, error_so_code_29 },
    { "error_so_code_30", 1, error_so_code_30 },
    { "error_so_code_31", 4, error_so_code_31 },
    { "error_so_code_32", 1, error_so_code_32 },
    { "error_so_code_33", 1, error_so_code_33 },
    { "error_so_code_34", 1, error_so_code_34 },
    { "error_so_code_35", 1, error_so_code_35 },
    { "error_so_code_36", 1, error_so_code_36 },
    { "error_so_code_37", 2, error_so_code_37 },
    { "error_so_code_38", 1, error_so_code_38 },
    { "error_so_code_39", 3, error_so_code_39 },
    { "error_so_code_40", 20, error_so_code_40 },
    { "error_so_code_41", 23, error_so_code_41 },
    { "error_so_code_42", 5, error_so_code_42 },
    { "error_so_code_43", 2, error_so_code_43 },
    { "error_so_code_44", 3, error_so_code_44 },
    { "error_so_code_45", 4, error_so_code_45 },
    { "error_so_code_46", 11, error_so_code_46 },
    { "error_so_code_47", 4, error_so_code_47 },
    { "error_so_code_48", 2, error_so_code_48 },
    { "error_so_code_49", 2, error_so_code_49 },
    { "error_so_code_50", 3, error_so_code_50 },
    { "error_so_code_51", 2, error_so_code_51 },
    { "error_so_code_52", 2, error_so_code_52 },
    { "error_so_code_53", 2, error_so_code_53 },
    { "error_so_code_54", 10, error_so_code_54 },
    { "error_so_code_55", 2, error_so_code_55 },
    { "error_so_code_56", 1, error_so_code_56 },
    { "error_so_code_57", 1, error_so_code_57 },
    { "error_so_code_58", 1, error_so_code_58 },
    { "error_so_code_59", 1, error_so_code_59 },
    { "error_so_code_60", 1, error_so_code_60 },
    { "error_so_code_61", 3, error_so_code_61 },
    { "error_so_code_62", 1, error_so_code_62 },
    { "error_so_code_63", 1, error_so_code_63 },
    { "error_so_code_64", 1, error_so_code_64 },
    { "error_so_code_65", 1, error_so_code_65 },
    { "error_so_code_66", 1, error_so_code_66 },
    { "error_so_code_67", 1, error_so_code_67 },
    { "error_so_code_68", 2, error_so_code_68 },
    { "error_so_code_69", 1, error_so_code_69 },
    { "error_so_code_70", 2, error_so_code_70 },
    { "error_so_code_71", 17, error_so_code_71 },
    { "error_so_code_72", 4, error_so_code_72 },
    { "error_so_code_73", 2, error_so_code_73 },
    { "error_so_code_74", 4, error_so_code_74 },
    { "error_so_code_75", 2, error_so_code_75 },
    { "error_so_code_76", 2, error_so_code_76 },
    { "error_so_code_77", 2, error_so_code_77 },
    { "error_so_code_78", 2, error_so_code_78 },
    { "error_so_code_79", 2, error_so_code_79 },
    { "error_so_code_80", 4, error_so_code_80 },
    { "error_so_code_81", 3, error_so_code_81 },
    { "error_so_code_82", 10, error_so_code_82 },
    { "error_so_code_83", 4, error_so_code_83 },
    { "error_so_code_84", 10, error_so_code_84 },
    { "error_so_code_85", 6, error_so_code_85 },
    { "error_so_code_86", 3, error_so_code_86 },
    { "error_so_code_87", 5, error_so_code_87 },
    { "error_so_code_88", 3, error_so_code_88 },
    { "error_so_code_89", 5, error_so_code_89 },
    { "error_so_code_90", 4, error_so_code_90 },
    { "error_so_code_91", 5, error_so_code_91 },
    { "error_so_code_92", 4, error_so_code_92 },
    { "error_so_code_93", 4, error_so_code_93 },
    { "error_so_code_94", 4, error_so_code_94 },
    { "error_so_code_95", 6, error_so_code_95 },
    { "error_so_code_96", 6, error_so_code_96 },
    { "error_so_code_97", 12, error_so_code_97 },
    { "error_so_code_98", 1, error_so_code_98 },
    { "error_so_code_99", 4, error_so_code_99 },
    { "error_so_code_100", 1, error_so_code_100 },
    { "error_so_code_101", 61, error_so_code_101 },
    { "error_so_code_102", 3, error_so_code_102 },
    { "error_so_code_103", 4, error_so_code_103 },
    { "error_so_code_104", 7, error_so_code_104 },
    { "error_so_code_105", 11, error_so_code_105 },
    { "error_so_code_106", 13, error_so_code_106 },
    { "error_so_code_107", 7, error_so_code_107 },
    { "error_so_code_108", 21, error_so_code_108 },
    { "error_so_code_109", 4, error_so_code_109 },
    { "error_so_code_110", 5, error_so_code_110 },
    { "error_so_code_111", 4, error_so_code_111 },
    { "error_so_code_112", 3, error_so_code_112 },
    { "error_so_code_113", 361, error_so_code_113 },
    { "error_so_code_114", 8, error_so_code_114 },
    { "error_so_code_115", 19, error_so_code_115 },
    { "error_so_code_116", 2, error_so_code_116 },
    { "error_so_code_117", 15, error_so_code_117 },
    { "error_so_code_118", 3, error_so_code_118 }
  };

int
decl_error_so_5fc8fc217ca49f46 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_error_so_5fc8fc217ca49f46);
  return (0);
}

DECLARE_COMPILED_CODE ("error.so", 50, decl_error_so_5fc8fc217ca49f46, error_so_5fc8fc217ca49f46)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_error_so_data_5fc8fc217ca49f46 [20523] =
  "\x83\x09\x84\x02\xad\x26\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29"
  "\x21\x9c\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0"
  "\x83\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c"
  "\x2b\xbc\x1d\xb0\x85\x88\x22\x29\x21\x9c\x2b\xbd\x1d\xb0\x86\x88"
  "\x28\x0d\xbe\x23\x22\x29\x21\x9f\x2b\xbf\x1d\xb0\x02\x88\xc2\x1c"
  "\x81\x0f\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x86\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xc3"
  "\x1c\x1d\x82\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x06\x1d\x0c\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0c\x1c\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x81\x0c\x0c\x0c\x06\x07\xc2\x1c\x02\x0c"
  "\x85\x1b\x1b\x82\x08\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x1b\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xc1\x1c\xc1\x1c\x80\x08\x84\x1b\x83\x28\x0d\x1c\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x83\x28\x0d\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x83\x0d\x1c\x0d\x24\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b"
  "\x82\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x86\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x28\xb6\x23\x22\x29\x21\x9f\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\x0f\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x85\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x28"
  "\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\xc3\x1c\x1b\x1b\x84\x0d\x1c\x1b\x83\x0c\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x24\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x1b\x28\x0d"
  "\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x84\x1b\x1b\x83"
  "\x1b\x0d\x1c\x1b\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x83\x1b\x1b\x1b\x1b\x24\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x1b"
  "\x81\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0c\xc2\x1c\x1b\x84\x0d\x1c\x28\x1b\x28"
  "\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x0d\x1c"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x0d\x1c\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x0d\x1c"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x85\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x85\x1b\x81\x0d\x1c\x0d\x1c"
  "\x24\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\xb6\x23\x22\x29\x21\x9f\x2b\xbe\x1d\xb0\x02\x88\x0c\x1b"
  "\x81\x0f\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1d\x84\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1d\x0c\x0c\x81\x0c\x0d\x1c\x1b\x25\x1b\x24"
  "\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0d\x1c\x24\x28\x0d"
  "\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x83\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x0d\x1c\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x85\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1d\x84\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x0d\x1c"
  "\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x06\x1d\x08\x84\x1b\x83\x0d\x1c\x0d\x24\x28"
  "\x1b\x28\x1b\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x0d\x1c\x0d\x1c\x1d\x1b\x28\x1b\x28\x1b\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x08\x1b\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x81"
  "\x1b\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x1d\x1b\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x83\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x83\x1d\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x1d\x0d\x1c\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x83\x1d\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x1b"
  "\x1b\x1d\x1b\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x81"
  "\x1b\x0d\x1c\x0d\x1c\x25\x1b\x1b\x24\x28\x1b\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\x81\x1b\x0d\x1c\x0d\x1c\x25\x1b\x1b\x24\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x81\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\x1b\x0d\x1c\x0d\x1c\x25\x1b\x24\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22"
  "\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x07\x0d\x1c\x0c\x1d\x1b\x1b"
  "\x82\x1b\x81\x08\x0d\x1c\x1b\x1b\x1b\x25\x1b\x1b\x1b\x24\x28\x1b"
  "\x28\x1b\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x1b\x0d\x1c\x0d\x1c\x24\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x1b\x08\x0c\x0d\x1c\x25\x1b\x24\x28\x0d\x28\x1b\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d"
  "\x0d\x1c\x25\x1b\x24\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28\x1b\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xc2\x1c\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b\x81\x0d"
  "\x1c\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x0d\x1c\x1b\x24\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x82\x1b\x81\x0d\x1c\x1b\x24\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x82\x1b\x81\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x1b\x24\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c"
  "\x0d\x1c\x08\x89\x0d\x1c\x0d\x1c\x0d\x1c\x08\x8a\x1b\x0d\x1c\x08"
  "\x89\x1b\x1b\x1b\x08\x8a\x1b\x1b\x08\x89\x0d\x1c\x0c\x0c\x0c\x0d"
  "\x0d\x1b\x08\x88\x0d\x1c\x0d\x0c\x0c\x0d\x0c\x0d\x1b\x1b\x08\x89"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0d\x0c\x0c\x0c\x0c\x0c\x0d\x0c\x0c"
  "\x0c\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x1b\x1b\x08\x8d\x0c\x0d\x1b\x0c"
  "\x1b\x0d\x1b\x08\x88\x1b\x0c\x1b\x0c\x0d\x1b\x1b\x1b\x1b\x1b\x08"
  "\x8c\x0d\x1c\x0d\x1c\x0c\x1b\x1b\x08\x89\x0d\x1c\x0c\x0d\x82\x1b"
  "\x83\x1b\x0c\x0c\x1b\x1b\x08\x89\x0d\x1c\x0c\x0c\x0c\x0d\x0c\x0c"
  "\x0d\x1c\x1b\x08\x89\x0d\x1b\x08\x88\x0c\x0c\x0c\x81\x0f\x0d\x1b"
  "\x0c\x0c\x0c\x0c\x0d\x1b\x0c\x0c\x0d\x1c\x0d\x1b\x0c\x06\x07\x85"
  "\x1b\x02\x1d\x1b\x0c\x0c\x0d\x1b\x1b\x0c\x0d\x1b\x08\x88\x0c\x0d"
  "\x1c\x0d\x0c\x0c\x0d\x0c\x0d\x1b\x08\x88\x0c\x0c\xc2\x80\x0d\x0c"
  "\x0c\x0d\x1b\x1b\x08\x89\x1b\x0c\x0d\x1b\x08\x88\x1b\x0f\x0f\x0f"
  "\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0c\x0d\x0d\x1b\x08\x88\x0d\x1c\x0d"
  "\x0d\x1c\x0d\x0d\x1b\x1b\x08\x89\x0d\x1c\x0d\x1b\x0d\x08\x1b\x1b"
  "\x0d\x1c\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x0d\x1c\x1b\x0d\x1c\x1b\x1b\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x1b\x1b\x0d\x1c\x0d\x1c\x1b\x1b\x1b\x0d\x1c"
  "\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x25\x0d\x1c\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28\x1b\x28"
  "\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x0d"
  "\x1c\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28"
  "\x1b\x28\x1b\x28\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x81\x1d\x08\x0c\x1b\x1b\x24\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f\x1b"
  "\x1b\x1d\x82\x85\x0d\x1c\x0d\x1c\x25\x0d\x1c\x1b\x1b\x24\x28\x1b"
  "\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x9f"
  "\x82\x1b\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x17\x0c\x0c\x0c"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x17\x02\x02\x0c\x1b\x02\x28\x1b\x28"
  "\x1b\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x17\x1c\x88\x1b\x1b\x1b\x2a\x1b\x2a\x0d\x1c\x08\x88\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1e"
  "\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e"
  "\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e"
  "\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1e"
  "\x1e\x1b\x2a\x1b\x2a\x06\x06\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x08\x08"
  "\x08\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x0d\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x17\x1b\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x9d\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9d\x0c"
  "\x1b\x0d\x1c\x0d\x0d\x0d\x1c\x08\x8c\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\xb6\x2a\x0d\x1c\x0d\x1b\x2a\x1b\x1b\x0d\x1b\x0d\x0d\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x17\x08\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x17\x85\x1b\x0d\x0d\x0d\x0d\x0d\x9c\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9c\x0c\x1b\x0d\x0d\x0d\x1b\x08"
  "\x8c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x0d\x1c\x07\x1b\x80"
  "\x1b\x1b\x2a\x1b\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x17"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x17\x86\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x9e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9e"
  "\x0c\x1b\x0d\x0d\x0d\x1b\x1b\x08\x8d\xb1\x2a\xb2\x2a\xb3\x2a\xb4"
  "\x2a\xb5\x2a\x08\xb7\x2a\xc3\x0d\x1c\x0d\x1b\x2a\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x26\x1b\x1b\x1b\x24\x28\x0d\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x02\x46\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31"
  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
  "\x30\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
  "\x65\x72\x72\x6f\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
  "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x33"
  "\x04\x82\x02\x03\x02\x34\x04\x82\x02\x03\x02\x35\x04\x82\x02\x03"
  "\x02\x36\x04\x82\x02\x03\x02\x37\x04\x82\x02\x03\x02\x02\x0e\x6d"
  "\x61\x6b\x65\x2d\x31\x64\x2d\x74\x61\x62\x6c\x65\x02\x38\x04\x82"
  "\x02\x03\x02\x08\x0c\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66"
  "\x09\x01\x21\x04\x0b\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x0a"
  "\x04\x0d\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x0b\x03"
  "\x3b\x08\x81\x85\x02\x3a\x06\x81\x85\x02\x39\x04\x84\x06\x07\x12"
  "\x0c\x02\x09\x09\x3c\x04\x83\x04\x03\x0d\x02\x0a\x09\x3d\x04\x83"
  "\x04\x03\x0e\x02\x0b\x09\x3e\x04\x83\x04\x03\x0f\x02\x0c\x09\x3f"
  "\x04\x83\x04\x03\x10\x02\x0d\x09\x40\x04\x83\x04\x03\x11\x02\x0e"
  "\x09\x41\x04\x83\x04\x03\x12\x02\x0f\x0d\x25\x72\x65\x63\x6f\x72"
  "\x64\x2d\x73\x65\x74\x21\x13\x02\x42\x04\x84\x06\x03\x14\x02\x10"
  "\x02\x03\x10\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70"
  "\x65\x3f\x15\x04\x19\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x16\x03\x44"
  "\x06\x81\x85\x02\x43\x04\x84\x04\x05\x0e\x17\x02\x11\x08\x0f\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x20\x74\x79\x70\x65\x05\x1a\x65"
  "\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d"
  "\x61\x72\x67\x75\x6d\x65\x6e\x74\x18\x02\x45\x04\x84\x04\x03\x0c"
  "\x19\x02\x12\x18\x6c\x69\x73\x74\x20\x6f\x66\x20\x63\x6f\x6e\x64"
  "\x69\x74\x69\x6f\x6e\x20\x74\x79\x70\x65\x73\x1a\x15\x02\x06\x17"
  "\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6c\x69\x73\x74\x2d\x6f"
  "\x66\x2d\x74\x79\x70\x65\x1b\x02\x47\x06\x81\x85\x02\x46\x04\x84"
  "\x06\x05\x0e\x1c\x02\x13\x20\x75\x6e\x64\x6f\x63\x75\x6d\x65\x6e"
  "\x74\x65\x64\x20\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x20\x6f\x66"
  "\x20\x74\x79\x70\x65\x20\x14\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x74\x79\x70\x65\x20\x6e\x61\x6d\x65\x0c\x28\x61\x6e\x6f\x6e"
  "\x79\x6d\x6f\x75\x73\x29\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79"
  "\x70\x65\x3f\x1d\x1e\x18\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d"
  "\x74\x79\x70\x65\x20\x72\x65\x70\x6f\x72\x74\x65\x72\x13\x09\x14"
  "\x6d\x61\x6b\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74"
  "\x79\x70\x65\x1e\x04\x21\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d"
  "\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x75\x6e\x69\x71\x75\x65\x2d\x73"
  "\x79\x6d\x62\x6f\x6c\x73\x1f\x04\x19\x67\x75\x61\x72\x61\x6e\x74"
  "\x65\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70"
  "\x65\x20\x04\x16\x63\x6f\x6d\x70\x75\x74\x65\x2d\x66\x69\x65\x6c"
  "\x64\x2d\x69\x6e\x64\x65\x78\x65\x73\x21\x05\x18\x03\x0c\x73\x74"
  "\x72\x69\x6e\x67\x2d\x63\x6f\x70\x79\x06\x15\x25\x6d\x61\x6b\x65"
  "\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x22"
  "\x04\x14\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x6f\x66\x2d\x61"
  "\x72\x69\x74\x79\x3f\x23\x03\x14\x73\x79\x6d\x62\x6f\x6c\x2d\x3e"
  "\x75\x74\x66\x38\x2d\x73\x74\x72\x69\x6e\x67\x04\x0b\x04\x06\x77"
  "\x72\x69\x74\x65\x24\x0b\x5a\x28\x81\x85\x02\x59\x26\x81\x85\x02"
  "\x58\x24\x84\x06\x57\x22\x81\x87\x02\x56\x20\x81\x8d\x02\x55\x1e"
  "\x81\x83\x02\x54\x1c\x81\x87\x02\x53\x1a\x81\x87\x02\x52\x18\x81"
  "\x89\x02\x51\x16\x81\x89\x02\x50\x14\x81\x8b\x02\x4f\x12\x81\x8b"
  "\x02\x4e\x10\x81\x8b\x02\x4d\x0e\x81\x8d\x02\x4c\x0c\x81\x89\x02"
  "\x4b\x0a\x81\x8b\x02\x4a\x08\x81\x89\x02\x49\x06\x86\x0a\x48\x04"
  "\x81\x89\x02\x27\x4e\x25\x02\x14\x04\x63\x64\x72\x26\x04\x63\x61"
  "\x72\x27\x09\x04\x05\x6d\x65\x6d\x71\x28\x03\x09\x72\x65\x76\x65"
  "\x72\x73\x65\x21\x03\x6b\x24\x81\x85\x02\x6a\x22\x81\x87\x02\x69"
  "\x20\x81\x8b\x02\x68\x1e\x81\x8d\x02\x67\x1c\x81\x87\x02\x66\x1a"
  "\x81\x87\x02\x65\x18\x81\x87\x02\x64\x16\x81\x87\x02\x63\x14\x81"
  "\x91\x02\x62\x12\x81\x8b\x02\x61\x10\x81\x8b\x02\x60\x0e\x83\x04"
  "\x5f\x0c\x81\x87\x02\x5e\x0a\x81\x85\x02\x5d\x08\x81\x87\x02\x5c"
  "\x06\x81\x85\x02\x5b\x04\x84\x06\x23\x32\x29\x02\x15\x26\x09\x04"
  "\x05\x61\x73\x73\x71\x04\x19\x65\x72\x72\x6f\x72\x3a\x62\x61\x64"
  "\x2d\x72\x61\x6e\x67\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x2a"
  "\x03\x6f\x0a\x81\x87\x02\x6e\x08\x81\x89\x02\x6d\x06\x81\x89\x02"
  "\x6c\x04\x85\x08\x09\x14\x2b\x02\x16\x09\x1b\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x66\x69\x65\x6c\x64\x2d"
  "\x6e\x61\x6d\x65\x73\x2c\x04\x63\x61\x72\x02\x04\x20\x04\x04\x6d"
  "\x61\x70\x2d\x03\x73\x0a\x81\x85\x02\x72\x08\x81\x83\x02\x71\x06"
  "\x81\x83\x02\x70\x04\x83\x04\x09\x16\x2e\x02\x17\x26\x09\x1f\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x67\x65"
  "\x6e\x65\x72\x61\x6c\x69\x7a\x61\x74\x69\x6f\x6e\x73\x2f\x04\x20"
  "\x03\x0a\x6c\x69\x73\x74\x2d\x63\x6f\x70\x79\x30\x03\x77\x0a\x81"
  "\x83\x02\x76\x08\x81\x83\x02\x75\x06\x81\x83\x02\x74\x04\x83\x04"
  "\x09\x15\x31\x02\x18\x09\x1a\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x74\x79\x70\x65\x2f\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73"
  "\x32\x04\x20\x02\x79\x06\x81\x83\x02\x78\x04\x83\x04\x05\x0e\x33"
  "\x02\x19\x03\x32\x05\x0e\x31\x64\x2d\x74\x61\x62\x6c\x65\x2f\x70"
  "\x75\x74\x21\x34\x03\x7b\x06\x81\x87\x02\x7a\x04\x85\x08\x05\x0d"
  "\x35\x02\x1a\x03\x32\x05\x0d\x31\x64\x2d\x74\x61\x62\x6c\x65\x2f"
  "\x67\x65\x74\x36\x03\x7d\x06\x81\x85\x02\x7c\x04\x84\x06\x05\x0d"
  "\x37\x02\x1b\x7e\x04\x82\x02\x03\x38\x02\x1c\x7f\x04\x82\x02\x03"
  "\x39\x02\x1d\x80\x01\x04\x82\x02\x03\x3a\x02\x1e\x81\x01\x04\x82"
  "\x02\x03\x3b\x02\x1f\x02\x02\x82\x01\x04\x82\x02\x03\x3c\x02\x20"
  "\x09\x01\x21\x04\x0a\x04\x0b\x03\x86\x01\x0a\x81\x85\x02\x85\x01"
  "\x08\x81\x85\x02\x84\x01\x06\x81\x85\x02\x83\x01\x04\x84\x06\x09"
  "\x14\x3d\x02\x21\x09\x87\x01\x04\x83\x04\x03\x3e\x02\x22\x09\x88"
  "\x01\x04\x83\x04\x03\x3f\x02\x23\x09\x89\x01\x04\x83\x04\x03\x40"
  "\x02\x24\x09\x8a\x01\x04\x83\x04\x03\x41\x02\x25\x09\x8b\x01\x04"
  "\x83\x04\x03\x42\x02\x26\x02\x03\x0b\x63\x6f\x6e\x64\x69\x74\x69"
  "\x6f\x6e\x3f\x43\x04\x14\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x44\x03\x8d\x01\x06\x81\x85"
  "\x02\x8c\x01\x04\x84\x04\x05\x0e\x45\x02\x27\x08\x0a\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x05\x18\x02\x8e\x01\x04\x84\x04\x03\x0c"
  "\x46\x02\x28\x09\x04\x0c\x6d\x61\x6b\x65\x2d\x76\x65\x63\x74\x6f"
  "\x72\x06\x11\x25\x25\x6d\x61\x6b\x65\x2d\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x47\x03\x91\x01\x08\x81\x8b\x02\x90\x01\x06\x81\x8f"
  "\x02\x8f\x01\x04\x85\x08\x07\x11\x48\x02\x29\x0c\x76\x65\x63\x74"
  "\x6f\x72\x2d\x73\x65\x74\x21\x49\x27\x26\x0f\x62\x6f\x75\x6e\x64"
  "\x2d\x72\x65\x73\x74\x61\x72\x74\x73\x4a\x09\x11\x6c\x69\x73\x74"
  "\x20\x6f\x66\x20\x72\x65\x73\x74\x61\x72\x74\x73\x4b\x0f\x6d\x61"
  "\x6b\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x4c\x09\x72\x65"
  "\x73\x74\x61\x72\x74\x3f\x4d\x11\x2a\x62\x6f\x75\x6e\x64\x2d\x72"
  "\x65\x73\x74\x61\x72\x74\x73\x2a\x4e\x03\x04\x20\x04\x17\x67\x75"
  "\x61\x72\x61\x6e\x74\x65\x65\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61"
  "\x74\x69\x6f\x6e\x4f\x04\x1e\x67\x75\x61\x72\x61\x6e\x74\x65\x65"
  "\x2d\x75\x6e\x69\x71\x75\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d"
  "\x6c\x69\x73\x74\x06\x1b\x05\x10\x25\x6d\x61\x6b\x65\x2d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x50\x03\x43\x05\x1c\x25\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x66\x69\x65\x6c"
  "\x64\x2d\x69\x6e\x64\x65\x78\x51\x03\x30\x09\xa5\x01\x2a\x81\x8f"
  "\x02\xa4\x01\x28\x81\x8f\x02\xa3\x01\x26\x81\x8f\x02\xa2\x01\x24"
  "\x81\x91\x02\xa1\x01\x22\x81\x8d\x02\xa0\x01\x20\x81\x95\x02\x9f"
  "\x01\x1e\x81\x8f\x02\x9e\x01\x1c\x81\x8f\x02\x9d\x01\x1a\x81\x8f"
  "\x02\x9c\x01\x18\x81\x8b\x02\x9b\x01\x16\x81\x89\x02\x9a\x01\x14"
  "\x81\x8d\x02\x99\x01\x12\x81\x89\x02\x98\x01\x10\x81\x8b\x02\x97"
  "\x01\x0e\x81\x8d\x02\x96\x01\x0c\x81\x93\x02\x95\x01\x0a\x81\x8d"
  "\x02\x94\x01\x08\x81\x89\x02\x93\x01\x06\x81\x89\x02\x92\x01\x04"
  "\x86\x0a\x29\x49\x52\x02\x2a\x26\x49\x27\x4a\x09\x4b\x16\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63"
  "\x74\x6f\x72\x49\x4d\x4e\x03\x04\x20\x04\x1f\x04\x2d\x05\x51\x04"
  "\x4f\x06\x1b\x05\x50\x03\x43\x03\x07\x6c\x65\x6e\x67\x74\x68\x4f"
  "\x03\x30\x05\x20\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d"
  "\x6e\x75\x6d\x62\x65\x72\x2d\x6f\x66\x2d\x61\x72\x67\x75\x6d\x65"
  "\x6e\x74\x73\x2d\x0c\xbc\x01\x30\x81\x87\x02\xbb\x01\x2e\x81\x8d"
  "\x02\xba\x01\x2c\x81\x8b\x02\xb9\x01\x2a\x81\x87\x02\xb8\x01\x28"
  "\x81\x87\x02\xb7\x01\x26\x81\x87\x02\xb6\x01\x24\x81\x89\x02\xb5"
  "\x01\x22\x81\x87\x02\xb4\x01\x20\x81\x87\x02\xb3\x01\x1e\x81\x8d"
  "\x02\xb2\x01\x1c\x81\x89\x02\xb1\x01\x1a\x81\x8d\x02\xb0\x01\x18"
  "\x81\x89\x02\xaf\x01\x16\x81\x8b\x02\xae\x01\x14\x81\x8d\x02\xad"
  "\x01\x12\x81\x93\x02\xac\x01\x10\x81\x8d\x02\xab\x01\x0e\x81\x89"
  "\x02\xaa\x01\x0c\x81\x85\x02\xa9\x01\x0a\x81\x85\x02\xa8\x01\x08"
  "\x81\x85\x02\xa7\x01\x06\x81\x85\x02\xa6\x01\x04\x84\x06\x2f\x55"
  "\x1f\x02\x2b\x09\x4b\x4a\x4e\x4d\x03\x03\x43\x06\x1b\x03\x30\x04"
  "\xc1\x01\x0c\x81\x85\x02\xc0\x01\x0a\x81\x8b\x02\xbf\x01\x08\x81"
  "\x85\x02\xbe\x01\x06\x81\x85\x02\xbd\x01\x04\x84\x06\x0b\x1c\x53"
  "\x02\x2c\x13\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x6f\x66\x2d"
  "\x74\x79\x70\x65\x3f\x54\x04\x20\x04\x14\x25\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2d\x6f\x66\x2d\x74\x79\x70\x65\x3f\x55\x03\xc3"
  "\x01\x06\x81\x85\x02\xc2\x01\x04\x84\x06\x05\x0e\x56\x02\x2d\x14"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x70\x72\x65\x64\x69\x63"
  "\x61\x74\x65\x57\x04\x20\x04\x55\x03\xc6\x01\x08\x81\x85\x02\xc5"
  "\x01\x06\x81\x83\x02\xc4\x01\x04\x83\x04\x07\x10\x58\x02\x2e\x09"
  "\x03\x43\x04\x28\x03\xca\x01\x0a\x81\x85\x02\xc9\x01\x08\x81\x85"
  "\x02\xc8\x01\x06\x81\x85\x02\xc7\x01\x04\x84\x06\x09\x14\x59\x02"
  "\x2f\x13\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x20\x6f\x66\x20\x74"
  "\x79\x70\x65\x20\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x5a"
  "\x09\x13\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x61\x63\x63\x65"
  "\x73\x73\x6f\x72\x5b\x04\x20\x04\x11\x67\x75\x61\x72\x61\x6e\x74"
  "\x65\x65\x2d\x73\x79\x6d\x62\x6f\x6c\x5c\x05\x51\x03\x57\x03\x10"
  "\x77\x72\x69\x74\x65\x2d\x74\x6f\x2d\x73\x74\x72\x69\x6e\x67\x05"
  "\x18\x04\x0e\x73\x74\x72\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64"
  "\x5d\x08\xd5\x01\x18\x81\x8b\x02\xd4\x01\x16\x81\x89\x02\xd3\x01"
  "\x14\x81\x87\x02\xd2\x01\x12\x81\x85\x02\xd1\x01\x10\x81\x85\x02"
  "\xd0\x01\x0e\x81\x85\x02\xcf\x01\x0c\x81\x87\x02\xce\x01\x0a\x81"
  "\x85\x02\xcd\x01\x08\x81\x85\x02\xcc\x01\x06\x81\x85\x02\xcb\x01"
  "\x04\x84\x06\x17\x2e\x5e\x02\x30\x09\x11\x61\x63\x63\x65\x73\x73"
  "\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x5f\x04\x14\x67\x75\x61"
  "\x72\x61\x6e\x74\x65\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x60\x04\x5b\x03\xd9\x01\x0a\x81\x87\x02\xd8\x01\x08\x81\x8b\x02"
  "\xd7\x01\x06\x81\x85\x02\xd6\x01\x04\x84\x06\x09\x14\x61\x02\x31"
  "\x09\x0f\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x74\x79\x70\x65"
  "\x62\x04\x60\x02\xdb\x01\x06\x81\x83\x02\xda\x01\x04\x83\x04\x05"
  "\x0e\x63\x02\x32\x09\x17\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f"
  "\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x64\x04\x60\x02"
  "\xdd\x01\x06\x81\x83\x02\xdc\x01\x04\x83\x04\x05\x0e\x65\x02\x33"
  "\x09\x13\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x72\x65\x73\x74"
  "\x61\x72\x74\x73\x66\x04\x60\x03\x30\x03\xe0\x01\x08\x81\x83\x02"
  "\xdf\x01\x06\x81\x83\x02\xde\x01\x04\x83\x04\x07\x12\x30\x02\x34"
  "\x09\x15\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x70\x72\x6f\x70"
  "\x65\x72\x74\x69\x65\x73\x67\x04\x60\x02\xe2\x01\x06\x81\x83\x02"
  "\xe1\x01\x04\x83\x04\x05\x0e\x68\x02\x35\x03\x67\x05\x34\x03\xe4"
  "\x01\x06\x81\x87\x02\xe3\x01\x04\x85\x08\x05\x0d\x69\x02\x36\x03"
  "\x67\x05\x36\x03\xe6\x01\x06\x81\x85\x02\xe5\x01\x04\x84\x06\x05"
  "\x0d\x6a\x02\x37\x09\x17\x77\x72\x69\x74\x65\x2d\x63\x6f\x6e\x64"
  "\x69\x74\x69\x6f\x6e\x2d\x72\x65\x70\x6f\x72\x74\x6b\x15\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x65\x72\x72"
  "\x6f\x72\x6c\x02\x04\x60\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65"
  "\x65\x2d\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x6d\x04\x28"
  "\x03\x0e\x69\x67\x6e\x6f\x72\x65\x2d\x65\x72\x72\x6f\x72\x73\x6e"
  "\x05\xf0\x01\x16\x81\x83\x02\xef\x01\x14\x81\x87\x02\xee\x01\x12"
  "\x81\x8b\x02\xed\x01\x10\x81\x89\x02\xec\x01\x0e\x81\x89\x02\xeb"
  "\x01\x0c\x81\x85\x02\xea\x01\x0a\x81\x85\x02\xe9\x01\x08\x81\x85"
  "\x02\xe8\x01\x06\x81\x85\x02\xe7\x01\x04\x84\x06\x15\x28\x6f\x02"
  "\x38\x03\x18\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x6f\x75\x74"
  "\x70\x75\x74\x2d\x73\x74\x72\x69\x6e\x67\x04\x6b\x03\xf2\x01\x06"
  "\x81\x85\x02\xf1\x01\x04\x83\x04\x05\x0d\x70\x02\x39\xf3\x01\x04"
  "\x82\x02\x03\x71\x02\x3a\xf4\x01\x04\x82\x02\x03\x72\x02\x3b\xf5"
  "\x01\x04\x82\x02\x03\x73\x02\x3c\xf6\x01\x04\x82\x02\x03\x74\x02"
  "\x3d\x02\x02\xf7\x01\x04\x82\x02\x03\x02\x3e\x0c\x28\x61\x6e\x6f"
  "\x6e\x79\x6d\x6f\x75\x73\x29\x09\x01\x21\x04\x0a\x04\x0b\x04\x24"
  "\x04\xfa\x01\x08\x81\x85\x02\xf9\x01\x06\x81\x85\x02\xf8\x01\x04"
  "\x84\x06\x07\x15\x75\x02\x3f\x09\xfb\x01\x04\x83\x04\x03\x76\x02"
  "\x40\x09\xfc\x01\x04\x83\x04\x03\x77\x02\x41\x09\xfd\x01\x04\x83"
  "\x04\x03\x78\x02\x42\x09\xfe\x01\x04\x83\x04\x03\x79\x02\x43\x09"
  "\xff\x01\x04\x83\x04\x03\x7a\x02\x44\x13\x02\x80\x02\x04\x84\x06"
  "\x03\x7b\x02\x45\x02\x03\x4d\x04\x12\x65\x72\x72\x6f\x72\x3a\x6e"
  "\x6f\x74\x2d\x72\x65\x73\x74\x61\x72\x74\x7c\x03\x82\x02\x06\x81"
  "\x85\x02\x81\x02\x04\x84\x04\x05\x0e\x7d\x02\x46\x08\x08\x72\x65"
  "\x73\x74\x61\x72\x74\x05\x18\x02\x83\x02\x04\x84\x04\x03\x0c\x7e"
  "\x02\x47\x4b\x4d\x02\x06\x1b\x02\x85\x02\x06\x81\x85\x02\x84\x02"
  "\x04\x84\x06\x05\x0e\x7f\x02\x48\x02\x09\x65\x66\x66\x65\x63\x74"
  "\x6f\x72\x0b\x69\x6e\x74\x65\x72\x61\x63\x74\x6f\x72\x09\x72\x65"
  "\x70\x6f\x72\x74\x65\x72\x0d\x77\x69\x74\x68\x2d\x72\x65\x73\x74"
  "\x61\x72\x74\x80\x01\x4e\x02\x4e\x02\x05\x18\x03\x0b\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x3f\x81\x01\x04\x23\x04\x5c\x06\x0e\x25"
  "\x6d\x61\x6b\x65\x2d\x72\x65\x73\x74\x61\x72\x74\x23\x05\x13\x73"
  "\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e"
  "\x64\x82\x01\x07\x96\x02\x24\x81\x87\x02\x95\x02\x22\x81\x85\x02"
  "\x94\x02\x20\x81\x83\x02\x93\x02\x1e\x81\x83\x02\x92\x02\x1c\x81"
  "\x87\x02\x91\x02\x1a\x81\x85\x02\x90\x02\x18\x81\x83\x02\x8f\x02"
  "\x16\x81\x8f\x02\x8e\x02\x14\x81\x8d\x02\x8d\x02\x12\x81\x8b\x02"
  "\x8c\x02\x10\x81\x8b\x02\x8b\x02\x0e\x81\x8b\x02\x8a\x02\x0c\x81"
  "\x8b\x02\x89\x02\x0a\x87\x0c\x88\x02\x08\x81\x8b\x02\x87\x02\x06"
  "\x81\x8b\x02\x86\x02\x04\x81\x8b\x02\x23\x3d\x83\x01\x02\x49\x02"
  "\x07\x76\x61\x6c\x75\x65\x73\x84\x01\x02\x03\x1f\x63\x61\x6c\x6c"
  "\x2d\x77\x69\x74\x68\x2d\x63\x75\x72\x72\x65\x6e\x74\x2d\x63\x6f"
  "\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x85\x01\x07\x80\x01\x03"
  "\x9a\x02\x0a\x81\x83\x02\x99\x02\x08\x81\x8b\x02\x98\x02\x06\x81"
  "\x85\x02\x97\x02\x04\x85\x08\x09\x14\x86\x01\x02\x4a\x09\x0d\x72"
  "\x65\x73\x74\x61\x72\x74\x2f\x6e\x61\x6d\x65\x87\x01\x04\x12\x67"
  "\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x72\x65\x73\x74\x61\x72\x74"
  "\x88\x01\x02\x9c\x02\x06\x81\x83\x02\x9b\x02\x04\x83\x04\x05\x0e"
  "\x89\x01\x02\x4b\x09\x15\x77\x72\x69\x74\x65\x2d\x72\x65\x73\x74"
  "\x61\x72\x74\x2d\x72\x65\x70\x6f\x72\x74\x8a\x01\x04\x88\x01\x04"
  "\x6d\x04\x0b\x04\xa0\x02\x0a\x81\x85\x02\x9f\x02\x08\x81\x85\x02"
  "\x9e\x02\x06\x81\x85\x02\x9d\x02\x04\x84\x06\x09\x16\x6d\x02\x4c"
  "\x09\x11\x72\x65\x73\x74\x61\x72\x74\x2f\x65\x66\x66\x65\x63\x74"
  "\x6f\x72\x8b\x01\x04\x88\x01\x02\xa2\x02\x06\x81\x83\x02\xa1\x02"
  "\x04\x83\x04\x05\x0e\x8c\x01\x02\x4d\x09\x13\x72\x65\x73\x74\x61"
  "\x72\x74\x2f\x69\x6e\x74\x65\x72\x61\x63\x74\x6f\x72\x8d\x01\x04"
  "\x88\x01\x02\xa4\x02\x06\x81\x83\x02\xa3\x02\x04\x83\x04\x05\x0e"
  "\x8e\x01\x02\x4e\x09\x13\x72\x65\x73\x74\x61\x72\x74\x2f\x70\x72"
  "\x6f\x70\x65\x72\x74\x69\x65\x73\x8f\x01\x04\x88\x01\x02\xa6\x02"
  "\x06\x81\x83\x02\xa5\x02\x04\x83\x04\x05\x0e\x90\x01\x02\x4f\x0c"
  "\x69\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x91\x01\x03\x8d\x01"
  "\x03\x8f\x01\x05\x36\x04\xa8\x02\x06\x81\x85\x02\xa7\x02\x04\x84"
  "\x06\x05\x10\x36\x02\x50\x13\x02\x91\x01\x03\x8f\x01\x05\x34\x03"
  "\xaa\x02\x06\x81\x87\x02\xa9\x02\x04\x85\x08\x05\x11\x91\x01\x02"
  "\x51\x27\x4e\x02\x07\x80\x01\x02\xae\x02\x0a\x81\x85\x02\xad\x02"
  "\x08\x81\x85\x02\xac\x02\x06\x81\x83\x02\xab\x02\x04\x86\x0a\x09"
  "\x12\x34\x02\x52\x09\x0f\x69\x6e\x76\x6f\x6b\x65\x2d\x72\x65\x73"
  "\x74\x61\x72\x74\x13\x04\x88\x01\x04\x14\x68\x6f\x6f\x6b\x2f\x69"
  "\x6e\x76\x6f\x6b\x65\x2d\x72\x65\x73\x74\x61\x72\x74\x92\x01\x03"
  "\xb1\x02\x08\x81\x85\x02\xb0\x02\x06\x81\x85\x02\xaf\x02\x04\xfe"
  "\x05\x07\x12\x93\x01\x02\x53\x04\x61\x73\x6b\x08\x09\x1d\x69\x6e"
  "\x76\x6f\x6b\x65\x2d\x72\x65\x73\x74\x61\x72\x74\x2d\x69\x6e\x74"
  "\x65\x72\x61\x63\x74\x69\x76\x65\x6c\x79\x94\x01\x05\x6c\x69\x73"
  "\x74\x02\x04\x88\x01\x04\x92\x01\x05\x0f\x72\x65\x73\x74\x61\x72"
  "\x74\x2d\x74\x68\x72\x65\x61\x64\x03\x17\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2f\x6f\x74\x68\x65\x72\x2d\x74\x68\x72\x65\x61\x64"
  "\x95\x01\x03\x23\x63\x6f\x6e\x74\x69\x6e\x75\x65\x2d\x66\x72\x6f"
  "\x6d\x2d\x64\x65\x72\x69\x76\x65\x64\x2d\x74\x68\x72\x65\x61\x64"
  "\x2d\x65\x72\x72\x6f\x72\x96\x01\x06\xbb\x02\x16\x81\x83\x02\xba"
  "\x02\x14\x81\x89\x02\xb9\x02\x12\x81\x85\x02\xb8\x02\x10\x81\x83"
  "\x02\xb7\x02\x0e\x81\x89\x02\xb6\x02\x0c\x81\x85\x02\xb5\x02\x0a"
  "\x81\x85\x02\xb4\x02\x08\x81\x87\x02\xb3\x02\x06\x81\x87\x02\xb2"
  "\x02\x04\x84\x04\x15\x2d\x97\x01\x02\x54\x07\x74\x68\x72\x65\x61"
  "\x64\x98\x01\x03\x1a\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x64"
  "\x65\x72\x69\x76\x65\x64\x2d\x74\x68\x72\x65\x61\x64\x3f\x99\x01"
  "\x04\x5f\x02\x0f\x63\x75\x72\x72\x65\x6e\x74\x2d\x74\x68\x72\x65"
  "\x61\x64\x04\xbf\x02\x0a\x81\x83\x02\xbe\x02\x08\x81\x83\x02\xbd"
  "\x02\x06\x81\x83\x02\xbc\x02\x04\x83\x04\x09\x14\x9a\x01\x02\x55"
  "\x26\x15\x61\x73\x73\x6f\x63\x69\x61\x74\x65\x64\x2d\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x9b\x01\x09\x63\x6f\x6e\x74\x69\x6e\x75"
  "\x65\x9c\x01\x02\x27\x02\x4a\x03\x87\x01\x04\x0c\x72\x65\x73\x74"
  "\x61\x72\x74\x2f\x67\x65\x74\x9d\x01\x03\x13\x05\xc9\x02\x16\x81"
  "\x85\x02\xc8\x02\x14\x81\x85\x02\xc7\x02\x12\x81\x85\x02\xc6\x02"
  "\x10\x81\x85\x02\xc5\x02\x0e\x81\x89\x02\xc4\x02\x0c\x81\x85\x02"
  "\xc3\x02\x0a\x81\x87\x02\xc2\x02\x08\x81\x85\x02\xc1\x02\x06\x81"
  "\x83\x02\xc0\x02\x04\x83\x04\x15\x26\x9e\x01\x02\x56\x27\x26\x4e"
  "\x02\xcf\x02\x0e\x81\x85\x02\xce\x02\x0c\x81\x83\x02\xcd\x02\x0a"
  "\x81\x85\x02\xcc\x02\x08\x81\x83\x02\xcb\x02\x06\x81\x81\x02\xca"
  "\x02\x04\x82\x02\x0d\x15\x9f\x01\x02\x57\x27\x4e\x02\x03\x16\x65"
  "\x72\x72\x6f\x72\x3a\x6e\x6f\x2d\x73\x75\x63\x68\x2d\x72\x65\x73"
  "\x74\x61\x72\x74\xa0\x01\x02\xd2\x02\x08\x81\x81\x02\xd1\x02\x06"
  "\x82\x02\xd0\x02\x04\x81\x83\x02\x07\x10\xa1\x01\x02\x58\x26\x09"
  "\x27\xd7\x02\x0c\x81\x87\x02\xd6\x02\x0a\x81\x87\x02\xd5\x02\x08"
  "\x81\x87\x02\xd4\x02\x06\x81\x87\x02\xd3\x02\x04\x84\x06\x0b\x12"
  "\xa2\x01\x02\x59\x0d\x66\x69\x6e\x64\x2d\x72\x65\x73\x74\x61\x72"
  "\x74\xa3\x01\x04\x5c\x04\x11\x72\x65\x73\x74\x61\x72\x74\x73\x2d"
  "\x64\x65\x66\x61\x75\x6c\x74\x5c\x04\x0e\x25\x66\x69\x6e\x64\x2d"
  "\x72\x65\x73\x74\x61\x72\x74\xa4\x01\x04\xda\x02\x08\x81\x85\x02"
  "\xd9\x02\x06\x81\x85\x02\xd8\x02\x04\x84\x04\x07\x12\xa5\x01\x02"
  "\x5a\x09\x06\x61\x62\x6f\x72\x74\xa6\x01\x04\x5c\x03\xa0\x01\x04"
  "\xa4\x01\x04\xdf\x02\x0c\x81\x85\x02\xde\x02\x0a\x81\x83\x02\xdd"
  "\x02\x08\x81\x83\x02\xdc\x02\x06\x81\x83\x02\xdb\x02\x04\x83\x02"
  "\x0b\x18\xa7\x01\x02\x5b\x09\x02\x9c\x01\x04\x5c\x04\xa4\x01\x03"
  "\xe3\x02\x0a\x81\x85\x02\xe2\x02\x08\x81\x83\x02\xe1\x02\x06\x81"
  "\x83\x02\xe0\x02\x04\x83\x02\x09\x15\xa8\x01\x02\x5c\x09\x0f\x6d"
  "\x75\x66\x66\x6c\x65\x2d\x77\x61\x72\x6e\x69\x6e\x67\xa9\x01\x04"
  "\x5c\x03\xa0\x01\x04\xa4\x01\x04\xe8\x02\x0c\x81\x85\x02\xe7\x02"
  "\x0a\x81\x83\x02\xe6\x02\x08\x81\x83\x02\xe5\x02\x06\x81\x83\x02"
  "\xe4\x02\x04\x83\x02\x0b\x18\xaa\x01\x02\x5d\x09\x02\x06\x72\x65"
  "\x74\x72\x79\xab\x01\x04\x5c\x04\xa4\x01\x03\xec\x02\x0a\x81\x85"
  "\x02\xeb\x02\x08\x81\x83\x02\xea\x02\x06\x81\x83\x02\xe9\x02\x04"
  "\x83\x02\x09\x15\xac\x01\x02\x5e\x09\x02\x0c\x73\x74\x6f\x72\x65"
  "\x2d\x76\x61\x6c\x75\x65\xad\x01\x04\x5c\x04\xa4\x01\x03\xf0\x02"
  "\x0a\x81\x87\x02\xef\x02\x08\x81\x87\x02\xee\x02\x06\x81\x85\x02"
  "\xed\x02\x04\x84\x04\x09\x15\xae\x01\x02\x5f\x09\x02\x0a\x75\x73"
  "\x65\x2d\x76\x61\x6c\x75\x65\xaf\x01\x04\x5c\x04\xa4\x01\x03\xf4"
  "\x02\x0a\x81\x87\x02\xf3\x02\x08\x81\x87\x02\xf2\x02\x06\x81\x85"
  "\x02\xf1\x02\x04\x84\x04\x09\x15\xb0\x01\x02\x60\x09\x4b\x4a\x08"
  "\x4e\x4d\x03\x03\x43\x06\x1b\x03\xfa\x02\x0e\x81\x85\x02\xf9\x02"
  "\x0c\x81\x8b\x02\xf8\x02\x0a\x81\x85\x02\xf7\x02\x08\x81\x85\x02"
  "\xf6\x02\x06\x81\x85\x02\xf5\x02\x04\x84\x06\x0d\x1d\x4b\x02\x61"
  "\x02\x1a\x1f\x62\x69\x6e\x64\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x68\x61\x6e\x64\x6c\x65"
  "\x72\xb1\x01\x16\x73\x74\x61\x74\x69\x63\x2d\x68\x61\x6e\x64\x6c"
  "\x65\x72\x2d\x66\x72\x61\x6d\x65\x73\xb2\x01\x02\x15\xb2\x01\x03"
  "\x06\x1b\x05\x1d\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x70\x72"
  "\x6f\x63\x65\x64\x75\x72\x65\x2d\x6f\x66\x2d\x61\x72\x69\x74\x79"
  "\xb3\x01\x03\x80\x03\x0e\x81\x85\x02\xff\x02\x0c\x81\x85\x02\xfe"
  "\x02\x0a\x81\x85\x02\xfd\x02\x08\x81\x85\x02\xfc\x02\x06\x81\x8b"
  "\x02\xfb\x02\x04\x84\x06\x0d\x1e\xb4\x01\x02\x62\x02\x1a\x17\x62"
  "\x69\x6e\x64\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x68\x61"
  "\x6e\x64\x6c\x65\x72\xb5\x01\x17\x64\x79\x6e\x61\x6d\x69\x63\x2d"
  "\x68\x61\x6e\x64\x6c\x65\x72\x2d\x66\x72\x61\x6d\x65\x73\xb6\x01"
  "\x02\x15\xb6\x01\x03\x06\x1b\x05\xb3\x01\x05\x82\x01\x04\x8c\x03"
  "\x1a\x81\x87\x02\x8b\x03\x18\x81\x85\x02\x8a\x03\x16\x81\x83\x02"
  "\x89\x03\x14\x81\x83\x02\x88\x03\x12\x81\x87\x02\x87\x03\x10\x81"
  "\x85\x02\x86\x03\x0e\x81\x83\x02\x85\x03\x0c\x81\x89\x02\x84\x03"
  "\x0a\x81\x87\x02\x83\x03\x08\x81\x87\x02\x82\x03\x06\x81\x8d\x02"
  "\x81\x03\x04\x85\x08\x19\x2c\xb7\x01\x02\x63\x05\xb3\x01\x02\x8d"
  "\x03\x04\x84\x06\x03\x0a\xb8\x01\x02\x64\x02\x1a\x11\x62\x72\x65"
  "\x61\x6b\x2d\x6f\x6e\x2d\x73\x69\x67\x6e\x61\x6c\x73\x1a\x17\x62"
  "\x72\x65\x61\x6b\x2d\x6f\x6e\x2d\x73\x69\x67\x6e\x61\x6c\x73\x2d"
  "\x74\x79\x70\x65\x73\xb9\x01\x02\x15\x02\x06\x1b\x02\x91\x03\x0a"
  "\x81\x83\x02\x90\x03\x08\x81\x83\x02\x8f\x03\x06\x81\x89\x02\x8e"
  "\x03\x04\x83\x04\x09\x16\x1b\x02\x65\x92\x03\x04\x84\x06\x03\xba"
  "\x01\x02\x66\x08\x69\x6e\x68\x65\x72\x69\x74\xbb\x01\x2a\x42\x4b"
  "\x50\x54\x20\x65\x6e\x74\x65\x72\x65\x64\x20\x62\x65\x63\x61\x75"
  "\x73\x65\x20\x6f\x66\x20\x42\x52\x45\x41\x4b\x2d\x4f\x4e\x2d\x53"
  "\x49\x47\x4e\x41\x4c\x53\x3a\x02\x27\x26\x09\x11\x73\x69\x67\x6e"
  "\x61\x6c\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\xbc\x01\xb9\x01"
  "\xb6\x01\xb2\x01\x04\xb9\x01\xb6\x01\xb2\x01\x04\x04\x60\x05\x82"
  "\x01\x05\x15\x62\x72\x65\x61\x6b\x70\x6f\x69\x6e\x74\x2d\x70\x72"
  "\x6f\x63\x65\x64\x75\x72\x65\x04\x1e\x68\x6f\x6f\x6b\x2f\x69\x6e"
  "\x76\x6f\x6b\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x68"
  "\x61\x6e\x64\x6c\x65\x72\xbd\x01\x05\xcf\x03\x7c\x81\x83\x02\xce"
  "\x03\x7a\x81\x83\x02\xcd\x03\x78\x81\x83\x02\xcc\x03\x76\x81\x87"
  "\x02\xcb\x03\x74\x81\x85\x02\xca\x03\x72\x81\x87\x02\xc9\x03\x70"
  "\x81\x85\x02\xc8\x03\x6e\x81\x83\x02\xc7\x03\x6c\x81\x87\x02\xc6"
  "\x03\x6a\x81\x85\x02\xc5\x03\x68\x81\x87\x02\xc4\x03\x66\x81\x85"
  "\x02\xc3\x03\x64\x81\x83\x02\xc2\x03\x62\x81\x8b\x02\xc1\x03\x60"
  "\x81\x8b\x02\xc0\x03\x5e\x81\x8b\x02\xbf\x03\x5c\x81\x8b\x02\xbe"
  "\x03\x5a\x81\x8b\x02\xbd\x03\x58\x81\x83\x02\xbc\x03\x56\x81\x83"
  "\x02\xbb\x03\x54\x81\x83\x02\xba\x03\x52\x81\x87\x02\xb9\x03\x50"
  "\x81\x85\x02\xb8\x03\x4e\x81\x83\x02\xb7\x03\x4c\x81\x87\x02\xb6"
  "\x03\x4a\x81\x85\x02\xb5\x03\x48\x81\x83\x02\xb4\x03\x46\x81\x91"
  "\x02\xb3\x03\x44\x81\x8b\x02\xb2\x03\x42\x81\x8b\x02\xb1\x03\x40"
  "\x81\x89\x02\xb0\x03\x3e\x81\x89\x02\xaf\x03\x3c\x81\x89\x02\xae"
  "\x03\x3a\x81\x89\x02\xad\x03\x38\x81\x83\x02\xac\x03\x36\x81\x87"
  "\x02\xab\x03\x34\x81\x85\x02\xaa\x03\x32\x81\x83\x02\xa9\x03\x30"
  "\x81\x87\x02\xa8\x03\x2e\x81\x85\x02\xa7\x03\x2c\x81\x83\x02\xa6"
  "\x03\x2a\x81\x89\x02\xa5\x03\x28\x81\x85\x02\xa4\x03\x26\x81\x8d"
  "\x02\xa3\x03\x24\x81\x8b\x02\xa2\x03\x22\x81\x8b\x02\xa1\x03\x20"
  "\x81\x89\x02\xa0\x03\x1e\x81\x89\x02\x9f\x03\x1c\x81\x89\x02\x9e"
  "\x03\x1a\x81\x89\x02\x9d\x03\x18\x81\x87\x02\x9c\x03\x16\x81\x85"
  "\x02\x9b\x03\x14\x81\x85\x02\x9a\x03\x12\x81\x85\x02\x99\x03\x10"
  "\x81\x87\x02\x98\x03\x0e\x81\x83\x02\x97\x03\x0c\x81\x83\x02\x96"
  "\x03\x0a\x81\x83\x02\x95\x03\x08\x81\x85\x02\x94\x03\x06\x81\x85"
  "\x02\x93\x03\x04\x83\x04\x7b\x9a\x01\xbe\x01\x02\x67\x12\x6d\x61"
  "\x6b\x65\x2d\x73\x69\x6d\x70\x6c\x65\x2d\x65\x72\x72\x6f\x72\xbf"
  "\x01\x17\x73\x74\x61\x6e\x64\x61\x72\x64\x2d\x65\x72\x72\x6f\x72"
  "\x2d\x68\x61\x6e\x64\x6c\x65\x72\xc0\x01\x03\x06\x0e\x73\x69\x67"
  "\x6e\x61\x6c\x2d\x73\x69\x6d\x70\x6c\x65\xc1\x01\x02\xd2\x03\x08"
  "\x81\x89\x02\xd1\x03\x06\x81\x89\x02\xd0\x03\x04\xfe\x05\x07\x10"
  "\xc2\x01\x02\x68\x10\x49\x67\x6e\x6f\x72\x65\x20\x77\x61\x72\x6e"
  "\x69\x6e\x67\x2e\xa9\x01\x14\x6d\x61\x6b\x65\x2d\x73\x69\x6d\x70"
  "\x6c\x65\x2d\x77\x61\x72\x6e\x69\x6e\x67\xc3\x01\x19\x73\x74\x61"
  "\x6e\x64\x61\x72\x64\x2d\x77\x61\x72\x6e\x69\x6e\x67\x2d\x68\x61"
  "\x6e\x64\x6c\x65\x72\xc4\x01\x03\x05\x14\x77\x69\x74\x68\x2d\x73"
  "\x69\x6d\x70\x6c\x65\x2d\x72\x65\x73\x74\x61\x72\x74\xc5\x01\x06"
  "\xc1\x01\x03\xd6\x03\x0a\x81\x89\x02\xd5\x03\x08\x81\x83\x02\xd4"
  "\x03\x06\x81\x83\x02\xd3\x03\x04\xfe\x05\x09\x16\xc6\x01\x02\x69"
  "\x4a\x03\x43\x03\x85\x01\x03\xbc\x01\x03\x15\x06\x4c\x06\xdd\x03"
  "\x10\x81\x87\x02\xdc\x03\x0e\x81\x87\x02\xdb\x03\x0c\x81\x85\x02"
  "\xda\x03\x0a\x81\x85\x02\xd9\x03\x08\x81\x89\x02\xd8\x03\x06\x81"
  "\x89\x02\xd7\x03\x04\x86\x0a\x0f\x1e\xc7\x01\x02\x6a\x02\xbb\x01"
  "\x07\x65\x72\x72\x6f\x72\x3e\x14\x73\x74\x61\x6e\x64\x61\x72\x64"
  "\x2d\x65\x72\x72\x6f\x72\x2d\x68\x6f\x6f\x6b\xbb\x01\x02\xbb\x01"
  "\x02\x06\x0a\x70\x75\x73\x68\x2d\x72\x65\x70\x6c\x05\x82\x01\x03"
  "\x0b\x72\x65\x70\x6c\x2f\x73\x74\x61\x72\x74\x04\xe8\x03\x18\x81"
  "\x83\x02\xe7\x03\x16\x81\x87\x02\xe6\x03\x14\x81\x85\x02\xe5\x03"
  "\x12\x81\x83\x02\xe4\x03\x10\x81\x83\x02\xe3\x03\x0e\x81\x87\x02"
  "\xe2\x03\x0c\x81\x85\x02\xe1\x03\x0a\x81\x83\x02\xe0\x03\x08\x81"
  "\x85\x02\xdf\x03\x06\x83\x04\xde\x03\x04\x81\x83\x02\x17\x29\xc8"
  "\x01\x02\x6b\x0b\x3b\x57\x61\x72\x6e\x69\x6e\x67\x3a\x20\x02\x16"
  "\x73\x74\x61\x6e\x64\x61\x72\x64\x2d\x77\x61\x72\x6e\x69\x6e\x67"
  "\x2d\x68\x6f\x6f\x6b\xc9\x01\x02\xc9\x01\x02\x02\x19\x6e\x6f\x74"
  "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x6f\x75\x74\x70\x75\x74"
  "\x2d\x70\x6f\x72\x74\x05\x82\x01\x03\x0b\x66\x72\x65\x73\x68\x2d"
  "\x6c\x69\x6e\x65\x04\x0b\x04\x6b\x03\x08\x6e\x65\x77\x6c\x69\x6e"
  "\x65\xca\x01\x07\xf5\x03\x1c\x81\x85\x02\xf4\x03\x1a\x81\x85\x02"
  "\xf3\x03\x18\x81\x85\x02\xf2\x03\x16\x81\x85\x02\xf1\x03\x14\x81"
  "\x87\x02\xf0\x03\x12\x81\x85\x02\xef\x03\x10\x81\x83\x02\xee\x03"
  "\x0e\x81\x87\x02\xed\x03\x0c\x81\x85\x02\xec\x03\x0a\x81\x83\x02"
  "\xeb\x03\x08\x81\x83\x02\xea\x03\x06\x81\x83\x02\xe9\x03\x04\x83"
  "\x04\x1b\x31\xcb\x01\x02\x6c\x06\x61\x70\x70\x6c\x79\xcc\x01\x4a"
  "\x14\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x73\x69\x67\x6e\x61"
  "\x6c\x6c\x65\x72\xcd\x01\x05\xb3\x01\x04\x49\x03\x85\x01\x03\xbc"
  "\x01\x05\xfc\x03\x10\x81\x87\x02\xfb\x03\x0e\x81\x85\x02\xfa\x03"
  "\x0c\x81\x85\x02\xf9\x03\x0a\x81\x85\x02\xf8\x03\x08\x81\x87\x02"
  "\xf7\x03\x06\x81\x87\x02\xf6\x03\x04\x85\x08\x0f\x1f\xce\x01\x02"
  "\x6d\xab\x01\xaf\x01\xcc\x01\x4a\x28\x73\x75\x62\x73\x74\x69\x74"
  "\x75\x74\x61\x62\x6c\x65\x2d\x76\x61\x6c\x75\x65\x2d\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x73\x69\x67\x6e\x61\x6c\x6c\x65\x72"
  "\xcf\x01\x84\x01\x02\x05\xb3\x01\x03\x4f\x04\x49\x03\x85\x01\x05"
  "\x2d\x07\x80\x01\x03\x20\x70\x72\x6f\x6d\x70\x74\x2d\x66\x6f\x72"
  "\x2d\x65\x76\x61\x6c\x75\x61\x74\x65\x64\x2d\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x04\x09\x6c\x69\x73\x74\x2d\x72\x65\x66\x03"
  "\xbc\x01\x0a\x91\x04\x2c\x81\x85\x02\x90\x04\x2a\x81\x83\x02\x8f"
  "\x04\x28\x81\x85\x02\x8e\x04\x26\x81\x83\x02\x8d\x04\x24\x81\x83"
  "\x02\x8c\x04\x22\x81\x83\x02\x8b\x04\x20\x81\x83\x02\x8a\x04\x1e"
  "\x81\x83\x02\x89\x04\x1c\x81\x83\x02\x88\x04\x1a\x81\x87\x02\x87"
  "\x04\x18\x81\x85\x02\x86\x04\x16\x81\x87\x02\x85\x04\x14\x81\x8d"
  "\x02\x84\x04\x12\x81\x85\x02\x83\x04\x10\x81\x85\x02\x82\x04\x0e"
  "\x81\x85\x02\x81\x04\x0c\x81\x85\x02\x80\x04\x0a\x81\x91\x02\xff"
  "\x03\x08\x81\x8f\x02\xfe\x03\x06\x81\x8f\x02\xfd\x03\x04\x89\x10"
  "\x2b\x49\xb3\x01\x02\x6e\x09\x16\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2d\x74\x79\x70\x65\x2f\x65\x72\x72\x6f\x72\x3f\x84\x01\x6c"
  "\x02\x04\x20\x04\x28\x03\x95\x04\x0a\x81\x85\x02\x94\x04\x08\x81"
  "\x83\x02\x93\x04\x06\x81\x83\x02\x92\x04\x04\x83\x04\x09\x16\xd0"
  "\x01\x02\x6f\x09\x11\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x65"
  "\x72\x72\x6f\x72\x3f\xd1\x01\x6c\x02\x04\x60\x04\x28\x03\x9a\x04"
  "\x0c\x81\x85\x02\x99\x04\x0a\x81\x85\x02\x98\x04\x08\x81\x83\x02"
  "\x97\x04\x06\x81\x83\x02\x96\x04\x04\x83\x04\x0b\x19\xd2\x01\x02"
  "\x70\x09\x6c\x02\x04\x28\x02\x9e\x04\x0a\x81\x85\x02\x9d\x04\x08"
  "\x81\x85\x02\x9c\x04\x06\x81\x83\x02\x9b\x04\x04\x83\x04\x09\x14"
  "\xd3\x01\x02\x71\x09\x6c\x02\x04\x28\x02\xa1\x04\x08\x81\x85\x02"
  "\xa0\x04\x06\x81\x83\x02\x9f\x04\x04\x83\x04\x07\x11\x28\x02\x72"
  "\x0c\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\xd4\x01\x09\x6c"
  "\x6f\x63\x61\x74\x69\x6f\x6e\xd5\x01\x06\x64\x61\x74\x75\x6d\xd6"
  "\x01\x05\x74\x79\x70\x65\xd7\x01\x09\x6f\x70\x65\x72\x61\x6e\x64"
  "\x73\xd8\x01\xd6\x01\x09\x6f\x70\x65\x72\x61\x74\x6f\x72\xd9\x01"
  "\xd6\x01\xd7\x01\xd9\x01\xd6\x01\xd7\x01\x05\x63\x68\x61\x72\xda"
  "\x01\x27\x43\x68\x61\x72\x61\x63\x74\x65\x72\x20\x74\x6f\x6f\x20"
  "\x6c\x61\x72\x67\x65\x20\x66\x6f\x72\x20\x38\x2d\x62\x69\x74\x20"
  "\x73\x74\x72\x69\x6e\x67\x3a\x20\x09\x4e\x6f\x20\x73\x75\x63\x68"
  "\x20\x0f\x20\x73\x69\x67\x6e\x61\x6c\x6c\x65\x64\x20\x62\x79\x20"
  "\x19\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x70\x6f\x69\x6e\x74\x2d"
  "\x75\x6e\x64\x65\x72\x66\x6c\x6f\x77\x0f\x6e\x6f\x74\x2d\x38\x2d"
  "\x62\x69\x74\x2d\x63\x68\x61\x72\xda\x01\x07\x72\x65\x61\x73\x6f"
  "\x6e\xda\x01\x18\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x70\x6f\x69"
  "\x6e\x74\x2d\x6f\x76\x65\x72\x66\x6c\x6f\x77\x19\x46\x6c\x6f\x61"
  "\x74\x69\x6e\x67\x2d\x70\x6f\x69\x6e\x74\x20\x75\x6e\x64\x65\x72"
  "\x66\x6c\x6f\x77\x0b\x20\x62\x65\x63\x61\x75\x73\x65\x3a\x20\x0f"
  "\x64\x69\x76\x69\x64\x65\x2d\x62\x79\x2d\x7a\x65\x72\x6f\x18\x46"
  "\x6c\x6f\x61\x74\x69\x6e\x67\x2d\x70\x6f\x69\x6e\x74\x20\x6f\x76"
  "\x65\x72\x66\x6c\x6f\x77\x11\x61\x72\x69\x74\x68\x6d\x65\x74\x69"
  "\x63\x2d\x65\x72\x72\x6f\x72\xd9\x01\xd8\x01\x11\x44\x69\x76\x69"
  "\x73\x69\x6f\x6e\x20\x62\x79\x20\x7a\x65\x72\x6f\x08\x20\x61\x67"
  "\x61\x69\x6e\x2e\x2c\x56\x61\x72\x69\x61\x62\x6c\x65\x20\x72\x65"
  "\x66\x65\x72\x65\x6e\x63\x65\x20\x74\x6f\x20\x61\x20\x73\x79\x6e"
  "\x74\x61\x63\x74\x69\x63\x20\x6b\x65\x79\x77\x6f\x72\x64\x3a\x20"
  "\x1b\x41\x6e\x6f\x6e\x79\x6d\x6f\x75\x73\x20\x61\x72\x69\x74\x68"
  "\x6d\x65\x74\x69\x63\x20\x65\x72\x72\x6f\x72\x08\x54\x72\x79\x20"
  "\x74\x6f\x20\x26\x20\x6e\x61\x6d\x65\x20\x28\x61\x6e\x20\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x20\x74\x6f\x20\x62\x65\x20\x65"
  "\x76\x61\x6c\x75\x61\x74\x65\x64\x29\x16\x55\x6e\x61\x73\x73\x69"
  "\x67\x6e\x65\x64\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x3a\x20\x0e"
  "\x6d\x61\x63\x72\x6f\x2d\x62\x69\x6e\x64\x69\x6e\x67\x02\x20\x0e"
  "\x20\x61\x20\x64\x69\x66\x66\x65\x72\x65\x6e\x74\x20\x0b\x20\x74"
  "\x68\x65\x20\x73\x61\x6d\x65\x20\x05\x4e\x65\x77\x20\x13\x55\x6e"
  "\x62\x6f\x75\x6e\x64\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x3a\x20"
  "\x14\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x09\x61\x6e\x20\x65\x72\x72\x6f\x72\x0c\x61\x20"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x02\x3a\x09\x66\x69\x6c\x65"
  "\x6e\x61\x6d\x65\xdb\x01\x05\x76\x65\x72\x62\xdc\x01\x05\x6e\x6f"
  "\x75\x6e\xdd\x01\xda\x01\xd9\x01\xd8\x01\x2a\x41\x6e\x6f\x6e\x79"
  "\x6d\x6f\x75\x73\x20\x65\x72\x72\x6f\x72\x20\x61\x73\x73\x6f\x63"
  "\x69\x61\x74\x65\x64\x20\x77\x69\x74\x68\x20\x76\x61\x72\x69\x61"
  "\x62\x6c\x65\x20\x11\x75\x6e\x62\x6f\x75\x6e\x64\x2d\x76\x61\x72"
  "\x69\x61\x62\x6c\x65\x9b\x01\x0b\x55\x6e\x61\x62\x6c\x65\x20\x74"
  "\x6f\x20\xdc\x01\x0f\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x65\x72"
  "\x72\x6f\x72\xd4\x01\x9c\x01\x15\x43\x6f\x6e\x74\x69\x6e\x75\x65"
  "\x20\x66\x72\x6f\x6d\x20\x65\x72\x72\x6f\x72\x2e\xdd\x01\x0c\x20"
  "\x73\x69\x67\x6e\x61\x6c\x6c\x65\x64\x20\x15\x66\x69\x6c\x65\x2d"
  "\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x2d\x65\x72\x72\x6f\x72\xdc"
  "\x01\xdd\x01\xda\x01\xd9\x01\xd8\x01\x15\x65\x72\x72\x6f\x72\x3a"
  "\x64\x65\x72\x69\x76\x65\x64\x2d\x74\x68\x72\x65\x61\x64\xdd\x01"
  "\x0a\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\xdc\x01\x0c\x54\x68\x65"
  "\x20\x74\x68\x72\x65\x61\x64\x20\x98\x01\xdc\x01\x13\x65\x72\x72"
  "\x6f\x72\x3a\x64\x65\x72\x69\x76\x65\x64\x2d\x66\x69\x6c\x65\xda"
  "\x01\x06\x20\x61\x6e\x64\x20\x15\x64\x65\x72\x69\x76\x65\x64\x2d"
  "\x74\x68\x72\x65\x61\x64\x2d\x65\x72\x72\x6f\x72\x09\x27\x15\x20"
  "\x73\x69\x67\x6e\x61\x6c\x6c\x65\x64\x20\x61\x6e\x20\x65\x72\x72"
  "\x6f\x72\x3a\x0a\x54\x68\x65\x20\x66\x69\x6c\x65\x20\xdb\x01\xdc"
  "\x01\x13\x65\x72\x72\x6f\x72\x3a\x64\x65\x72\x69\x76\x65\x64\x2d"
  "\x70\x6f\x72\x74\xd4\x01\x09\x65\x78\x61\x63\x74\x6c\x79\x20\x09"
  "\x62\x65\x74\x77\x65\x65\x6e\x20\x0a\x61\x74\x20\x6c\x65\x61\x73"
  "\x74\x20\x13\x64\x65\x72\x69\x76\x65\x64\x2d\x66\x69\x6c\x65\x2d"
  "\x65\x72\x72\x6f\x72\x02\x2c\x0a\x54\x68\x65\x20\x70\x6f\x72\x74"
  "\x20\x05\x70\x6f\x72\x74\x9b\x01\xdc\x01\x13\x64\x65\x72\x69\x76"
  "\x65\x64\x2d\x70\x6f\x72\x74\x2d\x65\x72\x72\x6f\x72\xdc\x01\x05"
  "\x20\x74\x6f\x20\x0a\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x0b\x20"
  "\x61\x72\x67\x75\x6d\x65\x6e\x74\x73\x01\x2f\x0d\x74\x68\x72\x65"
  "\x61\x64\x2d\x65\x72\x72\x6f\x72\x98\x01\x08\x61\x73\x20\x74\x68"
  "\x65\x20\x0f\x61\x73\x20\x61\x6e\x20\x61\x72\x67\x75\x6d\x65\x6e"
  "\x74\x0f\x20\x69\x73\x20\x6e\x6f\x74\x20\x62\x6f\x75\x6e\x64\x2e"
  "\x21\x41\x6e\x6f\x6e\x79\x6d\x6f\x75\x73\x20\x65\x72\x72\x6f\x72"
  "\x20\x61\x73\x73\x6f\x63\x69\x61\x74\x65\x64\x20\x77\x69\x74\x68"
  "\x20\x0b\x63\x65\x6c\x6c\x2d\x65\x72\x72\x6f\x72\xd5\x01\x11\x61"
  "\x73\x20\x74\x68\x65\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x0f"
  "\x3b\x20\x69\x74\x20\x72\x65\x71\x75\x69\x72\x65\x73\x20\x05\x6e"
  "\x61\x6d\x65\xd5\x01\x0b\x66\x69\x6c\x65\x2d\x65\x72\x72\x6f\x72"
  "\xdb\x01\x0a\x2c\x20\x70\x61\x73\x73\x65\x64\x20\x1d\x1e\x02\xd8"
  "\x01\x1a\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x20\x76\x61\x6c\x69"
  "\x64\x20\x70\x61\x74\x68\x6e\x61\x6d\x65\x20\x13\x54\x68\x65\x20"
  "\x72\x65\x73\x74\x61\x72\x74\x20\x6e\x61\x6d\x65\x64\x20\x0b\x70"
  "\x6f\x72\x74\x2d\x65\x72\x72\x6f\x72\x9b\x01\xd9\x01\x17\x20\x68"
  "\x61\x73\x20\x62\x65\x65\x6e\x20\x63\x61\x6c\x6c\x65\x64\x20\x77"
  "\x69\x74\x68\x20\x10\x6e\x6f\x2d\x73\x75\x63\x68\x2d\x72\x65\x73"
  "\x74\x61\x72\x74\xd5\x01\x02\x2e\x08\x6f\x70\x65\x72\x61\x6e\x64"
  "\xdb\x01\x0e\x63\x6f\x6e\x74\x72\x6f\x6c\x2d\x65\x72\x72\x6f\x72"
  "\x0f\x43\x6f\x6e\x74\x72\x6f\x6c\x20\x65\x72\x72\x6f\x72\x2e\x0f"
  "\x54\x68\x65\x20\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x20\x1b\x69"
  "\x6c\x6c\x65\x67\x61\x6c\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d"
  "\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x09\x20\x69\x73\x20\x6e\x6f"
  "\x74\x20\x1a\x77\x72\x6f\x6e\x67\x2d\x6e\x75\x6d\x62\x65\x72\x2d"
  "\x6f\x66\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x73\xd8\x01\x03\x61"
  "\x20\x04\x61\x6e\x20\x0b\x73\x74\x72\x69\x6e\x67\x2d\x72\x65\x66"
  "\x13\x62\x61\x64\x2d\x72\x61\x6e\x67\x65\x2d\x61\x72\x67\x75\x6d"
  "\x65\x6e\x74\x11\x74\x68\x65\x20\x63\x6f\x72\x72\x65\x63\x74\x20"
  "\x74\x79\x70\x65\x1e\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6e\x20"
  "\x74\x68\x65\x20\x63\x6f\x72\x72\x65\x63\x74\x20\x72\x61\x6e\x67"
  "\x65\x2e\x14\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61\x72"
  "\x67\x75\x6d\x65\x6e\x74\xd9\x01\xdb\x01\xd7\x01\x2d\x20\x68\x61"
  "\x73\x20\x62\x65\x65\x6e\x20\x66\x6f\x75\x6e\x64\x20\x69\x6e\x20"
  "\x61\x6e\x20\x69\x6e\x61\x70\x70\x72\x6f\x70\x72\x69\x61\x74\x65"
  "\x20\x63\x6f\x6e\x74\x65\x78\x74\x2e\x11\x77\x72\x6f\x6e\x67\x2d"
  "\x74\x79\x70\x65\x2d\x64\x61\x74\x75\x6d\xd7\x01\xd6\x01\x01\x62"
  "\x01\x66\x01\x6a\x01\x70\x01\x76\x01\x42\x01\x46\x01\x4a\x01\x50"
  "\x01\x56\x0c\x54\x68\x65\x20\x6f\x62\x6a\x65\x63\x74\x20\x13\x64"
  "\x61\x74\x75\x6d\x2d\x6f\x75\x74\x2d\x6f\x66\x2d\x72\x61\x6e\x67"
  "\x65\x0e\x69\x6c\x6c\x65\x67\x61\x6c\x2d\x64\x61\x74\x75\x6d\xd6"
  "\x01\x0a\x69\x72\x72\x69\x74\x61\x6e\x74\x73\xdb\x01\x0f\x73\x69"
  "\x6d\x70\x6c\x65\x2d\x77\x61\x72\x6e\x69\x6e\x67\x08\x6d\x65\x73"
  "\x73\x61\x67\x65\xd9\x01\x0d\x73\x69\x6d\x70\x6c\x65\x2d\x65\x72"
  "\x72\x6f\x72\x11\x73\x69\x6d\x70\x6c\x65\x2d\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\xd9\x01\xdb\x01\x06\x65\x72\x72\x6f\x72\xdb\x01"
  "\x08\x77\x61\x72\x6e\x69\x6e\x67\xcc\x01\x12\x73\x65\x72\x69\x6f"
  "\x75\x73\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\xbd\x01\x92\x01"
  "\x21\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a"
  "\x73\x65\x72\x69\x6f\x75\x73\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\xd9\x01\x17\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79"
  "\x70\x65\x3a\x77\x61\x72\x6e\x69\x6e\x67\xd8\x01\x6c\x20\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x73\x69\x6d"
  "\x70\x6c\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\xd6\x01\x1c"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x73"
  "\x69\x6d\x70\x6c\x65\x2d\x65\x72\x72\x6f\x72\xcc\x01\x1e\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x73\x69\x6d"
  "\x70\x6c\x65\x2d\x77\x61\x72\x6e\x69\x6e\x67\x9b\x01\x1d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x69\x6c\x6c"
  "\x65\x67\x61\x6c\x2d\x64\x61\x74\x75\x6d\x98\x01\x22\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x64\x61\x74\x75"
  "\x6d\x2d\x6f\x75\x74\x2d\x6f\x66\x2d\x72\x61\x6e\x67\x65\x1d\x20"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x77"
  "\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x64\x61\x74\x75\x6d\xde"
  "\x01\x23\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65"
  "\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61\x72\x67\x75"
  "\x6d\x65\x6e\x74\xdf\x01\x22\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x74\x79\x70\x65\x3a\x62\x61\x64\x2d\x72\x61\x6e\x67\x65\x2d"
  "\x61\x72\x67\x75\x6d\x65\x6e\x74\xe0\x01\x29\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x77\x72\x6f\x6e\x67\x2d"
  "\x6e\x75\x6d\x62\x65\x72\x2d\x6f\x66\x2d\x61\x72\x67\x75\x6d\x65"
  "\x6e\x74\x73\xe1\x01\x2a\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d"
  "\x74\x79\x70\x65\x3a\x69\x6c\x6c\x65\x67\x61\x6c\x2d\x70\x61\x74"
  "\x68\x6e\x61\x6d\x65\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\xe2"
  "\x01\x1d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65"
  "\x3a\x63\x6f\x6e\x74\x72\x6f\x6c\x2d\x65\x72\x72\x6f\x72\xe3\x01"
  "\x1f\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a"
  "\x6e\x6f\x2d\x73\x75\x63\x68\x2d\x72\x65\x73\x74\x61\x72\x74\xe4"
  "\x01\x1a\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65"
  "\x3a\x70\x6f\x72\x74\x2d\x65\x72\x72\x6f\x72\xe5\x01\x1a\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x66\x69\x6c"
  "\x65\x2d\x65\x72\x72\x6f\x72\xe6\x01\x1a\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x63\x65\x6c\x6c\x2d\x65\x72"
  "\x72\x6f\x72\xe7\x01\x1c\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d"
  "\x74\x79\x70\x65\x3a\x74\x68\x72\x65\x61\x64\x2d\x65\x72\x72\x6f"
  "\x72\xe8\x01\x22\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79"
  "\x70\x65\x3a\x64\x65\x72\x69\x76\x65\x64\x2d\x70\x6f\x72\x74\x2d"
  "\x65\x72\x72\x6f\x72\xe9\x01\xd4\x01\x22\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x64\x65\x72\x69\x76\x65\x64"
  "\x2d\x66\x69\x6c\x65\x2d\x65\x72\x72\x6f\x72\xea\x01\xda\x01\x24"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x64"
  "\x65\x72\x69\x76\x65\x64\x2d\x74\x68\x72\x65\x61\x64\x2d\x65\x72"
  "\x72\x6f\x72\xeb\x01\xdd\x01\x99\x01\x24\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x66\x69\x6c\x65\x2d\x6f\x70"
  "\x65\x72\x61\x74\x69\x6f\x6e\x2d\x65\x72\x72\x6f\x72\xec\x01\x15"
  "\x65\x72\x72\x6f\x72\x3a\x66\x69\x6c\x65\x2d\x6f\x70\x65\x72\x61"
  "\x74\x69\x6f\x6e\xed\x01\x1e\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x74\x79\x70\x65\x3a\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x65"
  "\x72\x72\x6f\x72\xee\x01\x20\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x74\x79\x70\x65\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x2d\x76\x61"
  "\x72\x69\x61\x62\x6c\x65\xef\x01\x23\x63\x6f\x6e\x64\x69\x74\x69"
  "\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x75\x6e\x61\x73\x73\x69\x67\x6e"
  "\x65\x64\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\xf0\x01\x1d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x6d\x61\x63"
  "\x72\x6f\x2d\x62\x69\x6e\x64\x69\x6e\x67\xf1\x01\x20\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x61\x72\x69\x74"
  "\x68\x6d\x65\x74\x69\x63\x2d\x65\x72\x72\x6f\x72\xf2\x01\x1e\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x64\x69"
  "\x76\x69\x64\x65\x2d\x62\x79\x2d\x7a\x65\x72\x6f\xf3\x01\x27\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x66\x6c"
  "\x6f\x61\x74\x69\x6e\x67\x2d\x70\x6f\x69\x6e\x74\x2d\x6f\x76\x65"
  "\x72\x66\x6c\x6f\x77\xf4\x01\x28\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2d\x74\x79\x70\x65\x3a\x66\x6c\x6f\x61\x74\x69\x6e\x67\x2d"
  "\x70\x6f\x69\x6e\x74\x2d\x75\x6e\x64\x65\x72\x66\x6c\x6f\x77\xf5"
  "\x01\x1e\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65"
  "\x3a\x6e\x6f\x74\x2d\x38\x2d\x62\x69\x74\x2d\x63\x68\x61\x72\xf6"
  "\x01\xbf\x01\xc3\x01\x17\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e"
  "\x67\x2d\x74\x79\x70\x65\x2d\x64\x61\x74\x75\x6d\xf7\x01\x19\x65"
  "\x72\x72\x6f\x72\x3a\x64\x61\x74\x75\x6d\x2d\x6f\x75\x74\x2d\x6f"
  "\x66\x2d\x72\x61\x6e\x67\x65\xf8\x01\x18\x2a\x2d\x21\x65\x72\x72"
  "\x6f\x72\x3a\x69\x6c\x6c\x65\x67\x61\x6c\x2d\x70\x61\x74\x68\x6e"
  "\x61\x6d\x65\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\xf9\x01\x15"
  "\x65\x72\x72\x6f\x72\x3a\x64\x69\x76\x69\x64\x65\x2d\x62\x79\x2d"
  "\x7a\x65\x72\x6f\xfa\x01\xa0\x01\x1a\x65\x72\x72\x6f\x72\x3a\x75"
  "\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x76\x61\x72\x69\x61\x62"
  "\x6c\x65\xfb\x01\x17\x65\x72\x72\x6f\x72\x3a\x75\x6e\x62\x6f\x75"
  "\x6e\x64\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\xfc\x01\x14\x65\x72"
  "\x72\x6f\x72\x3a\x6d\x61\x63\x72\x6f\x2d\x62\x69\x6e\x64\x69\x6e"
  "\x67\xfd\x01\x15\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x38\x2d"
  "\x62\x69\x74\x2d\x63\x68\x61\x72\xfe\x01\x36\x21\x64\x65\x66\x61"
  "\x75\x6c\x74\x2f\x69\x6e\x76\x6f\x6b\x65\x2d\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2d\x68\x61\x6e\x64\x6c\x65\x72\xff\x01\xd9\x01"
  "\x6c\xd8\x01\x98\x01\xde\x01\x1d\xe3\x01\xe5\x01\xe9\x01\xe6\x01"
  "\xea\x01\xe8\x01\xeb\x01\xec\x01\xe7\x01\xee\x01\xc0\x01\xf2\x01"
  "\xcc\x01\x9b\x01\xdf\x01\xe0\x01\xe1\x01\xe2\x01\xf3\x01\xe4\x01"
  "\xf0\x01\xef\x01\xf1\x01\xf6\x01\x20\x06\x1e\x04\x5f\x05\x15\x66"
  "\x6f\x72\x6d\x61\x74\x2d\x65\x72\x72\x6f\x72\x2d\x6d\x65\x73\x73"
  "\x61\x67\x65\x80\x02\x04\x0b\x0c\x09\x63\x68\x61\x72\x2d\x73\x65"
  "\x74\x04\x24\x03\x0d\x73\x74\x72\x69\x6e\x67\x2d\x6e\x75\x6c\x6c"
  "\x3f\x04\x11\x63\x68\x61\x72\x2d\x73\x65\x74\x2d\x6d\x65\x6d\x62"
  "\x65\x72\x3f\x04\x12\x73\x74\x72\x69\x6e\x67\x2d\x70\x72\x65\x66"
  "\x69\x78\x2d\x63\x69\x3f\x04\x0f\x77\x72\x69\x74\x65\x2d\x6f\x70"
  "\x65\x72\x61\x74\x6f\x72\x0b\x03\x81\x01\x03\x4f\x03\x1b\x65\x78"
  "\x61\x63\x74\x2d\x6e\x6f\x6e\x6e\x65\x67\x61\x74\x69\x76\x65\x2d"
  "\x69\x6e\x74\x65\x67\x65\x72\x3f\x4f\x04\x0a\x03\x14\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x2d\x61\x72\x69\x74\x79\x2d\x6d\x61\x78"
  "\x03\x16\x6f\x72\x64\x69\x6e\x61\x6c\x2d\x6e\x75\x6d\x62\x65\x72"
  "\x2d\x73\x74\x72\x69\x6e\x67\x81\x02\x03\x14\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x2d\x61\x72\x69\x74\x79\x2d\x6d\x69\x6e\x04\x49"
  "\x04\x05\x65\x71\x76\x3f\x04\x60\x03\xca\x01\x03\xdb\x01\x03\x57"
  "\x04\x6b\x04\x5b\x05\xc5\x01\x03\xd1\x01\x02\x14\x66\x69\x72\x73"
  "\x74\x2d\x62\x6f\x75\x6e\x64\x2d\x72\x65\x73\x74\x61\x72\x74\xca"
  "\x01\x09\xcf\x01\x05\x0d\x72\x65\x73\x74\x61\x72\x74\x2f\x70\x75"
  "\x74\x21\x82\x02\x05\x5d\x07\x5d\x03\x0d\x2d\x3e\x6e\x61\x6d\x65"
  "\x73\x74\x72\x69\x6e\x67\x03\x12\x73\x74\x72\x69\x6e\x67\x2d\x63"
  "\x61\x70\x69\x74\x61\x6c\x69\x7a\x65\x05\xcd\x01\x24\x8a\x07\xd4"
  "\x05\x81\x81\x02\x89\x07\xd2\x05\x81\x81\x02\x88\x07\xd0\x05\x81"
  "\x87\x02\x87\x07\xce\x05\x81\x83\x02\x86\x07\xcc\x05\x81\x81\x02"
  "\x85\x07\xca\x05\x81\x81\x02\x84\x07\xc8\x05\x81\x87\x02\x83\x07"
  "\xc6\x05\x81\x83\x02\x82\x07\xc4\x05\x81\x81\x02\x81\x07\xc2\x05"
  "\x81\x81\x02\x80\x07\xc0\x05\x81\x87\x02\xff\x06\xbe\x05\x81\x83"
  "\x02\xfe\x06\xbc\x05\x81\x81\x02\xfd\x06\xba\x05\x81\x81\x02\xfc"
  "\x06\xb8\x05\x81\x87\x02\xfb\x06\xb6\x05\x81\x83\x02\xfa\x06\xb4"
  "\x05\x81\x81\x02\xf9\x06\xb2\x05\x81\x81\x02\xf8\x06\xb0\x05\x81"
  "\x87\x02\xf7\x06\xae\x05\x81\x83\x02\xf6\x06\xac\x05\x81\x81\x02"
  "\xf5\x06\xaa\x05\x81\x81\x02\xf4\x06\xa8\x05\x81\x87\x02\xf3\x06"
  "\xa6\x05\x81\x83\x02\xf2\x06\xa4\x05\x81\x81\x02\xf1\x06\xa2\x05"
  "\x81\x81\x02\xf0\x06\xa0\x05\x81\x87\x02\xef\x06\x9e\x05\x81\x83"
  "\x02\xee\x06\x9c\x05\x81\x81\x02\xed\x06\x9a\x05\x81\x81\x02\xec"
  "\x06\x98\x05\x81\x87\x02\xeb\x06\x96\x05\x81\x83\x02\xea\x06\x94"
  "\x05\x81\x81\x02\xe9\x06\x92\x05\x81\x81\x02\xe8\x06\x90\x05\x81"
  "\x87\x02\xe7\x06\x8e\x05\x81\x83\x02\xe6\x06\x8c\x05\x81\x81\x02"
  "\xe5\x06\x8a\x05\x81\x81\x02\xe4\x06\x88\x05\x81\x87\x02\xe3\x06"
  "\x86\x05\x81\x83\x02\xe2\x06\x84\x05\x81\x81\x02\xe1\x06\x82\x05"
  "\x81\x81\x02\xe0\x06\x80\x05\x81\x87\x02\xdf\x06\xfe\x04\x81\x83"
  "\x02\xde\x06\xfc\x04\x81\x81\x02\xdd\x06\xfa\x04\x81\x81\x02\xdc"
  "\x06\xf8\x04\x81\x89\x02\xdb\x06\xf6\x04\x81\x85\x02\xda\x06\xf4"
  "\x04\x81\x87\x02\xd9\x06\xf2\x04\x81\x83\x02\xd8\x06\xf0\x04\x81"
  "\x81\x02\xd7\x06\xee\x04\x81\x81\x02\xd6\x06\xec\x04\x81\x89\x02"
  "\xd5\x06\xea\x04\x81\x85\x02\xd4\x06\xe8\x04\x81\x85\x02\xd3\x06"
  "\xe6\x04\x81\x81\x02\xd2\x06\xe4\x04\x81\x81\x02\xd1\x06\xe2\x04"
  "\x81\x83\x02\xd0\x06\xe0\x04\x81\x83\x02\xcf\x06\xde\x04\x81\x89"
  "\x02\xce\x06\xdc\x04\x84\x06\xcd\x06\xda\x04\x81\x85\x02\xcc\x06"
  "\xd8\x04\x81\x81\x02\xcb\x06\xd6\x04\x81\x81\x02\xca\x06\xd4\x04"
  "\x81\x89\x02\xc9\x06\xd2\x04\x81\x87\x02\xc8\x06\xd0\x04\x81\x87"
  "\x02\xc7\x06\xce\x04\x81\x87\x02\xc6\x06\xcc\x04\x81\x83\x02\xc5"
  "\x06\xca\x04\x81\x87\x02\xc4\x06\xc8\x04\x81\x81\x02\xc3\x06\xc6"
  "\x04\x81\x81\x02\xc2\x06\xc4\x04\x81\x87\x02\xc1\x06\xc2\x04\x81"
  "\x87\x02\xc0\x06\xc0\x04\x81\x87\x02\xbf\x06\xbe\x04\x81\x83\x02"
  "\xbe\x06\xbc\x04\x81\x81\x02\xbd\x06\xba\x04\x81\x81\x02\xbc\x06"
  "\xb8\x04\x81\x8d\x02\xbb\x06\xb6\x04\x81\x8b\x02\xba\x06\xb4\x04"
  "\x81\x87\x02\xb9\x06\xb2\x04\x81\x85\x02\xb8\x06\xb0\x04\x81\x87"
  "\x02\xb7\x06\xae\x04\x81\x87\x02\xb6\x06\xac\x04\x81\x83\x02\xb5"
  "\x06\xaa\x04\x81\x81\x02\xb4\x06\xa8\x04\x81\x81\x02\xb3\x06\xa6"
  "\x04\x81\x87\x02\xb2\x06\xa4\x04\x81\x85\x02\xb1\x06\xa2\x04\x81"
  "\x85\x02\xb0\x06\xa0\x04\x81\x83\x02\xaf\x06\x9e\x04\x81\x87\x02"
  "\xae\x06\x9c\x04\x81\x83\x02\xad\x06\x9a\x04\x81\x81\x02\xac\x06"
  "\x98\x04\x81\x81\x02\xab\x06\x96\x04\x81\x87\x02\xaa\x06\x94\x04"
  "\x81\x8b\x02\xa9\x06\x92\x04\x81\x8b\x02\xa8\x06\x90\x04\x81\x85"
  "\x02\xa7\x06\x8e\x04\x81\x85\x02\xa6\x06\x8c\x04\x84\x06\xa5\x06"
  "\x8a\x04\x81\x81\x02\xa4\x06\x88\x04\x81\x81\x02\xa3\x06\x86\x04"
  "\x81\x87\x02\xa2\x06\x84\x04\x81\x87\x02\xa1\x06\x82\x04\x81\x87"
  "\x02\xa0\x06\x80\x04\x81\x87\x02\x9f\x06\xfe\x03\x81\x87\x02\x9e"
  "\x06\xfc\x03\x81\x89\x02\x9d\x06\xfa\x03\x81\x85\x02\x9c\x06\xf8"
  "\x03\x81\x85\x02\x9b\x06\xf6\x03\x84\x06\x9a\x06\xf4\x03\x81\x87"
  "\x02\x99\x06\xf2\x03\x81\x81\x02\x98\x06\xf0\x03\x81\x81\x02\x97"
  "\x06\xee\x03\x81\x87\x02\x96\x06\xec\x03\x81\x8b\x02\x95\x06\xea"
  "\x03\x81\x87\x02\x94\x06\xe8\x03\x81\x85\x02\x93\x06\xe6\x03\x81"
  "\x85\x02\x92\x06\xe4\x03\x81\x85\x02\x91\x06\xe2\x03\x81\x85\x02"
  "\x90\x06\xe0\x03\x84\x06\x8f\x06\xde\x03\x81\x87\x02\x8e\x06\xdc"
  "\x03\x81\x81\x02\x8d\x06\xda\x03\x81\x81\x02\x8c\x06\xd8\x03\x81"
  "\x89\x02\x8b\x06\xd6\x03\x81\x83\x02\x8a\x06\xd4\x03\x81\x8b\x02"
  "\x89\x06\xd2\x03\x81\x87\x02\x88\x06\xd0\x03\x81\x87\x02\x87\x06"
  "\xce\x03\x81\x8d\x02\x86\x06\xcc\x03\x81\x89\x02\x85\x06\xca\x03"
  "\x81\x85\x02\x84\x06\xc8\x03\x84\x06\x83\x06\xc6\x03\x81\x87\x02"
  "\x82\x06\xc4\x03\x81\x81\x02\x81\x06\xc2\x03\x81\x81\x02\x80\x06"
  "\xc0\x03\x81\x83\x02\xff\x05\xbe\x03\x81\x85\x02\xfe\x05\xbc\x03"
  "\x81\x85\x02\xfd\x05\xba\x03\x81\x89\x02\xfc\x05\xb8\x03\x81\x83"
  "\x02\xfb\x05\xb6\x03\x81\x87\x02\xfa\x05\xb4\x03\x81\x81\x02\xf9"
  "\x05\xb2\x03\x81\x81\x02\xf8\x05\xb0\x03\x81\x87\x02\xf7\x05\xae"
  "\x03\x81\x85\x02\xf6\x05\xac\x03\x81\x85\x02\xf5\x05\xaa\x03\x84"
  "\x06\xf4\x05\xa8\x03\x81\x87\x02\xf3\x05\xa6\x03\x81\x81\x02\xf2"
  "\x05\xa4\x03\x81\x81\x02\xf1\x05\xa2\x03\x81\x8f\x02\xf0\x05\xa0"
  "\x03\x81\x8d\x02\xef\x05\x9e\x03\x81\x87\x02\xee\x05\x9c\x03\x81"
  "\x85\x02\xed\x05\x9a\x03\x81\x89\x02\xec\x05\x98\x03\x81\x85\x02"
  "\xeb\x05\x96\x03\x81\x87\x02\xea\x05\x94\x03\x81\x81\x02\xe9\x05"
  "\x92\x03\x81\x81\x02\xe8\x05\x90\x03\x81\x87\x02\xe7\x05\x8e\x03"
  "\x81\x87\x02\xe6\x05\x8c\x03\x81\x87\x02\xe5\x05\x8a\x03\x81\x85"
  "\x02\xe4\x05\x88\x03\x81\x85\x02\xe3\x05\x86\x03\x81\x85\x02\xe2"
  "\x05\x84\x03\x81\x83\x02\xe1\x05\x82\x03\x81\x81\x02\xe0\x05\x80"
  "\x03\x81\x81\x02\xdf\x05\xfe\x02\x81\x8f\x02\xde\x05\xfc\x02\x81"
  "\x8d\x02\xdd\x05\xfa\x02\x81\x87\x02\xdc\x05\xf8\x02\x81\x87\x02"
  "\xdb\x05\xf6\x02\x81\x85\x02\xda\x05\xf4\x02\x81\x89\x02\xd9\x05"
  "\xf2\x02\x81\x85\x02\xd8\x05\xf0\x02\x84\x06\xd7\x05\xee\x02\x81"
  "\x85\x02\xd6\x05\xec\x02\x81\x81\x02\xd5\x05\xea\x02\x81\x81\x02"
  "\xd4\x05\xe8\x02\x81\x87\x02\xd3\x05\xe6\x02\x81\x87\x02\xd2\x05"
  "\xe4\x02\x81\x87\x02\xd1\x05\xe2\x02\x81\x87\x02\xd0\x05\xe0\x02"
  "\x81\x87\x02\xcf\x05\xde\x02\x81\x87\x02\xce\x05\xdc\x02\x81\x85"
  "\x02\xcd\x05\xda\x02\x81\x85\x02\xcc\x05\xd8\x02\x81\x87\x02\xcb"
  "\x05\xd6\x02\x81\x81\x02\xca\x05\xd4\x02\x81\x81\x02\xc9\x05\xd2"
  "\x02\x81\x8f\x02\xc8\x05\xd0\x02\x81\x8d\x02\xc7\x05\xce\x02\x81"
  "\x87\x02\xc6\x05\xcc\x02\x81\x8b\x02\xc5\x05\xca\x02\x81\x87\x02"
  "\xc4\x05\xc8\x02\x81\x87\x02\xc3\x05\xc6\x02\x81\x87\x02\xc2\x05"
  "\xc4\x02\x81\x89\x02\xc1\x05\xc2\x02\x81\x85\x02\xc0\x05\xc0\x02"
  "\x84\x06\xbf\x05\xbe\x02\x81\x85\x02\xbe\x05\xbc\x02\x81\x81\x02"
  "\xbd\x05\xba\x02\x81\x81\x02\xbc\x05\xb8\x02\x81\x87\x02\xbb\x05"
  "\xb6\x02\x81\x87\x02\xba\x05\xb4\x02\x81\x85\x02\xb9\x05\xb2\x02"
  "\x81\x87\x02\xb8\x05\xb0\x02\x81\x81\x02\xb7\x05\xae\x02\x81\x81"
  "\x02\xb6\x05\xac\x02\x81\x89\x02\xb5\x05\xaa\x02\x81\x85\x02\xb4"
  "\x05\xa8\x02\x84\x06\xb3\x05\xa6\x02\x81\x85\x02\xb2\x05\xa4\x02"
  "\x81\x81\x02\xb1\x05\xa2\x02\x81\x81\x02\xb0\x05\xa0\x02\x81\x89"
  "\x02\xaf\x05\x9e\x02\x81\x8d\x02\xae\x05\x9c\x02\x81\x89\x02\xad"
  "\x05\x9a\x02\x81\x83\x02\xac\x05\x98\x02\x81\x8b\x02\xab\x05\x96"
  "\x02\x81\x87\x02\xaa\x05\x94\x02\x81\x87\x02\xa9\x05\x92\x02\x81"
  "\x81\x02\xa8\x05\x90\x02\x81\x81\x02\xa7\x05\x8e\x02\x81\x89\x02"
  "\xa6\x05\x8c\x02\x81\x8f\x02\xa5\x05\x8a\x02\x81\x89\x02\xa4\x05"
  "\x88\x02\x81\x85\x02\xa3\x05\x86\x02\x81\x85\x02\xa2\x05\x84\x02"
  "\x81\x87\x02\xa1\x05\x82\x02\x81\x85\x02\xa0\x05\x80\x02\x81\x87"
  "\x02\x9f\x05\xfe\x01\x81\x81\x02\x9e\x05\xfc\x01\x81\x81\x02\x9d"
  "\x05\xfa\x01\x81\x89\x02\x9c\x05\xf8\x01\x81\x89\x02\x9b\x05\xf6"
  "\x01\x81\x83\x02\x9a\x05\xf4\x01\x81\x85\x02\x99\x05\xf2\x01\x81"
  "\x89\x02\x98\x05\xf0\x01\x81\x85\x02\x97\x05\xee\x01\x81\x89\x02"
  "\x96\x05\xec\x01\x81\x85\x02\x95\x05\xea\x01\x81\x87\x02\x94\x05"
  "\xe8\x01\x81\x81\x02\x93\x05\xe6\x01\x81\x81\x02\x92\x05\xe4\x01"
  "\x81\x83\x02\x91\x05\xe2\x01\x81\x89\x02\x90\x05\xe0\x01\x81\x89"
  "\x02\x8f\x05\xde\x01\x81\x89\x02\x8e\x05\xdc\x01\x81\x87\x02\x8d"
  "\x05\xda\x01\x81\x85\x02\x8c\x05\xd8\x01\x81\x85\x02\x8b\x05\xd6"
  "\x01\x81\x85\x02\x8a\x05\xd4\x01\x81\x85\x02\x89\x05\xd2\x01\x81"
  "\x85\x02\x88\x05\xd0\x01\x81\x81\x02\x87\x05\xce\x01\x81\x81\x02"
  "\x86\x05\xcc\x01\x81\x83\x02\x85\x05\xca\x01\x81\x87\x02\x84\x05"
  "\xc8\x01\x81\x89\x02\x83\x05\xc6\x01\x81\x89\x02\x82\x05\xc4\x01"
  "\x81\x87\x02\x81\x05\xc2\x01\x81\x85\x02\x80\x05\xc0\x01\x81\x89"
  "\x02\xff\x04\xbe\x01\x81\x85\x02\xfe\x04\xbc\x01\x84\x06\xfd\x04"
  "\xba\x01\x81\x81\x02\xfc\x04\xb8\x01\x81\x81\x02\xfb\x04\xb6\x01"
  "\x81\x85\x02\xfa\x04\xb4\x01\x81\x87\x02\xf9\x04\xb2\x01\x81\x85"
  "\x02\xf8\x04\xb0\x01\x81\x89\x02\xf7\x04\xae\x01\x81\x85\x02\xf6"
  "\x04\xac\x01\x81\x85\x02\xf5\x04\xaa\x01\x81\x87\x02\xf4\x04\xa8"
  "\x01\x81\x81\x02\xf3\x04\xa6\x01\x81\x81\x02\xf2\x04\xa4\x01\x81"
  "\x8d\x02\xf1\x04\xa2\x01\x81\x87\x02\xf0\x04\xa0\x01\x81\x85\x02"
  "\xef\x04\x9e\x01\x81\x87\x02\xee\x04\x9c\x01\x81\x89\x02\xed\x04"
  "\x9a\x01\x81\x85\x02\xec\x04\x98\x01\x81\x85\x02\xeb\x04\x96\x01"
  "\x84\x06\xea\x04\x94\x01\x81\x87\x02\xe9\x04\x92\x01\x81\x81\x02"
  "\xe8\x04\x90\x01\x81\x81\x02\xe7\x04\x8e\x01\x81\x87\x02\xe6\x04"
  "\x8c\x01\x81\x8b\x02\xe5\x04\x8a\x01\x81\x87\x02\xe4\x04\x88\x01"
  "\x81\x85\x02\xe3\x04\x86\x01\x84\x06\xe2\x04\x84\x01\x81\x87\x02"
  "\xe1\x04\x82\x01\x81\x81\x02\xe0\x04\x80\x01\x81\x81\x02\xdf\x04"
  "\x7e\x81\x8b\x02\xde\x04\x7c\x81\x87\x02\xdd\x04\x7a\x81\x87\x02"
  "\xdc\x04\x78\x84\x06\xdb\x04\x76\x81\x87\x02\xda\x04\x74\x81\x83"
  "\x02\xd9\x04\x72\x81\x83\x02\xd8\x04\x70\x81\x89\x02\xd7\x04\x6e"
  "\x81\x89\x02\xd6\x04\x6c\x81\x8f\x02\xd5\x04\x6a\x81\x89\x02\xd4"
  "\x04\x68\x81\x89\x02\xd3\x04\x66\x81\x87\x02\xd2\x04\x64\x81\x87"
  "\x02\xd1\x04\x62\x81\x89\x02\xd0\x04\x60\x81\x83\x02\xcf\x04\x5e"
  "\x81\x83\x02\xce\x04\x5c\x81\x87\x02\xcd\x04\x5a\x81\x89\x02\xcc"
  "\x04\x58\x81\x85\x02\xcb\x04\x56\x81\x87\x02\xca\x04\x54\x81\x89"
  "\x02\xc9\x04\x52\x81\x83\x02\xc8\x04\x50\x81\x83\x02\xc7\x04\x4e"
  "\x81\x87\x02\xc6\x04\x4c\x81\x89\x02\xc5\x04\x4a\x81\x85\x02\xc4"
  "\x04\x48\x81\x85\x02\xc3\x04\x46\x81\x89\x02\xc2\x04\x44\x81\x81"
  "\x02\xc1\x04\x42\x81\x85\x02\xc0\x04\x40\x84\x06\xbf\x04\x3e\x81"
  "\x81\x02\xbe\x04\x3c\x81\x81\x02\xbd\x04\x3a\x84\x06\xbc\x04\x38"
  "\x81\x87\x02\xbb\x04\x36\x81\x81\x02\xba\x04\x34\x81\x81\x02\xb9"
  "\x04\x32\x81\x87\x02\xb8\x04\x30\x81\x87\x02\xb7\x04\x2e\x81\x81"
  "\x02\xb6\x04\x2c\x81\x81\x02\xb5\x04\x2a\x81\x85\x02\xb4\x04\x28"
  "\x81\x87\x02\xb3\x04\x26\x81\x81\x02\xb2\x04\x24\x81\x81\x02\xb1"
  "\x04\x22\x84\x06\xb0\x04\x20\x81\x87\x02\xaf\x04\x1e\x81\x81\x02"
  "\xae\x04\x1c\x81\x81\x02\xad\x04\x1a\x81\x81\x02\xac\x04\x18\x81"
  "\x81\x02\xab\x04\x16\x81\x87\x02\xaa\x04\x14\x81\x81\x02\xa9\x04"
  "\x12\x81\x81\x02\xa8\x04\x10\x81\x81\x02\xa7\x04\x0e\x81\x81\x02"
  "\xa6\x04\x0c\x84\x06\xa5\x04\x0a\x81\x81\x02\xa4\x04\x08\x81\x81"
  "\x02\xa3\x04\x06\x81\x81\x02\xa2\x04\x04\x82\x02\xd3\x05\x90\x08"
  "\x83\x02\x02\x73\x08\x14\x6d\x61\x70\x2d\x65\x72\x72\x6f\x72\x20"
  "\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x6e\x6c\x02\x03\x85\x01\x05"
  "\x18\x05\xb5\x01\x03\x81\x01\x04\x17\x70\x72\x6f\x63\x65\x64\x75"
  "\x72\x65\x2d\x61\x72\x69\x74\x79\x2d\x76\x61\x6c\x69\x64\x3f\x06"
  "\x92\x07\x12\x81\x85\x02\x91\x07\x10\x81\x85\x02\x90\x07\x0e\x81"
  "\x8b\x02\x8f\x07\x0c\x81\x85\x02\x8e\x07\x0a\x81\x85\x02\x8d\x07"
  "\x08\x81\x89\x02\x8c\x07\x06\x81\x8b\x02\x8b\x07\x04\x84\x04\x11"
  "\x26\x85\x01\x02\x74\x01\x21\x26\x27\x02\x1c\x2a\x75\x6e\x70\x61"
  "\x72\x73\x65\x72\x2d\x6c\x69\x73\x74\x2d\x64\x65\x70\x74\x68\x2d"
  "\x6c\x69\x6d\x69\x74\x2a\x81\x01\x1e\x2a\x75\x6e\x70\x61\x72\x73"
  "\x65\x72\x2d\x6c\x69\x73\x74\x2d\x62\x72\x65\x61\x64\x74\x68\x2d"
  "\x6c\x69\x6d\x69\x74\x2a\x27\x03\x19\x65\x72\x72\x6f\x72\x2d\x69"
  "\x72\x72\x69\x74\x61\x6e\x74\x2f\x6e\x6f\x69\x73\x65\x2d\x74\x61"
  "\x67\x26\x81\x01\x27\x04\x05\x82\x01\x04\x09\x66\x6f\x72\x2d\x65"
  "\x61\x63\x68\x04\x08\x64\x69\x73\x70\x6c\x61\x79\x04\x0a\x04\x24"
  "\x06\xa5\x07\x28\x81\x85\x02\xa4\x07\x26\x81\x85\x02\xa3\x07\x24"
  "\x81\x87\x02\xa2\x07\x22\x81\x87\x02\xa1\x07\x20\x81\x85\x02\xa0"
  "\x07\x1e\x81\x85\x02\x9f\x07\x1c\x81\x87\x02\x9e\x07\x1a\x81\x85"
  "\x02\x9d\x07\x18\x81\x87\x02\x9c\x07\x16\x81\x85\x02\x9b\x07\x14"
  "\x81\x83\x02\x9a\x07\x12\x81\x87\x02\x99\x07\x10\x81\x85\x02\x98"
  "\x07\x0e\x81\x87\x02\x97\x07\x0c\x81\x85\x02\x96\x07\x0a\x81\x83"
  "\x02\x95\x07\x08\x81\x85\x02\x94\x07\x06\x81\x83\x02\x93\x07\x04"
  "\x85\x08\x27\x42\x82\x01\x02\x75\x26\x02\xa7\x07\x06\x81\x83\x02"
  "\xa6\x07\x04\x83\x04\x05\x0a\x81\x01\x02\x76\x06\x74\x69\x65\x74"
  "\x68\x04\x74\x79\x2d\x05\x6e\x69\x6e\x65\x05\x65\x69\x67\x68\x06"
  "\x73\x65\x76\x65\x6e\x04\x73\x69\x78\x04\x66\x69\x66\x04\x66\x6f"
  "\x72\x05\x74\x68\x69\x72\x05\x74\x77\x65\x6e\x5a\x06\x6e\x69\x6e"
  "\x74\x68\x07\x65\x69\x67\x68\x74\x68\x08\x73\x65\x76\x65\x6e\x74"
  "\x68\x06\x73\x69\x78\x74\x68\x06\x66\x69\x66\x74\x68\x07\x66\x6f"
  "\x75\x72\x74\x68\x06\x74\x68\x69\x72\x64\x07\x73\x65\x63\x6f\x6e"
  "\x64\x06\x66\x69\x72\x73\x74\x07\x7a\x65\x72\x6f\x74\x68\x0b\x0b"
  "\x6e\x69\x6e\x65\x74\x65\x65\x6e\x74\x68\x0b\x65\x69\x67\x68\x74"
  "\x65\x65\x6e\x74\x68\x0c\x73\x65\x76\x65\x6e\x74\x65\x65\x6e\x74"
  "\x68\x0a\x73\x69\x78\x74\x65\x65\x6e\x74\x68\x0a\x66\x69\x66\x74"
  "\x65\x65\x6e\x74\x68\x0b\x66\x6f\x75\x72\x74\x65\x65\x6e\x74\x68"
  "\x0b\x74\x68\x69\x72\x74\x65\x65\x6e\x74\x68\x08\x74\x77\x65\x6c"
  "\x66\x74\x68\x09\x65\x6c\x65\x76\x65\x6e\x74\x68\x06\x74\x65\x6e"
  "\x74\x68\x0b\x15\x0b\x1f\x65\x78\x61\x63\x74\x20\x69\x6e\x74\x65"
  "\x67\x65\x72\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x30\x20\x61\x6e"
  "\x64\x20\x39\x39\x81\x02\x65\x03\x4f\x05\x18\x04\x0f\x69\x6e\x74"
  "\x65\x67\x65\x72\x2d\x64\x69\x76\x69\x64\x65\x03\x18\x69\x6e\x74"
  "\x65\x67\x65\x72\x2d\x64\x69\x76\x69\x64\x65\x2d\x71\x75\x6f\x74"
  "\x69\x65\x6e\x74\x03\x19\x69\x6e\x74\x65\x67\x65\x72\x2d\x64\x69"
  "\x76\x69\x64\x65\x2d\x72\x65\x6d\x61\x69\x6e\x64\x65\x72\x04\x5d"
  "\x07\xb6\x07\x20\x81\x85\x02\xb5\x07\x1e\x81\x85\x02\xb4\x07\x1c"
  "\x81\x83\x02\xb3\x07\x1a\x81\x87\x02\xb2\x07\x18\x81\x83\x02\xb1"
  "\x07\x16\x81\x83\x02\xb0\x07\x14\x81\x83\x02\xaf\x07\x12\x81\x83"
  "\x02\xae\x07\x10\x81\x85\x02\xad\x07\x0e\x81\x83\x02\xac\x07\x0c"
  "\x81\x83\x02\xab\x07\x0a\x81\x83\x02\xaa\x07\x08\x81\x83\x02\xa9"
  "\x07\x06\x81\x83\x02\xa8\x07\x04\x83\x04\x1f\x3b\x5d\x02\x77\x03"
  "\x15\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x3f\x03\x19\x70\x72\x69\x6d\x69\x74\x69\x76\x65"
  "\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x6e\x61\x6d\x65\x04"
  "\x24\x04\xb9\x07\x08\x81\x85\x02\xb8\x07\x06\x81\x87\x02\xb7\x07"
  "\x04\x84\x06\x07\x11\x5a\x77\x4f\x4f\x4d\x5a\x04\x5d\x04\x15\x65"
  "\x72\x72\x6f\x72\x2d\x69\x72\x72\x69\x74\x61\x6e\x74\x2f\x6e\x6f"
  "\x69\x73\x65\x5d\x81\x01\x04\x82\x01\x04\x85\x01\x04\x83\x02\x04"
  "\x28\x04\xd3\x01\x04\xd2\x01\x04\xd0\x01\x04\xb3\x01\x04\xce\x01"
  "\x04\xcb\x01\x04\xc8\x01\x06\xc7\x01\x04\xc6\x01\x04\xc2\x01\x04"
  "\xbe\x01\x04\xba\x01\x04\x1b\x04\xb8\x01\x04\xb7\x01\x04\xb4\x01"
  "\x04\x4b\x04\xb0\x01\x04\xae\x01\x04\xac\x01\x04\xaa\x01\x04\xa8"
  "\x01\x04\xa7\x01\x04\xa5\x01\x04\xa2\x01\x04\xa1\x01\x06\x9f\x01"
  "\x04\x9e\x01\x04\x9a\x01\x04\x97\x01\x04\x93\x01\x04\x34\x04\x91"
  "\x01\x04\x36\x04\x90\x01\x04\x8e\x01\x04\x8c\x01\x04\x6d\x04\x89"
  "\x01\x04\x86\x01\x04\x83\x01\x0a\x7f\x04\x7e\x04\x7d\x04\x6f\x0b"
  "\x81\x02\x26\x5d\x80\x02\x6e\x14\x69\x6e\x69\x74\x69\x61\x6c\x69"
  "\x7a\x65\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x17\x25\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x65\x72\x72\x6f"
  "\x72\x3f\x12\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x65\x72"
  "\x72\x6f\x72\x3f\xd1\x01\x84\x01\x99\x01\xf7\x01\x18\x2d\xfc\x01"
  "\xfb\x01\xfe\x01\xfd\x01\xf9\x01\xdd\x01\xd4\x01\xda\x01\xa0\x01"
  "\xed\x01\xfa\x01\xf8\x01\x2a\xc3\x01\xbf\x01\xde\x01\xdf\x01\xe1"
  "\x01\xd8\x01\xee\x01\xef\x01\xf0\x01\xe8\x01\x9b\x01\xcc\x01\xd6"
  "\x01\xd9\x01\xe5\x01\xf6\x01\xe4\x01\xf1\x01\xe2\x01\x98\x01\xf5"
  "\x01\xf4\x01\xec\x01\xe6\x01\x6c\xf3\x01\xeb\x01\xe9\x01\xea\x01"
  "\x1d\xe3\x01\xe7\x01\xe0\x01\xf2\x01\xcf\x01\xcd\x01\xc9\x01\xbb"
  "\x01\xc4\x01\xc0\x01\xc1\x01\x05\x77\x61\x72\x6e\xdb\x01\xbc\x01"
  "\xff\x01\xbd\x01\x1a\x1c\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x68\x61\x6e\x64\x6c\x65"
  "\x72\xb5\x01\xb1\x01\xb9\x01\xb6\x01\xb2\x01\x5c\xaf\x01\xad\x01"
  "\xab\x01\xa9\x01\x9c\x01\xa6\x01\xa3\x01\xa4\x01\xca\x01\x4a\x92"
  "\x01\x96\x01\x95\x01\x94\x01\x13\x0d\x62\x69\x6e\x64\x2d\x72\x65"
  "\x73\x74\x61\x72\x74\x82\x02\x9d\x01\x8f\x01\x8d\x01\x8b\x01\x8a"
  "\x01\x87\x01\xc5\x01\x80\x01\x13\x67\x75\x61\x72\x61\x6e\x74\x65"
  "\x65\x2d\x72\x65\x73\x74\x61\x72\x74\x73\x7c\x88\x01\x6f\x23\x19"
  "\x73\x65\x74\x2d\x25\x72\x65\x73\x74\x61\x72\x74\x2f\x69\x6e\x74"
  "\x65\x72\x61\x63\x74\x6f\x72\x21\x14\x25\x72\x65\x73\x74\x61\x72"
  "\x74\x2f\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73\x14\x25\x72\x65"
  "\x73\x74\x61\x72\x74\x2f\x69\x6e\x74\x65\x72\x61\x63\x74\x6f\x72"
  "\x12\x25\x72\x65\x73\x74\x61\x72\x74\x2f\x65\x66\x66\x65\x63\x74"
  "\x6f\x72\x12\x25\x72\x65\x73\x74\x61\x72\x74\x2f\x72\x65\x70\x6f"
  "\x72\x74\x65\x72\x0e\x25\x72\x65\x73\x74\x61\x72\x74\x2f\x6e\x61"
  "\x6d\x65\x7b\x04\x7a\x04\x79\x04\x78\x04\x77\x04\x76\x04\x08\x72"
  "\x65\x73\x74\x61\x72\x74\xd5\x01\x09\x72\x65\x70\x6f\x72\x74\x65"
  "\x72\x83\x02\x09\x65\x66\x66\x65\x63\x74\x6f\x72\x0b\x69\x6e\x74"
  "\x65\x72\x61\x63\x74\x6f\x72\x0b\x70\x72\x6f\x70\x65\x72\x74\x69"
  "\x65\x73\x82\x02\x71\x04\x72\x04\x73\x04\x74\x04\x04\x0c\x72\x74"
  "\x64\x3a\x72\x65\x73\x74\x61\x72\x74\x81\x02\x08\x72\x65\x73\x74"
  "\x61\x72\x74\x75\x04\x43\x4e\x18\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2f\x72\x65\x70\x6f\x72\x74\x2d\x73\x74\x72\x69\x6e\x67\x6b"
  "\x0e\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x67\x65\x74\x0f\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x70\x75\x74\x21\x67\x66\x64"
  "\x62\x5f\x5b\x55\x57\x54\x13\x25\x72\x65\x73\x74\x61\x72\x74\x73"
  "\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x49\x4c\x50\x44\x60\x15\x70"
  "\x04\x6f\x04\x6a\x04\x69\x04\x68\x04\x30\x04\x65\x04\x63\x04\x61"
  "\x04\x5e\x04\x59\x04\x58\x04\x56\x04\x53\x04\x1f\x04\x52\x04\x48"
  "\x04\x46\x04\x45\x04\x15\x47\x16\x25\x63\x6f\x6e\x64\x69\x74\x69"
  "\x6f\x6e\x2f\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73\x18\x25\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x66\x69\x65\x6c\x64\x2d\x76"
  "\x61\x6c\x75\x65\x73\x14\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2f\x72\x65\x73\x74\x61\x72\x74\x73\x18\x25\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2f\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f"
  "\x6e\x10\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2f\x74\x79\x70"
  "\x65\x42\x04\x41\x04\x40\x04\x3f\x04\x3e\x04\x0a\x63\x6f\x6e\x64"
  "\x69\x74\x69\x6f\x6e\xd7\x01\x0d\x63\x6f\x6e\x74\x69\x6e\x75\x61"
  "\x74\x69\x6f\x6e\x09\x72\x65\x73\x74\x61\x72\x74\x73\x0d\x66\x69"
  "\x65\x6c\x64\x2d\x76\x61\x6c\x75\x65\x73\x82\x02\x38\x04\x39\x04"
  "\x3a\x04\x3b\x04\x3c\x04\x0e\x72\x74\x64\x3a\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x80\x02\x09\xdc\x01\x3d\x04\x15\x13\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x67\x65\x74\x14"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x70"
  "\x75\x74\x21\x32\x2f\x2c\x51\x21\x1e\x1a\x67\x75\x61\x72\x61\x6e"
  "\x74\x65\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79"
  "\x70\x65\x73\x16\x20\x0c\x37\x04\x35\x04\x33\x04\x31\x04\x2e\x04"
  "\x2b\x04\x29\x04\x25\x06\x1c\x04\x19\x04\x17\x04\x0c\x22\x25\x73"
  "\x65\x74\x2d\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79"
  "\x70\x65\x2f\x67\x65\x6e\x65\x72\x61\x6c\x69\x7a\x61\x74\x69\x6f"
  "\x6e\x73\x21\x1b\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74"
  "\x79\x70\x65\x2f\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73\x19\x25"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x72"
  "\x65\x70\x6f\x72\x74\x65\x72\x21\x25\x63\x6f\x6e\x64\x69\x74\x69"
  "\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x6e\x75\x6d\x62\x65\x72\x2d\x6f"
  "\x66\x2d\x66\x69\x65\x6c\x64\x73\x1e\x25\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x66\x69\x65\x6c\x64\x2d\x69"
  "\x6e\x64\x65\x78\x65\x73\x20\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2d\x74\x79\x70\x65\x2f\x67\x65\x6e\x65\x72\x61\x6c\x69\x7a"
  "\x61\x74\x69\x6f\x6e\x73\x15\x25\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x2d\x74\x79\x70\x65\x2f\x6e\x61\x6d\x65\x14\x04\x12\x04\x11"
  "\x04\x10\x04\x0f\x04\x0e\x04\x0d\x04\x0f\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\xd5\x01\x10\x67\x65\x6e\x65\x72"
  "\x61\x6c\x69\x7a\x61\x74\x69\x6f\x6e\x73\x0e\x66\x69\x65\x6c\x64"
  "\x2d\x69\x6e\x64\x65\x78\x65\x73\x11\x6e\x75\x6d\x62\x65\x72\x2d"
  "\x6f\x66\x2d\x66\x69\x65\x6c\x64\x73\x83\x02\x82\x02\x04\x04\x04"
  "\x04\x04\x04\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e"
  "\x6d\x65\x6e\x74\x13\x72\x74\x64\x3a\x63\x6f\x6e\x64\x69\x74\x69"
  "\x6f\x6e\x2d\x74\x79\x70\x65\x83\x02\x0f\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x2d\x74\x79\x70\x65\x0c\x04\x03\x19\x72\x65\x63\x6f"
  "\x72\x64\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61\x74\x63\x68"
  "\x2d\x74\x61\x67\x06\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63\x6f\x72"
  "\x64\x2d\x74\x79\x70\x65\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d"
  "\x75\x6c\x74\x69\x70\x6c\x65\x04\x23\x72\x65\x63\x6f\x72\x64\x2d"
  "\x74\x79\x70\x65\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d\x76\x61\x6c"
  "\x75\x65\x2d\x62\x79\x2d\x69\x6e\x64\x65\x78\x05\x83\x02\x80\x02"
  "\x81\x02\x04\x04\x19\x73\x74\x61\x6e\x64\x61\x72\x64\x2d\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x02\x32\x66"
  "\x80\x80\x04\x31\x64\x81\x81\x02\x30\x62\x81\x81\x02\x2f\x60\x81"
  "\x85\x02\x2e\x5e\x81\x85\x02\x2d\x5c\x81\x8b\x02\x2c\x5a\x81\x85"
  "\x02\x2b\x58\x81\x83\x02\x2a\x56\x81\x8f\x02\x29\x54\x81\x8b\x02"
  "\x28\x52\x81\x87\x02\x27\x50\x81\x83\x02\x26\x4e\x81\x85\x02\x25"
  "\x4c\x81\x83\x02\x24\x4a\x81\x87\x02\x23\x48\x81\x85\x02\x22\x46"
  "\x81\x87\x02\x21\x44\x81\x83\x02\x20\x42\x81\x85\x02\x1f\x40\x81"
  "\x85\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x8b\x02\x1c\x3a\x81\x85"
  "\x02\x1b\x38\x81\x83\x02\x1a\x36\x81\x8f\x02\x19\x34\x81\x8b\x02"
  "\x18\x32\x81\x87\x02\x17\x30\x81\x83\x02\x16\x2e\x81\x85\x02\x15"
  "\x2c\x81\x83\x02\x14\x2a\x81\x87\x02\x13\x28\x81\x85\x02\x12\x26"
  "\x81\x87\x02\x11\x24\x81\x83\x02\x10\x22\x81\x85\x02\x0f\x20\x81"
  "\x85\x02\x0e\x1e\x81\x83\x02\x0d\x1c\x81\x8b\x02\x0c\x1a\x81\x85"
  "\x02\x0b\x18\x81\x83\x02\x0a\x16\x81\x8f\x02\x09\x14\x81\x8b\x02"
  "\x08\x12\x81\x87\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x85\x02\x05"
  "\x0c\x81\x83\x02\x04\x0a\x81\x87\x02\x03\x08\x81\x85\x02\x02\x06"
  "\x81\x87\x02\x01\x04\x81\x83\x02\x65\xb2\x01";

SCHEME_OBJECT *
error_so_data_5fc8fc217ca49f46 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_error_so_data_5fc8fc217ca49f46 [0]))), (sizeof (prog_error_so_data_5fc8fc217ca49f46)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_64]));
}

DECLARE_COMPILED_DATA_NS ("error.so", error_so_data_5fc8fc217ca49f46)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("error.so", "fd2b198034ff0bfe")
