/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:56-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_7 7
#define LABEL_8 9
#define LABEL_9 11
#define LABEL_10 13
#define LABEL_12 15
#define LABEL_13 17
#define LABEL_25 19
#define LABEL_26 21
#define LABEL_15 23
#define LABEL_27 25
#define LABEL_28 27
#define LABEL_22 29
#define LABEL_23 31
#define TAG_24 14
#define LABEL_32 33
#define LABEL_20 35
#define TAG_21 16
#define LABEL_34 37
#define LABEL_35 39
#define LABEL_36 41
#define LABEL_18 43
#define TAG_19 20
#define LABEL_39 45
#define LABEL_40 47
#define LABEL_41 49
#define LABEL_42 51
#define LABEL_16 53
#define TAG_17 25
#define LABEL_46 55
#define LABEL_48 57
#define LABEL_49 59
#define LABEL_52 61
#define LABEL_53 63
#define LABEL_54 65
#define LABEL_55 67
#define LABEL_58 69
#define LABEL_61 71
#define LABEL_29 73
#define LABEL_30 75
#define LABEL_66 77
#define LABEL_31 79
#define LABEL_69 81
#define LABEL_37 83
#define LABEL_73 85
#define LABEL_74 87
#define LABEL_75 89
#define LABEL_77 91
#define LABEL_43 93
#define LABEL_45 95
#define LABEL_56 97
#define LABEL_84 99
#define LABEL_57 101
#define LABEL_59 103
#define LABEL_50 105
#define TAG_51 51
#define LABEL_62 107
#define LABEL_63 109
#define LABEL_64 111
#define LABEL_67 113
#define TAG_68 55
#define LABEL_89 115
#define LABEL_90 117
#define LABEL_91 119
#define LABEL_92 121
#define LABEL_93 123
#define LABEL_94 125
#define LABEL_95 127
#define LABEL_71 129
#define LABEL_72 131
#define LABEL_102 133
#define LABEL_103 135
#define LABEL_70 137
#define LABEL_76 139
#define LABEL_79 141
#define LABEL_104 143
#define LABEL_105 145
#define LABEL_106 147
#define LABEL_107 149
#define LABEL_110 151
#define LABEL_111 153
#define LABEL_112 155
#define LABEL_115 157
#define LABEL_117 159
#define LABEL_118 161
#define LABEL_119 163
#define LABEL_121 165
#define LABEL_80 167
#define LABEL_123 169
#define LABEL_124 171
#define LABEL_125 173
#define LABEL_81 175
#define LABEL_127 177
#define LABEL_82 179
#define LABEL_128 181
#define LABEL_129 183
#define LABEL_130 185
#define LABEL_131 187
#define LABEL_132 189
#define LABEL_135 191
#define LABEL_136 193
#define LABEL_86 195
#define LABEL_85 197
#define LABEL_139 199
#define LABEL_141 201
#define LABEL_142 203
#define LABEL_96 205
#define LABEL_145 207
#define LABEL_146 209
#define LABEL_98 211
#define LABEL_152 213
#define LABEL_99 215
#define LABEL_153 217
#define LABEL_100 219
#define LABEL_157 221
#define LABEL_158 223
#define LABEL_101 225
#define LABEL_161 227
#define LABEL_162 229
#define LABEL_163 231
#define LABEL_165 233
#define LABEL_166 235
#define LABEL_167 237
#define LABEL_168 239
#define LABEL_171 241
#define LABEL_172 243
#define LABEL_173 245
#define LABEL_174 247
#define LABEL_175 249
#define LABEL_176 251
#define LABEL_177 253
#define LABEL_178 255
#define LABEL_179 257
#define LABEL_180 259
#define LABEL_182 261
#define LABEL_183 263
#define LABEL_184 265
#define LABEL_185 267
#define LABEL_186 269
#define LABEL_187 271
#define LABEL_120 273
#define LABEL_113 275
#define LABEL_114 277
#define LABEL_108 279
#define LABEL_133 281
#define LABEL_137 283
#define LABEL_138 285
#define LABEL_140 287
#define LABEL_190 289
#define LABEL_143 291
#define LABEL_191 293
#define LABEL_192 295
#define LABEL_193 297
#define LABEL_195 299
#define LABEL_148 301
#define TAG_149 149
#define LABEL_150 303
#define LABEL_151 305
#define LABEL_201 307
#define LABEL_202 309
#define LABEL_154 311
#define LABEL_203 313
#define LABEL_156 315
#define LABEL_159 317
#define TAG_160 157
#define LABEL_209 319
#define LABEL_169 321
#define LABEL_213 323
#define LABEL_164 325
#define LABEL_215 327
#define LABEL_216 329
#define LABEL_217 331
#define LABEL_218 333
#define LABEL_219 335
#define LABEL_220 337
#define LABEL_221 339
#define LABEL_222 341
#define LABEL_181 343
#define LABEL_188 345
#define LABEL_227 347
#define LABEL_228 349
#define LABEL_229 351
#define LABEL_232 353
#define LABEL_189 355
#define LABEL_233 357
#define LABEL_234 359
#define LABEL_236 361
#define LABEL_237 363
#define LABEL_238 365
#define LABEL_194 367
#define LABEL_241 369
#define LABEL_196 371
#define TAG_197 184
#define LABEL_198 373
#define LABEL_204 375
#define TAG_205 186
#define LABEL_244 377
#define LABEL_206 379
#define LABEL_207 381
#define TAG_208 189
#define LABEL_246 383
#define LABEL_211 385
#define LABEL_214 387
#define LABEL_223 389
#define LABEL_225 391
#define LABEL_249 393
#define LABEL_250 395
#define LABEL_226 397
#define LABEL_230 399
#define LABEL_253 401
#define LABEL_231 403
#define LABEL_235 405
#define LABEL_258 407
#define LABEL_242 409
#define TAG_243 203
#define LABEL_259 411
#define LABEL_260 413
#define LABEL_261 415
#define LABEL_263 417
#define LABEL_264 419
#define LABEL_265 421
#define LABEL_270 423
#define LABEL_271 425
#define LABEL_245 427
#define LABEL_247 429
#define LABEL_272 431
#define LABEL_273 433
#define LABEL_248 435
#define LABEL_274 437
#define LABEL_251 439
#define LABEL_277 441
#define LABEL_254 443
#define LABEL_255 445
#define TAG_256 221
#define LABEL_280 447
#define LABEL_281 449
#define LABEL_284 451
#define LABEL_257 453
#define LABEL_285 455
#define LABEL_286 457
#define LABEL_287 459
#define LABEL_269 461
#define LABEL_290 463
#define LABEL_291 465
#define LABEL_292 467
#define LABEL_293 469
#define LABEL_289 471
#define LABEL_262 473
#define LABEL_266 475
#define LABEL_295 477
#define LABEL_267 479
#define TAG_268 238
#define LABEL_296 481
#define LABEL_297 483
#define LABEL_298 485
#define LABEL_275 487
#define LABEL_299 489
#define LABEL_276 491
#define LABEL_301 493
#define LABEL_278 495
#define LABEL_303 497
#define LABEL_304 499
#define LABEL_306 501
#define LABEL_307 503
#define LABEL_282 505
#define LABEL_283 507
#define LABEL_302 509
#define LABEL_308 511
#define LABEL_309 513
#define LABEL_305 515
#define LABEL_312 517
#define LABEL_313 519
#define ENVIRONMENT_LABEL_3 668
#define DEBUGGING_LABEL_2 667
#define OBJECT_55 666
#define OBJECT_54 665
#define OBJECT_53 664
#define OBJECT_52 663
#define OBJECT_51 662
#define OBJECT_50 661
#define OBJECT_49 660
#define OBJECT_48 659
#define OBJECT_47 658
#define OBJECT_46 657
#define OBJECT_45 656
#define OBJECT_44 655
#define OBJECT_43 654
#define OBJECT_42 653
#define OBJECT_41 652
#define OBJECT_40 651
#define OBJECT_39 650
#define OBJECT_38 649
#define OBJECT_37 648
#define OBJECT_36 647
#define OBJECT_35 646
#define OBJECT_34 645
#define OBJECT_33 644
#define OBJECT_32 643
#define OBJECT_31 642
#define OBJECT_30 641
#define OBJECT_29 640
#define OBJECT_28 639
#define OBJECT_27 638
#define OBJECT_26 637
#define OBJECT_25 636
#define OBJECT_24 635
#define OBJECT_23 634
#define OBJECT_22 633
#define OBJECT_21 632
#define OBJECT_20 631
#define OBJECT_19 630
#define OBJECT_18 629
#define OBJECT_17 628
#define OBJECT_16 627
#define OBJECT_15 626
#define OBJECT_14 625
#define OBJECT_13 624
#define OBJECT_12 623
#define OBJECT_11 622
#define OBJECT_10 621
#define OBJECT_9 620
#define OBJECT_8 619
#define OBJECT_7 618
#define OBJECT_6 617
#define OBJECT_5 616
#define OBJECT_4 615
#define OBJECT_3 614
#define OBJECT_2 613
#define OBJECT_1 612
#define OBJECT_0 611
#define EXECUTE_CACHE_311 521
#define EXECUTE_CACHE_310 523
#define EXECUTE_CACHE_300 525
#define EXECUTE_CACHE_294 527
#define EXECUTE_CACHE_288 529
#define EXECUTE_CACHE_279 531
#define EXECUTE_CACHE_252 533
#define EXECUTE_CACHE_240 535
#define EXECUTE_CACHE_239 537
#define EXECUTE_CACHE_224 539
#define EXECUTE_CACHE_212 541
#define EXECUTE_CACHE_210 543
#define EXECUTE_CACHE_200 545
#define EXECUTE_CACHE_199 547
#define EXECUTE_CACHE_170 549
#define EXECUTE_CACHE_155 551
#define EXECUTE_CACHE_147 553
#define EXECUTE_CACHE_144 555
#define EXECUTE_CACHE_134 557
#define EXECUTE_CACHE_126 559
#define EXECUTE_CACHE_122 561
#define EXECUTE_CACHE_116 563
#define EXECUTE_CACHE_109 565
#define EXECUTE_CACHE_97 567
#define EXECUTE_CACHE_88 569
#define EXECUTE_CACHE_87 571
#define EXECUTE_CACHE_83 573
#define EXECUTE_CACHE_78 575
#define EXECUTE_CACHE_65 577
#define EXECUTE_CACHE_60 579
#define EXECUTE_CACHE_47 581
#define EXECUTE_CACHE_44 583
#define EXECUTE_CACHE_38 585
#define EXECUTE_CACHE_33 587
#define EXECUTE_CACHE_14 589
#define EXECUTE_CACHE_11 591
#define FREE_REFERENCE_13 594
#define FREE_REFERENCE_12 595
#define FREE_REFERENCE_11 596
#define FREE_REFERENCE_10 597
#define FREE_REFERENCE_9 598
#define FREE_REFERENCE_8 599
#define FREE_REFERENCE_7 600
#define FREE_REFERENCE_6 601
#define FREE_REFERENCE_5 602
#define FREE_REFERENCE_4 603
#define FREE_REFERENCE_3 604
#define FREE_REFERENCE_2 605
#define FREE_REFERENCE_1 606
#define FREE_REFERENCE_0 607
#define GLOBAL_EXECUTE_CACHE_5 609
#define FREE_REFERENCES_LABEL_0 520
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
sideff_so_9f9fa6ea6f208bc8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd141;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd129;
  machine_word Wrd126;
  machine_word Wrd124;
  machine_word Wrd148;
  machine_word Wrd150;
  machine_word Wrd144;
  machine_word Wrd61;
  machine_word Wrd75;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd74;
  machine_word Wrd162;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd149;
  machine_word Wrd155;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd146;
  machine_word Wrd143;
  machine_word Wrd163;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd135;
  machine_word Wrd127;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd133;
  machine_word Wrd125;
  machine_word Wrd119;
  machine_word Wrd120;
  machine_word Wrd121;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd167;
  machine_word Wrd86;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd82;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd68;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd52;
  machine_word Wrd25;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd87;
  machine_word Wrd88;
  machine_word Wrd107;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto compute_call_graphB_3;

    case 3:
      current_block = (Rpc - LABEL_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto clear_call_graphB_8;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_12);
      goto continuation_56;

    case 7:
      current_block = (Rpc - LABEL_13);
      goto lambda_7;

    case 8:
      current_block = (Rpc - LABEL_25);
      goto label_350;

    case 9:
      current_block = (Rpc - LABEL_26);
      goto label_349;

    case 10:
      current_block = (Rpc - LABEL_15);
      goto find_memoize_calleesB_35;

    case 11:
      current_block = (Rpc - LABEL_27);
      goto label_351;

    case 12:
      current_block = (Rpc - LABEL_28);
      goto label_352;

    case 13:
      current_block = (Rpc - LABEL_22);
      goto continuation_68;

    case 14:
      current_block = (Rpc - LABEL_23);
      goto side_effect_analysis_494;

    case 15:
      current_block = (Rpc - LABEL_32);
      goto label_353;

    case 16:
      current_block = (Rpc - LABEL_20);
      goto analyze_procedureB_187;

    case 17:
      current_block = (Rpc - LABEL_34);
      goto label_354;

    case 18:
      current_block = (Rpc - LABEL_35);
      goto label_355;

    case 19:
      current_block = (Rpc - LABEL_36);
      goto label_356;

    case 20:
      current_block = (Rpc - LABEL_18);
      goto analyze_combinationB_287;

    case 21:
      current_block = (Rpc - LABEL_39);
      goto label_357;

    case 22:
      current_block = (Rpc - LABEL_40);
      goto label_358;

    case 23:
      current_block = (Rpc - LABEL_41);
      goto label_359;

    case 24:
      current_block = (Rpc - LABEL_42);
      goto label_360;

    case 25:
      current_block = (Rpc - LABEL_16);
      goto procedure_simplified_value_344;

    case 26:
      current_block = (Rpc - LABEL_46);
      goto label_361;

    case 27:
      current_block = (Rpc - LABEL_48);
      goto loop_33;

    case 28:
      current_block = (Rpc - LABEL_49);
      goto label_368;

    case 29:
      current_block = (Rpc - LABEL_52);
      goto label_362;

    case 30:
      current_block = (Rpc - LABEL_53);
      goto label_363;

    case 31:
      current_block = (Rpc - LABEL_54);
      goto label_365;

    case 32:
      current_block = (Rpc - LABEL_55);
      goto label_366;

    case 33:
      current_block = (Rpc - LABEL_58);
      goto label_367;

    case 34:
      current_block = (Rpc - LABEL_61);
      goto label_364;

    case 35:
      current_block = (Rpc - LABEL_29);
      goto continuation_71;

    case 36:
      current_block = (Rpc - LABEL_30);
      goto lambda_70;

    case 37:
      current_block = (Rpc - LABEL_66);
      goto value_test_generator_299;

    case 38:
      current_block = (Rpc - LABEL_31);
      goto continuation_57;

    case 39:
      current_block = (Rpc - LABEL_69);
      goto label_369;

    case 40:
      current_block = (Rpc - LABEL_37);
      goto continuation_172;

    case 41:
      current_block = (Rpc - LABEL_73);
      goto label_370;

    case 42:
      current_block = (Rpc - LABEL_74);
      goto label_371;

    case 43:
      current_block = (Rpc - LABEL_75);
      goto label_373;

    case 44:
      current_block = (Rpc - LABEL_77);
      goto label_372;

    case 45:
      current_block = (Rpc - LABEL_43);
      goto continuation_229;

    case 46:
      current_block = (Rpc - LABEL_45);
      goto continuation_331;

    case 47:
      current_block = (Rpc - LABEL_56);
      goto continuation_22;

    case 48:
      current_block = (Rpc - LABEL_84);
      goto label_374;

    case 49:
      current_block = (Rpc - LABEL_57);
      goto continuation_21;

    case 50:
      current_block = (Rpc - LABEL_59);
      goto continuation_20;

    case 51:
      current_block = (Rpc - LABEL_50);
      goto lambda_498;

    case 52:
      current_block = (Rpc - LABEL_62);
      goto continuation_73;

    case 53:
      current_block = (Rpc - LABEL_63);
      goto lambda_72;

    case 54:
      current_block = (Rpc - LABEL_64);
      goto continuation_69;

    case 55:
      current_block = (Rpc - LABEL_67);
      goto lambda_501;

    case 56:
      current_block = (Rpc - LABEL_89);
      goto label_375;

    case 57:
      current_block = (Rpc - LABEL_90);
      goto label_376;

    case 58:
      current_block = (Rpc - LABEL_91);
      goto label_381;

    case 59:
      current_block = (Rpc - LABEL_92);
      goto label_377;

    case 60:
      current_block = (Rpc - LABEL_93);
      goto label_378;

    case 61:
      current_block = (Rpc - LABEL_94);
      goto label_379;

    case 62:
      current_block = (Rpc - LABEL_95);
      goto label_380;

    case 63:
      current_block = (Rpc - LABEL_71);
      goto continuation_60;

    case 64:
      current_block = (Rpc - LABEL_72);
      goto setup_side_effectsB_97;

    case 65:
      current_block = (Rpc - LABEL_102);
      goto label_382;

    case 66:
      current_block = (Rpc - LABEL_103);
      goto label_383;

    case 67:
      current_block = (Rpc - LABEL_70);
      goto lambda_59;

    case 68:
      current_block = (Rpc - LABEL_76);
      goto continuation_189;

    case 69:
      current_block = (Rpc - LABEL_79);
      goto continuation_235;

    case 70:
      current_block = (Rpc - LABEL_104);
      goto label_384;

    case 71:
      current_block = (Rpc - LABEL_105);
      goto label_385;

    case 72:
      current_block = (Rpc - LABEL_106);
      goto label_390;

    case 73:
      current_block = (Rpc - LABEL_107);
      goto label_391;

    case 74:
      current_block = (Rpc - LABEL_110);
      goto label_392;

    case 75:
      current_block = (Rpc - LABEL_111);
      goto label_393;

    case 76:
      current_block = (Rpc - LABEL_112);
      goto label_394;

    case 77:
      current_block = (Rpc - LABEL_115);
      goto label_395;

    case 78:
      current_block = (Rpc - LABEL_117);
      goto label_386;

    case 79:
      current_block = (Rpc - LABEL_118);
      goto label_387;

    case 80:
      current_block = (Rpc - LABEL_119);
      goto label_388;

    case 81:
      current_block = (Rpc - LABEL_121);
      goto label_389;

    case 82:
      current_block = (Rpc - LABEL_80);
      goto lambda_234;

    case 83:
      current_block = (Rpc - LABEL_123);
      goto label_396;

    case 84:
      current_block = (Rpc - LABEL_124);
      goto label_397;

    case 85:
      current_block = (Rpc - LABEL_125);
      goto label_398;

    case 86:
      current_block = (Rpc - LABEL_81);
      goto continuation_230;

    case 87:
      current_block = (Rpc - LABEL_127);
      goto continuation_337;

    case 88:
      current_block = (Rpc - LABEL_82);
      goto continuation_332;

    case 89:
      current_block = (Rpc - LABEL_128);
      goto label_399;

    case 90:
      current_block = (Rpc - LABEL_129);
      goto label_400;

    case 91:
      current_block = (Rpc - LABEL_130);
      goto label_401;

    case 92:
      current_block = (Rpc - LABEL_131);
      goto label_402;

    case 93:
      current_block = (Rpc - LABEL_132);
      goto label_403;

    case 94:
      current_block = (Rpc - LABEL_135);
      goto continuation_26;

    case 95:
      current_block = (Rpc - LABEL_136);
      goto label_424;

    case 96:
      current_block = (Rpc - LABEL_86);
      goto continuation_24;

    case 97:
      current_block = (Rpc - LABEL_85);
      goto continuation_25;

    case 98:
      current_block = (Rpc - LABEL_139);
      goto label_404;

    case 99:
      current_block = (Rpc - LABEL_141);
      goto add_caller_calleeB_54;

    case 100:
      current_block = (Rpc - LABEL_142);
      goto label_405;

    case 101:
      current_block = (Rpc - LABEL_96);
      goto continuation_294;

    case 102:
      current_block = (Rpc - LABEL_145);
      goto label_406;

    case 103:
      current_block = (Rpc - LABEL_146);
      goto label_407;

    case 104:
      current_block = (Rpc - LABEL_98);
      goto continuation_61;

    case 105:
      current_block = (Rpc - LABEL_152);
      goto label_408;

    case 106:
      current_block = (Rpc - LABEL_99);
      goto compute_side_effectsB_167;

    case 107:
      current_block = (Rpc - LABEL_153);
      goto label_409;

    case 108:
      current_block = (Rpc - LABEL_100);
      goto continuation_88;

    case 109:
      current_block = (Rpc - LABEL_157);
      goto label_410;

    case 110:
      current_block = (Rpc - LABEL_158);
      goto label_411;

    case 111:
      current_block = (Rpc - LABEL_101);
      goto lambda_87;

    case 112:
      current_block = (Rpc - LABEL_161);
      goto label_412;

    case 113:
      current_block = (Rpc - LABEL_162);
      goto label_413;

    case 114:
      current_block = (Rpc - LABEL_163);
      goto label_418;

    case 115:
      current_block = (Rpc - LABEL_165);
      goto label_414;

    case 116:
      current_block = (Rpc - LABEL_166);
      goto label_415;

    case 117:
      current_block = (Rpc - LABEL_167);
      goto label_416;

    case 118:
      current_block = (Rpc - LABEL_168);
      goto label_417;

    case 119:
      current_block = (Rpc - LABEL_171);
      goto continuation_215;

    case 120:
      current_block = (Rpc - LABEL_172);
      goto label_467;

    case 121:
      current_block = (Rpc - LABEL_173);
      goto compare_222;

    case 122:
      current_block = (Rpc - LABEL_174);
      goto label_452;

    case 123:
      current_block = (Rpc - LABEL_175);
      goto label_453;

    case 124:
      current_block = (Rpc - LABEL_176);
      goto label_454;

    case 125:
      current_block = (Rpc - LABEL_177);
      goto label_451;

    case 126:
      current_block = (Rpc - LABEL_178);
      goto continuation_193;

    case 127:
      current_block = (Rpc - LABEL_179);
      goto label_432;

    case 128:
      current_block = (Rpc - LABEL_180);
      goto find_200;

    case 129:
      current_block = (Rpc - LABEL_182);
      goto label_423;

    case 130:
      current_block = (Rpc - LABEL_183);
      goto label_420;

    case 131:
      current_block = (Rpc - LABEL_184);
      goto label_421;

    case 132:
      current_block = (Rpc - LABEL_185);
      goto label_422;

    case 133:
      current_block = (Rpc - LABEL_186);
      goto label_419;

    case 134:
      current_block = (Rpc - LABEL_187);
      goto check_operators_286;

    case 135:
      current_block = (Rpc - LABEL_120);
      goto continuation_241;

    case 136:
      current_block = (Rpc - LABEL_113);
      goto continuation_251;

    case 137:
      current_block = (Rpc - LABEL_114);
      goto continuation_250;

    case 138:
      current_block = (Rpc - LABEL_108);
      goto continuation_253;

    case 139:
      current_block = (Rpc - LABEL_133);
      goto continuation_341;

    case 140:
      current_block = (Rpc - LABEL_137);
      goto continuation_30;

    case 141:
      current_block = (Rpc - LABEL_138);
      goto continuation_29;

    case 142:
      current_block = (Rpc - LABEL_140);
      goto continuation_28;

    case 143:
      current_block = (Rpc - LABEL_190);
      goto continuation_52;

    case 144:
      current_block = (Rpc - LABEL_143);
      goto continuation_41;

    case 145:
      current_block = (Rpc - LABEL_191);
      goto label_428;

    case 146:
      current_block = (Rpc - LABEL_192);
      goto label_425;

    case 147:
      current_block = (Rpc - LABEL_193);
      goto label_427;

    case 148:
      current_block = (Rpc - LABEL_195);
      goto label_426;

    case 149:
      current_block = (Rpc - LABEL_148);
      goto lambda_507;

    case 150:
      current_block = (Rpc - LABEL_150);
      goto continuation_65;

    case 151:
      current_block = (Rpc - LABEL_151);
      goto continuation_64;

    case 152:
      current_block = (Rpc - LABEL_201);
      goto continuation_164;

    case 153:
      current_block = (Rpc - LABEL_202);
      goto label_448;

    case 154:
      current_block = (Rpc - LABEL_154);
      goto continuation_131;

    case 155:
      current_block = (Rpc - LABEL_203);
      goto label_429;

    case 156:
      current_block = (Rpc - LABEL_156);
      goto continuation_75;

    case 157:
      current_block = (Rpc - LABEL_159);
      goto lambda_509;

    case 158:
      current_block = (Rpc - LABEL_209);
      goto label_430;

    case 159:
      current_block = (Rpc - LABEL_169);
      goto continuation_111;

    case 160:
      current_block = (Rpc - LABEL_213);
      goto label_431;

    case 161:
      current_block = (Rpc - LABEL_164);
      goto continuation_99;

    case 162:
      current_block = (Rpc - LABEL_215);
      goto test_return_212;

    case 163:
      current_block = (Rpc - LABEL_216);
      goto label_433;

    case 164:
      current_block = (Rpc - LABEL_217);
      goto label_434;

    case 165:
      current_block = (Rpc - LABEL_218);
      goto label_435;

    case 166:
      current_block = (Rpc - LABEL_219);
      goto label_436;

    case 167:
      current_block = (Rpc - LABEL_220);
      goto label_437;

    case 168:
      current_block = (Rpc - LABEL_221);
      goto label_438;

    case 169:
      current_block = (Rpc - LABEL_222);
      goto label_439;

    case 170:
      current_block = (Rpc - LABEL_181);
      goto continuation_178;

    case 171:
      current_block = (Rpc - LABEL_188);
      goto continuation_275;

    case 172:
      current_block = (Rpc - LABEL_227);
      goto label_440;

    case 173:
      current_block = (Rpc - LABEL_228);
      goto label_441;

    case 174:
      current_block = (Rpc - LABEL_229);
      goto label_442;

    case 175:
      current_block = (Rpc - LABEL_232);
      goto label_443;

    case 176:
      current_block = (Rpc - LABEL_189);
      goto continuation_243;

    case 177:
      current_block = (Rpc - LABEL_233);
      goto continuation_257;

    case 178:
      current_block = (Rpc - LABEL_234);
      goto simplify_combinationB_266;

    case 179:
      current_block = (Rpc - LABEL_236);
      goto label_444;

    case 180:
      current_block = (Rpc - LABEL_237);
      goto label_445;

    case 181:
      current_block = (Rpc - LABEL_238);
      goto label_446;

    case 182:
      current_block = (Rpc - LABEL_194);
      goto continuation_49;

    case 183:
      current_block = (Rpc - LABEL_241);
      goto label_447;

    case 184:
      current_block = (Rpc - LABEL_196);
      goto lambda_514;

    case 185:
      current_block = (Rpc - LABEL_198);
      goto continuation_62;

    case 186:
      current_block = (Rpc - LABEL_204);
      goto lambda_515;

    case 187:
      current_block = (Rpc - LABEL_244);
      goto label_449;

    case 188:
      current_block = (Rpc - LABEL_206);
      goto continuation_95;

    case 189:
      current_block = (Rpc - LABEL_207);
      goto lambda_516;

    case 190:
      current_block = (Rpc - LABEL_246);
      goto label_450;

    case 191:
      current_block = (Rpc - LABEL_211);
      goto continuation_112;

    case 192:
      current_block = (Rpc - LABEL_214);
      goto continuation_100;

    case 193:
      current_block = (Rpc - LABEL_223);
      goto continuation_204;

    case 194:
      current_block = (Rpc - LABEL_225);
      goto continuation_179;

    case 195:
      current_block = (Rpc - LABEL_249);
      goto label_455;

    case 196:
      current_block = (Rpc - LABEL_250);
      goto continuation_312;

    case 197:
      current_block = (Rpc - LABEL_226);
      goto continuation_311;

    case 198:
      current_block = (Rpc - LABEL_230);
      goto continuation_282;

    case 199:
      current_block = (Rpc - LABEL_253);
      goto label_456;

    case 200:
      current_block = (Rpc - LABEL_231);
      goto continuation_281;

    case 201:
      current_block = (Rpc - LABEL_235);
      goto continuation_259;

    case 202:
      current_block = (Rpc - LABEL_258);
      goto label_457;

    case 203:
      current_block = (Rpc - LABEL_242);
      goto lambda_519;

    case 204:
      current_block = (Rpc - LABEL_259);
      goto dispatch_loop_160;

    case 205:
      current_block = (Rpc - LABEL_260);
      goto label_458;

    case 206:
      current_block = (Rpc - LABEL_261);
      goto label_459;

    case 207:
      current_block = (Rpc - LABEL_263);
      goto label_462;

    case 208:
      current_block = (Rpc - LABEL_264);
      goto label_463;

    case 209:
      current_block = (Rpc - LABEL_265);
      goto label_464;

    case 210:
      current_block = (Rpc - LABEL_270);
      goto label_460;

    case 211:
      current_block = (Rpc - LABEL_271);
      goto label_461;

    case 212:
      current_block = (Rpc - LABEL_245);
      goto continuation_79;

    case 213:
      current_block = (Rpc - LABEL_247);
      goto continuation_101;

    case 214:
      current_block = (Rpc - LABEL_272);
      goto label_465;

    case 215:
      current_block = (Rpc - LABEL_273);
      goto label_466;

    case 216:
      current_block = (Rpc - LABEL_248);
      goto continuation_181;

    case 217:
      current_block = (Rpc - LABEL_274);
      goto label_468;

    case 218:
      current_block = (Rpc - LABEL_251);
      goto continuation_313;

    case 219:
      current_block = (Rpc - LABEL_277);
      goto label_469;

    case 220:
      current_block = (Rpc - LABEL_254);
      goto continuation_273;

    case 221:
      current_block = (Rpc - LABEL_255);
      goto lambda_520;

    case 222:
      current_block = (Rpc - LABEL_280);
      goto label_470;

    case 223:
      current_block = (Rpc - LABEL_281);
      goto label_471;

    case 224:
      current_block = (Rpc - LABEL_284);
      goto label_472;

    case 225:
      current_block = (Rpc - LABEL_257);
      goto continuation_261;

    case 226:
      current_block = (Rpc - LABEL_285);
      goto label_473;

    case 227:
      current_block = (Rpc - LABEL_286);
      goto label_474;

    case 228:
      current_block = (Rpc - LABEL_287);
      goto label_475;

    case 229:
      current_block = (Rpc - LABEL_269);
      goto continuation_146;

    case 230:
      current_block = (Rpc - LABEL_290);
      goto continuation_124;

    case 231:
      current_block = (Rpc - LABEL_291);
      goto label_487;

    case 232:
      current_block = (Rpc - LABEL_292);
      goto continuation_121;

    case 233:
      current_block = (Rpc - LABEL_293);
      goto label_484;

    case 234:
      current_block = (Rpc - LABEL_289);
      goto continuation_147;

    case 235:
      current_block = (Rpc - LABEL_262);
      goto continuation_153;

    case 236:
      current_block = (Rpc - LABEL_266);
      goto continuation_119;

    case 237:
      current_block = (Rpc - LABEL_295);
      goto label_476;

    case 238:
      current_block = (Rpc - LABEL_267);
      goto lambda_522;

    case 239:
      current_block = (Rpc - LABEL_296);
      goto label_478;

    case 240:
      current_block = (Rpc - LABEL_297);
      goto label_477;

    case 241:
      current_block = (Rpc - LABEL_298);
      goto continuation_306;

    case 242:
      current_block = (Rpc - LABEL_275);
      goto continuation_183;

    case 243:
      current_block = (Rpc - LABEL_299);
      goto label_479;

    case 244:
      current_block = (Rpc - LABEL_276);
      goto continuation_303;

    case 245:
      current_block = (Rpc - LABEL_301);
      goto continuation_321;

    case 246:
      current_block = (Rpc - LABEL_278);
      goto continuation_315;

    case 247:
      current_block = (Rpc - LABEL_303);
      goto label_480;

    case 248:
      current_block = (Rpc - LABEL_304);
      goto label_481;

    case 249:
      current_block = (Rpc - LABEL_306);
      goto label_482;

    case 250:
      current_block = (Rpc - LABEL_307);
      goto label_483;

    case 251:
      current_block = (Rpc - LABEL_282);
      goto continuation_271;

    case 252:
      current_block = (Rpc - LABEL_283);
      goto continuation_270;

    case 253:
      current_block = (Rpc - LABEL_302);
      goto continuation_323;

    case 254:
      current_block = (Rpc - LABEL_308);
      goto label_485;

    case 255:
      current_block = (Rpc - LABEL_309);
      goto label_486;

    case 256:
      current_block = (Rpc - LABEL_305);
      goto continuation_318;

    case 257:
      current_block = (Rpc - LABEL_312);
      goto label_523;

    case 258:
      current_block = (Rpc - LABEL_313);
      goto expression_348;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_348)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_312])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_523)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 3);

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_12);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16])));
  Rhp += 1;
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd45.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18])));
  Rhp += 2;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd45.pObj)));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd43.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_20])));
  Rhp += 2;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  Wrd32 = Wrd43;
  ((Wrd32.pObj) [2]) = (Wrd7.Obj);
  ((Wrd32.pObj) [3]) = (Wrd13.Obj);
  Wrd38 = Wrd45;
  ((Wrd38.pObj) [2]) = (Wrd48.Obj);
  ((Wrd38.pObj) [3]) = (Wrd7.Obj);
  ((Wrd47.pObj) [2]) = (Wrd7.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd21.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_24);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23])));
  Rhp += 2;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd21.pObj)));
  Wrd24 = Wrd21;
  ((Wrd24.pObj) [2]) = (Wrd46.Obj);
  ((Wrd24.pObj) [3]) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd9.Obj);
  goto value_test_generator_299;

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd6.Obj) = (Rsp [3]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd12.Obj);
  goto value_test_generator_299;

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_62);
  (Wrd6.Obj) = (Rsp [4]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (compute_call_graphB_489)
DEFLABEL (compute_call_graphB_3)
  INTERRUPT_CHECK (26, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (clear_call_graphB_490)
DEFLABEL (clear_call_graphB_8)
  INTERRUPT_CHECK (26, LABEL_9);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (lambda_495)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_13);
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_529;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd46.Lng))))
    goto label_529;
  (Wrd40.Obj) = (current_block [OBJECT_7]);
  ((Wrd44.pObj) [24]) = (Wrd40.Obj);

DEFLABEL (label_528)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_527;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 24L) < ((unsigned long) (Wrd29.Lng))))
    goto label_527;
  (Wrd23.Obj) = (current_block [OBJECT_7]);
  ((Wrd27.pObj) [25]) = (Wrd23.Obj);

DEFLABEL (label_526)
  (Wrd5.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_7]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_525;

DEFLABEL (label_524)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_525)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd18.Lng))))
    goto label_524;
  ((Wrd16.pObj) [26]) = (Wrd7.Obj);
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_527)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (current_block [OBJECT_10]);
  (Wrd34.Obj) = (current_block [OBJECT_7]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_349)
  goto label_526;

DEFLABEL (label_529)
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.Obj) = (current_block [OBJECT_8]);
  (Wrd51.Obj) = (current_block [OBJECT_7]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_350)
  goto label_528;

DEFLABEL (find_memoize_calleesB_496)
DEFLABEL (find_memoize_calleesB_35)
  INTERRUPT_CHECK (26, LABEL_15);
  (Wrd5.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_533;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_533;
  (Wrd7.Obj) = ((Wrd13.pObj) [4]);

DEFLABEL (label_532)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 10))
    goto label_531;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd29.Lng))))
    goto label_531;
  (Wrd24.Obj) = ((Wrd27.pObj) [13]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_530)
  goto loop_33;

DEFLABEL (label_531)
  (Wrd32.Obj) = (current_block [OBJECT_15]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_352)
  (* (--Rsp)) = Rvl;
  goto label_530;

DEFLABEL (label_533)
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (current_block [OBJECT_13]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_351)
  (Wrd7.Obj) = Rvl;
  goto label_532;

DEFLABEL (side_effect_analysis_494)
  CLOSURE_HEADER (LABEL_23);

DEFLABEL (side_effect_analysis_67)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_540;
  Wrd8 = Wrd12;

DEFLABEL (label_539)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_31);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_538;
  Wrd5 = Wrd9;

DEFLABEL (label_537)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_534;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (Rsp [2]) = (Wrd18.Obj);
  (Wrd20.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd20.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (label_534)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_71);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_98);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_149);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_148])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_536;
  Wrd22 = Wrd26;

DEFLABEL (label_535)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd28.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88]));

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_151);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_200]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_150);
  (Rsp [3]) = Rvl;
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_199]));

DEFLABEL (label_536)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_152])), (Wrd23.pObj));

DEFLABEL (label_408)
  (Wrd22.Obj) = Rvl;
  goto label_535;

DEFLABEL (label_538)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69])), (Wrd6.pObj));

DEFLABEL (label_369)
  (Wrd5.Obj) = Rvl;
  goto label_537;

DEFLABEL (label_540)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32])), (Wrd9.pObj));

DEFLABEL (label_353)
  (Wrd8.Obj) = Rvl;
  goto label_539;

DEFLABEL (analyze_procedureB_493)
DEFLABEL (analyze_procedureB_187)
  INTERRUPT_CHECK (26, LABEL_20);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_558;
  Wrd5 = Wrd9;

DEFLABEL (label_557)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_556;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_556;
  (Wrd11.Obj) = ((Wrd17.pObj) [3]);

DEFLABEL (label_555)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_542;

DEFLABEL (label_541)
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_542)
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_554;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd38.Lng))))
    goto label_554;
  (Wrd30.Obj) = ((Wrd36.pObj) [29]);

DEFLABEL (label_553)
  if (! ((Wrd30.Obj) == (current_block [OBJECT_7])))
    goto label_541;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38]));

DEFLABEL (continuation_172)
  INTERRUPT_CHECK (27, LABEL_37);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_543;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_543)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_552;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_552;
  (Wrd9.Obj) = ((Wrd15.pObj) [6]);

DEFLABEL (label_551)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_550;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_549)
  (Wrd66.Obj) = (Rsp [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_548;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd65.Lng))))
    goto label_548;
  (Wrd34.Obj) = ((Wrd63.pObj) [13]);
  if ((Wrd34.Obj) == ((SCHEME_OBJECT) 0))
    goto label_545;

DEFLABEL (label_544)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_545)
  (Wrd36.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_547;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd49.Lng))))
    goto label_547;
  (Wrd43.Obj) = ((Wrd47.pObj) [6]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_546)
  (Wrd57.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78]));

DEFLABEL (continuation_189)
  INTERRUPT_CHECK (27, LABEL_76);
  (Rsp [1]) = Rvl;
  goto find_200;

DEFLABEL (label_547)
  (Wrd52.Obj) = (Rsp [2]);
  (Wrd53.Obj) = (current_block [OBJECT_19]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_372)
  (* (--Rsp)) = Rvl;
  goto label_546;

DEFLABEL (label_548)
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.Obj) = (current_block [OBJECT_15]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_373)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_545;
  goto label_544;

DEFLABEL (label_550)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_371)
  (* (--Rsp)) = Rvl;
  goto label_549;

DEFLABEL (label_552)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_19]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_370)
  (Wrd9.Obj) = Rvl;
  goto label_551;

DEFLABEL (label_554)
  (Wrd41.Obj) = (Rsp [1]);
  (Wrd42.Obj) = (current_block [OBJECT_17]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_356)
  (Wrd30.Obj) = Rvl;
  goto label_553;

DEFLABEL (label_556)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_16]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_355)
  (Wrd11.Obj) = Rvl;
  goto label_555;

DEFLABEL (label_558)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34])), (Wrd6.pObj));

DEFLABEL (label_354)
  (Wrd5.Obj) = Rvl;
  goto label_557;

DEFLABEL (analyze_combinationB_492)
DEFLABEL (analyze_combinationB_287)
  INTERRUPT_CHECK (26, LABEL_18);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_599;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd13.Lng))))
    goto label_599;
  (Wrd5.Obj) = ((Wrd11.pObj) [6]);

DEFLABEL (label_598)
  if ((Wrd5.Obj) == (current_block [OBJECT_20]))
    goto label_559;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_559)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_597;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd32.Lng))))
    goto label_597;
  (Wrd24.Obj) = ((Wrd30.pObj) [9]);

DEFLABEL (label_596)
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_595;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_594)
  (Wrd56.Obj) = (Rsp [2]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 10))
    goto label_593;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [0]);
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd54.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd55.Lng))))
    goto label_593;
  (Wrd49.Obj) = ((Wrd53.pObj) [8]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_592)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (Wrd66.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd66.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44]));

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_43);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_560;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_560)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));

DEFLABEL (continuation_230)
  INTERRUPT_CHECK (27, LABEL_81);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126]));

DEFLABEL (continuation_235)
  INTERRUPT_CHECK (27, LABEL_79);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_561;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_561)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_591;
  Wrd7 = Wrd11;

DEFLABEL (label_590)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_589;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_589;
  (Wrd13.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_588)
  (Wrd29.Obj) = (* (Rsp++));
  if ((Wrd13.Obj) == (Wrd29.Obj))
    goto label_572;
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_571;
  Wrd30 = Wrd34;

DEFLABEL (label_570)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_569;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd44.Lng))))
    goto label_569;
  (Wrd36.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_568)
  (Wrd52.Obj) = (* (Rsp++));
  if ((Wrd36.Obj) == (Wrd52.Obj))
    goto label_562;
  (Wrd53.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd53.Obj);
  Rsp = (& (Rsp [1]));
  goto check_operators_286;

DEFLABEL (label_562)
  (Wrd56.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd59.Obj) = ((Wrd56.pObj) [0]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if ((Wrd60.uLng) == 50)
    goto label_567;
  Wrd55 = Wrd59;

DEFLABEL (label_566)
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd73.Obj) = (Rsp [3]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 10))
    goto label_565;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd71.Obj) = ((Wrd70.pObj) [0]);
  (Wrd72.Lng) = (FIXNUM_TO_LONG (Wrd71.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd72.Lng))))
    goto label_565;
  (Wrd66.Obj) = ((Wrd70.pObj) [4]);
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_564)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122]));

DEFLABEL (continuation_241)
  INTERRUPT_CHECK (27, LABEL_120);
  (Wrd5.Obj) = (* (Rsp++));
  if (Rvl == (Wrd5.Obj))
    goto label_563;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto check_operators_286;

DEFLABEL (label_563)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109]));

DEFLABEL (continuation_243)
  INTERRUPT_CHECK (27, LABEL_189);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto simplify_combinationB_266;

DEFLABEL (label_565)
  (Wrd75.Obj) = (Rsp [3]);
  (Wrd76.Obj) = (current_block [OBJECT_13]);
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_389)
  (* (--Rsp)) = Rvl;
  goto label_564;

DEFLABEL (label_567)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_119])), (Wrd56.pObj));

DEFLABEL (label_388)
  (Wrd55.Obj) = Rvl;
  goto label_566;

DEFLABEL (label_569)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.Obj) = (current_block [OBJECT_27]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_387)
  (Wrd36.Obj) = Rvl;
  goto label_568;

DEFLABEL (label_571)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_117])), (Wrd31.pObj));

DEFLABEL (label_386)
  (Wrd30.Obj) = Rvl;
  goto label_570;

DEFLABEL (label_572)
  (Wrd81.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd84.Obj) = ((Wrd81.pObj) [0]);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd84.Obj));
  if ((Wrd85.uLng) == 50)
    goto label_587;
  Wrd80 = Wrd84;

DEFLABEL (label_586)
  (* (--Rsp)) = (Wrd80.Obj);
  (Wrd95.Obj) = (Rsp [2]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_585;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd94.Lng))))
    goto label_585;
  (Wrd86.Obj) = ((Wrd92.pObj) [3]);

DEFLABEL (label_584)
  (Wrd102.Obj) = (* (Rsp++));
  if (! ((Wrd86.Obj) == (Wrd102.Obj)))
    goto label_573;
  (Wrd167.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd167.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109]));

DEFLABEL (continuation_253)
  INTERRUPT_CHECK (27, LABEL_108);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto simplify_combinationB_266;

DEFLABEL (label_573)
  (Wrd112.Obj) = (Rsp [1]);
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd112.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_583;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd110.Obj) = ((Wrd109.pObj) [0]);
  (Wrd111.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd111.Lng))))
    goto label_583;
  (Wrd103.Obj) = ((Wrd109.pObj) [12]);

DEFLABEL (label_582)
  (Wrd121.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd121.uLng) == 1))
    goto label_581;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd119.Obj) = ((Wrd120.pObj) [0]);

DEFLABEL (label_580)
  (Wrd133.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if (! ((Wrd133.uLng) == 10))
    goto label_579;
  (Wrd130.pObj) = (OBJECT_ADDRESS (Wrd119.Obj));
  (Wrd131.Obj) = ((Wrd130.pObj) [0]);
  (Wrd132.Lng) = (FIXNUM_TO_LONG (Wrd131.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd132.Lng))))
    goto label_579;
  (Wrd127.Obj) = ((Wrd130.pObj) [10]);
  (* (--Rsp)) = (Wrd127.Obj);

DEFLABEL (label_578)
  (Wrd139.Obj) = (Rsp [0]);
  if (! ((Wrd139.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_574;
  (Wrd163.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd163.Obj);
  Rsp = (& (Rsp [2]));
  goto check_operators_286;

DEFLABEL (label_574)
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd143.Obj);
  (Wrd146.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd146.Obj);
  (Wrd156.Obj) = (Rsp [6]);
  (Wrd157.uLng) = (OBJECT_TYPE (Wrd156.Obj));
  if (! ((Wrd157.uLng) == 10))
    goto label_577;
  (Wrd153.pObj) = (OBJECT_ADDRESS (Wrd156.Obj));
  (Wrd154.Obj) = ((Wrd153.pObj) [0]);
  (Wrd155.Lng) = (FIXNUM_TO_LONG (Wrd154.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd155.Lng))))
    goto label_577;
  (Wrd149.Obj) = ((Wrd153.pObj) [7]);
  (* (--Rsp)) = (Wrd149.Obj);

DEFLABEL (label_576)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_250)
  INTERRUPT_CHECK (27, LABEL_114);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [6]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_251)
  INTERRUPT_CHECK (27, LABEL_113);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_575;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto simplify_combinationB_266;

DEFLABEL (label_575)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_577)
  (Wrd158.Obj) = (Rsp [6]);
  (Wrd159.Obj) = (current_block [OBJECT_32]);
  (Wrd162.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd159.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_395)
  (* (--Rsp)) = Rvl;
  goto label_576;

DEFLABEL (label_579)
  (Wrd135.Obj) = (current_block [OBJECT_31]);
  (Wrd138.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd138.Obj);
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_394)
  (* (--Rsp)) = Rvl;
  goto label_578;

DEFLABEL (label_581)
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_393)
  (Wrd119.Obj) = Rvl;
  goto label_580;

DEFLABEL (label_583)
  (Wrd114.Obj) = (Rsp [1]);
  (Wrd115.Obj) = (current_block [OBJECT_30]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_392)
  (Wrd103.Obj) = Rvl;
  goto label_582;

DEFLABEL (label_585)
  (Wrd97.Obj) = (Rsp [2]);
  (Wrd98.Obj) = (current_block [OBJECT_16]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_391)
  (Wrd86.Obj) = Rvl;
  goto label_584;

DEFLABEL (label_587)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_106])), (Wrd81.pObj));

DEFLABEL (label_390)
  (Wrd80.Obj) = Rvl;
  goto label_586;

DEFLABEL (label_589)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_27]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_385)
  (Wrd13.Obj) = Rvl;
  goto label_588;

DEFLABEL (label_591)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104])), (Wrd8.pObj));

DEFLABEL (label_384)
  (Wrd7.Obj) = Rvl;
  goto label_590;

DEFLABEL (label_593)
  (Wrd58.Obj) = (Rsp [2]);
  (Wrd59.Obj) = (current_block [OBJECT_23]);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_360)
  (* (--Rsp)) = Rvl;
  goto label_592;

DEFLABEL (label_595)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_359)
  (* (--Rsp)) = Rvl;
  goto label_594;

DEFLABEL (label_597)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_21]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_358)
  (Wrd24.Obj) = Rvl;
  goto label_596;

DEFLABEL (label_599)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_19]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_357)
  (Wrd5.Obj) = Rvl;
  goto label_598;

DEFLABEL (procedure_simplified_value_491)
DEFLABEL (procedure_simplified_value_344)
  INTERRUPT_CHECK (26, LABEL_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_620;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd16.Lng))))
    goto label_620;
  (Wrd10.Obj) = ((Wrd14.pObj) [11]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_619)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47]));

DEFLABEL (continuation_331)
  INTERRUPT_CHECK (27, LABEL_45);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83]));

DEFLABEL (continuation_332)
  INTERRUPT_CHECK (27, LABEL_82);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_601;

DEFLABEL (label_600)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_601)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_618;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd15.Lng))))
    goto label_618;
  (Wrd7.Obj) = ((Wrd13.pObj) [6]);

DEFLABEL (label_617)
  if (! ((Wrd7.Obj) == (current_block [OBJECT_33])))
    goto label_600;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_616;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd37.Lng))))
    goto label_616;
  (Wrd29.Obj) = ((Wrd35.pObj) [9]);

DEFLABEL (label_615)
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_614;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_613)
  (Wrd53.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd56.Obj) = ((Wrd53.pObj) [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if ((Wrd57.uLng) == 50)
    goto label_612;
  Wrd52 = Wrd56;

DEFLABEL (label_611)
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd67.Obj) = (Rsp [1]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if (! ((Wrd68.uLng) == 10))
    goto label_610;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd66.Lng))))
    goto label_610;
  (Wrd58.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_609)
  (Wrd74.Obj) = (* (Rsp++));
  if ((Wrd58.Obj) == (Wrd74.Obj))
    goto label_602;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134]));

DEFLABEL (label_602)
  (Wrd75.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (current_block [OBJECT_13]);
  (Rsp [1]) = (Wrd76.Obj);
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if ((Wrd88.uLng) == 10)
    goto label_604;

DEFLABEL (label_603)
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_604)
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd85.Obj) = ((Wrd84.pObj) [0]);
  (Wrd86.Lng) = (FIXNUM_TO_LONG (Wrd85.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd86.Lng))))
    goto label_603;
  (Wrd78.Obj) = ((Wrd84.pObj) [4]);
  Rsp = (& (Rsp [3]));

DEFLABEL (label_608)
  (Rsp [0]) = (Wrd78.Obj);
  if ((Wrd78.Obj) == ((SCHEME_OBJECT) 0))
    goto label_600;
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133]))));
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd94.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd96.Obj) = (Rsp [4]);
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [2]);
  (Wrd99.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd100.Obj) = ((Wrd99.pObj) [0]);
  (* (--Rsp)) = (Wrd100.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_341)
  INTERRUPT_CHECK (27, LABEL_133);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_606;
  Rvl = (Rsp [0]);
  goto label_605;

DEFLABEL (label_606)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_605)
DEFLABEL (label_607)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_610)
  (Wrd69.Obj) = (Rsp [1]);
  (Wrd70.Obj) = (current_block [OBJECT_27]);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_403)
  (Wrd58.Obj) = Rvl;
  goto label_609;

DEFLABEL (label_612)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_131])), (Wrd53.pObj));

DEFLABEL (label_402)
  (Wrd52.Obj) = Rvl;
  goto label_611;

DEFLABEL (label_614)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_401)
  (* (--Rsp)) = Rvl;
  goto label_613;

DEFLABEL (label_616)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.Obj) = (current_block [OBJECT_21]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_400)
  (Wrd29.Obj) = Rvl;
  goto label_615;

DEFLABEL (label_618)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_19]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_399)
  (Wrd7.Obj) = Rvl;
  goto label_617;

DEFLABEL (label_620)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_24]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_361)
  (* (--Rsp)) = Rvl;
  goto label_619;

DEFLABEL (continuation_337)
  INTERRUPT_CHECK (27, LABEL_127);
  (Wrd78.Obj) = Rvl;
  goto label_608;

DEFLABEL (loop_497)
DEFLABEL (loop_33)
  INTERRUPT_CHECK (26, LABEL_48);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_7]))
    goto label_643;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_642;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_641)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_640;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd22.Lng))))
    goto label_640;
  (Wrd16.Obj) = ((Wrd20.pObj) [6]);

DEFLABEL (label_639)
  if ((Wrd16.Obj) == (current_block [OBJECT_20]))
    goto label_623;
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_622;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_621)
  (Rsp [0]) = (Wrd30.Obj);
  goto loop_33;

DEFLABEL (label_622)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_364)
  (Wrd30.Obj) = Rvl;
  goto label_621;

DEFLABEL (label_623)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_638;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [0]);

DEFLABEL (label_637)
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_636;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd54.Lng))))
    goto label_636;
  (Wrd49.Obj) = ((Wrd52.pObj) [8]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_635)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd64.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd72.Obj) = ((Wrd69.pObj) [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if ((Wrd73.uLng) == 50)
    goto label_634;
  Wrd68 = Wrd72;

DEFLABEL (label_633)
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_59);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_57);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_56);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_632;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_631)
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_86);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_627;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_135);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_628;

DEFLABEL (label_627)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [1]));

DEFLABEL (label_626)
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_625;
  Wrd13 = Wrd17;

DEFLABEL (label_624)
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_140);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_138);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_137);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [2]));
  goto loop_33;

DEFLABEL (label_625)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_139])), (Wrd14.pObj));

DEFLABEL (label_404)
  (Wrd13.Obj) = Rvl;
  goto label_624;

DEFLABEL (label_628)
  (Wrd33.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd43.Obj) = (Rsp [3]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_630;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd42.Lng))))
    goto label_630;
  (Wrd36.Obj) = ((Wrd40.pObj) [4]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_629)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_85);
  (Wrd5.Obj) = Rvl;
  goto label_626;

DEFLABEL (label_630)
  (Wrd45.Obj) = (Rsp [3]);
  (Wrd46.Obj) = (current_block [OBJECT_13]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_424)
  (* (--Rsp)) = Rvl;
  goto label_629;

DEFLABEL (label_632)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_374)
  (Wrd5.Obj) = Rvl;
  goto label_631;

DEFLABEL (label_634)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_58])), (Wrd69.pObj));

DEFLABEL (label_367)
  (Wrd68.Obj) = Rvl;
  goto label_633;

DEFLABEL (label_636)
  (Wrd57.Obj) = (current_block [OBJECT_23]);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_366)
  (* (--Rsp)) = Rvl;
  goto label_635;

DEFLABEL (label_638)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_365)
  (Wrd39.Obj) = Rvl;
  goto label_637;

DEFLABEL (label_640)
  (Wrd25.Obj) = (current_block [OBJECT_19]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_363)
  (Wrd16.Obj) = Rvl;
  goto label_639;

DEFLABEL (label_642)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_362)
  (Wrd7.Obj) = Rvl;
  goto label_641;

DEFLABEL (label_643)
  (Wrd78.Obj) = (Rsp [3]);
  (Wrd79.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd79.Obj);
  (Wrd80.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd80.Obj);
  (Rsp [1]) = (Wrd78.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd84.Obj) = (Rsp [1]);
  (Wrd85.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd84.Obj);
  (* (Rhp++)) = (Wrd85.Obj);
  (Wrd83.pObj) = (& (Rhp [-2]));
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd83.pObj)));
  (Wrd100.Obj) = (Rsp [0]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 10))
    goto label_645;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [0]);
  (Wrd99.Lng) = (FIXNUM_TO_LONG (Wrd98.Obj));
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd99.Lng))))
    goto label_645;
  ((Wrd97.pObj) [24]) = (Wrd81.Obj);

DEFLABEL (label_644)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd88.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_51);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_50])));
  Rhp += 1;
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd88.pObj)));
  Wrd89 = Wrd88;
  (Wrd90.Obj) = (Rsp [0]);
  ((Wrd89.pObj) [2]) = (Wrd90.Obj);
  (Rsp [1]) = (Wrd87.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (label_645)
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd103.Obj) = (current_block [OBJECT_8]);
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd107.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_368)
  goto label_644;

DEFLABEL (lambda_499)
DEFLABEL (lambda_70)
  INTERRUPT_CHECK (26, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65]));

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_64);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_647;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_646;

DEFLABEL (label_647)
  Rvl = (current_block [OBJECT_26]);

DEFLABEL (label_646)
DEFLABEL (label_648)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (value_test_generator_500)
DEFLABEL (value_test_generator_299)
  INTERRUPT_CHECK (26, LABEL_66);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_498)
  CLOSURE_HEADER (LABEL_50);

DEFLABEL (lambda_38)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  goto add_caller_calleeB_54;

DEFLABEL (lambda_502)
DEFLABEL (lambda_72)
  INTERRUPT_CHECK (26, LABEL_63);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65]));

DEFLABEL (lambda_501)
  CLOSURE_HEADER (LABEL_67);

DEFLABEL (lambda_298)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_671;
  Wrd5 = Wrd9;

DEFLABEL (label_670)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_669;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_669;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_668)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_665;
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_664;
  Wrd28 = Wrd32;

DEFLABEL (label_663)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_662;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd42.Lng))))
    goto label_662;
  (Wrd34.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_661)
  (Wrd50.Obj) = (* (Rsp++));
  if ((Wrd34.Obj) == (Wrd50.Obj))
    goto label_660;
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_659;
  Wrd51 = Wrd55;

DEFLABEL (label_658)
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd66.Obj) = (Rsp [2]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_657;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd65.Lng))))
    goto label_657;
  (Wrd57.Obj) = ((Wrd63.pObj) [1]);

DEFLABEL (label_656)
  (Wrd73.Obj) = (* (Rsp++));
  if (! ((Wrd57.Obj) == (Wrd73.Obj)))
    goto label_654;
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd79.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_294)
  INTERRUPT_CHECK (27, LABEL_96);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_649;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_147]));

DEFLABEL (label_649)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [0]) = (Wrd9.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_653;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd20.Lng))))
    goto label_653;
  (Wrd12.Obj) = ((Wrd18.pObj) [4]);

DEFLABEL (label_652)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_651;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd34.Lng))))
    goto label_651;
  (Wrd28.Obj) = ((Wrd32.pObj) [4]);

DEFLABEL (label_650)
  (Wrd41.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd41.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  goto pop_return;

DEFLABEL (label_651)
  (Wrd37.Obj) = (current_block [OBJECT_13]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_407)
  (Wrd28.Obj) = Rvl;
  goto label_650;

DEFLABEL (label_653)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.Obj) = (current_block [OBJECT_13]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_406)
  (Wrd12.Obj) = Rvl;
  goto label_652;

DEFLABEL (label_654)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_655)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_657)
  (Wrd68.Obj) = (Rsp [2]);
  (Wrd69.Obj) = (current_block [OBJECT_27]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_380)
  (Wrd57.Obj) = Rvl;
  goto label_656;

DEFLABEL (label_659)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_94])), (Wrd52.pObj));

DEFLABEL (label_379)
  (Wrd51.Obj) = Rvl;
  goto label_658;

DEFLABEL (label_660)
  Rvl = (current_block [OBJECT_26]);
  goto label_655;

DEFLABEL (label_662)
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.Obj) = (current_block [OBJECT_27]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_378)
  (Wrd34.Obj) = Rvl;
  goto label_661;

DEFLABEL (label_664)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_92])), (Wrd29.pObj));

DEFLABEL (label_377)
  (Wrd28.Obj) = Rvl;
  goto label_663;

DEFLABEL (label_665)
  (Wrd83.Obj) = (Rsp [0]);
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [2]);
  (Rsp [0]) = (Wrd82.Obj);
  (Wrd94.Obj) = (Rsp [1]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_667;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd93.Lng))))
    goto label_667;
  (Wrd85.Obj) = ((Wrd91.pObj) [15]);

DEFLABEL (label_666)
  (Wrd101.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd101.Obj);
  (Rsp [2]) = (Wrd85.Obj);
  goto pop_return;

DEFLABEL (label_667)
  (Wrd96.Obj) = (Rsp [1]);
  (Wrd97.Obj) = (current_block [OBJECT_28]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_381)
  (Wrd85.Obj) = Rvl;
  goto label_666;

DEFLABEL (label_669)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_27]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_376)
  (Wrd11.Obj) = Rvl;
  goto label_668;

DEFLABEL (label_671)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89])), (Wrd6.pObj));

DEFLABEL (label_375)
  (Wrd5.Obj) = Rvl;
  goto label_670;

DEFLABEL (setup_side_effectsB_503)
DEFLABEL (setup_side_effectsB_97)
  INTERRUPT_CHECK (26, LABEL_72);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_679;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 23L) < ((unsigned long) (Wrd18.Lng))))
    goto label_679;
  (Wrd10.Obj) = ((Wrd16.pObj) [24]);

DEFLABEL (label_678)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_677;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_676)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_88)
  INTERRUPT_CHECK (27, LABEL_100);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_675;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_675;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_674)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_673;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd32.Lng))))
    goto label_673;
  (Wrd26.Obj) = ((Wrd30.pObj) [10]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_672)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_160);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_159])));
  Rhp += 1;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  Wrd43 = Wrd42;
  (Wrd44.Obj) = (Rsp [1]);
  ((Wrd43.pObj) [2]) = (Wrd44.Obj);
  (Rsp [1]) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88]));

DEFLABEL (label_673)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_31]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_411)
  (* (--Rsp)) = Rvl;
  goto label_672;

DEFLABEL (label_675)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_13]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_410)
  (* (--Rsp)) = Rvl;
  goto label_674;

DEFLABEL (label_677)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_383)
  (* (--Rsp)) = Rvl;
  goto label_676;

DEFLABEL (label_679)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_8]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_382)
  (Wrd10.Obj) = Rvl;
  goto label_678;

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_156);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_206]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (current_block [OBJECT_7]);
  if ((Wrd8.Obj) == (Wrd9.Obj))
    goto label_681;
  (Wrd13.Obj) = (current_block [OBJECT_34]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto label_680;

DEFLABEL (label_681)
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_680)
DEFLABEL (label_687)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_7]);
  if ((Wrd19.Obj) == (Wrd20.Obj))
    goto label_683;
  (Wrd24.Obj) = (current_block [OBJECT_39]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  goto label_682;

DEFLABEL (label_683)
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_682)
DEFLABEL (label_686)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_200]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_206);
  (Wrd5.Obj) = (current_block [OBJECT_17]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [0]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_685;

DEFLABEL (label_684)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_685)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd18.Lng))))
    goto label_684;
  ((Wrd16.pObj) [29]) = Rvl;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_504)
DEFLABEL (lambda_59)
  INTERRUPT_CHECK (26, LABEL_70);
  (Wrd5.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_29]);
  (Wrd11.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd24.uLng) == 10)
    goto label_689;

DEFLABEL (label_688)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_689)
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd22.Lng))))
    goto label_688;
  ((Wrd20.pObj) [29]) = (Wrd7.Obj);
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_505)
DEFLABEL (lambda_234)
  INTERRUPT_CHECK (26, LABEL_80);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_698;
  Wrd5 = Wrd9;

DEFLABEL (label_697)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_696;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_696;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_695)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_692;

DEFLABEL (label_691)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_690)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_692)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_694;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd38.Lng))))
    goto label_694;
  (Wrd30.Obj) = ((Wrd36.pObj) [29]);

DEFLABEL (label_693)
  if (! ((Wrd30.Obj) == (current_block [OBJECT_7])))
    goto label_691;
  Rvl = (current_block [OBJECT_26]);
  goto label_690;

DEFLABEL (label_694)
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (current_block [OBJECT_17]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_398)
  (Wrd30.Obj) = Rvl;
  goto label_693;

DEFLABEL (label_696)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_27]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_397)
  (Wrd11.Obj) = Rvl;
  goto label_695;

DEFLABEL (label_698)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_123])), (Wrd6.pObj));

DEFLABEL (label_396)
  (Wrd5.Obj) = Rvl;
  goto label_697;

DEFLABEL (add_caller_calleeB_506)
DEFLABEL (add_caller_calleeB_54)
  INTERRUPT_CHECK (26, LABEL_141);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_712;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 24L) < ((unsigned long) (Wrd13.Lng))))
    goto label_712;
  (Wrd7.Obj) = ((Wrd11.pObj) [25]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_711)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_143);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_700;

DEFLABEL (label_699)
  Rvl = (current_block [OBJECT_38]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_700)
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (Wrd81.Obj) = (Rsp [1]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 10))
    goto label_710;
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  if (! (((unsigned long) 24L) < ((unsigned long) (Wrd80.Lng))))
    goto label_710;
  ((Wrd78.pObj) [25]) = (Wrd9.Obj);

DEFLABEL (label_709)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_708;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd22.Lng))))
    goto label_708;
  (Wrd14.Obj) = ((Wrd20.pObj) [26]);

DEFLABEL (label_707)
  (Wrd33.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 10))
    goto label_706;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd64.Lng))))
    goto label_706;
  ((Wrd62.pObj) [26]) = (Wrd30.Obj);

DEFLABEL (label_705)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_704;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 24L) < ((unsigned long) (Wrd45.Lng))))
    goto label_704;
  (Wrd39.Obj) = ((Wrd43.pObj) [25]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_703)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd54.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_197);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_196])));
  Rhp += 1;
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd54.pObj)));
  Wrd55 = Wrd54;
  (Wrd56.Obj) = (Rsp [3]);
  ((Wrd55.pObj) [2]) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_194);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_190]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_702;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd16.Lng))))
    goto label_702;
  (Wrd10.Obj) = ((Wrd14.pObj) [26]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_701)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_243);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_242])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [4]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_190);
  goto label_699;

DEFLABEL (label_702)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_11]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_241]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_447)
  (* (--Rsp)) = Rvl;
  goto label_701;

DEFLABEL (label_704)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.Obj) = (current_block [OBJECT_10]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_195]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_426)
  (* (--Rsp)) = Rvl;
  goto label_703;

DEFLABEL (label_706)
  (Wrd67.Obj) = (Rsp [2]);
  (Wrd68.Obj) = (current_block [OBJECT_11]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_427)
  goto label_705;

DEFLABEL (label_708)
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.Obj) = (current_block [OBJECT_11]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_192]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_425)
  (Wrd14.Obj) = Rvl;
  goto label_707;

DEFLABEL (label_710)
  (Wrd83.Obj) = (Rsp [1]);
  (Wrd84.Obj) = (current_block [OBJECT_10]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_191]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_428)
  goto label_709;

DEFLABEL (label_712)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_10]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_405)
  (* (--Rsp)) = Rvl;
  goto label_711;

DEFLABEL (compute_side_effectsB_508)
DEFLABEL (compute_side_effectsB_167)
  INTERRUPT_CHECK (26, LABEL_99);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_719;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd13.Lng))))
    goto label_719;
  (Wrd7.Obj) = ((Wrd11.pObj) [29]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_718)
  (Wrd31.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd31.Obj);
  (Wrd29.pObj) = (& (Rhp [-1]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd29.pObj)));
  (Rsp [0]) = (Wrd30.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_131)
  INTERRUPT_CHECK (27, LABEL_154);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_714;

DEFLABEL (label_713)
  Rvl = (current_block [OBJECT_38]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_714)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_201]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_717;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 24L) < ((unsigned long) (Wrd20.Lng))))
    goto label_717;
  (Wrd14.Obj) = ((Wrd18.pObj) [25]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_716)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_205);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_204])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  (Wrd33.Obj) = (Rsp [3]);
  ((Wrd32.pObj) [2]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_164)
  INTERRUPT_CHECK (27, LABEL_201);
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_715;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd44.Lng))))
    goto label_715;
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  ((Wrd42.pObj) [29]) = (Wrd38.Obj);
  goto label_713;

DEFLABEL (label_715)
  (Wrd47.Obj) = (Rsp [1]);
  (Wrd48.Obj) = (current_block [OBJECT_17]);
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd49.Obj) = ((Wrd51.pObj) [0]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_202]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_448)
  goto label_713;

DEFLABEL (label_717)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.Obj) = (current_block [OBJECT_10]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_203]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_429)
  (* (--Rsp)) = Rvl;
  goto label_716;

DEFLABEL (label_719)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_17]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_409)
  (* (--Rsp)) = Rvl;
  goto label_718;

DEFLABEL (lambda_510)
DEFLABEL (lambda_87)
  INTERRUPT_CHECK (26, LABEL_101);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_749;
  Wrd5 = Wrd9;

DEFLABEL (label_748)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_747;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_747;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_746)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_736;
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_735;
  Wrd28 = Wrd32;

DEFLABEL (label_734)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_733;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd42.Lng))))
    goto label_733;
  (Wrd34.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_732)
  (Wrd50.Obj) = (* (Rsp++));
  if ((Wrd34.Obj) == (Wrd50.Obj))
    goto label_721;

DEFLABEL (label_720)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_721)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_731;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_731;
  (Wrd53.Obj) = ((Wrd59.pObj) [3]);

DEFLABEL (label_730)
  (Rsp [0]) = (Wrd53.Obj);
  (Wrd71.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd74.Obj) = ((Wrd71.pObj) [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if ((Wrd75.uLng) == 50)
    goto label_729;
  Wrd70 = Wrd74;

DEFLABEL (label_728)
  (Wrd76.Obj) = (Rsp [0]);
  if ((Wrd76.Obj) == (Wrd70.Obj))
    goto label_720;
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170]));

DEFLABEL (continuation_111)
  INTERRUPT_CHECK (27, LABEL_169);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_725;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_211]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_212]));

DEFLABEL (continuation_112)
  INTERRUPT_CHECK (27, LABEL_211);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_723;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_722;

DEFLABEL (label_723)
  Rvl = (current_block [OBJECT_26]);

DEFLABEL (label_722)
DEFLABEL (label_724)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_725)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_727;
  Wrd9 = Wrd13;

DEFLABEL (label_726)
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (label_727)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_213])), (Wrd10.pObj));

DEFLABEL (label_431)
  (Wrd9.Obj) = Rvl;
  goto label_726;

DEFLABEL (label_729)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_168])), (Wrd71.pObj));

DEFLABEL (label_417)
  (Wrd70.Obj) = Rvl;
  goto label_728;

DEFLABEL (label_731)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (current_block [OBJECT_16]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_416)
  (Wrd53.Obj) = Rvl;
  goto label_730;

DEFLABEL (label_733)
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.Obj) = (current_block [OBJECT_27]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_415)
  (Wrd34.Obj) = Rvl;
  goto label_732;

DEFLABEL (label_735)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_165])), (Wrd29.pObj));

DEFLABEL (label_414)
  (Wrd28.Obj) = Rvl;
  goto label_734;

DEFLABEL (label_736)
  (Wrd92.Obj) = (Rsp [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if (! ((Wrd93.uLng) == 10))
    goto label_745;
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  (Wrd90.Obj) = ((Wrd89.pObj) [0]);
  (Wrd91.Lng) = (FIXNUM_TO_LONG (Wrd90.Obj));
  if (! (((unsigned long) 19L) < ((unsigned long) (Wrd91.Lng))))
    goto label_745;
  (Wrd85.Obj) = ((Wrd89.pObj) [20]);
  (* (--Rsp)) = (Wrd85.Obj);

DEFLABEL (label_744)
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (Wrd102.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd102.Obj);
  (Wrd103.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd103.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_164);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_737;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_737)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_214]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_214);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_738;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_738)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_247]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_247);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_739;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_739)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_743;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 15L) < ((unsigned long) (Wrd15.Lng))))
    goto label_743;
  (Wrd7.Obj) = ((Wrd13.pObj) [16]);

DEFLABEL (label_742)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_741;
  Wrd24 = Wrd28;

DEFLABEL (label_740)
  (Rsp [2]) = (Wrd24.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (label_741)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_273])), (Wrd25.pObj));

DEFLABEL (label_466)
  (Wrd24.Obj) = Rvl;
  goto label_740;

DEFLABEL (label_743)
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (current_block [OBJECT_49]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_272]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_465)
  (Wrd7.Obj) = Rvl;
  goto label_742;

DEFLABEL (label_745)
  (Wrd94.Obj) = (Rsp [0]);
  (Wrd95.Obj) = (current_block [OBJECT_35]);
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163]))));
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_418)
  (* (--Rsp)) = Rvl;
  goto label_744;

DEFLABEL (label_747)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_27]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_413)
  (Wrd11.Obj) = Rvl;
  goto label_746;

DEFLABEL (label_749)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_161])), (Wrd6.pObj));

DEFLABEL (label_412)
  (Wrd5.Obj) = Rvl;
  goto label_748;

DEFLABEL (find_512)
DEFLABEL (find_200)
  INTERRUPT_CHECK (26, LABEL_180);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_7]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_753;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_178]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_751;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_750)
  goto test_return_212;

DEFLABEL (label_751)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_186]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_419)
DEFLABEL (label_752)
  (* (--Rsp)) = Rvl;
  goto label_750;

DEFLABEL (label_753)
  (Wrd19.Obj) = (Rsp [1]);
  if ((Wrd19.Obj) == (Wrd6.Obj))
    goto label_760;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_759;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_758)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_757;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd36.Lng))))
    goto label_757;
  (Wrd30.Obj) = ((Wrd34.pObj) [11]);

DEFLABEL (label_756)
  (Rsp [0]) = (Wrd30.Obj);
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_755;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_754)
  (Rsp [1]) = (Wrd43.Obj);
  goto find_200;

DEFLABEL (label_755)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_422)
  (Wrd43.Obj) = Rvl;
  goto label_754;

DEFLABEL (label_757)
  (Wrd39.Obj) = (current_block [OBJECT_24]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_421)
  (Wrd30.Obj) = Rvl;
  goto label_756;

DEFLABEL (label_759)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_420)
  (Wrd21.Obj) = Rvl;
  goto label_758;

DEFLABEL (label_760)
  (Wrd53.Obj) = (current_block [OBJECT_37]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_782)
  (Rsp [0]) = (Wrd53.Obj);
  if (! ((Wrd53.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_761;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_761)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_181]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd68.Obj) = (Rsp [3]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_781;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd67.Lng))))
    goto label_781;
  (Wrd61.Obj) = ((Wrd65.pObj) [4]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_780)
  (Wrd75.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [4]);
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [2]);
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [0]);
  (* (--Rsp)) = (Wrd80.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_178)
  INTERRUPT_CHECK (27, LABEL_181);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_762;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_762)
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_225]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38]));

DEFLABEL (continuation_311)
  INTERRUPT_CHECK (27, LABEL_226);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_779;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_250]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_224]));

DEFLABEL (continuation_312)
  INTERRUPT_CHECK (27, LABEL_250);

DEFLABEL (label_779)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_251]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_252]));

DEFLABEL (continuation_313)
  INTERRUPT_CHECK (27, LABEL_251);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_778;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_778;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_777)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_278]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_279]));

DEFLABEL (continuation_315)
  INTERRUPT_CHECK (27, LABEL_278);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_302]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_301]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_776;
  Wrd12 = Wrd16;

DEFLABEL (label_775)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd27.Obj) = (Rsp [7]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_774;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd26.Lng))))
    goto label_774;
  (Wrd18.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_773)
  (Wrd34.Obj) = (* (Rsp++));
  if (! ((Wrd18.Obj) == (Wrd34.Obj)))
    goto label_772;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd70.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd71.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd71.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_239]));

DEFLABEL (continuation_321)
  INTERRUPT_CHECK (27, LABEL_301);
  (Wrd36.Obj) = Rvl;

DEFLABEL (label_771)
  (Wrd40.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_305]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd54.Obj) = (Rsp [7]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_770;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd53.Lng))))
    goto label_770;
  (Wrd45.Obj) = ((Wrd51.pObj) [6]);

DEFLABEL (label_769)
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd63.uLng) == 1))
    goto label_768;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (* (--Rsp)) = (Wrd62.Obj);

DEFLABEL (label_767)
  (Wrd68.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd68.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_239]));

DEFLABEL (continuation_318)
  INTERRUPT_CHECK (27, LABEL_305);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_311]));

DEFLABEL (continuation_323)
  INTERRUPT_CHECK (27, LABEL_302);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_766;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd12.Lng))))
    goto label_766;
  (Wrd7.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_765)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_764;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd29.Lng))))
    goto label_764;
  (Wrd23.Obj) = (Rsp [1]);
  ((Wrd27.pObj) [7]) = (Wrd23.Obj);

DEFLABEL (label_763)
  (Wrd19.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd19.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_310]));

DEFLABEL (label_764)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (current_block [OBJECT_32]);
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_309]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_486)
  goto label_763;

DEFLABEL (label_766)
  (Wrd15.Obj) = (current_block [OBJECT_55]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_308]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_485)
  (* (--Rsp)) = Rvl;
  goto label_765;

DEFLABEL (label_768)
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_307]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_483)
  (* (--Rsp)) = Rvl;
  goto label_767;

DEFLABEL (label_770)
  (Wrd56.Obj) = (Rsp [7]);
  (Wrd57.Obj) = (current_block [OBJECT_19]);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_306]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_482)
  (Wrd45.Obj) = Rvl;
  goto label_769;

DEFLABEL (label_772)
  (Wrd36.Obj) = (Rsp [6]);
  Rsp = (& (Rsp [1]));
  goto label_771;

DEFLABEL (label_774)
  (Wrd29.Obj) = (Rsp [7]);
  (Wrd30.Obj) = (current_block [OBJECT_27]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_304]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_481)
  (Wrd18.Obj) = Rvl;
  goto label_773;

DEFLABEL (label_776)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_303])), (Wrd13.pObj));

DEFLABEL (label_480)
  (Wrd12.Obj) = Rvl;
  goto label_775;

DEFLABEL (label_778)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_13]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_277]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_469)
  (* (--Rsp)) = Rvl;
  goto label_777;

DEFLABEL (label_781)
  (Wrd70.Obj) = (Rsp [3]);
  (Wrd71.Obj) = (current_block [OBJECT_13]);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_182]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_423)
  (* (--Rsp)) = Rvl;
  goto label_780;

DEFLABEL (continuation_193)
  INTERRUPT_CHECK (27, LABEL_178);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_785;
  (Wrd88.Obj) = (Rsp [1]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd89.uLng) == 1))
    goto label_784;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd85.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_783)
  (Rsp [1]) = (Wrd85.Obj);
  goto compare_222;

DEFLABEL (label_784)
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_179]))));
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_432)
  (Wrd85.Obj) = Rvl;
  goto label_783;

DEFLABEL (label_785)
  (Wrd53.Obj) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_786)
  Rsp = (& (Rsp [3]));
  goto label_782;

DEFLABEL (continuation_179)
  INTERRUPT_CHECK (27, LABEL_225);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_248]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_799;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_799;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_798)
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_181)
  INTERRUPT_CHECK (27, LABEL_248);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_788;

DEFLABEL (label_787)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_788)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_797;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 16L) < ((unsigned long) (Wrd26.Lng))))
    goto label_797;
  (Wrd8.Obj) = ((Wrd24.pObj) [17]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_787;

DEFLABEL (label_796)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_275]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_276]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38]));

DEFLABEL (continuation_303)
  INTERRUPT_CHECK (27, LABEL_276);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_795;
  (Wrd8.Obj) = (current_block [OBJECT_7]);
  if (Rvl == (Wrd8.Obj))
    goto label_793;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_298]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd13.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_306)
  INTERRUPT_CHECK (27, LABEL_298);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_789;
  (Wrd25.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_54]);
  (Wrd30.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_50]);
  (Rsp [1]) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_252]));

DEFLABEL (label_789)
  Rsp = (& (Rsp [3]));

DEFLABEL (label_792)
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_791;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 15L) < ((unsigned long) (Wrd13.Lng))))
    goto label_791;
  (Wrd5.Obj) = ((Wrd11.pObj) [16]);

DEFLABEL (label_790)
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_300]));

DEFLABEL (label_791)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_49]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_299]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_479)
  (Wrd5.Obj) = Rvl;
  goto label_790;

DEFLABEL (label_793)
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_50]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_54]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd8.Obj);

DEFLABEL (label_794)
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Rsp [2]) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_252]));

DEFLABEL (label_795)
  (Wrd21.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_50]);
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_54]);
  (Wrd27.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  goto label_794;

DEFLABEL (label_797)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.Obj) = (current_block [OBJECT_40]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_274]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_468)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_787;
  goto label_796;

DEFLABEL (label_799)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_13]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_249]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_455)
  (* (--Rsp)) = Rvl;
  goto label_798;

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_275);
  goto label_792;

DEFLABEL (check_operators_513)
DEFLABEL (check_operators_286)
  INTERRUPT_CHECK (26, LABEL_187);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));

DEFLABEL (continuation_275)
  INTERRUPT_CHECK (27, LABEL_188);
  (Rsp [0]) = Rvl;
  if (! (Rvl == (current_block [OBJECT_7])))
    goto label_800;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_800)
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 1))
    goto label_813;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_812)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_811;
  Wrd17 = Wrd21;

DEFLABEL (label_810)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_809;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd31.Lng))))
    goto label_809;
  (Wrd23.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_808)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_801;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_801)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_230]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd57.Obj) = (Rsp [5]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 10))
    goto label_807;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd56.Lng))))
    goto label_807;
  (Wrd50.Obj) = ((Wrd54.pObj) [7]);
  (* (--Rsp)) = (Wrd50.Obj);

DEFLABEL (label_806)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_281)
  INTERRUPT_CHECK (27, LABEL_231);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [5]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto procedure_simplified_value_344;

DEFLABEL (continuation_282)
  INTERRUPT_CHECK (27, LABEL_230);
  (Rsp [0]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_805;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_804)
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd15.Obj) = (Rsp [0]);
  if (! ((Wrd15.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_802;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_802)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd21.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_256);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_255])));
  Rhp += 3;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd21.pObj)));
  Wrd26 = Wrd21;
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  ((Wrd26.pObj) [4]) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126]));

DEFLABEL (continuation_273)
  INTERRUPT_CHECK (27, LABEL_254);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_803;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto simplify_combinationB_266;

DEFLABEL (label_803)
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_805)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_456)
  (Wrd6.Obj) = Rvl;
  goto label_804;

DEFLABEL (label_807)
  (Wrd59.Obj) = (Rsp [5]);
  (Wrd60.Obj) = (current_block [OBJECT_32]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_443)
  (* (--Rsp)) = Rvl;
  goto label_806;

DEFLABEL (label_809)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_27]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_229]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_442)
  (Wrd23.Obj) = Rvl;
  goto label_808;

DEFLABEL (label_811)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_228])), (Wrd18.pObj));

DEFLABEL (label_441)
  (Wrd17.Obj) = Rvl;
  goto label_810;

DEFLABEL (label_813)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_440)
  (* (--Rsp)) = Rvl;
  goto label_812;

DEFLABEL (lambda_507)
  CLOSURE_HEADER (LABEL_148);

DEFLABEL (lambda_63)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83]));

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_198);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_814;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  goto analyze_combinationB_287;

DEFLABEL (label_814)
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  goto analyze_procedureB_187;

DEFLABEL (lambda_509)
  CLOSURE_HEADER (LABEL_159);

DEFLABEL (lambda_81)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_208);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_207])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  ((Wrd7.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_816;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 16L) < ((unsigned long) (Wrd19.Lng))))
    goto label_816;
  (Wrd11.Obj) = ((Wrd17.pObj) [17]);

DEFLABEL (label_815)
  (Rsp [1]) = (Wrd11.Obj);
  (Wrd27.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_210]));

DEFLABEL (label_816)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_40]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_209]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_430)
  (Wrd11.Obj) = Rvl;
  goto label_815;

DEFLABEL (test_return_517)
DEFLABEL (test_return_212)
  INTERRUPT_CHECK (26, LABEL_215);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_834;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd13.Lng))))
    goto label_834;
  (Wrd5.Obj) = ((Wrd11.pObj) [6]);

DEFLABEL (label_833)
  if ((Wrd5.Obj) == (current_block [OBJECT_33]))
    goto label_817;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_223]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_224]));

DEFLABEL (continuation_204)
  INTERRUPT_CHECK (27, LABEL_223);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_817)
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_832;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd35.Lng))))
    goto label_832;
  (Wrd27.Obj) = ((Wrd33.pObj) [9]);

DEFLABEL (label_831)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_830;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd43.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_829)
  (Rsp [0]) = (Wrd43.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_828;
  Wrd50 = Wrd54;

DEFLABEL (label_827)
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd65.Obj) = (Rsp [1]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 10))
    goto label_826;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd64.Lng))))
    goto label_826;
  (Wrd56.Obj) = ((Wrd62.pObj) [1]);

DEFLABEL (label_825)
  (Wrd72.Obj) = (* (Rsp++));
  if ((Wrd56.Obj) == (Wrd72.Obj))
    goto label_819;
  (Wrd74.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd77.Obj) = ((Wrd74.pObj) [0]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd78.uLng) == 50)
    goto label_824;
  Wrd73 = Wrd77;

DEFLABEL (label_823)
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd88.Obj) = (Rsp [1]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd89.uLng) == 10))
    goto label_822;
  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd86.Obj) = ((Wrd85.pObj) [0]);
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd86.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd87.Lng))))
    goto label_822;
  (Wrd79.Obj) = ((Wrd85.pObj) [1]);

DEFLABEL (label_821)
  (Wrd95.Obj) = (* (Rsp++));
  if ((Wrd79.Obj) == (Wrd95.Obj))
    goto label_819;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_818;

DEFLABEL (label_819)
  Rvl = (Rsp [0]);

DEFLABEL (label_818)
DEFLABEL (label_820)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_822)
  (Wrd90.Obj) = (Rsp [1]);
  (Wrd91.Obj) = (current_block [OBJECT_27]);
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_222]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_439)
  (Wrd79.Obj) = Rvl;
  goto label_821;

DEFLABEL (label_824)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_221])), (Wrd74.pObj));

DEFLABEL (label_438)
  (Wrd73.Obj) = Rvl;
  goto label_823;

DEFLABEL (label_826)
  (Wrd67.Obj) = (Rsp [1]);
  (Wrd68.Obj) = (current_block [OBJECT_27]);
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_220]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_437)
  (Wrd56.Obj) = Rvl;
  goto label_825;

DEFLABEL (label_828)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_219])), (Wrd51.pObj));

DEFLABEL (label_436)
  (Wrd50.Obj) = Rvl;
  goto label_827;

DEFLABEL (label_830)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_218]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_435)
  (Wrd43.Obj) = Rvl;
  goto label_829;

DEFLABEL (label_832)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.Obj) = (current_block [OBJECT_21]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_217]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_434)
  (Wrd27.Obj) = Rvl;
  goto label_831;

DEFLABEL (label_834)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_19]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_216]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_433)
  (Wrd5.Obj) = Rvl;
  goto label_833;

DEFLABEL (simplify_combinationB_518)
DEFLABEL (simplify_combinationB_266)
  INTERRUPT_CHECK (26, LABEL_234);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_235]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_233]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_851;
  Wrd11 = Wrd15;

DEFLABEL (label_850)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_849;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd25.Lng))))
    goto label_849;
  (Wrd17.Obj) = ((Wrd23.pObj) [1]);

DEFLABEL (label_848)
  (Wrd33.Obj) = (* (Rsp++));
  if ((Wrd17.Obj) == (Wrd33.Obj))
    goto label_845;
  (Wrd35.Obj) = (Rsp [2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_844)
  (Wrd36.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_240]));

DEFLABEL (continuation_259)
  INTERRUPT_CHECK (27, LABEL_235);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_257]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_843;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_843;
  (Wrd10.Obj) = ((Wrd14.pObj) [7]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_842)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_261)
  INTERRUPT_CHECK (27, LABEL_257);
  (Wrd5.Obj) = Rvl;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_841;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd12.Lng))))
    goto label_841;
  (Wrd6.Obj) = ((Wrd10.pObj) [8]);

DEFLABEL (label_840)
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_839;
  Wrd19 = Wrd23;

DEFLABEL (label_838)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_837;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd33.Lng))))
    goto label_837;
  (Wrd25.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_836)
  (Wrd41.Obj) = (* (Rsp++));
  if ((Wrd25.Obj) == (Wrd41.Obj))
    goto label_835;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_835)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_288]));

DEFLABEL (label_837)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.Obj) = (current_block [OBJECT_27]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_287]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_475)
  (Wrd25.Obj) = Rvl;
  goto label_836;

DEFLABEL (label_839)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_286])), (Wrd20.pObj));

DEFLABEL (label_474)
  (Wrd19.Obj) = Rvl;
  goto label_838;

DEFLABEL (label_841)
  (Wrd15.Obj) = (current_block [OBJECT_23]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_285]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_473)
  (Wrd6.Obj) = Rvl;
  goto label_840;

DEFLABEL (label_843)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_32]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_258]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_457)
  (* (--Rsp)) = Rvl;
  goto label_842;

DEFLABEL (label_845)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd38.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd48.Obj) = (Rsp [6]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_847;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd47.Lng))))
    goto label_847;
  (Wrd41.Obj) = ((Wrd45.pObj) [7]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_846)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_239]));

DEFLABEL (continuation_257)
  INTERRUPT_CHECK (27, LABEL_233);
  (* (--Rsp)) = Rvl;
  goto label_844;

DEFLABEL (label_847)
  (Wrd50.Obj) = (Rsp [6]);
  (Wrd51.Obj) = (current_block [OBJECT_32]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_446)
  (* (--Rsp)) = Rvl;
  goto label_846;

DEFLABEL (label_849)
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.Obj) = (current_block [OBJECT_27]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_237]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_445)
  (Wrd17.Obj) = Rvl;
  goto label_848;

DEFLABEL (label_851)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_236])), (Wrd12.pObj));

DEFLABEL (label_444)
  (Wrd11.Obj) = Rvl;
  goto label_850;

DEFLABEL (lambda_514)
  CLOSURE_HEADER (LABEL_196);

DEFLABEL (lambda_47)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  goto add_caller_calleeB_54;

DEFLABEL (lambda_515)
  CLOSURE_HEADER (LABEL_204);

DEFLABEL (lambda_162)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  if (! ((Wrd5.Obj) == (Wrd8.Obj)))
    goto label_852;
  Rvl = (current_block [OBJECT_12]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_852)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_854;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 28L) < ((unsigned long) (Wrd17.Lng))))
    goto label_854;
  (Wrd11.Obj) = ((Wrd15.pObj) [29]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_853)
  goto dispatch_loop_160;

DEFLABEL (label_854)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_17]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_244]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_449)
  (* (--Rsp)) = Rvl;
  goto label_853;

DEFLABEL (lambda_516)
  CLOSURE_HEADER (LABEL_207);

DEFLABEL (lambda_80)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_245]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_859;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_859;
  (Wrd10.Obj) = ((Wrd14.pObj) [6]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_858)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_245);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  if (Rvl == (Wrd9.Obj))
    goto label_856;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_855;

DEFLABEL (label_856)
  Rvl = (current_block [OBJECT_26]);

DEFLABEL (label_855)
DEFLABEL (label_857)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_859)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_19]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_246]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_450)
  (* (--Rsp)) = Rvl;
  goto label_858;

DEFLABEL (compare_511)
DEFLABEL (compare_222)
  INTERRUPT_CHECK (26, LABEL_173);
  (Wrd95.Obj) = (Rsp [1]);
  (Wrd96.Obj) = (current_block [OBJECT_7]);
  if ((Wrd95.Obj) == (Wrd96.Obj))
    goto label_861;
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd104.uLng) == 1))
    goto label_860;
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd102.Obj) = ((Wrd101.pObj) [0]);
  (* (--Rsp)) = (Wrd102.Obj);
  goto label_750;

DEFLABEL (label_860)
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177]))));
  (* (--Rsp)) = (Wrd108.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_451)
  goto label_752;

DEFLABEL (label_861)
  (Wrd109.Obj) = (Rsp [2]);
  if ((Wrd109.Obj) == (Wrd96.Obj))
    goto label_868;
  (Wrd115.uLng) = (OBJECT_TYPE (Wrd109.Obj));
  if (! ((Wrd115.uLng) == 1))
    goto label_867;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd111.Obj) = ((Wrd113.pObj) [0]);

DEFLABEL (label_866)
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_865;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd125.Obj) = ((Wrd124.pObj) [0]);
  (Wrd126.Lng) = (FIXNUM_TO_LONG (Wrd125.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd126.Lng))))
    goto label_865;
  (Wrd120.Obj) = ((Wrd124.pObj) [11]);

DEFLABEL (label_864)
  (Rsp [1]) = (Wrd120.Obj);
  (Wrd136.Obj) = (Rsp [2]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if (! ((Wrd137.uLng) == 1))
    goto label_863;
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd136.Obj));
  (Wrd133.Obj) = ((Wrd135.pObj) [1]);

DEFLABEL (label_862)
  (Rsp [2]) = (Wrd133.Obj);
  goto compare_222;

DEFLABEL (label_863)
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_176]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd136.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_454)
  (Wrd133.Obj) = Rvl;
  goto label_862;

DEFLABEL (label_865)
  (Wrd129.Obj) = (current_block [OBJECT_24]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_175]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_453)
  (Wrd120.Obj) = Rvl;
  goto label_864;

DEFLABEL (label_867)
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_452)
  (Wrd111.Obj) = Rvl;
  goto label_866;

DEFLABEL (label_868)
  (Wrd53.Obj) = (Rsp [0]);
  goto label_786;

DEFLABEL (continuation_215)
  INTERRUPT_CHECK (27, LABEL_171);
  (Wrd144.Obj) = (Rsp [0]);
  if ((Wrd144.Obj) == Rvl)
    goto label_869;
  (Wrd53.Obj) = (current_block [OBJECT_37]);
  goto label_786;

DEFLABEL (label_869)
  (Wrd149.Obj) = (Rsp [1]);
  (Wrd150.uLng) = (OBJECT_TYPE (Wrd149.Obj));
  if (! ((Wrd150.uLng) == 1))
    goto label_871;
  (Wrd148.pObj) = (OBJECT_ADDRESS (Wrd149.Obj));
  (Wrd146.Obj) = ((Wrd148.pObj) [1]);

DEFLABEL (label_870)
  (Rsp [1]) = (Wrd146.Obj);
  goto compare_222;

DEFLABEL (label_871)
  (Wrd154.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172]))));
  (* (--Rsp)) = (Wrd154.Obj);
  (* (--Rsp)) = (Wrd149.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_467)
  (Wrd146.Obj) = Rvl;
  goto label_870;

DEFLABEL (lambda_519)
  CLOSURE_HEADER (LABEL_242);

DEFLABEL (lambda_50)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  goto add_caller_calleeB_54;

DEFLABEL (dispatch_loop_521)
DEFLABEL (dispatch_loop_160)
  INTERRUPT_CHECK (26, LABEL_259);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_7])))
    goto label_872;
  Rvl = (current_block [OBJECT_38]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_872)
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_900;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_899)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_898;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_897)
  (Wrd23.Obj) = (Rsp [0]);
  if (! ((Wrd23.Obj) == (current_block [OBJECT_34])))
    goto label_877;

DEFLABEL (label_876)
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd104.Obj) = (Rsp [3]);
  (Wrd105.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd106.Obj) = ((Wrd105.pObj) [3]);
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (* (--Rsp)) = (Wrd108.Obj);
  (Wrd109.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd109.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_153)
  INTERRUPT_CHECK (27, LABEL_262);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_875;
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd41.Obj) = (current_block [OBJECT_45]);
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd49.Obj);
  (Wrd44.pObj) = (& (Rhp [-2]));
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd44.pObj)));
  ((Wrd48.pObj) [0]) = (Wrd42.Obj);

DEFLABEL (label_875)
  Rsp = (& (Rsp [1]));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_874;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_873)
  (Rsp [0]) = (Wrd20.Obj);
  goto dispatch_loop_160;

DEFLABEL (label_874)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_295]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_476)
  (Wrd20.Obj) = Rvl;
  goto label_873;

DEFLABEL (label_877)
  if ((Wrd23.Obj) == (current_block [OBJECT_45]))
    goto label_876;
  if ((Wrd23.Obj) == (current_block [OBJECT_46]))
    goto label_876;
  if ((Wrd23.Obj) == (current_block [OBJECT_39]))
    goto label_882;
  if ((Wrd23.Obj) == (current_block [OBJECT_47]))
    goto label_882;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_269]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [2]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_881;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_880)
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_879;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_878)
  (Wrd52.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd52.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_224]));

DEFLABEL (continuation_146)
  INTERRUPT_CHECK (27, LABEL_269);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_289]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_147)
  INTERRUPT_CHECK (27, LABEL_289);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_875;
  (Wrd61.Obj) = (current_block [OBJECT_52]);
  (Wrd62.Obj) = (Rsp [2]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [3]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  ((Wrd65.pObj) [0]) = (Wrd58.Obj);
  goto label_875;

DEFLABEL (label_879)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_271]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_461)
  (* (--Rsp)) = Rvl;
  goto label_878;

DEFLABEL (label_881)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_270]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_460)
  (Wrd36.Obj) = Rvl;
  goto label_880;

DEFLABEL (label_882)
  (Wrd53.Obj) = (Rsp [2]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [3]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [0]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (Rsp [2]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_896;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [0]);

DEFLABEL (label_895)
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_894;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [1]);
  (* (--Rsp)) = (Wrd68.Obj);

DEFLABEL (label_893)
  (Wrd74.Obj) = (Rsp [4]);
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd87.uLng) == 10))
    goto label_892;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd84.Obj) = ((Wrd83.pObj) [0]);
  (Wrd85.Lng) = (FIXNUM_TO_LONG (Wrd84.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd85.Lng))))
    goto label_892;
  (Wrd79.Obj) = ((Wrd83.pObj) [4]);
  (* (--Rsp)) = (Wrd79.Obj);

DEFLABEL (label_891)
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_266]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd97.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_268);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_267])));
  Rhp += 1;
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd97.pObj)));
  Wrd98 = Wrd97;
  (Wrd99.Obj) = (Rsp [1]);
  ((Wrd98.pObj) [2]) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd100.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd100.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_119)
  INTERRUPT_CHECK (27, LABEL_266);
  (Rsp [0]) = Rvl;
  if (Rvl == (current_block [OBJECT_7]))
    goto label_890;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_292]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_121)
  INTERRUPT_CHECK (27, LABEL_292);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_889;
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_290]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd80.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd80.uLng) == 1))
    goto label_888;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd78.Obj) = ((Wrd77.pObj) [1]);
  (* (--Rsp)) = (Wrd78.Obj);

DEFLABEL (label_887)
  (Wrd85.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd85.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_294]));

DEFLABEL (continuation_124)
  INTERRUPT_CHECK (27, LABEL_290);
  (Wrd99.Obj) = (Rsp [0]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd100.uLng) == 1))
    goto label_886;
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd99.Obj));
  ((Wrd98.pObj) [1]) = Rvl;

DEFLABEL (label_885)
  (Wrd14.Obj) = (Rsp [4]);

DEFLABEL (label_884)
  Rsp = (& (Rsp [5]));

DEFLABEL (label_883)
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  ((Wrd18.pObj) [0]) = (Wrd14.Obj);
  goto label_875;

DEFLABEL (label_886)
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_291]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 2);

DEFLABEL (label_487)
  goto label_885;

DEFLABEL (label_888)
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_293]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_484)
  (* (--Rsp)) = Rvl;
  goto label_887;

DEFLABEL (label_889)
  (Wrd89.Obj) = (current_block [OBJECT_47]);
  (Wrd90.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd89.Obj);
  (* (Rhp++)) = (Wrd90.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Wrd94.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd94.Obj);
  (Wrd93.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd93.pObj)));
  goto label_884;

DEFLABEL (label_890)
  (Wrd14.Obj) = (Rsp [3]);
  Rsp = (& (Rsp [4]));
  goto label_883;

DEFLABEL (label_892)
  (Wrd88.Obj) = (Rsp [0]);
  (Wrd89.Obj) = (current_block [OBJECT_13]);
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_265]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_464)
  (* (--Rsp)) = Rvl;
  goto label_891;

DEFLABEL (label_894)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_264]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25]), 1);

DEFLABEL (label_463)
  (* (--Rsp)) = Rvl;
  goto label_893;

DEFLABEL (label_896)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_263]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_462)
  (Wrd58.Obj) = Rvl;
  goto label_895;

DEFLABEL (label_898)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_459)
  (* (--Rsp)) = Rvl;
  goto label_897;

DEFLABEL (label_900)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_260]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_458)
  (Wrd7.Obj) = Rvl;
  goto label_899;

DEFLABEL (lambda_520)
  CLOSURE_HEADER (LABEL_255);

DEFLABEL (lambda_272)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_910;
  Wrd5 = Wrd9;

DEFLABEL (label_909)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_908;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_908;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_907)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_901;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_901)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_282]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_283]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [3]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_906;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd48.Lng))))
    goto label_906;
  (Wrd40.Obj) = ((Wrd46.pObj) [7]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_905)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_270)
  INTERRUPT_CHECK (27, LABEL_283);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto procedure_simplified_value_344;

DEFLABEL (continuation_271)
  INTERRUPT_CHECK (27, LABEL_282);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [4]);
  if ((Wrd9.Obj) == Rvl)
    goto label_903;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_902;

DEFLABEL (label_903)
  Rvl = (current_block [OBJECT_26]);

DEFLABEL (label_902)
DEFLABEL (label_904)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_906)
  (Wrd54.Obj) = (Rsp [2]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [3]);
  (Wrd56.Obj) = (current_block [OBJECT_32]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_284]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_472)
  (* (--Rsp)) = Rvl;
  goto label_905;

DEFLABEL (label_908)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_27]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_281]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_471)
  (Wrd11.Obj) = Rvl;
  goto label_907;

DEFLABEL (label_910)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_280])), (Wrd6.pObj));

DEFLABEL (label_470)
  (Wrd5.Obj) = Rvl;
  goto label_909;

DEFLABEL (lambda_522)
  CLOSURE_HEADER (LABEL_267);

DEFLABEL (lambda_118)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_915;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 20L) < ((unsigned long) (Wrd36.Lng))))
    goto label_915;
  (Wrd7.Obj) = ((Wrd34.pObj) [21]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_912;

DEFLABEL (label_911)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_912)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_914;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd20.Lng))))
    goto label_914;
  (Wrd12.Obj) = ((Wrd18.pObj) [15]);

DEFLABEL (label_913)
  (Rsp [1]) = (Wrd12.Obj);
  (Wrd28.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65]));

DEFLABEL (label_914)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.Obj) = (current_block [OBJECT_28]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_297]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_477)
  (Wrd12.Obj) = Rvl;
  goto label_913;

DEFLABEL (label_915)
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.Obj) = (current_block [OBJECT_53]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_296]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 2);

DEFLABEL (label_478)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_912;
  goto label_911;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

int
decl_sideff_so_9f9fa6ea6f208bc8 (void)
{
  return (0);
}

DECLARE_COMPILED_CODE ("sideff.so", 259, decl_sideff_so_9f9fa6ea6f208bc8, sideff_so_9f9fa6ea6f208bc8)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_sideff_so_data_9f9fa6ea6f208bc8 [3777] =
  "\x9d\x05\x03\xab\x05\x1d\x0c\x81\x0d\x02\x0d\xb8\x08\x88\xc2\x0d"
  "\x02\x0c\x0d\xb0\x0d\x0c\x0d\x0c\x0d\x02\x0d\x0d\x06\x0d\x02\x0d"
  "\xb8\x0d\x86\x02\x02\xb0\x0d\x08\x89\x02\x80\x07\xc1\x02\x02\xc1"
  "\x02\x0d\x85\x0d\x02\x82\x02\xc2\x83\x1d\x02\x02\xc3\x02\x08\xc3"
  "\x0d\x0d\xb8\xc3\x0d\xb9\xb0\xb1\x99\x1e\x1e\x99\x28\x0d\x26\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x24\x28\xb0"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02"
  "\x4e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f\x6d\x69"
  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30\x2e\x31"
  "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67"
  "\x6f\x70\x74\x2f\x73\x69\x64\x65\x66\x66\x2e\x69\x6e\x66\x05\x62"
  "\x65\x74\x61\x15\x07\x72\x61\x6e\x64\x6f\x6d\x09\x73\x65\x74\x2d"
  "\x63\x64\x72\x21\x08\x74\x72\x69\x76\x69\x61\x6c\x10\x31\x63\x6f"
  "\x6d\x70\x75\x74\x65\x2d\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63"
  "\x74\x73\x21\x3a\x20\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x73\x69\x64"
  "\x65\x2d\x65\x66\x66\x65\x63\x74\x20\x63\x6c\x61\x73\x73\x13\x64"
  "\x65\x72\x69\x76\x65\x64\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e"
  "\x74\x12\x64\x65\x72\x69\x76\x65\x64\x2d\x61\x72\x62\x69\x74\x72"
  "\x61\x72\x79\x27\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2f\x74\x72"
  "\x69\x76\x69\x61\x6c\x21\x3a\x20\x41\x6c\x72\x65\x61\x64\x79\x20"
  "\x73\x69\x6d\x70\x6c\x69\x66\x69\x65\x64\x11\x75\x73\x75\x61\x6c"
  "\x2d\x64\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x38\x63\x6f\x6e\x74"
  "\x69\x6e\x75\x61\x74\x69\x6f\x6e\x20\x76\x61\x72\x69\x61\x62\x6c"
  "\x65\x20\x69\x6e\x76\x6f\x6b\x65\x64\x20\x69\x6e\x20\x6e\x6f\x6e"
  "\x2d\x72\x65\x74\x75\x72\x6e\x20\x61\x70\x70\x6c\x69\x63\x61\x74"
  "\x69\x6f\x6e\x0e\x70\x75\x72\x65\x2d\x66\x75\x6e\x63\x74\x69\x6f"
  "\x6e\x11\x0b\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x05\x64\x6f"
  "\x6e\x65\x11\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63\x74\x2d\x66"
  "\x72\x65\x65\x14\x0a\x61\x72\x62\x69\x74\x72\x61\x72\x79\x07\x72"
  "\x65\x74\x75\x72\x6e\x0a\x0c\x09\x62\x79\x70\x61\x73\x73\x65\x64"
  "\x0f\x04\x63\x64\x72\x0b\x08\x04\x63\x61\x72\x09\x0c\x63\x6f\x6d"
  "\x62\x69\x6e\x61\x74\x69\x6f\x6e\x0b\x73\x69\x6d\x70\x6c\x69\x66"
  "\x69\x65\x64\x1d\x0d\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66"
  "\x02\x1a\x19\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x18"
  "\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e"
  "\x74\x15\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63\x74\x2d\x61\x6e"
  "\x61\x6c\x79\x73\x69\x73\x12\x63\x6c\x65\x61\x72\x2d\x63\x61\x6c"
  "\x6c\x2d\x67\x72\x61\x70\x68\x21\x13\x6c\x65\x78\x69\x63\x61\x6c"
  "\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x14\x63\x6f\x6d\x70"
  "\x75\x74\x65\x2d\x63\x61\x6c\x6c\x2d\x67\x72\x61\x70\x68\x21\x05"
  "\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65"
  "\x02\x18\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x63\x6f\x6e\x74"
  "\x69\x6e\x75\x61\x74\x69\x6f\x6e\x3f\x1c\x63\x6f\x6e\x74\x69\x6e"
  "\x75\x61\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x11\x72\x76\x61\x6c\x75\x65\x2f\x63\x6f\x6e"
  "\x73\x74\x61\x6e\x74\x3f\x1f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x61\x6e\x61\x6c\x79\x7a\x65\x2d\x73\x69\x64\x65\x2d\x65\x66\x66"
  "\x65\x63\x74\x73\x3f\x0d\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x74"
  "\x61\x67\x0d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x74\x61\x67\x0e"
  "\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x74\x61\x67\x19\x63\x6f"
  "\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x2f"
  "\x65\x66\x66\x65\x63\x74\x0e\x72\x65\x66\x65\x72\x65\x6e\x63\x65"
  "\x2d\x74\x61\x67\x12\x72\x76\x61\x6c\x75\x65\x2f\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x3f\x19\x61\x70\x70\x6c\x69\x63\x61\x74\x69"
  "\x6f\x6e\x2f\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3f\x19"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x65\x72\x72\x6f\x72\x2d\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x1c\x73\x69\x64\x65\x2d\x65\x66"
  "\x66\x65\x63\x74\x2d\x66\x72\x65\x65\x2d\x70\x72\x69\x6d\x69\x74"
  "\x69\x76\x65\x73\x1b\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63\x74"
  "\x2d\x66\x72\x65\x65\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x0f"
  "\x03\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x04\x18\x6c\x69\x73"
  "\x74\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x2d\x6e\x65\x67\x61"
  "\x74\x69\x76\x65\x04\x0e\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d"
  "\x67\x65\x74\x03\x12\x72\x76\x61\x6c\x75\x65\x2d\x70\x61\x73\x73"
  "\x65\x64\x2d\x69\x6e\x3f\x03\x0f\x65\x64\x67\x65\x2d\x6e\x65\x78"
  "\x74\x2d\x6e\x6f\x64\x65\x03\x0e\x72\x76\x61\x6c\x75\x65\x2d\x76"
  "\x61\x6c\x75\x65\x73\x04\x18\x62\x6c\x6f\x63\x6b\x2d\x61\x6e\x63"
  "\x65\x73\x74\x6f\x72\x2d\x6f\x72\x2d\x73\x65\x6c\x66\x3f\x04\x0e"
  "\x65\x71\x2d\x73\x65\x74\x2d\x61\x64\x6a\x6f\x69\x6e\x03\x0d\x61"
  "\x70\x70\x6c\x69\x63\x61\x74\x69\x6f\x6e\x3f\x04\x0d\x65\x71\x2d"
  "\x73\x65\x74\x2d\x75\x6e\x69\x6f\x6e\x04\x18\x6c\x69\x73\x74\x2d"
  "\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x2d\x70\x6f\x73\x69\x74\x69"
  "\x76\x65\x03\x13\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2f\x63\x6c"
  "\x6f\x73\x75\x72\x65\x3f\x03\x0e\x6d\x61\x6b\x65\x2d\x63\x6f\x6e"
  "\x73\x74\x61\x6e\x74\x03\x18\x72\x65\x66\x65\x72\x65\x6e\x63\x65"
  "\x2d\x63\x6f\x6e\x74\x65\x78\x74\x2f\x62\x6c\x6f\x63\x6b\x03\x1b"
  "\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x76\x61\x72"
  "\x69\x61\x62\x6c\x65\x2f\x74\x79\x70\x65\x04\x09\x66\x6f\x72\x2d"
  "\x61\x6c\x6c\x3f\x03\x13\x72\x76\x61\x6c\x75\x65\x2d\x6b\x6e\x6f"
  "\x77\x6e\x2d\x76\x61\x6c\x75\x65\x04\x05\x6d\x65\x6d\x71\x03\x1b"
  "\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2f\x74\x72\x69\x76\x69\x61"
  "\x6c\x2d\x63\x6c\x6f\x73\x75\x72\x65\x3f\x04\x05\x61\x73\x73\x71"
  "\x03\x15\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x3f\x05\x13\x74\x72\x61\x6e\x73\x69\x74\x69"
  "\x76\x65\x2d\x63\x6c\x6f\x73\x75\x72\x65\x04\x07\x61\x70\x70\x65"
  "\x6e\x64\x04\x0e\x74\x68\x65\x72\x65\x2d\x65\x78\x69\x73\x74\x73"
  "\x3f\x03\x12\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x6f\x62\x6a"
  "\x65\x63\x74\x3f\x04\x06\x65\x72\x72\x6f\x72\x05\x0f\x6d\x61\x6b"
  "\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x04\x16\x63\x6f\x6d"
  "\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2f\x63\x6f\x6e\x73\x74\x61\x6e"
  "\x74\x21\x05\x0f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x70\x75"
  "\x74\x21\x03\x17\x6d\x61\x6b\x65\x2d\x72\x65\x66\x65\x72\x65\x6e"
  "\x63\x65\x2d\x63\x6f\x6e\x74\x65\x78\x74\x03\x0e\x65\x6e\x71\x75"
  "\x65\x75\x65\x2d\x6e\x6f\x64\x65\x21\x04\x08\x61\x70\x70\x65\x6e"
  "\x64\x21\x03\x0f\x65\x6e\x71\x75\x65\x75\x65\x2d\x6e\x6f\x64\x65"
  "\x73\x21\x04\x1a\x73\x65\x74\x2d\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x65\x6e\x74\x72\x79\x2d\x6e\x6f\x64\x65\x21\x07\x11\x6d"
  "\x61\x6b\x65\x2d\x61\x70\x70\x6c\x69\x63\x61\x74\x69\x6f\x6e\x25"
  "\x83\x02\x88\x04\x80\x80\x04\x82\x02\x86\x04\x81\x81\x02\x81\x02"
  "\x84\x04\x81\x8f\x02\x80\x02\x82\x04\x81\x8b\x02\xff\x01\x80\x04"
  "\x81\x89\x02\xfe\x01\xfe\x03\x81\x89\x02\xfd\x01\xfc\x03\x81\x87"
  "\x02\xfc\x01\xfa\x03\x81\x85\x02\xfb\x01\xf8\x03\x81\x93\x02\xfa"
  "\x01\xf6\x03\x81\x93\x02\xf9\x01\xf4\x03\x81\x91\x02\xf8\x01\xf2"
  "\x03\x81\x8f\x02\xf7\x01\xf0\x03\x81\x87\x02\xf6\x01\xee\x03\x81"
  "\x8d\x02\xf5\x01\xec\x03\x81\x83\x02\xf4\x01\xea\x03\x81\x87\x02"
  "\xf3\x01\xe8\x03\x81\x87\x02\xf2\x01\xe6\x03\x81\x85\x02\xf1\x01"
  "\xe4\x03\x81\x87\x02\xf0\x01\xe2\x03\x81\x85\x02\xef\x01\xe0\x03"
  "\x81\x85\x02\xee\x01\xde\x03\x81\x87\x02\xed\x01\xdc\x03\x81\x91"
  "\x02\xec\x01\xda\x03\x81\x89\x02\xeb\x01\xd8\x03\x81\x89\x02\xea"
  "\x01\xd6\x03\x81\x95\x02\xe9\x01\xd4\x03\x81\x91\x02\xe8\x01\xd2"
  "\x03\x81\x93\x02\xe7\x01\xd0\x03\x81\x93\x02\xe6\x01\xce\x03\x81"
  "\x89\x02\xe5\x01\xcc\x03\x81\x85\x02\xe4\x01\xca\x03\x81\x83\x02"
  "\xe3\x01\xc8\x03\x81\x87\x02\xe2\x01\xc6\x03\x81\x87\x02\xe1\x01"
  "\xc4\x03\x81\x89\x02\xe0\x01\xc2\x03\x81\x87\x02\xdf\x01\xc0\x03"
  "\x81\x85\x02\xde\x01\xbe\x03\x81\x85\x02\xdd\x01\xbc\x03\x81\x89"
  "\x02\xdc\x01\xba\x03\x81\x85\x02\xdb\x01\xb8\x03\x81\x85\x02\xda"
  "\x01\xb6\x03\x81\x87\x02\xd9\x01\xb4\x03\x81\x87\x02\xd8\x01\xb2"
  "\x03\x81\x87\x02\xd7\x01\xb0\x03\x81\x87\x02\xd6\x01\xae\x03\x81"
  "\x87\x02\xd5\x01\xac\x03\x81\x85\x02\xd4\x01\xaa\x03\x81\x8b\x02"
  "\xd3\x01\xa8\x03\x81\x8b\x02\xd2\x01\xa6\x03\x81\x8f\x02\xd1\x01"
  "\xa4\x03\x81\x8b\x02\xd0\x01\xa2\x03\x81\x8b\x02\xcf\x01\xa0\x03"
  "\x81\x87\x02\xce\x01\x9e\x03\x81\x87\x02\xcd\x01\x9c\x03\x81\x87"
  "\x02\xcc\x01\x9a\x03\x81\x85\x02\xcb\x01\x98\x03\x81\x89\x02\xca"
  "\x01\x96\x03\x81\x87\x02\xc9\x01\x94\x03\x81\x8b\x02\xc8\x01\x92"
  "\x03\x81\x89\x02\xc7\x01\x90\x03\x81\x89\x02\xc6\x01\x8e\x03\x81"
  "\x85\x02\xc5\x01\x8c\x03\x81\x85\x02\xc4\x01\x8a\x03\x81\x89\x02"
  "\xc3\x01\x88\x03\x81\x87\x02\xc2\x01\x86\x03\x81\x83\x02\xc1\x01"
  "\x84\x03\x81\x87\x02\xc0\x01\x82\x03\x81\x83\x02\xbf\x01\x80\x03"
  "\x81\x87\x02\xbe\x01\xfe\x02\x81\x85\x02\xbd\x01\xfc\x02\x81\x87"
  "\x02\xbc\x01\xfa\x02\x81\x85\x02\xbb\x01\xf8\x02\x81\x85\x02\xba"
  "\x01\xf6\x02\x81\x85\x02\xb9\x01\xf4\x02\x81\x85\x02\xb8\x01\xf2"
  "\x02\x81\x89\x02\xb7\x01\xf0\x02\x81\x87\x02\xb6\x01\xee\x02\x81"
  "\x8f\x02\xb5\x01\xec\x02\x81\x8d\x02\xb4\x01\xea\x02\x81\x8b\x02"
  "\xb3\x01\xe8\x02\x81\x87\x02\xb2\x01\xe6\x02\x81\x89\x02\xb1\x01"
  "\xe4\x02\x81\x89\x02\xb0\x01\xe2\x02\x81\x8d\x02\xaf\x01\xe0\x02"
  "\x81\x8b\x02\xae\x01\xde\x02\x81\x89\x02\xad\x01\xdc\x02\x81\x87"
  "\x02\xac\x01\xda\x02\x81\x87\x02\xab\x01\xd8\x02\x81\x87\x02\xaa"
  "\x01\xd6\x02\x81\x85\x02\xa9\x01\xd4\x02\x81\x83\x02\xa8\x01\xd2"
  "\x02\x81\x85\x02\xa7\x01\xd0\x02\x81\x83\x02\xa6\x01\xce\x02\x81"
  "\x83\x02\xa5\x01\xcc\x02\x81\x83\x02\xa4\x01\xca\x02\x81\x83\x02"
  "\xa3\x01\xc8\x02\x81\x83\x02\xa2\x01\xc6\x02\x81\x85\x02\xa1\x01"
  "\xc4\x02\x81\x85\x02\xa0\x01\xc2\x02\x81\x83\x02\x9f\x01\xc0\x02"
  "\x81\x87\x02\x9e\x01\xbe\x02\x81\x85\x02\x9d\x01\xbc\x02\x81\x85"
  "\x02\x9c\x01\xba\x02\x81\x87\x02\x9b\x01\xb8\x02\x81\x85\x02\x9a"
  "\x01\xb6\x02\x81\x85\x02\x99\x01\xb4\x02\x81\x85\x02\x98\x01\xb2"
  "\x02\x81\x8b\x02\x97\x01\xb0\x02\x81\x89\x02\x96\x01\xae\x02\x81"
  "\x85\x02\x95\x01\xac\x02\x81\x89\x02\x94\x01\xaa\x02\x81\x87\x02"
  "\x93\x01\xa8\x02\x81\x87\x02\x92\x01\xa6\x02\x81\x87\x02\x91\x01"
  "\xa4\x02\x81\x87\x02\x90\x01\xa2\x02\x81\x87\x02\x8f\x01\xa0\x02"
  "\x81\x95\x02\x8e\x01\x9e\x02\x81\x91\x02\x8d\x01\x9c\x02\x81\x8d"
  "\x02\x8c\x01\x9a\x02\x81\x89\x02\x8b\x01\x98\x02\x81\x89\x02\x8a"
  "\x01\x96\x02\x81\x8d\x02\x89\x01\x94\x02\x81\x8b\x02\x88\x01\x92"
  "\x02\x81\x8b\x02\x87\x01\x90\x02\x81\x87\x02\x86\x01\x8e\x02\x81"
  "\x8d\x02\x85\x01\x8c\x02\x81\x8b\x02\x84\x01\x8a\x02\x81\x8b\x02"
  "\x83\x01\x88\x02\x81\x8b\x02\x82\x01\x86\x02\x81\x89\x02\x81\x01"
  "\x84\x02\x81\x8b\x02\x80\x01\x82\x02\x81\x8d\x02\x7f\x80\x02\x81"
  "\x8b\x02\x7e\xfe\x01\x81\x8f\x02\x7d\xfc\x01\x81\x8d\x02\x7c\xfa"
  "\x01\x81\x8d\x02\x7b\xf8\x01\x81\x8d\x02\x7a\xf6\x01\x81\x8d\x02"
  "\x79\xf4\x01\x81\x8d\x02\x78\xf2\x01\x81\x8d\x02\x77\xf0\x01\x81"
  "\x83\x02\x76\xee\x01\x81\x83\x02\x75\xec\x01\x81\x85\x02\x74\xea"
  "\x01\x81\x83\x02\x73\xe8\x01\x81\x83\x02\x72\xe6\x01\x81\x85\x02"
  "\x71\xe4\x01\x81\x83\x02\x70\xe2\x01\x83\x04\x6f\xe0\x01\x81\x83"
  "\x02\x6e\xde\x01\x81\x87\x02\x6d\xdc\x01\x81\x83\x02\x6c\xda\x01"
  "\x81\x83\x02\x6b\xd8\x01\x83\x04\x6a\xd6\x01\x81\x8d\x02\x69\xd4"
  "\x01\x81\x89\x02\x68\xd2\x01\x81\x87\x02\x67\xd0\x01\x81\x87\x02"
  "\x66\xce\x01\x81\x87\x02\x65\xcc\x01\x81\x85\x02\x64\xca\x01\x81"
  "\x85\x02\x63\xc8\x01\x81\x93\x02\x62\xc6\x01\x81\x8d\x02\x61\xc4"
  "\x01\x81\x8f\x02\x60\xc2\x01\x81\x91\x02\x5f\xc0\x01\x81\x8f\x02"
  "\x5e\xbe\x01\x81\x85\x02\x5d\xbc\x01\x81\x83\x02\x5c\xba\x01\x81"
  "\x8b\x02\x5b\xb8\x01\x81\x8b\x02\x5a\xb6\x01\x81\x89\x02\x59\xb4"
  "\x01\x81\x89\x02\x58\xb2\x01\x81\x89\x02\x57\xb0\x01\x81\x8d\x02"
  "\x56\xae\x01\x81\x83\x02\x55\xac\x01\x81\x85\x02\x54\xaa\x01\x81"
  "\x83\x02\x53\xa8\x01\x83\x04\x52\xa6\x01\x81\x8d\x02\x51\xa4\x01"
  "\x81\x89\x02\x50\xa2\x01\x81\x8b\x02\x4f\xa0\x01\x81\x89\x02\x4e"
  "\x9e\x01\x81\x8f\x02\x4d\x9c\x01\x81\x89\x02\x4c\x9a\x01\x81\x89"
  "\x02\x4b\x98\x01\x81\x89\x02\x4a\x96\x01\x81\x8b\x02\x49\x94\x01"
  "\x81\x89\x02\x48\x92\x01\x81\x8b\x02\x47\x90\x01\x81\x89\x02\x46"
  "\x8e\x01\x81\x89\x02\x45\x8c\x01\x81\x8b\x02\x44\x8a\x01\x83\x04"
  "\x43\x88\x01\x81\x87\x02\x42\x86\x01\x81\x87\x02\x41\x84\x01\x83"
  "\x04\x40\x82\x01\x81\x89\x02\x3f\x80\x01\x81\x89\x02\x3e\x7e\x81"
  "\x87\x02\x3d\x7c\x81\x89\x02\x3c\x7a\x81\x87\x02\x3b\x78\x81\x87"
  "\x02\x3a\x76\x81\x89\x02\x39\x74\x81\x87\x02\x38\x72\x81\x87\x02"
  "\x37\x70\x81\x85\x02\x36\x6e\x84\x06\x35\x6c\x81\x8d\x02\x34\x6a"
  "\x81\x85\x02\x33\x68\x81\x93\x02\x32\x66\x81\x8f\x02\x31\x64\x81"
  "\x8d\x02\x30\x62\x81\x8b\x02\x2f\x60\x81\x87\x02\x2e\x5e\x81\x89"
  "\x02\x2d\x5c\x81\x8d\x02\x2c\x5a\x81\x87\x02\x2b\x58\x81\x85\x02"
  "\x2a\x56\x81\x85\x02\x29\x54\x81\x85\x02\x28\x52\x81\x89\x02\x27"
  "\x50\x81\x87\x02\x26\x4e\x81\x83\x02\x25\x4c\x84\x06\x24\x4a\x81"
  "\x8d\x02\x23\x48\x81\x89\x02\x22\x46\x81\x91\x02\x21\x44\x81\x89"
  "\x02\x20\x42\x81\x89\x02\x1f\x40\x81\x89\x02\x1e\x3e\x81\x89\x02"
  "\x1d\x3c\x81\x87\x02\x1c\x3a\x81\x89\x02\x1b\x38\x81\x89\x02\x1a"
  "\x36\x81\x87\x02\x19\x34\x81\x87\x02\x18\x32\x81\x85\x02\x17\x30"
  "\x81\x85\x02\x16\x2e\x81\x85\x02\x15\x2c\x81\x85\x02\x14\x2a\x81"
  "\x85\x02\x13\x28\x81\x87\x02\x12\x26\x81\x85\x02\x11\x24\x81\x85"
  "\x02\x10\x22\x81\x89\x02\x0f\x20\x81\x87\x02\x0e\x1e\x81\x8d\x02"
  "\x0d\x1c\x81\x87\x02\x0c\x1a\x81\x87\x02\x0b\x18\x83\x04\x0a\x16"
  "\x81\x83\x02\x09\x14\x81\x83\x02\x08\x12\x83\x04\x07\x10\x81\x83"
  "\x02\x06\x0e\x81\x83\x02\x05\x0c\x83\x04\x04\x0a\x81\x83\x02\x03"
  "\x08\x83\x04\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x87\x04\x9d"
  "\x05";

SCHEME_OBJECT *
sideff_so_data_9f9fa6ea6f208bc8 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_sideff_so_data_9f9fa6ea6f208bc8 [0]))), (sizeof (prog_sideff_so_data_9f9fa6ea6f208bc8)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_313]));
}

DECLARE_COMPILED_DATA_NS ("sideff.so", sideff_so_data_9f9fa6ea6f208bc8)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("sideff.so", "cc0856506d7dd9b4")
