/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:07-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_7 5
#define LABEL_1_8 7
#define LABEL_1_9 9
#define LABEL_1_10 11
#define LABEL_1_11 13
#define LABEL_1_12 15
#define LABEL_1_13 17
#define LABEL_1_14 19
#define LABEL_1_15 21
#define LABEL_1_16 23
#define LABEL_1_17 25
#define LABEL_1_18 27
#define LABEL_1_19 29
#define LABEL_1_20 31
#define LABEL_1_21 33
#define LABEL_1_5 35
#define LABEL_1_23 37
#define LABEL_1_6 39
#define LABEL_1_24 41
#define ENVIRONMENT_LABEL_1_3 84
#define DEBUGGING_LABEL_1_2 83
#define OBJECT_1_16 82
#define OBJECT_1_15 81
#define OBJECT_1_14 80
#define OBJECT_1_13 79
#define OBJECT_1_12 78
#define OBJECT_1_11 77
#define OBJECT_1_10 76
#define OBJECT_1_9 75
#define OBJECT_1_8 74
#define OBJECT_1_7 73
#define OBJECT_1_6 72
#define OBJECT_1_5 71
#define OBJECT_1_4 70
#define OBJECT_1_3 69
#define OBJECT_1_2 68
#define OBJECT_1_1 67
#define OBJECT_1_0 66
#define EXECUTE_CACHE_1_25 43
#define EXECUTE_CACHE_1_22 45
#define FREE_REFERENCE_1_15 48
#define FREE_REFERENCE_1_14 49
#define FREE_REFERENCE_1_13 50
#define FREE_REFERENCE_1_12 51
#define FREE_REFERENCE_1_11 52
#define FREE_REFERENCE_1_10 53
#define FREE_REFERENCE_1_9 54
#define FREE_REFERENCE_1_8 55
#define FREE_REFERENCE_1_7 56
#define FREE_REFERENCE_1_6 57
#define FREE_REFERENCE_1_5 58
#define FREE_REFERENCE_1_4 59
#define FREE_REFERENCE_1_3 60
#define FREE_REFERENCE_1_2 61
#define FREE_REFERENCE_1_1 62
#define FREE_REFERENCE_1_0 63
#define FREE_ASSIGNMENT_1_0 65
#define FREE_REFERENCES_LABEL_1_0 42
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd234;
  machine_word Wrd233;
  machine_word Wrd235;
  machine_word Wrd228;
  machine_word Wrd230;
  machine_word Wrd231;
  machine_word Wrd222;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd223;
  machine_word Wrd219;
  machine_word Wrd218;
  machine_word Wrd220;
  machine_word Wrd213;
  machine_word Wrd215;
  machine_word Wrd216;
  machine_word Wrd207;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd208;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd205;
  machine_word Wrd198;
  machine_word Wrd200;
  machine_word Wrd201;
  machine_word Wrd192;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd193;
  machine_word Wrd189;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd183;
  machine_word Wrd185;
  machine_word Wrd186;
  machine_word Wrd177;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd178;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd175;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd162;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd160;
  machine_word Wrd153;
  machine_word Wrd155;
  machine_word Wrd156;
  machine_word Wrd147;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd145;
  machine_word Wrd138;
  machine_word Wrd140;
  machine_word Wrd141;
  machine_word Wrd132;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd130;
  machine_word Wrd123;
  machine_word Wrd125;
  machine_word Wrd126;
  machine_word Wrd117;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd118;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd111;
  machine_word Wrd102;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd93;
  machine_word Wrd95;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd72;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd70;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto initialize_packageB_32;

    case 1:
      current_block = (Rpc - LABEL_1_7);
      goto label_34;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_35;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto label_36;

    case 4:
      current_block = (Rpc - LABEL_1_10);
      goto label_37;

    case 5:
      current_block = (Rpc - LABEL_1_11);
      goto label_38;

    case 6:
      current_block = (Rpc - LABEL_1_12);
      goto label_39;

    case 7:
      current_block = (Rpc - LABEL_1_13);
      goto label_40;

    case 8:
      current_block = (Rpc - LABEL_1_14);
      goto label_41;

    case 9:
      current_block = (Rpc - LABEL_1_15);
      goto label_42;

    case 10:
      current_block = (Rpc - LABEL_1_16);
      goto label_43;

    case 11:
      current_block = (Rpc - LABEL_1_17);
      goto label_44;

    case 12:
      current_block = (Rpc - LABEL_1_18);
      goto label_45;

    case 13:
      current_block = (Rpc - LABEL_1_19);
      goto label_46;

    case 14:
      current_block = (Rpc - LABEL_1_20);
      goto label_47;

    case 15:
      current_block = (Rpc - LABEL_1_21);
      goto label_48;

    case 16:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_31;

    case 17:
      current_block = (Rpc - LABEL_1_23);
      goto label_49;

    case 18:
      current_block = (Rpc - LABEL_1_6);
      goto continuation_30;

    case 19:
      current_block = (Rpc - LABEL_1_24);
      goto label_50;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_52)
DEFLABEL (initialize_packageB_32)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_87;
  Wrd12 = Wrd16;

DEFLABEL (label_86)
  (Wrd21.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_1_1]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_85;
  Wrd27 = Wrd31;

DEFLABEL (label_84)
  (Wrd36.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd40.Obj) = (current_block [OBJECT_1_2]);
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_83;
  Wrd42 = Wrd46;

DEFLABEL (label_82)
  (Wrd51.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd51.Obj);
  (Wrd50.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd50.pObj)));
  (Wrd55.Obj) = (current_block [OBJECT_1_3]);
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 50)
    goto label_81;
  Wrd57 = Wrd61;

DEFLABEL (label_80)
  (Wrd66.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd65.pObj) = (& (Rhp [-2]));
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd65.pObj)));
  (Wrd70.Obj) = (current_block [OBJECT_1_4]);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd63.Obj);
  (Wrd68.pObj) = (& (Rhp [-2]));
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd68.pObj)));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_4]));
  (Wrd76.Obj) = ((Wrd73.pObj) [0]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if ((Wrd77.uLng) == 50)
    goto label_79;
  Wrd72 = Wrd76;

DEFLABEL (label_78)
  (Wrd81.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd72.Obj);
  (* (Rhp++)) = (Wrd81.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (Wrd85.Obj) = (current_block [OBJECT_1_5]);
  (* (Rhp++)) = (Wrd85.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd83.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd83.pObj)));
  (* (--Rsp)) = (Wrd84.Obj);
  (Wrd88.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_5]));
  (Wrd91.Obj) = ((Wrd88.pObj) [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd92.uLng) == 50)
    goto label_77;
  Wrd87 = Wrd91;

DEFLABEL (label_76)
  (Wrd96.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd87.Obj);
  (* (Rhp++)) = (Wrd96.Obj);
  (Wrd95.pObj) = (& (Rhp [-2]));
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd95.pObj)));
  (Wrd100.Obj) = (current_block [OBJECT_1_6]);
  (* (Rhp++)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd93.Obj);
  (Wrd98.pObj) = (& (Rhp [-2]));
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd98.pObj)));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd103.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_6]));
  (Wrd106.Obj) = ((Wrd103.pObj) [0]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if ((Wrd107.uLng) == 50)
    goto label_75;
  Wrd102 = Wrd106;

DEFLABEL (label_74)
  (Wrd111.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd102.Obj);
  (* (Rhp++)) = (Wrd111.Obj);
  (Wrd110.pObj) = (& (Rhp [-2]));
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd110.pObj)));
  (Wrd115.Obj) = (current_block [OBJECT_1_7]);
  (* (Rhp++)) = (Wrd115.Obj);
  (* (Rhp++)) = (Wrd108.Obj);
  (Wrd113.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd113.pObj)));
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd118.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_7]));
  (Wrd121.Obj) = ((Wrd118.pObj) [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if ((Wrd122.uLng) == 50)
    goto label_73;
  Wrd117 = Wrd121;

DEFLABEL (label_72)
  (Wrd126.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd117.Obj);
  (* (Rhp++)) = (Wrd126.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (Wrd130.Obj) = (current_block [OBJECT_1_8]);
  (* (Rhp++)) = (Wrd130.Obj);
  (* (Rhp++)) = (Wrd123.Obj);
  (Wrd128.pObj) = (& (Rhp [-2]));
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd128.pObj)));
  (* (--Rsp)) = (Wrd129.Obj);
  (Wrd133.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_8]));
  (Wrd136.Obj) = ((Wrd133.pObj) [0]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if ((Wrd137.uLng) == 50)
    goto label_71;
  Wrd132 = Wrd136;

DEFLABEL (label_70)
  (Wrd141.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd132.Obj);
  (* (Rhp++)) = (Wrd141.Obj);
  (Wrd140.pObj) = (& (Rhp [-2]));
  (Wrd138.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd140.pObj)));
  (Wrd145.Obj) = (current_block [OBJECT_1_9]);
  (* (Rhp++)) = (Wrd145.Obj);
  (* (Rhp++)) = (Wrd138.Obj);
  (Wrd143.pObj) = (& (Rhp [-2]));
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd143.pObj)));
  (* (--Rsp)) = (Wrd144.Obj);
  (Wrd148.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_9]));
  (Wrd151.Obj) = ((Wrd148.pObj) [0]);
  (Wrd152.uLng) = (OBJECT_TYPE (Wrd151.Obj));
  if ((Wrd152.uLng) == 50)
    goto label_69;
  Wrd147 = Wrd151;

DEFLABEL (label_68)
  (Wrd156.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd147.Obj);
  (* (Rhp++)) = (Wrd156.Obj);
  (Wrd155.pObj) = (& (Rhp [-2]));
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd155.pObj)));
  (Wrd160.Obj) = (current_block [OBJECT_1_10]);
  (* (Rhp++)) = (Wrd160.Obj);
  (* (Rhp++)) = (Wrd153.Obj);
  (Wrd158.pObj) = (& (Rhp [-2]));
  (Wrd159.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd158.pObj)));
  (* (--Rsp)) = (Wrd159.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_10]));
  (Wrd166.Obj) = ((Wrd163.pObj) [0]);
  (Wrd167.uLng) = (OBJECT_TYPE (Wrd166.Obj));
  if ((Wrd167.uLng) == 50)
    goto label_67;
  Wrd162 = Wrd166;

DEFLABEL (label_66)
  (Wrd171.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd162.Obj);
  (* (Rhp++)) = (Wrd171.Obj);
  (Wrd170.pObj) = (& (Rhp [-2]));
  (Wrd168.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd170.pObj)));
  (Wrd175.Obj) = (current_block [OBJECT_1_11]);
  (* (Rhp++)) = (Wrd175.Obj);
  (* (Rhp++)) = (Wrd168.Obj);
  (Wrd173.pObj) = (& (Rhp [-2]));
  (Wrd174.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd173.pObj)));
  (* (--Rsp)) = (Wrd174.Obj);
  (Wrd178.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_11]));
  (Wrd181.Obj) = ((Wrd178.pObj) [0]);
  (Wrd182.uLng) = (OBJECT_TYPE (Wrd181.Obj));
  if ((Wrd182.uLng) == 50)
    goto label_65;
  Wrd177 = Wrd181;

DEFLABEL (label_64)
  (Wrd186.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd177.Obj);
  (* (Rhp++)) = (Wrd186.Obj);
  (Wrd185.pObj) = (& (Rhp [-2]));
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd185.pObj)));
  (Wrd190.Obj) = (current_block [OBJECT_1_12]);
  (* (Rhp++)) = (Wrd190.Obj);
  (* (Rhp++)) = (Wrd183.Obj);
  (Wrd188.pObj) = (& (Rhp [-2]));
  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd188.pObj)));
  (* (--Rsp)) = (Wrd189.Obj);
  (Wrd193.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_12]));
  (Wrd196.Obj) = ((Wrd193.pObj) [0]);
  (Wrd197.uLng) = (OBJECT_TYPE (Wrd196.Obj));
  if ((Wrd197.uLng) == 50)
    goto label_63;
  Wrd192 = Wrd196;

DEFLABEL (label_62)
  (Wrd201.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd192.Obj);
  (* (Rhp++)) = (Wrd201.Obj);
  (Wrd200.pObj) = (& (Rhp [-2]));
  (Wrd198.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd200.pObj)));
  (Wrd205.Obj) = (current_block [OBJECT_1_13]);
  (* (Rhp++)) = (Wrd205.Obj);
  (* (Rhp++)) = (Wrd198.Obj);
  (Wrd203.pObj) = (& (Rhp [-2]));
  (Wrd204.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd203.pObj)));
  (* (--Rsp)) = (Wrd204.Obj);
  (Wrd208.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_13]));
  (Wrd211.Obj) = ((Wrd208.pObj) [0]);
  (Wrd212.uLng) = (OBJECT_TYPE (Wrd211.Obj));
  if ((Wrd212.uLng) == 50)
    goto label_61;
  Wrd207 = Wrd211;

DEFLABEL (label_60)
  (Wrd216.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd207.Obj);
  (* (Rhp++)) = (Wrd216.Obj);
  (Wrd215.pObj) = (& (Rhp [-2]));
  (Wrd213.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd215.pObj)));
  (Wrd220.Obj) = (current_block [OBJECT_1_14]);
  (* (Rhp++)) = (Wrd220.Obj);
  (* (Rhp++)) = (Wrd213.Obj);
  (Wrd218.pObj) = (& (Rhp [-2]));
  (Wrd219.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd218.pObj)));
  (* (--Rsp)) = (Wrd219.Obj);
  (Wrd223.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_14]));
  (Wrd226.Obj) = ((Wrd223.pObj) [0]);
  (Wrd227.uLng) = (OBJECT_TYPE (Wrd226.Obj));
  if ((Wrd227.uLng) == 50)
    goto label_59;
  Wrd222 = Wrd226;

DEFLABEL (label_58)
  (Wrd231.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd222.Obj);
  (* (Rhp++)) = (Wrd231.Obj);
  (Wrd230.pObj) = (& (Rhp [-2]));
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd230.pObj)));
  (Wrd235.Obj) = (current_block [OBJECT_1_15]);
  (* (Rhp++)) = (Wrd235.Obj);
  (* (Rhp++)) = (Wrd228.Obj);
  (Wrd233.pObj) = (& (Rhp [-2]));
  (Wrd234.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd233.pObj)));
  (* (--Rsp)) = (Wrd234.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_22]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_1_6);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_15]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_57;
  Wrd5 = Wrd9;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_25]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_55;

DEFLABEL (label_54)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_53)
  Rvl = (current_block [OBJECT_1_16]);
  goto pop_return;

DEFLABEL (label_55)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_54;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_23])), (Wrd6.pObj), Rvl);

DEFLABEL (label_49)
  goto label_53;

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_24])), (Wrd6.pObj));

DEFLABEL (label_50)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_21])), (Wrd223.pObj));

DEFLABEL (label_48)
  (Wrd222.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_20])), (Wrd208.pObj));

DEFLABEL (label_47)
  (Wrd207.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_19])), (Wrd193.pObj));

DEFLABEL (label_46)
  (Wrd192.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_18])), (Wrd178.pObj));

DEFLABEL (label_45)
  (Wrd177.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_17])), (Wrd163.pObj));

DEFLABEL (label_44)
  (Wrd162.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_16])), (Wrd148.pObj));

DEFLABEL (label_43)
  (Wrd147.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_15])), (Wrd133.pObj));

DEFLABEL (label_42)
  (Wrd132.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_14])), (Wrd118.pObj));

DEFLABEL (label_41)
  (Wrd117.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_13])), (Wrd103.pObj));

DEFLABEL (label_40)
  (Wrd102.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_12])), (Wrd88.pObj));

DEFLABEL (label_39)
  (Wrd87.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_11])), (Wrd73.pObj));

DEFLABEL (label_38)
  (Wrd72.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_10])), (Wrd58.pObj));

DEFLABEL (label_37)
  (Wrd57.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_9])), (Wrd43.pObj));

DEFLABEL (label_36)
  (Wrd42.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_8])), (Wrd28.pObj));

DEFLABEL (label_35)
  (Wrd27.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_7])), (Wrd13.pObj));

DEFLABEL (label_34)
  (Wrd12.Obj) = Rvl;
  goto label_86;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_7 5
#define LABEL_2_5 7
#define LABEL_2_9 9
#define TAG_2_10 3
#define LABEL_2_11 11
#define TAG_2_12 4
#define LABEL_2_17 13
#define LABEL_2_18 15
#define LABEL_2_13 17
#define TAG_2_14 7
#define LABEL_2_19 19
#define LABEL_2_20 21
#define ENVIRONMENT_LABEL_2_3 39
#define DEBUGGING_LABEL_2_2 38
#define OBJECT_2_2 37
#define OBJECT_2_1 36
#define OBJECT_2_0 35
#define EXECUTE_CACHE_2_16 23
#define EXECUTE_CACHE_2_15 25
#define EXECUTE_CACHE_2_8 27
#define EXECUTE_CACHE_2_6 29
#define FREE_REFERENCE_2_0 32
#define FREE_ASSIGNMENT_2_0 34
#define FREE_REFERENCES_LABEL_2_0 22
#define NUMBER_OF_LINKER_SECTIONS_2_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd32;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto unsyntax_with_substitutions_18;

    case 1:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_2_9);
      goto lambda_26;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto lambda_27;

    case 5:
      current_block = (Rpc - LABEL_2_17);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_2_18);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_2_13);
      goto lambda_28;

    case 8:
      current_block = (Rpc - LABEL_2_19);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_2_20);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_with_substitutions_25)
DEFLABEL (unsyntax_with_substitutions_18)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;

DEFLABEL (label_29)
  (Wrd12.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd8.pObj) = (& (Rhp [-1]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-1]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_9])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd20 = Wrd19;
  (Wrd21.Obj) = (Rsp [2]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (Rsp [2]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_11])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd27 = Wrd24;
  ((Wrd27.pObj) [2]) = (Wrd9.Obj);
  ((Wrd27.pObj) [3]) = (Wrd15.Obj);
  (Rsp [3]) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_13])));
  Rhp += 2;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd34 = Wrd31;
  ((Wrd34.pObj) [2]) = (Wrd9.Obj);
  ((Wrd34.pObj) [3]) = (Wrd15.Obj);
  (Rsp [1]) = (Wrd30.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_15]));

DEFLABEL (label_30)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (current_block [OBJECT_2_0]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (current_block [OBJECT_2_1]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_7);
  goto label_29;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_2_9);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_16]));

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_2_11);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_36;

DEFLABEL (label_35)
  Wrd19 = Wrd23;

DEFLABEL (label_34)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_33;

DEFLABEL (label_32)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_31)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_33)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_32;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_21)
  goto label_31;

DEFLABEL (label_36)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_35;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_17])), (Wrd20.pObj));

DEFLABEL (label_20)
  (Wrd19.Obj) = Rvl;
  goto label_34;

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_2_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_42;

DEFLABEL (label_41)
  Wrd19 = Wrd23;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_39;

DEFLABEL (label_38)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_37)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_39)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_38;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_20])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_23)
  goto label_37;

DEFLABEL (label_42)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_41;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_19])), (Wrd20.pObj));

DEFLABEL (label_22)
  (Wrd19.Obj) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_5 3
#define LABEL_3_4 5
#define LABEL_3_6 7
#define LABEL_3_7 9
#define ENVIRONMENT_LABEL_3_3 17
#define DEBUGGING_LABEL_3_2 16
#define OBJECT_3_0 15
#define EXECUTE_CACHE_3_8 11
#define FREE_REFERENCE_3_0 14
#define FREE_REFERENCES_LABEL_3_0 10
#define NUMBER_OF_LINKER_SECTIONS_3_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd18;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_3_4);
      goto maybe_substitute_3;

    case 2:
      current_block = (Rpc - LABEL_3_6);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_3_7);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (maybe_substitute_8)
DEFLABEL (maybe_substitute_3)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_16;
  Wrd9 = Wrd13;

DEFLABEL (label_15)
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd15.uLng) == 1)
    goto label_12;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_11)
  (Wrd18.Obj) = (Rsp [0]);
  if (! ((Wrd18.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_9;
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd29.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_9)
  (Rsp [2]) = (Wrd18.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_10;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  Rvl = ((Wrd23.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_12)
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_14;
  Wrd31 = Wrd35;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_3_5);
  (* (--Rsp)) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_7])), (Wrd32.pObj));

DEFLABEL (label_6)
  (Wrd31.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_6])), (Wrd10.pObj));

DEFLABEL (label_5)
  (Wrd9.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_6 7
#define ENVIRONMENT_LABEL_4_3 14
#define DEBUGGING_LABEL_4_2 13
#define EXECUTE_CACHE_4_7 9
#define FREE_REFERENCE_4_0 12
#define FREE_REFERENCES_LABEL_4_0 8
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto has_substitutionP_1;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_4_6);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (has_substitutionP_6)
DEFLABEL (has_substitutionP_1)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_11;
  Wrd6 = Wrd10;

DEFLABEL (label_10)
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd12.uLng) == 1)
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd15.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_9;
  Wrd17 = Wrd21;

DEFLABEL (label_8)
  (Rsp [1]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_7]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_6])), (Wrd18.pObj));

DEFLABEL (label_4)
  (Wrd17.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_5])), (Wrd7.pObj));

DEFLABEL (label_3)
  (Wrd6.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define LABEL_5_6 7
#define LABEL_5_7 9
#define LABEL_5_8 11
#define LABEL_5_9 13
#define LABEL_5_11 15
#define LABEL_5_12 17
#define LABEL_5_13 19
#define ENVIRONMENT_LABEL_5_3 31
#define DEBUGGING_LABEL_5_2 30
#define OBJECT_5_2 29
#define OBJECT_5_1 28
#define OBJECT_5_0 27
#define EXECUTE_CACHE_5_10 21
#define FREE_REFERENCE_5_2 24
#define FREE_REFERENCE_5_1 25
#define FREE_REFERENCE_5_0 26
#define FREE_REFERENCES_LABEL_5_0 20
#define NUMBER_OF_LINKER_SECTIONS_5_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto with_bindings_9;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_5_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_5_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_5_8);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_5_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_5_11);
      goto label_15;

    case 7:
      current_block = (Rpc - LABEL_5_12);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_5_13);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (with_bindings_18)
DEFLABEL (with_bindings_9)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_35;
  Wrd5 = Wrd9;

DEFLABEL (label_34)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_20;

DEFLABEL (label_19)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_20)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_33;
  Wrd12 = Wrd16;

DEFLABEL (label_32)
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_31;
  Wrd19 = Wrd23;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_29;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_28)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [8]);
  if ((Wrd40.Obj) == ((SCHEME_OBJECT) 0))
    goto label_22;
  (Wrd46.Obj) = (current_block [OBJECT_5_1]);
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  goto label_21;

DEFLABEL (label_22)
  (Wrd47.Obj) = (current_block [OBJECT_5_1]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_21)
DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5_9);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_26;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  ((Wrd12.pObj) [1]) = Rvl;

DEFLABEL (label_25)
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_5_12);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_24;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [1]) = (Wrd9.Obj);

DEFLABEL (label_23)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [8]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_13]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 2);

DEFLABEL (label_16)
  goto label_23;

DEFLABEL (label_26)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_11]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 2);

DEFLABEL (label_15)
  goto label_25;

DEFLABEL (label_29)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_8]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_7])), (Wrd20.pObj));

DEFLABEL (label_13)
  (Wrd19.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_6])), (Wrd13.pObj));

DEFLABEL (label_12)
  (Wrd12.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_5])), (Wrd6.pObj));

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_34;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define TAG_6_6 1
#define LABEL_6_12 7
#define LABEL_6_13 9
#define LABEL_6_7 11
#define TAG_6_8 4
#define LABEL_6_9 13
#define TAG_6_10 5
#define LABEL_6_17 15
#define LABEL_6_18 17
#define LABEL_6_15 19
#define LABEL_6_14 21
#define ENVIRONMENT_LABEL_6_3 38
#define DEBUGGING_LABEL_6_2 37
#define OBJECT_6_1 36
#define OBJECT_6_0 35
#define EXECUTE_CACHE_6_20 23
#define EXECUTE_CACHE_6_19 25
#define EXECUTE_CACHE_6_16 27
#define EXECUTE_CACHE_6_11 29
#define FREE_REFERENCE_6_0 32
#define FREE_ASSIGNMENT_6_0 34
#define FREE_REFERENCES_LABEL_6_0 22
#define NUMBER_OF_LINKER_SECTIONS_6_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto unsyntax_20;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto lambda_28;

    case 2:
      current_block = (Rpc - LABEL_6_12);
      goto label_22;

    case 3:
      current_block = (Rpc - LABEL_6_13);
      goto label_23;

    case 4:
      current_block = (Rpc - LABEL_6_7);
      goto lambda_29;

    case 5:
      current_block = (Rpc - LABEL_6_9);
      goto lambda_30;

    case 6:
      current_block = (Rpc - LABEL_6_17);
      goto label_24;

    case 7:
      current_block = (Rpc - LABEL_6_18);
      goto label_25;

    case 8:
      current_block = (Rpc - LABEL_6_15);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_6_14);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_27)
DEFLABEL (unsyntax_20)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_6_0]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd40.pObj) = (& (Rhp [-1]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd40.pObj)));
  (Rsp [0]) = (Wrd41.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_5])));
  Rhp += 2;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd25 = Wrd22;
  ((Wrd25.pObj) [2]) = (Wrd7.Obj);
  ((Wrd25.pObj) [3]) = (Wrd41.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_7])));
  Rhp += 1;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd30 = Wrd29;
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd30.pObj) [2]) = (Wrd31.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd34.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_9])));
  Rhp += 2;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd34.pObj)));
  Wrd37 = Wrd34;
  ((Wrd37.pObj) [2]) = (Wrd7.Obj);
  ((Wrd37.pObj) [3]) = (Wrd41.Obj);
  (Rsp [2]) = (Wrd33.Obj);
  (Rsp [1]) = (Wrd28.Obj);
  (Rsp [0]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_11]));

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_6_5);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_36;

DEFLABEL (label_35)
  Wrd19 = Wrd23;

DEFLABEL (label_34)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_33;

DEFLABEL (label_32)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_31)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_6_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_33)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_32;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_13])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_23)
  goto label_31;

DEFLABEL (label_36)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_35;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_12])), (Wrd20.pObj));

DEFLABEL (label_22)
  (Wrd19.Obj) = Rvl;
  goto label_34;

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_6_7);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_6_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_19]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_6_14);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_37)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_20]));

DEFLABEL (label_38)
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd13.pObj) [2]);
  Rsp = (& (Rsp [1]));
  goto label_37;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_6_9);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_44;

DEFLABEL (label_43)
  Wrd19 = Wrd23;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_6_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_41;

DEFLABEL (label_40)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_39)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_6_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_41)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_40;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_6_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_25)
  goto label_39;

DEFLABEL (label_44)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_43;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_6_17])), (Wrd20.pObj));

DEFLABEL (label_24)
  (Wrd19.Obj) = Rvl;
  goto label_42;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_8 7
#define LABEL_7_7 9
#define ENVIRONMENT_LABEL_7_3 18
#define DEBUGGING_LABEL_7_2 17
#define EXECUTE_CACHE_7_9 11
#define EXECUTE_CACHE_7_6 13
#define FREE_REFERENCE_7_0 16
#define FREE_REFERENCES_LABEL_7_0 10
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto unsyntax_object_2;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto lambda_1;

    case 2:
      current_block = (Rpc - LABEL_7_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_7_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_object_6)
DEFLABEL (unsyntax_object_2)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_6]));

DEFLABEL (lambda_7)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_7_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_9;
  Wrd9 = Wrd13;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_7);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_8])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_6 5
#define LABEL_8_5 7
#define LABEL_8_9 9
#define LABEL_8_8 11
#define ENVIRONMENT_LABEL_8_3 21
#define DEBUGGING_LABEL_8_2 20
#define OBJECT_8_2 19
#define OBJECT_8_1 18
#define OBJECT_8_0 17
#define EXECUTE_CACHE_8_10 13
#define EXECUTE_CACHE_8_7 15
#define FREE_REFERENCES_LABEL_8_0 12
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto unsyntax_objects_5;

    case 1:
      current_block = (Rpc - LABEL_8_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_8_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_8_8);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_objects_10)
DEFLABEL (unsyntax_objects_5)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_11;
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_15;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_8_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_13;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_12)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_8_8);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_2]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_0]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_7 5
#define LABEL_9_8 7
#define LABEL_9_5 9
#define LABEL_9_9 11
#define LABEL_9_10 13
#define LABEL_9_11 15
#define LABEL_9_12 17
#define LABEL_9_13 19
#define LABEL_9_14 21
#define LABEL_9_16 23
#define ENVIRONMENT_LABEL_9_3 47
#define DEBUGGING_LABEL_9_2 46
#define OBJECT_9_12 45
#define OBJECT_9_11 44
#define OBJECT_9_10 43
#define OBJECT_9_9 42
#define OBJECT_9_8 41
#define OBJECT_9_7 40
#define OBJECT_9_6 39
#define OBJECT_9_5 38
#define OBJECT_9_4 37
#define OBJECT_9_3 36
#define OBJECT_9_2 35
#define OBJECT_9_1 34
#define OBJECT_9_0 33
#define EXECUTE_CACHE_9_18 25
#define EXECUTE_CACHE_9_17 27
#define EXECUTE_CACHE_9_15 29
#define EXECUTE_CACHE_9_6 31
#define FREE_REFERENCES_LABEL_9_0 24
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd73;
  machine_word Wrd79;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd67;
  machine_word Wrd57;
  machine_word Wrd104;
  machine_word Wrd54;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd120;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd39;
  machine_word Wrd29;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd146;
  machine_word Wrd143;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd156;
  machine_word Wrd153;
  machine_word Wrd171;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto unsyntax_constant_24;

    case 1:
      current_block = (Rpc - LABEL_9_7);
      goto continuation_11;

    case 2:
      current_block = (Rpc - LABEL_9_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_9_9);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_9_10);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_9_11);
      goto label_28;

    case 7:
      current_block = (Rpc - LABEL_9_12);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_9_13);
      goto label_26;

    case 9:
      current_block = (Rpc - LABEL_9_14);
      goto continuation_15;

    case 10:
      current_block = (Rpc - LABEL_9_16);
      goto continuation_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_constant_32)
DEFLABEL (unsyntax_constant_24)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;

DEFLABEL (label_34)
  Rvl = (Rsp [0]);

DEFLABEL (label_33)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd163.Obj) = (current_block [OBJECT_9_0]);
  (Wrd166.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd166.Lng))))
    goto label_65;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd163.Obj));
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_58;

DEFLABEL (label_64)
  (Wrd153.Obj) = (current_block [OBJECT_9_2]);
  (Wrd156.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd156.Lng))))
    goto label_63;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd153.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd18.Obj) == (Wrd20.Obj))
    goto label_58;

DEFLABEL (label_62)
  (Wrd143.Obj) = (current_block [OBJECT_9_3]);
  (Wrd146.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd146.Lng))))
    goto label_61;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd143.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_58;

DEFLABEL (label_60)
  (Wrd133.Obj) = (current_block [OBJECT_9_4]);
  (Wrd136.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd136.Lng))))
    goto label_59;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd133.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd26.Obj) == (Wrd28.Obj))
    goto label_58;

DEFLABEL (label_57)
  (Wrd29.Obj) = (current_block [OBJECT_9_5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd39.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 60L) < ((unsigned long) (Wrd39.Lng)))
    goto label_37;

DEFLABEL (label_36)
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_37)
  (Wrd33.uLng) = (OBJECT_DATUM (Wrd29.Obj));
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd33.Obj) == (Wrd35.Obj))
    goto label_39;
  (Wrd31.Obj) = (current_block [OBJECT_9_7]);
  goto label_38;

DEFLABEL (label_39)
  (Wrd31.Obj) = (current_block [OBJECT_9_6]);

DEFLABEL (label_38)
DEFLABEL (label_56)
  Rsp = (& (Rsp [3]));
  if (! ((Wrd31.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_34;

DEFLABEL (label_55)
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 2)
    goto label_54;
  if ((Wrd42.uLng) == 30)
    goto label_54;
  if ((Wrd42.uLng) == 1)
    goto label_53;
  (Wrd48.Obj) = (current_block [OBJECT_9_8]);
  if ((Wrd41.Obj) == (Wrd48.Obj))
    goto label_52;
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_7]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd96.Obj) = (current_block [OBJECT_9_9]);
  (Wrd99.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd99.Lng))))
    goto label_51;
  (Wrd54.uLng) = (OBJECT_DATUM (Wrd96.Obj));
  if ((Wrd54.Obj) == (Wrd42.Obj))
    goto label_50;

DEFLABEL (label_49)
  (Wrd57.Obj) = (current_block [OBJECT_9_10]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd67.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd67.Lng))))
    goto label_36;
  (Wrd61.uLng) = (OBJECT_DATUM (Wrd57.Obj));
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd61.Obj) == (Wrd63.Obj))
    goto label_41;
  (Wrd59.Obj) = (current_block [OBJECT_9_7]);
  goto label_40;

DEFLABEL (label_41)
  (Wrd59.Obj) = (current_block [OBJECT_9_6]);

DEFLABEL (label_40)
DEFLABEL (label_48)
  Rsp = (& (Rsp [3]));
  if ((Wrd59.Obj) == ((SCHEME_OBJECT) 0))
    goto label_44;

DEFLABEL (label_43)
  (Wrd88.Obj) = (Rsp [0]);
  (Wrd89.Obj) = (current_block [OBJECT_9_8]);
  (* (Rhp++)) = (Wrd88.Obj);
  (* (Rhp++)) = (Wrd89.Obj);

DEFLABEL (label_42)
  (Wrd77.pObj) = (& (Rhp [-2]));
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd77.pObj)));
  (Wrd84.Obj) = (current_block [OBJECT_9_11]);
  (* (Rhp++)) = (Wrd84.Obj);
  (* (Rhp++)) = (Wrd75.Obj);
  (Wrd82.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd82.pObj)));
  goto label_33;

DEFLABEL (label_44)
  (Wrd69.Obj) = (Rsp [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if ((Wrd70.uLng) == 10)
    goto label_47;
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_14]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_15]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_9_14);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_45;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_17]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_9_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  if (Rvl == (Wrd6.Obj))
    goto label_46;
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_18]));

DEFLABEL (label_46)
  (Wrd13.Obj) = (current_block [OBJECT_9_8]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (Wrd18.Obj) = (current_block [OBJECT_9_12]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_47)
  (Wrd79.Obj) = (current_block [OBJECT_9_8]);
  (* (Rhp++)) = (Wrd69.Obj);
  (* (Rhp++)) = (Wrd79.Obj);
  goto label_42;

DEFLABEL (label_50)
  Rsp = (& (Rsp [2]));
  goto label_43;

DEFLABEL (label_51)
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_13]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  goto label_50;

DEFLABEL (label_52)
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  goto label_42;

DEFLABEL (label_53)
  (Wrd120.Obj) = (current_block [OBJECT_9_8]);
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd120.Obj);
  goto label_42;

DEFLABEL (label_54)
  Rvl = (Wrd41.Obj);
  goto label_33;

DEFLABEL (label_58)
  Rsp = (& (Rsp [2]));
  goto label_34;

DEFLABEL (label_59)
  (Wrd138.Obj) = (Rsp [0]);
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  (* (--Rsp)) = (Wrd133.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  goto label_58;

DEFLABEL (label_61)
  (Wrd148.Obj) = (Rsp [0]);
  (Wrd151.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_11]))));
  (* (--Rsp)) = (Wrd151.Obj);
  (* (--Rsp)) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd143.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_28)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_60;
  goto label_58;

DEFLABEL (label_63)
  (Wrd158.Obj) = (Rsp [0]);
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_10]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd153.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_29)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  goto label_58;

DEFLABEL (label_65)
  (Wrd171.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_9]))));
  (* (--Rsp)) = (Wrd171.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_30)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  goto label_58;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_9_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  goto label_43;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  goto label_34;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_6 7
#define ENVIRONMENT_LABEL_10_3 16
#define DEBUGGING_LABEL_10_2 15
#define OBJECT_10_1 14
#define OBJECT_10_0 13
#define EXECUTE_CACHE_10_8 9
#define EXECUTE_CACHE_10_7 11
#define FREE_REFERENCES_LABEL_10_0 8
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto unsyntax_quotation_3;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_10_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_quotation_6)
DEFLABEL (unsyntax_quotation_3)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_10_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_10_5);
  (Wrd9.Obj) = (current_block [OBJECT_10_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_10_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 8
#define DEBUGGING_LABEL_11_2 7
#define EXECUTE_CACHE_11_5 5
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto unsyntax_variable_object_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_variable_object_3)
DEFLABEL (unsyntax_variable_object_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_5 3
#define LABEL_12_4 5
#define LABEL_12_6 7
#define LABEL_12_9 9
#define LABEL_12_11 11
#define LABEL_12_14 13
#define LABEL_12_15 15
#define LABEL_12_10 17
#define LABEL_12_7 19
#define LABEL_12_13 21
#define ENVIRONMENT_LABEL_12_3 36
#define DEBUGGING_LABEL_12_2 35
#define OBJECT_12_1 34
#define OBJECT_12_0 33
#define EXECUTE_CACHE_12_16 23
#define EXECUTE_CACHE_12_12 25
#define EXECUTE_CACHE_12_8 27
#define FREE_REFERENCE_12_2 30
#define FREE_REFERENCE_12_1 31
#define FREE_REFERENCE_12_0 32
#define FREE_REFERENCES_LABEL_12_0 22
#define NUMBER_OF_LINKER_SECTIONS_12_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_12_4);
      goto unsyntax_access_object_7;

    case 2:
      current_block = (Rpc - LABEL_12_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_12_9);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_12_11);
      goto lambda_4;

    case 5:
      current_block = (Rpc - LABEL_12_14);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_12_15);
      goto label_12;

    case 7:
      current_block = (Rpc - LABEL_12_10);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_12_7);
      goto continuation_0;

    case 9:
      current_block = (Rpc - LABEL_12_13);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_access_object_14)
DEFLABEL (unsyntax_access_object_7)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_23;
  Wrd5 = Wrd9;

DEFLABEL (label_22)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_7);
  (Wrd10.Obj) = (current_block [OBJECT_12_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_21;
  Wrd15 = Wrd19;

DEFLABEL (label_20)
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_5);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_18)
  (Wrd27.Obj) = (Rsp [0]);
  if ((Wrd27.Obj) == ((SCHEME_OBJECT) 0))
    goto label_17;
  Rvl = (Wrd27.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_12_10);
  (Wrd10.Obj) = (current_block [OBJECT_12_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_9])), (Wrd16.pObj));

DEFLABEL (label_10)
  (Wrd15.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_6])), (Wrd6.pObj));

DEFLABEL (label_9)
  (Wrd5.Obj) = Rvl;
  goto label_22;

DEFLABEL (lambda_15)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_12_11);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_24;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_13]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_2]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_31;
  Wrd13 = Wrd17;

DEFLABEL (label_30)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_29;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_28)
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_12_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_25;

DEFLABEL (label_26)
  Rvl = (Rsp [1]);

DEFLABEL (label_25)
DEFLABEL (label_27)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_15]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_14])), (Wrd14.pObj));

DEFLABEL (label_11)
  (Wrd13.Obj) = Rvl;
  goto label_30;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_10 7
#define LABEL_13_8 9
#define LABEL_13_13 11
#define LABEL_13_14 13
#define LABEL_13_6 15
#define LABEL_13_16 17
#define LABEL_13_19 19
#define LABEL_13_12 21
#define LABEL_13_18 23
#define LABEL_13_11 25
#define ENVIRONMENT_LABEL_13_3 41
#define DEBUGGING_LABEL_13_2 40
#define OBJECT_13_1 39
#define OBJECT_13_0 38
#define EXECUTE_CACHE_13_17 27
#define EXECUTE_CACHE_13_15 29
#define EXECUTE_CACHE_13_9 31
#define EXECUTE_CACHE_13_7 33
#define FREE_REFERENCE_13_1 36
#define FREE_REFERENCE_13_0 37
#define FREE_REFERENCES_LABEL_13_0 26
#define NUMBER_OF_LINKER_SECTIONS_13_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd36;
  machine_word Wrd29;
  machine_word Wrd35;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto unexpand_access_12;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto loop_10;

    case 2:
      current_block = (Rpc - LABEL_13_10);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_13_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_13_13);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_13_14);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_13_6);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_13_16);
      goto lambda_8;

    case 8:
      current_block = (Rpc - LABEL_13_19);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_13_12);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_13_18);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_13_11);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unexpand_access_18)
DEFLABEL (unexpand_access_12)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_13_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto loop_10;

DEFLABEL (loop_19)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_13_5);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_13_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_27;
  Wrd8 = Wrd12;

DEFLABEL (label_26)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_22;

DEFLABEL (label_21)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_16]))));
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_17]));

DEFLABEL (label_22)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_25;
  Wrd20 = Wrd24;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_15]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_13_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_11]))));
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_23)
  (Wrd36.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_7]));

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_14])), (Wrd21.pObj));

DEFLABEL (label_15)
  (Wrd20.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_13])), (Wrd9.pObj));

DEFLABEL (label_14)
  (Wrd8.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_12]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_23;

DEFLABEL (label_29)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_6);
  (Wrd10.Obj) = (current_block [OBJECT_13_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13_11);
  (Wrd10.Obj) = (current_block [OBJECT_13_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_13_12);
  (Wrd10.Obj) = (current_block [OBJECT_13_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_20)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_13_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_34;
  Wrd9 = Wrd13;

DEFLABEL (label_33)
  (Wrd15.Obj) = (current_block [OBJECT_13_0]);
  if ((Wrd15.Obj) == (Wrd9.Obj))
    goto label_31;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_30;

DEFLABEL (label_31)
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_30)
DEFLABEL (label_32)
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  goto loop_10;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_13_18);
  (Wrd10.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_19])), (Wrd10.pObj));

DEFLABEL (label_16)
  (Wrd9.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define ENVIRONMENT_LABEL_14_3 12
#define DEBUGGING_LABEL_14_2 11
#define EXECUTE_CACHE_14_6 7
#define FREE_REFERENCE_14_0 10
#define FREE_REFERENCES_LABEL_14_0 6
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto unsyntax_definition_object_0;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_definition_object_4)
DEFLABEL (unsyntax_definition_object_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define LABEL_15_7 7
#define ENVIRONMENT_LABEL_15_3 15
#define DEBUGGING_LABEL_15_2 14
#define OBJECT_15_0 13
#define EXECUTE_CACHE_15_8 9
#define EXECUTE_CACHE_15_6 11
#define FREE_REFERENCES_LABEL_15_0 8
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto unsyntax_assignment_object_3;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto lambda_2;

    case 2:
      current_block = (Rpc - LABEL_15_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_assignment_object_6)
DEFLABEL (unsyntax_assignment_object_3)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (lambda_7)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_15_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_7);
  (Wrd9.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_15_0]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define LABEL_16_7 7
#define LABEL_16_12 9
#define LABEL_16_13 11
#define LABEL_16_10 13
#define LABEL_16_16 15
#define LABEL_16_8 17
#define LABEL_16_19 19
#define LABEL_16_20 21
#define LABEL_16_22 23
#define TAG_16_23 10
#define LABEL_16_26 25
#define LABEL_16_18 27
#define LABEL_16_28 29
#define LABEL_16_25 31
#define LABEL_16_17 33
#define LABEL_16_29 35
#define ENVIRONMENT_LABEL_16_3 64
#define DEBUGGING_LABEL_16_2 63
#define OBJECT_16_3 62
#define OBJECT_16_2 61
#define OBJECT_16_1 60
#define OBJECT_16_0 59
#define EXECUTE_CACHE_16_30 37
#define EXECUTE_CACHE_16_27 39
#define EXECUTE_CACHE_16_24 41
#define EXECUTE_CACHE_16_21 43
#define EXECUTE_CACHE_16_15 45
#define EXECUTE_CACHE_16_14 47
#define EXECUTE_CACHE_16_11 49
#define EXECUTE_CACHE_16_9 51
#define EXECUTE_CACHE_16_6 53
#define FREE_REFERENCE_16_2 56
#define FREE_REFERENCE_16_1 57
#define FREE_REFERENCE_16_0 58
#define FREE_REFERENCES_LABEL_16_0 36
#define NUMBER_OF_LINKER_SECTIONS_16_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd42;
  machine_word Wrd35;
  machine_word Wrd41;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto unexpand_definition_23;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_16_7);
      goto label_25;

    case 3:
      current_block = (Rpc - LABEL_16_12);
      goto continuation_20;

    case 4:
      current_block = (Rpc - LABEL_16_13);
      goto continuation_19;

    case 5:
      current_block = (Rpc - LABEL_16_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_16_16);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_16_8);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_16_19);
      goto label_26;

    case 9:
      current_block = (Rpc - LABEL_16_20);
      goto label_27;

    case 10:
      current_block = (Rpc - LABEL_16_22);
      goto lambda_31;

    case 11:
      current_block = (Rpc - LABEL_16_26);
      goto label_28;

    case 12:
      current_block = (Rpc - LABEL_16_18);
      goto continuation_5;

    case 13:
      current_block = (Rpc - LABEL_16_28);
      goto continuation_10;

    case 14:
      current_block = (Rpc - LABEL_16_25);
      goto continuation_14;

    case 15:
      current_block = (Rpc - LABEL_16_17);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_16_29);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unexpand_definition_30)
DEFLABEL (unexpand_definition_23)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_13]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_14]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_16_13);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_15]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_16_12);
  (Wrd9.Obj) = (current_block [OBJECT_16_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd18.Obj) = (current_block [OBJECT_16_2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_32)
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_0]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_43;
  Wrd15 = Wrd19;

DEFLABEL (label_42)
  if ((Wrd15.Obj) == (current_block [OBJECT_16_0]))
    goto label_33;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_10]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_16_10);
  (Wrd9.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_16_3]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_16_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_40;
  Wrd8 = Wrd12;

DEFLABEL (label_39)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_35;

DEFLABEL (label_34)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x606, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16_22])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  (Wrd21.Obj) = (Rsp [1]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (Wrd19.Obj) = (Rsp [0]);
  ((Wrd20.pObj) [3]) = (Wrd19.Obj);
  (Rsp [0]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_24]));

DEFLABEL (label_35)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_16]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_1]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_38;
  Wrd26 = Wrd30;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_21]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_16_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_17]))));
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_36)
  (Wrd42.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_11]));

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_20])), (Wrd27.pObj));

DEFLABEL (label_27)
  (Wrd26.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_19])), (Wrd9.pObj));

DEFLABEL (label_26)
  (Wrd8.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_41)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_18]))));
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_36;

DEFLABEL (label_43)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_7])), (Wrd16.pObj));

DEFLABEL (label_25)
  (Wrd15.Obj) = Rvl;
  goto label_42;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_16_17);
  (Wrd9.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_16_3]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_16_18);
  (Wrd9.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_16_3]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_16_22);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  if ((Wrd5.Obj) == (Wrd8.Obj))
    goto label_44;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_28]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_11]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_16_28);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd16.Obj) = (current_block [OBJECT_16_3]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_25]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_46;
  Wrd19 = Wrd23;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd25.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_27]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_16_25);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_30]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_16_29);
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd12.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_16_3]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_26])), (Wrd20.pObj));

DEFLABEL (label_28)
  (Wrd19.Obj) = Rvl;
  goto label_45;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define LABEL_17_7 7
#define ENVIRONMENT_LABEL_17_3 15
#define DEBUGGING_LABEL_17_2 14
#define OBJECT_17_0 13
#define EXECUTE_CACHE_17_8 9
#define EXECUTE_CACHE_17_6 11
#define FREE_REFERENCES_LABEL_17_0 8
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto unexpand_binding_value_2;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unexpand_binding_value_5)
DEFLABEL (unexpand_binding_value_2)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_6;
  Rvl = (current_block [OBJECT_17_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_17_7);
  (Wrd10.Obj) = (current_block [OBJECT_17_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_8 7
#define LABEL_18_6 9
#define LABEL_18_9 11
#define ENVIRONMENT_LABEL_18_3 24
#define DEBUGGING_LABEL_18_2 23
#define OBJECT_18_1 22
#define OBJECT_18_0 21
#define EXECUTE_CACHE_18_11 13
#define EXECUTE_CACHE_18_10 15
#define EXECUTE_CACHE_18_7 17
#define FREE_REFERENCE_18_0 20
#define FREE_REFERENCES_LABEL_18_0 12
#define NUMBER_OF_LINKER_SECTIONS_18_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto unsyntax_comment_object_6;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_18_8);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_18_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_18_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_comment_object_10)
DEFLABEL (unsyntax_comment_object_6)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_13;
  Wrd5 = Wrd9;

DEFLABEL (label_12)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_9]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_18_9);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (current_block [OBJECT_18_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd18.Obj) = (current_block [OBJECT_18_1]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_8])), (Wrd6.pObj));

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_7 7
#define ENVIRONMENT_LABEL_19_3 16
#define DEBUGGING_LABEL_19_2 15
#define OBJECT_19_1 14
#define OBJECT_19_0 13
#define EXECUTE_CACHE_19_8 9
#define EXECUTE_CACHE_19_6 11
#define FREE_REFERENCES_LABEL_19_0 8
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto unsyntax_declaration_object_4;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto lambda_3;

    case 2:
      current_block = (Rpc - LABEL_19_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_declaration_object_7)
DEFLABEL (unsyntax_declaration_object_4)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (lambda_8)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_19_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_7);
  (Wrd9.Obj) = (current_block [OBJECT_19_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd18.Obj) = (current_block [OBJECT_19_1]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define ENVIRONMENT_LABEL_20_3 11
#define DEBUGGING_LABEL_20_2 10
#define OBJECT_20_0 9
#define EXECUTE_CACHE_20_6 7
#define FREE_REFERENCES_LABEL_20_0 6
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto unsyntax_sequence_object_1;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_sequence_object_4)
DEFLABEL (unsyntax_sequence_object_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  (Wrd10.Obj) = (current_block [OBJECT_20_0]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_9 7
#define LABEL_21_10 9
#define LABEL_21_7 11
#define ENVIRONMENT_LABEL_21_3 25
#define DEBUGGING_LABEL_21_2 24
#define OBJECT_21_2 23
#define OBJECT_21_1 22
#define OBJECT_21_0 21
#define EXECUTE_CACHE_21_11 13
#define EXECUTE_CACHE_21_8 15
#define EXECUTE_CACHE_21_6 17
#define FREE_REFERENCE_21_0 20
#define FREE_REFERENCES_LABEL_21_0 12
#define NUMBER_OF_LINKER_SECTIONS_21_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto unsyntax_sequence_5;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_21_9);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_21_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_21_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_sequence_9)
DEFLABEL (unsyntax_sequence_5)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_21_7);
  (Wrd10.Obj) = (current_block [OBJECT_21_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_13;
  Wrd8 = Wrd12;

DEFLABEL (label_12)
  if ((Wrd8.Obj) == (current_block [OBJECT_21_0]))
    goto label_11;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_10]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_11]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21_9])), (Wrd9.pObj));

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_12;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_21_10);
  (Wrd9.Obj) = (current_block [OBJECT_21_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_21_2]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define LABEL_22_7 7
#define LABEL_22_8 9
#define LABEL_22_9 11
#define LABEL_22_10 13
#define LABEL_22_11 15
#define LABEL_22_13 17
#define LABEL_22_15 19
#define LABEL_22_18 21
#define LABEL_22_20 23
#define LABEL_22_19 25
#define LABEL_22_21 27
#define LABEL_22_17 29
#define LABEL_22_23 31
#define LABEL_22_14 33
#define LABEL_22_26 35
#define LABEL_22_28 37
#define LABEL_22_22 39
#define LABEL_22_27 41
#define LABEL_22_30 43
#define LABEL_22_25 45
#define LABEL_22_33 47
#define LABEL_22_29 49
#define LABEL_22_32 51
#define ENVIRONMENT_LABEL_22_3 73
#define DEBUGGING_LABEL_22_2 72
#define OBJECT_22_3 71
#define OBJECT_22_2 70
#define OBJECT_22_1 69
#define OBJECT_22_0 68
#define EXECUTE_CACHE_22_34 53
#define EXECUTE_CACHE_22_31 55
#define EXECUTE_CACHE_22_24 57
#define EXECUTE_CACHE_22_16 59
#define EXECUTE_CACHE_22_12 61
#define EXECUTE_CACHE_22_6 63
#define FREE_REFERENCE_22_1 66
#define FREE_REFERENCE_22_0 67
#define FREE_REFERENCES_LABEL_22_0 52
#define NUMBER_OF_LINKER_SECTIONS_22_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd64;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd71;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd82;
  machine_word Wrd89;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd44;
  machine_word Wrd22;
  machine_word Wrd105;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd91;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto unsyntax_sequence_actions_28;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_22_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_22_8);
      goto loop_25;

    case 4:
      current_block = (Rpc - LABEL_22_9);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_22_10);
      goto label_35;

    case 6:
      current_block = (Rpc - LABEL_22_11);
      goto label_36;

    case 7:
      current_block = (Rpc - LABEL_22_13);
      goto label_32;

    case 8:
      current_block = (Rpc - LABEL_22_15);
      goto label_34;

    case 9:
      current_block = (Rpc - LABEL_22_18);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_22_20);
      goto label_31;

    case 11:
      current_block = (Rpc - LABEL_22_19);
      goto continuation_23;

    case 12:
      current_block = (Rpc - LABEL_22_21);
      goto label_37;

    case 13:
      current_block = (Rpc - LABEL_22_17);
      goto continuation_10;

    case 14:
      current_block = (Rpc - LABEL_22_23);
      goto label_38;

    case 15:
      current_block = (Rpc - LABEL_22_14);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_22_26);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_22_28);
      goto label_39;

    case 18:
      current_block = (Rpc - LABEL_22_22);
      goto continuation_8;

    case 19:
      current_block = (Rpc - LABEL_22_27);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_22_30);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_22_25);
      goto continuation_16;

    case 22:
      current_block = (Rpc - LABEL_22_33);
      goto label_42;

    case 23:
      current_block = (Rpc - LABEL_22_29);
      goto continuation_18;

    case 24:
      current_block = (Rpc - LABEL_22_32);
      goto continuation_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_sequence_actions_44)
DEFLABEL (unsyntax_sequence_actions_28)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (Rsp [0]) = Rvl;
  goto loop_25;

DEFLABEL (loop_45)
DEFLABEL (loop_25)
  INTERRUPT_CHECK (26, LABEL_22_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  Rvl = (current_block [OBJECT_22_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_46)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_69;
  Wrd13 = Wrd17;

DEFLABEL (label_68)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_63;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_62)
  Rdl = (& (Rsp [2]));
  (Wrd22.Obj) = (Rsp [0]);
  if ((Wrd22.Obj) == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_19]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_48;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_47)
  goto loop_25;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_20]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_31)
DEFLABEL (label_49)
  (Wrd64.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd64.Obj));
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd44.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22_1]));
  (Wrd51.Obj) = ((Wrd44.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_61;
  Wrd43 = Wrd51;

DEFLABEL (label_60)
  if ((Wrd43.Obj) == (current_block [OBJECT_22_1]))
    goto label_52;
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_17]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd62.Obj) = (Rsp [3]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 1))
    goto label_51;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [1]);
  (* (--Rsp)) = (Wrd61.Obj);
  goto label_47;

DEFLABEL (label_51)
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_18]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_33)
  goto label_49;

DEFLABEL (label_52)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_14]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd80.Obj) = (Rsp [3]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_59;
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (* (--Rsp)) = (Wrd79.Obj);

DEFLABEL (label_58)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_16]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_22_14);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_56;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_27]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_54;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_53)
  goto loop_25;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_28]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_39)
DEFLABEL (label_55)
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_25]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_57;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [1]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_53;

DEFLABEL (label_57)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_26]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_40)
  goto label_55;

DEFLABEL (label_59)
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_15]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_34)
  (Wrd82.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd82.Obj));
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22_13])), (Wrd44.pObj));

DEFLABEL (label_32)
  (Wrd45.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd92.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22_0]));
  (Wrd95.Obj) = ((Wrd92.pObj) [0]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if ((Wrd96.uLng) == 50)
    goto label_67;
  Wrd91 = Wrd95;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd91.Obj);
  (Wrd100.Obj) = (Rsp [2]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 1))
    goto label_65;
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd99.Obj) = ((Wrd98.pObj) [0]);
  (* (--Rsp)) = (Wrd99.Obj);

DEFLABEL (label_64)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_22_7);
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_11]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22_10])), (Wrd92.pObj));

DEFLABEL (label_35)
  (Wrd91.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22_9])), (Wrd14.pObj));

DEFLABEL (label_30)
  (Wrd13.Obj) = Rvl;
  goto label_68;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_22_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_71;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_70)
  (Wrd20.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_71)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_21]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_37)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd7.Obj) = Rvl;
  goto label_70;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_22_17);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_22]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_73;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_72)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_24]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_22_22);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_73)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_38)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_72;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_22_27);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_29]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_75;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_74)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_31]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_22_29);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_34]));

DEFLABEL (label_75)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_30]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_41)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_74;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_22_25);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_32]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_77;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_76)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_24]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_22_32);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_33]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 1);

DEFLABEL (label_42)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_76;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_6 7
#define LABEL_23_9 9
#define ENVIRONMENT_LABEL_23_3 22
#define DEBUGGING_LABEL_23_2 21
#define OBJECT_23_1 20
#define OBJECT_23_0 19
#define EXECUTE_CACHE_23_10 11
#define EXECUTE_CACHE_23_8 13
#define EXECUTE_CACHE_23_7 15
#define FREE_REFERENCE_23_0 18
#define FREE_REFERENCES_LABEL_23_0 10
#define NUMBER_OF_LINKER_SECTIONS_23_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto unsyntax_open_block_object_5;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_23_6);
      goto lambda_4;

    case 3:
      current_block = (Rpc - LABEL_23_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_open_block_object_9)
DEFLABEL (unsyntax_open_block_object_5)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_13;
  Wrd6 = Wrd10;

DEFLABEL (label_12)
  if ((Wrd6.Obj) == (current_block [OBJECT_23_0]))
    goto label_11;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_8]));

DEFLABEL (label_11)
  (Wrd13.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_6]))));
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_5])), (Wrd7.pObj));

DEFLABEL (label_7)
  (Wrd6.Obj) = Rvl;
  goto label_12;

DEFLABEL (lambda_10)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_23_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_23_9);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd18.Obj) = (current_block [OBJECT_23_1]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_6 7
#define ENVIRONMENT_LABEL_24_3 16
#define DEBUGGING_LABEL_24_2 15
#define OBJECT_24_1 14
#define OBJECT_24_0 13
#define EXECUTE_CACHE_24_8 9
#define EXECUTE_CACHE_24_7 11
#define FREE_REFERENCES_LABEL_24_0 8
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto unsyntax_delay_object_3;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_24_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_delay_object_6)
DEFLABEL (unsyntax_delay_object_3)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Wrd9.Obj) = (current_block [OBJECT_24_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_24_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define ENVIRONMENT_LABEL_25_3 6
#define DEBUGGING_LABEL_25_2 5
#define OBJECT_25_0 4
#define FREE_REFERENCES_LABEL_25_0 4
#define NUMBER_OF_LINKER_SECTIONS_25_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto unsyntax_the_environment_object_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_the_environment_object_3)
DEFLABEL (unsyntax_the_environment_object_0)
  INTERRUPT_CHECK (26, LABEL_25_4);
  Rvl = (current_block [OBJECT_25_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_6 5
#define LABEL_26_7 7
#define LABEL_26_5 9
#define LABEL_26_8 11
#define LABEL_26_10 13
#define LABEL_26_12 15
#define ENVIRONMENT_LABEL_26_3 28
#define DEBUGGING_LABEL_26_2 27
#define OBJECT_26_2 26
#define OBJECT_26_1 25
#define OBJECT_26_0 24
#define EXECUTE_CACHE_26_11 17
#define EXECUTE_CACHE_26_9 19
#define FREE_REFERENCE_26_1 22
#define FREE_REFERENCE_26_0 23
#define FREE_REFERENCES_LABEL_26_0 16
#define NUMBER_OF_LINKER_SECTIONS_26_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto unsyntax_disjunction_object_7;

    case 1:
      current_block = (Rpc - LABEL_26_6);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_26_7);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_26_8);
      goto lambda_5;

    case 5:
      current_block = (Rpc - LABEL_26_10);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_26_12);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_disjunction_object_12)
DEFLABEL (unsyntax_disjunction_object_7)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_19;
  Wrd9 = Wrd13;

DEFLABEL (label_18)
  if ((Wrd9.Obj) == (current_block [OBJECT_26_0]))
    goto label_15;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_8]))));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_14)
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_26_5);
  (Wrd10.Obj) = (current_block [OBJECT_26_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_17;
  Wrd19 = Wrd23;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd19.Obj);
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26_7])), (Wrd20.pObj));

DEFLABEL (label_10)
  (Wrd19.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26_6])), (Wrd10.pObj));

DEFLABEL (label_9)
  (Wrd9.Obj) = Rvl;
  goto label_18;

DEFLABEL (lambda_13)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_26_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_26_10);
  (Wrd9.Obj) = (current_block [OBJECT_26_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_12]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_26_12);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_8 5
#define LABEL_27_5 7
#define LABEL_27_6 9
#define LABEL_27_11 11
#define LABEL_27_9 13
#define ENVIRONMENT_LABEL_27_3 25
#define DEBUGGING_LABEL_27_2 24
#define OBJECT_27_0 23
#define EXECUTE_CACHE_27_12 15
#define EXECUTE_CACHE_27_10 17
#define EXECUTE_CACHE_27_7 19
#define FREE_REFERENCE_27_0 22
#define FREE_REFERENCES_LABEL_27_0 14
#define NUMBER_OF_LINKER_SECTIONS_27_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto unexpand_disjunction_4;

    case 1:
      current_block = (Rpc - LABEL_27_8);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_27_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_27_11);
      goto label_6;

    case 5:
      current_block = (Rpc - LABEL_27_9);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unexpand_disjunction_8)
DEFLABEL (unexpand_disjunction_4)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_27_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_27_8);
  (Wrd14.Obj) = (current_block [OBJECT_27_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_9)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_9);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_12;
  Wrd7 = Wrd11;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (* (--Rsp)) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_11])), (Wrd8.pObj));

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_6 7
#define LABEL_28_7 9
#define ENVIRONMENT_LABEL_28_3 19
#define DEBUGGING_LABEL_28_2 18
#define OBJECT_28_0 17
#define EXECUTE_CACHE_28_8 11
#define FREE_REFERENCE_28_2 14
#define FREE_REFERENCE_28_1 15
#define FREE_REFERENCE_28_0 16
#define FREE_REFERENCES_LABEL_28_0 10
#define NUMBER_OF_LINKER_SECTIONS_28_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto unsyntax_conditional_object_2;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_28_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_28_7);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_conditional_object_8)
DEFLABEL (unsyntax_conditional_object_2)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_16;
  Wrd7 = Wrd11;

DEFLABEL (label_15)
  if ((Wrd7.Obj) == (current_block [OBJECT_28_0]))
    goto label_12;
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_2]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_11;
  Wrd14 = Wrd18;

DEFLABEL (label_10)
  Wrd20 = Wrd14;

DEFLABEL (label_9)
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_8]));

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_7])), (Wrd15.pObj));

DEFLABEL (label_5)
  (Wrd14.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_12)
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_1]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_14;
  Wrd21 = Wrd25;

DEFLABEL (label_13)
  Wrd20 = Wrd21;
  goto label_9;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_6])), (Wrd22.pObj));

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_5])), (Wrd8.pObj));

DEFLABEL (label_4)
  (Wrd7.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define LABEL_29_7 7
#define LABEL_29_8 9
#define ENVIRONMENT_LABEL_29_3 16
#define DEBUGGING_LABEL_29_2 15
#define OBJECT_29_1 14
#define OBJECT_29_0 13
#define EXECUTE_CACHE_29_6 11
#define FREE_REFERENCES_LABEL_29_0 10
#define NUMBER_OF_LINKER_SECTIONS_29_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto unsyntax_conditional_default_6;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_29_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_29_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_conditional_default_9)
DEFLABEL (unsyntax_conditional_default_6)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_29_5);
  (Wrd9.Obj) = (current_block [OBJECT_29_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_7]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_29_7);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_8]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_8);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_29_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_10 5
#define LABEL_30_13 7
#define LABEL_30_15 9
#define LABEL_30_9 11
#define LABEL_30_7 13
#define LABEL_30_5 15
#define LABEL_30_17 17
#define LABEL_30_14 19
#define LABEL_30_19 21
#define LABEL_30_20 23
#define LABEL_30_21 25
#define ENVIRONMENT_LABEL_30_3 48
#define DEBUGGING_LABEL_30_2 47
#define OBJECT_30_5 46
#define OBJECT_30_4 45
#define OBJECT_30_3 44
#define OBJECT_30_2 43
#define OBJECT_30_1 42
#define OBJECT_30_0 41
#define EXECUTE_CACHE_30_18 27
#define EXECUTE_CACHE_30_16 29
#define EXECUTE_CACHE_30_12 31
#define EXECUTE_CACHE_30_11 33
#define EXECUTE_CACHE_30_8 35
#define EXECUTE_CACHE_30_6 37
#define FREE_REFERENCE_30_0 40
#define FREE_REFERENCES_LABEL_30_0 26
#define NUMBER_OF_LINKER_SECTIONS_30_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto unsyntax_conditional_18;

    case 1:
      current_block = (Rpc - LABEL_30_10);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_30_13);
      goto label_20;

    case 3:
      current_block = (Rpc - LABEL_30_15);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_30_9);
      goto continuation_11;

    case 5:
      current_block = (Rpc - LABEL_30_7);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_0;

    case 7:
      current_block = (Rpc - LABEL_30_17);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_30_14);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_30_19);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_30_20);
      goto continuation_14;

    case 11:
      current_block = (Rpc - LABEL_30_21);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_conditional_23)
DEFLABEL (unsyntax_conditional_18)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [2]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_24;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (Wrd10.Obj) = (current_block [OBJECT_30_2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd8.Obj) = (current_block [OBJECT_30_0]);
  if (! ((Wrd5.Obj) == (Wrd8.Obj)))
    goto label_25;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_8]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_30_7);
  (Wrd9.Obj) = (current_block [OBJECT_30_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_20]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_8]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_30_20);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_30_5]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd9.Obj) = (Rsp [1]);
  if ((Wrd9.Obj) == (Wrd8.Obj))
    goto label_33;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_30_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_26;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_12]));

DEFLABEL (label_26)
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_32;
  Wrd8 = Wrd12;

DEFLABEL (label_31)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_27;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_17]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_30_17);
  (Wrd10.Obj) = (current_block [OBJECT_30_3]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_30;
  Wrd24 = Wrd28;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_30_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_12]));

DEFLABEL (label_28)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_18]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_30_21);
  (Wrd10.Obj) = (current_block [OBJECT_30_3]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30_15])), (Wrd25.pObj));

DEFLABEL (label_21)
  (Wrd24.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30_13])), (Wrd9.pObj));

DEFLABEL (label_20)
  (Wrd8.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_33)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_8]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_30_9);
  (Wrd9.Obj) = (current_block [OBJECT_30_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_19]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_8]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_30_19);
  (Wrd9.Obj) = (current_block [OBJECT_30_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_30_4]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd14.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  (Wrd22.Obj) = (current_block [OBJECT_30_5]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_7 7
#define LABEL_31_9 9
#define ENVIRONMENT_LABEL_31_3 18
#define DEBUGGING_LABEL_31_2 17
#define EXECUTE_CACHE_31_10 11
#define EXECUTE_CACHE_31_8 13
#define EXECUTE_CACHE_31_6 15
#define FREE_REFERENCES_LABEL_31_0 10
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto unsyntax_cond_conditional_4;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_31_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_31_9);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_cond_conditional_7)
DEFLABEL (unsyntax_cond_conditional_4)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_31_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_9);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd10.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define LABEL_32_7 7
#define ENVIRONMENT_LABEL_32_3 15
#define DEBUGGING_LABEL_32_2 14
#define OBJECT_32_0 13
#define EXECUTE_CACHE_32_8 9
#define EXECUTE_CACHE_32_6 11
#define FREE_REFERENCES_LABEL_32_0 8
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto unsyntax_cond_disjunction_3;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_32_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_cond_disjunction_6)
DEFLABEL (unsyntax_cond_disjunction_3)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_7);
  (Wrd9.Obj) = (current_block [OBJECT_32_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd10.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_5 3
#define LABEL_33_4 5
#define LABEL_33_6 7
#define LABEL_33_7 9
#define LABEL_33_9 11
#define LABEL_33_13 13
#define LABEL_33_11 15
#define LABEL_33_17 17
#define LABEL_33_15 19
#define ENVIRONMENT_LABEL_33_3 41
#define DEBUGGING_LABEL_33_2 40
#define OBJECT_33_2 39
#define OBJECT_33_1 38
#define OBJECT_33_0 37
#define EXECUTE_CACHE_33_18 21
#define EXECUTE_CACHE_33_16 23
#define EXECUTE_CACHE_33_14 25
#define EXECUTE_CACHE_33_12 27
#define EXECUTE_CACHE_33_10 29
#define EXECUTE_CACHE_33_8 31
#define FREE_REFERENCE_33_2 34
#define FREE_REFERENCE_33_1 35
#define FREE_REFERENCE_33_0 36
#define FREE_REFERENCES_LABEL_33_0 20
#define NUMBER_OF_LINKER_SECTIONS_33_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd18;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd20;
  machine_word Wrd48;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_33_4);
      goto unsyntax_cond_alternative_11;

    case 2:
      current_block = (Rpc - LABEL_33_6);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_33_7);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_33_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_33_13);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_33_11);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_33_17);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_33_15);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_cond_alternative_18)
DEFLABEL (unsyntax_cond_alternative_11)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_33_0]))
    goto label_33;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_32;
  Wrd11 = Wrd15;

DEFLABEL (label_31)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd17.uLng) == 1)
    goto label_28;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_27)
  (Wrd20.Obj) = (Rsp [0]);
  if (! ((Wrd20.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_25;
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_9]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_33_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_33_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_19;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_15]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_33_15);
  (Wrd9.Obj) = (current_block [OBJECT_33_2]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_33_1]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_2]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_21;
  Wrd9 = Wrd13;

DEFLABEL (label_20)
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_18]));

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_17])), (Wrd10.pObj));

DEFLABEL (label_16)
  (Wrd9.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_22)
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_24;
  Wrd9 = Wrd13;

DEFLABEL (label_23)
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_14]));

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_13])), (Wrd10.pObj));

DEFLABEL (label_15)
  (Wrd9.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_25)
  (Rsp [1]) = (Wrd20.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.Obj) = (current_block [OBJECT_33_1]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd31.Obj) = (current_block [OBJECT_33_2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));

DEFLABEL (label_26)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33_0]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_30;
  Wrd42 = Wrd46;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd48.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_33_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_7])), (Wrd43.pObj));

DEFLABEL (label_14)
  (Wrd42.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33_6])), (Wrd12.pObj));

DEFLABEL (label_13)
  (Wrd11.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_33)
  Rvl = (current_block [OBJECT_33_1]);
  goto label_26;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_7 5
#define LABEL_34_5 7
#define LABEL_34_11 9
#define LABEL_34_12 11
#define LABEL_34_14 13
#define LABEL_34_15 15
#define LABEL_34_9 17
#define LABEL_34_17 19
#define LABEL_34_19 21
#define LABEL_34_8 23
#define LABEL_34_21 25
#define LABEL_34_22 27
#define ENVIRONMENT_LABEL_34_3 45
#define DEBUGGING_LABEL_34_2 44
#define OBJECT_34_0 43
#define EXECUTE_CACHE_34_20 29
#define EXECUTE_CACHE_34_18 31
#define EXECUTE_CACHE_34_16 33
#define EXECUTE_CACHE_34_13 35
#define EXECUTE_CACHE_34_10 37
#define EXECUTE_CACHE_34_6 39
#define FREE_REFERENCE_34_0 42
#define FREE_REFERENCES_LABEL_34_0 28
#define NUMBER_OF_LINKER_SECTIONS_34_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd39;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto unexpand_conjunction_13;

    case 1:
      current_block = (Rpc - LABEL_34_7);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_34_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_34_11);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_34_12);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_34_14);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_34_15);
      goto lambda_8;

    case 7:
      current_block = (Rpc - LABEL_34_9);
      goto continuation_2;

    case 8:
      current_block = (Rpc - LABEL_34_17);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_34_19);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_34_8);
      goto continuation_11;

    case 11:
      current_block = (Rpc - LABEL_34_21);
      goto continuation_1;

    case 12:
      current_block = (Rpc - LABEL_34_22);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unexpand_conjunction_18)
DEFLABEL (unexpand_conjunction_13)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_34_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_26;
  Wrd8 = Wrd12;

DEFLABEL (label_25)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_21;

DEFLABEL (label_20)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_14]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_15]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_34_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_34_17);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_24;
  Wrd24 = Wrd28;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_34_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_8]))));
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_22)
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_10]));

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_12])), (Wrd25.pObj));

DEFLABEL (label_16)
  (Wrd24.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34_11])), (Wrd9.pObj));

DEFLABEL (label_15)
  (Wrd8.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_27)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  goto label_22;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_34_8);
  (Wrd9.Obj) = (current_block [OBJECT_34_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_22]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_34_22);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_34_9);
  (Wrd9.Obj) = (current_block [OBJECT_34_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_21]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_34_21);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_19)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_34_15);
  (Wrd5.Obj) = (Rsp [2]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_28;
  (Wrd13.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd14.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_18]));

DEFLABEL (label_28)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_20]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_34_19);
  (Wrd10.Obj) = (current_block [OBJECT_34_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_5 5
#define LABEL_35_8 7
#define LABEL_35_11 9
#define LABEL_35_6 11
#define LABEL_35_10 13
#define LABEL_35_13 15
#define LABEL_35_15 17
#define LABEL_35_17 19
#define ENVIRONMENT_LABEL_35_3 39
#define DEBUGGING_LABEL_35_2 38
#define OBJECT_35_1 37
#define OBJECT_35_0 36
#define EXECUTE_CACHE_35_18 21
#define EXECUTE_CACHE_35_16 23
#define EXECUTE_CACHE_35_14 25
#define EXECUTE_CACHE_35_12 27
#define EXECUTE_CACHE_35_9 29
#define EXECUTE_CACHE_35_7 31
#define FREE_REFERENCE_35_1 34
#define FREE_REFERENCE_35_0 35
#define FREE_REFERENCES_LABEL_35_0 20
#define NUMBER_OF_LINKER_SECTIONS_35_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto unsyntax_lambda_object_10;

    case 1:
      current_block = (Rpc - LABEL_35_5);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_35_8);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_35_11);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_35_6);
      goto lambda_6;

    case 5:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_35_15);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_35_17);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_lambda_object_15)
DEFLABEL (unsyntax_lambda_object_10)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_20;
  Wrd5 = Wrd9;

DEFLABEL (label_19)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_18;
  (Wrd12.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (label_18)
  (Wrd15.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (Rsp [1]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_5])), (Wrd6.pObj));

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_19;

DEFLABEL (lambda_16)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_35_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_22;
  Wrd9 = Wrd13;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_35_10);
  (Rsp [4]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_35_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_35_15);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_11])), (Wrd10.pObj));

DEFLABEL (label_13)
  (Wrd9.Obj) = Rvl;
  goto label_21;

DEFLABEL (lambda_17)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_35_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [6]);
  if ((Wrd5.Obj) == (current_block [OBJECT_35_0]))
    goto label_24;
  (Wrd10.Obj) = (current_block [OBJECT_35_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  goto label_23;

DEFLABEL (label_24)
  (Wrd13.Obj) = Rvl;

DEFLABEL (label_23)
DEFLABEL (label_25)
  Rsp = (& (Rsp [1]));
  (Rsp [6]) = (Wrd13.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_17]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_17);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 8
#define DEBUGGING_LABEL_36_2 7
#define OBJECT_36_2 6
#define OBJECT_36_1 5
#define OBJECT_36_0 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto collect_lambda_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (collect_lambda_7)
DEFLABEL (collect_lambda_4)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_36_0]))
    goto label_9;
  (Wrd11.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd15.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_36_2]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  goto label_8;

DEFLABEL (label_9)
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Wrd30.Obj) = (current_block [OBJECT_36_1]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd21.Obj);

DEFLABEL (label_8)
DEFLABEL (label_10)
  (Wrd28.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_7 5
#define LABEL_37_5 7
#define LABEL_37_9 9
#define ENVIRONMENT_LABEL_37_3 23
#define DEBUGGING_LABEL_37_2 22
#define OBJECT_37_2 21
#define OBJECT_37_1 20
#define OBJECT_37_0 19
#define EXECUTE_CACHE_37_11 11
#define EXECUTE_CACHE_37_10 13
#define EXECUTE_CACHE_37_8 15
#define EXECUTE_CACHE_37_6 17
#define FREE_REFERENCES_LABEL_37_0 10
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto unsyntax_lambda_list_3;

    case 1:
      current_block = (Rpc - LABEL_37_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_37_9);
      goto lambda_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_lambda_list_6)
DEFLABEL (unsyntax_lambda_list_3)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;

DEFLABEL (label_8)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_9]))));
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_10]));

DEFLABEL (label_9)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_7]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_37_0]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_37_1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_37_7);
  goto label_8;

DEFLABEL (lambda_7)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_37_9);
  (Wrd5.Obj) = (current_block [OBJECT_37_2]);
  (Rsp [4]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_6 7
#define LABEL_38_11 9
#define LABEL_38_9 11
#define LABEL_38_10 13
#define LABEL_38_7 15
#define ENVIRONMENT_LABEL_38_3 25
#define DEBUGGING_LABEL_38_2 24
#define OBJECT_38_0 23
#define EXECUTE_CACHE_38_8 17
#define FREE_REFERENCE_38_2 20
#define FREE_REFERENCE_38_1 21
#define FREE_REFERENCE_38_0 22
#define FREE_REFERENCES_LABEL_38_0 16
#define NUMBER_OF_LINKER_SECTIONS_38_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd57;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd47;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd66;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto lambda_list_11;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_38_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_38_11);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_38_9);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_38_10);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_list_17)
DEFLABEL (lambda_list_11)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd7.Obj) = (Rsp [3]);
  if ((Wrd7.Obj) == (current_block [OBJECT_38_0]))
    goto label_28;
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_38_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_27;
  Wrd10 = Wrd14;

DEFLABEL (label_26)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_38_0]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_25)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_38_0]);
  if ((Wrd24.Obj) == (Wrd25.Obj))
    goto label_24;
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_38_1]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_23;
  Wrd27 = Wrd31;

DEFLABEL (label_22)
  (Wrd36.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_21)
  (Wrd37.Obj) = (Rsp [5]);
  if (! ((Wrd37.Obj) == (current_block [OBJECT_38_0])))
    goto label_18;
  (Wrd58.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd58.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd62.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_38_7);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (label_18)
  (Wrd39.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd39.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_10]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd48.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_38_2]));
  (Wrd51.Obj) = ((Wrd48.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_20;
  Wrd47 = Wrd51;

DEFLABEL (label_19)
  (Wrd56.Obj) = (Rsp [7]);
  (* (Rhp++)) = (Wrd47.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (Wrd54.pObj) = (& (Rhp [-2]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd54.pObj)));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd57.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_38_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_38_9);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38_11])), (Wrd48.pObj));

DEFLABEL (label_15)
  (Wrd47.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38_6])), (Wrd28.pObj));

DEFLABEL (label_14)
  (Wrd27.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_21;

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38_5])), (Wrd11.pObj));

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (* (--Rsp)) = (Wrd5.Obj);
  goto label_25;

DEFLABEL (label_29)
  (Wrd66.Obj) = (current_block [OBJECT_38_0]);
  (* (--Rsp)) = (Wrd66.Obj);
  goto label_25;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define TAG_39_6 1
#define LABEL_39_14 7
#define LABEL_39_13 9
#define LABEL_39_10 11
#define TAG_39_11 4
#define LABEL_39_8 13
#define TAG_39_9 5
#define LABEL_39_16 15
#define TAG_39_17 6
#define ENVIRONMENT_LABEL_39_3 27
#define DEBUGGING_LABEL_39_2 26
#define OBJECT_39_0 25
#define EXECUTE_CACHE_39_18 17
#define EXECUTE_CACHE_39_15 19
#define EXECUTE_CACHE_39_12 21
#define EXECUTE_CACHE_39_7 23
#define FREE_REFERENCES_LABEL_39_0 16
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto lambda_components___8;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto lambda_12;

    case 2:
      current_block = (Rpc - LABEL_39_14);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_39_13);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_39_10);
      goto lambda_14;

    case 5:
      current_block = (Rpc - LABEL_39_8);
      goto bind_auxilliaries_6;

    case 6:
      current_block = (Rpc - LABEL_39_16);
      goto lambda_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_components___11)
DEFLABEL (lambda_components___8)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x808, 2);
  (* (Rhp++)) = (dispatch_base + TAG_39_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_39_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_7]));

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_39_5);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_39_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_39_8])));
  Rhp += 5;
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  (* (--Rsp)) = (Wrd48.Obj);
  Wrd43 = Wrd47;
  (Wrd44.Obj) = (Rsp [1]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  ((Wrd43.pObj) [2]) = (Wrd46.Obj);
  (Wrd41.Obj) = (Rsp [5]);
  ((Wrd43.pObj) [3]) = (Wrd41.Obj);
  (Wrd38.Obj) = (Rsp [4]);
  ((Wrd43.pObj) [4]) = (Wrd38.Obj);
  (Wrd35.Obj) = (Rsp [3]);
  ((Wrd43.pObj) [5]) = (Wrd35.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  ((Wrd43.pObj) [6]) = (Wrd32.Obj);
  (Wrd5.Obj) = (Rsp [6]);
  (Wrd6.Obj) = (current_block [OBJECT_39_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_17;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_15]));

DEFLABEL (label_17)
  (Wrd13.Obj) = (Rsp [7]);
  if (! ((Wrd13.Obj) == (Wrd6.Obj)))
    goto label_18;
  (Wrd21.Obj) = (Rsp [8]);
  (Rsp [7]) = (Wrd21.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_39_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_39_10])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd27 = Wrd24;
  ((Wrd27.pObj) [2]) = (Wrd48.Obj);
  ((Wrd27.pObj) [3]) = (Wrd21.Obj);
  (Rsp [8]) = (Wrd23.Obj);
  Rsp = (& (Rsp [7]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_12]));

DEFLABEL (label_18)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_13]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  goto label_16;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_39_14);
  (Rsp [8]) = Rvl;
  (Wrd6.Obj) = (Rsp [6]);
  (Rsp [7]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [6]) = (Wrd7.Obj);
  Rsp = (& (Rsp [6]));
  goto bind_auxilliaries_6;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_39_13);
  (Rsp [8]) = Rvl;
  (Wrd6.Obj) = (Rsp [6]);
  (Rsp [7]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [6]) = (Wrd7.Obj);
  Rsp = (& (Rsp [6]));
  goto bind_auxilliaries_6;

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_39_10);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  goto bind_auxilliaries_6;

DEFLABEL (bind_auxilliaries_13)
DEFLABEL (bind_auxilliaries_6)
  INTERRUPT_CHECK (26, LABEL_39_8);
  (Wrd5.Obj) = (current_block [OBJECT_39_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_39_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_39_16])));
  Rhp += 5;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd26 = Wrd9;
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Wrd25.Obj) = ((Wrd28.pObj) [3]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd28.pObj) [4]);
  ((Wrd26.pObj) [4]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd28.pObj) [5]);
  ((Wrd26.pObj) [5]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd28.pObj) [6]);
  ((Wrd26.pObj) [6]) = (Wrd13.Obj);
  (Rsp [3]) = (Wrd8.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_18]));

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_39_16);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [4]) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 6);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define LABEL_40_9 7
#define LABEL_40_10 9
#define LABEL_40_11 11
#define LABEL_40_12 13
#define LABEL_40_13 15
#define LABEL_40_14 17
#define LABEL_40_17 19
#define LABEL_40_18 21
#define LABEL_40_20 23
#define LABEL_40_21 25
#define LABEL_40_22 27
#define LABEL_40_23 29
#define LABEL_40_24 31
#define LABEL_40_26 33
#define LABEL_40_6 35
#define LABEL_40_31 37
#define LABEL_40_32 39
#define LABEL_40_33 41
#define LABEL_40_29 43
#define TAG_40_30 20
#define LABEL_40_37 45
#define LABEL_40_27 47
#define LABEL_40_39 49
#define LABEL_40_41 51
#define TAG_40_42 24
#define LABEL_40_15 53
#define LABEL_40_46 55
#define LABEL_40_16 57
#define LABEL_40_44 59
#define LABEL_40_45 61
#define LABEL_40_47 63
#define LABEL_40_48 65
#define LABEL_40_50 67
#define LABEL_40_51 69
#define LABEL_40_53 71
#define LABEL_40_52 73
#define LABEL_40_49 75
#define LABEL_40_55 77
#define LABEL_40_57 79
#define ENVIRONMENT_LABEL_40_3 123
#define DEBUGGING_LABEL_40_2 122
#define OBJECT_40_9 121
#define OBJECT_40_8 120
#define OBJECT_40_7 119
#define OBJECT_40_6 118
#define OBJECT_40_5 117
#define OBJECT_40_4 116
#define OBJECT_40_3 115
#define OBJECT_40_2 114
#define OBJECT_40_1 113
#define OBJECT_40_0 112
#define EXECUTE_CACHE_40_56 81
#define EXECUTE_CACHE_40_54 83
#define EXECUTE_CACHE_40_43 85
#define EXECUTE_CACHE_40_40 87
#define EXECUTE_CACHE_40_38 89
#define EXECUTE_CACHE_40_36 91
#define EXECUTE_CACHE_40_35 93
#define EXECUTE_CACHE_40_34 95
#define EXECUTE_CACHE_40_28 97
#define EXECUTE_CACHE_40_25 99
#define EXECUTE_CACHE_40_19 101
#define EXECUTE_CACHE_40_8 103
#define EXECUTE_CACHE_40_7 105
#define FREE_REFERENCE_40_3 108
#define FREE_REFERENCE_40_2 109
#define FREE_REFERENCE_40_1 110
#define FREE_REFERENCE_40_0 111
#define FREE_REFERENCES_LABEL_40_0 80
#define NUMBER_OF_LINKER_SECTIONS_40_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd58;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd14;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd86;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd29;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd61;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd57;
  machine_word Wrd119;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd104;
  machine_word Wrd106;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd103;
  machine_word Wrd100;
  machine_word Wrd144;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd140;
  machine_word Wrd137;
  machine_word Wrd129;
  machine_word Wrd131;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd123;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd122;
  machine_word Wrd97;
  machine_word Wrd91;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto unsyntax_combination_object_42;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_41;

    case 2:
      current_block = (Rpc - LABEL_40_9);
      goto continuation_16;

    case 3:
      current_block = (Rpc - LABEL_40_10);
      goto continuation_12;

    case 4:
      current_block = (Rpc - LABEL_40_11);
      goto label_50;

    case 5:
      current_block = (Rpc - LABEL_40_12);
      goto label_53;

    case 6:
      current_block = (Rpc - LABEL_40_13);
      goto label_54;

    case 7:
      current_block = (Rpc - LABEL_40_14);
      goto label_55;

    case 8:
      current_block = (Rpc - LABEL_40_17);
      goto label_51;

    case 9:
      current_block = (Rpc - LABEL_40_18);
      goto label_52;

    case 10:
      current_block = (Rpc - LABEL_40_20);
      goto continuation_5;

    case 11:
      current_block = (Rpc - LABEL_40_21);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_40_22);
      goto label_49;

    case 13:
      current_block = (Rpc - LABEL_40_23);
      goto label_47;

    case 14:
      current_block = (Rpc - LABEL_40_24);
      goto label_48;

    case 15:
      current_block = (Rpc - LABEL_40_26);
      goto continuation_7;

    case 16:
      current_block = (Rpc - LABEL_40_6);
      goto lambda_40;

    case 17:
      current_block = (Rpc - LABEL_40_31);
      goto label_44;

    case 18:
      current_block = (Rpc - LABEL_40_32);
      goto label_45;

    case 19:
      current_block = (Rpc - LABEL_40_33);
      goto label_46;

    case 20:
      current_block = (Rpc - LABEL_40_29);
      goto lambda_2;

    case 21:
      current_block = (Rpc - LABEL_40_37);
      goto continuation_1;

    case 22:
      current_block = (Rpc - LABEL_40_27);
      goto continuation_17;

    case 23:
      current_block = (Rpc - LABEL_40_39);
      goto continuation_0;

    case 24:
      current_block = (Rpc - LABEL_40_41);
      goto lambda_65;

    case 25:
      current_block = (Rpc - LABEL_40_15);
      goto continuation_36;

    case 26:
      current_block = (Rpc - LABEL_40_46);
      goto label_56;

    case 27:
      current_block = (Rpc - LABEL_40_16);
      goto continuation_35;

    case 28:
      current_block = (Rpc - LABEL_40_44);
      goto continuation_20;

    case 29:
      current_block = (Rpc - LABEL_40_45);
      goto continuation_32;

    case 30:
      current_block = (Rpc - LABEL_40_47);
      goto continuation_19;

    case 31:
      current_block = (Rpc - LABEL_40_48);
      goto label_57;

    case 32:
      current_block = (Rpc - LABEL_40_50);
      goto label_60;

    case 33:
      current_block = (Rpc - LABEL_40_51);
      goto label_58;

    case 34:
      current_block = (Rpc - LABEL_40_53);
      goto label_59;

    case 35:
      current_block = (Rpc - LABEL_40_52);
      goto continuation_25;

    case 36:
      current_block = (Rpc - LABEL_40_49);
      goto continuation_28;

    case 37:
      current_block = (Rpc - LABEL_40_55);
      goto continuation_24;

    case 38:
      current_block = (Rpc - LABEL_40_57);
      goto continuation_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_combination_object_62)
DEFLABEL (unsyntax_combination_object_42)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_7]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_8]));

DEFLABEL (lambda_63)
DEFLABEL (lambda_40)
  INTERRUPT_CHECK (26, LABEL_40_6);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_40_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_40_29])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_100;
  Wrd12 = Wrd16;

DEFLABEL (label_99)
  if ((Wrd12.Obj) == (current_block [OBJECT_40_3]))
    goto label_67;

DEFLABEL (label_66)
  (Wrd86.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd86.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_2;

DEFLABEL (label_67)
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_98;
  Wrd22 = Wrd26;

DEFLABEL (label_97)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd28.uLng) == 1)
    goto label_94;

DEFLABEL (label_93)
  (Wrd29.Obj) = (Rsp [1]);
  if ((Wrd29.Obj) == (current_block [OBJECT_40_4]))
    goto label_92;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_26]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_40_5]);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_36]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_40_26);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;

DEFLABEL (label_92)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_21]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_35]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_40_21);
  (Wrd57.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd57.uLng) == 26))
    goto label_91;
  if (Rvl == (current_block [OBJECT_40_2]))
    goto label_70;

DEFLABEL (label_69)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_27]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd55.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_28]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_40_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_68;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x606, 2);
  (* (Rhp++)) = (dispatch_base + TAG_40_42);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_40_41])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_43]));

DEFLABEL (label_68)
  (Wrd15.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd15.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_2;

DEFLABEL (label_70)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_10]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd65.Obj) = (Rsp [3]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_90;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_89)
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_88;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd72.Obj) = ((Wrd71.pObj) [0]);
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_87)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_25]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_40_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;
  (Wrd92.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd95.Obj) = ((Wrd92.pObj) [0]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if ((Wrd96.uLng) == 50)
    goto label_86;
  Wrd91 = Wrd95;

DEFLABEL (label_85)
  (Wrd97.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd97.uLng) == 1)
    goto label_78;

DEFLABEL (label_77)
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_15]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_16]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd107.Obj) = (Rsp [4]);
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if (! ((Wrd108.uLng) == 1))
    goto label_76;
  (Wrd106.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd104.Obj) = ((Wrd106.pObj) [1]);

DEFLABEL (label_75)
  (Wrd115.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if (! ((Wrd115.uLng) == 1))
    goto label_74;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (* (--Rsp)) = (Wrd114.Obj);

DEFLABEL (label_73)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_19]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_40_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_40]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_40_15);
  (Wrd9.Obj) = (current_block [OBJECT_40_6]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_45]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_72;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_71)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_40]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_40_45);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_40_7]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_72)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_46]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_18]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd104.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_52)
  (* (--Rsp)) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_17]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd107.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_0]), 1);

DEFLABEL (label_51)
  (Wrd104.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_9]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (Wrd124.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd127.Obj) = ((Wrd124.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_84;
  Wrd123 = Wrd127;

DEFLABEL (label_83)
  (* (--Rsp)) = (Wrd123.Obj);
  (Wrd132.Obj) = (Rsp [4]);
  (Wrd133.uLng) = (OBJECT_TYPE (Wrd132.Obj));
  if (! ((Wrd133.uLng) == 1))
    goto label_82;
  (Wrd131.pObj) = (OBJECT_ADDRESS (Wrd132.Obj));
  (Wrd129.Obj) = ((Wrd131.pObj) [1]);

DEFLABEL (label_81)
  (Wrd140.uLng) = (OBJECT_TYPE (Wrd129.Obj));
  if (! ((Wrd140.uLng) == 1))
    goto label_80;
  (Wrd138.pObj) = (OBJECT_ADDRESS (Wrd129.Obj));
  (Wrd139.Obj) = ((Wrd138.pObj) [0]);
  (* (--Rsp)) = (Wrd139.Obj);

DEFLABEL (label_79)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_34]));

DEFLABEL (label_80)
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_14]))));
  (* (--Rsp)) = (Wrd144.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd137.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_13]))));
  (* (--Rsp)) = (Wrd137.Obj);
  (* (--Rsp)) = (Wrd132.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_0]), 1);

DEFLABEL (label_54)
  (Wrd129.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_12])), (Wrd124.pObj));

DEFLABEL (label_53)
  (Wrd123.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_11])), (Wrd92.pObj));

DEFLABEL (label_50)
  (Wrd91.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_24]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_23]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_0]), 1);

DEFLABEL (label_47)
  (Wrd62.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_91)
  (Wrd79.Obj) = (current_block [OBJECT_40_2]);
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_22]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_49)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;
  goto label_70;

DEFLABEL (label_94)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_20]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd44.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_0]));
  (Wrd47.Obj) = ((Wrd44.pObj) [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if ((Wrd48.uLng) == 50)
    goto label_96;
  Wrd43 = Wrd47;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd49.Obj);
  goto label_79;

DEFLABEL (label_96)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_33])), (Wrd44.pObj));

DEFLABEL (label_46)
  (Wrd43.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_32])), (Wrd23.pObj));

DEFLABEL (label_45)
  (Wrd22.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_31])), (Wrd13.pObj));

DEFLABEL (label_44)
  (Wrd12.Obj) = Rvl;
  goto label_99;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_40_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_77;
  goto label_69;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_40_20);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_93;
  goto label_66;

DEFLABEL (lambda_64)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_40_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_38]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_40_37);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_40]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_39);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_65)
  CLOSURE_HEADER (LABEL_40_41);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [3]);
  if ((Wrd5.Obj) == (current_block [OBJECT_40_6]))
    goto label_102;

DEFLABEL (label_101)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [3]);
  (Rsp [5]) = (Wrd13.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_2;

DEFLABEL (label_102)
  (Wrd11.Obj) = (Rsp [4]);
  if (! ((Wrd11.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_101;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_44]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_35]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_40_44);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_35]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_40_47);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd7.uLng) == 26))
    goto label_113;
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_113;
  if (Rvl == (Wrd5.Obj))
    goto label_104;

DEFLABEL (label_103)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [3]);
  (Rsp [5]) = (Wrd29.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_2;

DEFLABEL (label_104)
  (Wrd19.Obj) = (Rsp [1]);
  if ((Wrd19.Obj) == (current_block [OBJECT_40_8]))
    goto label_110;
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_3]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_109;
  Wrd22 = Wrd26;

DEFLABEL (label_108)
  (Wrd28.Obj) = (Rsp [1]);
  if (! ((Wrd28.Obj) == (Wrd22.Obj)))
    goto label_103;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_52]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd38.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_2]));
  (Wrd41.Obj) = ((Wrd38.pObj) [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 50)
    goto label_107;
  Wrd37 = Wrd41;

DEFLABEL (label_106)
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_105)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd57.Obj) = (current_block [OBJECT_40_6]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd58.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_54]));

DEFLABEL (label_107)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_53])), (Wrd38.pObj));

DEFLABEL (label_59)
  (Wrd37.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_51])), (Wrd23.pObj));

DEFLABEL (label_58)
  (Wrd22.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_110)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_49]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40_2]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_112;
  Wrd50 = Wrd54;

DEFLABEL (label_111)
  (* (--Rsp)) = (Wrd50.Obj);
  goto label_105;

DEFLABEL (label_112)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40_50])), (Wrd51.pObj));

DEFLABEL (label_60)
  (Wrd50.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_113)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_48]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_57)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_103;
  goto label_104;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_40_52);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_56]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_40_55);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_40_9]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_40_49);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_57]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_56]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_40_57);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_40_9]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define ENVIRONMENT_LABEL_41_3 12
#define DEBUGGING_LABEL_41_2 11
#define EXECUTE_CACHE_41_6 7
#define FREE_REFERENCE_41_0 10
#define FREE_REFERENCES_LABEL_41_0 6
#define NUMBER_OF_LINKER_SECTIONS_41_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto unsyntax_let_bindings_0;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_let_bindings_4)
DEFLABEL (unsyntax_let_bindings_0)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define ENVIRONMENT_LABEL_42_3 10
#define DEBUGGING_LABEL_42_2 9
#define EXECUTE_CACHE_42_6 7
#define FREE_REFERENCES_LABEL_42_0 6
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto unsyntax_let_binding_1;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unsyntax_let_binding_4)
DEFLABEL (unsyntax_let_binding_1)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_5);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_6 5
#define LABEL_43_9 7
#define LABEL_43_10 9
#define LABEL_43_11 11
#define LABEL_43_12 13
#define LABEL_43_13 15
#define LABEL_43_15 17
#define LABEL_43_16 19
#define LABEL_43_17 21
#define LABEL_43_18 23
#define LABEL_43_19 25
#define LABEL_43_20 27
#define LABEL_43_21 29
#define LABEL_43_22 31
#define LABEL_43_23 33
#define LABEL_43_24 35
#define LABEL_43_25 37
#define LABEL_43_26 39
#define LABEL_43_27 41
#define LABEL_43_28 43
#define LABEL_43_29 45
#define LABEL_43_30 47
#define LABEL_43_31 49
#define LABEL_43_32 51
#define LABEL_43_33 53
#define LABEL_43_34 55
#define LABEL_43_35 57
#define LABEL_43_36 59
#define LABEL_43_37 61
#define LABEL_43_38 63
#define LABEL_43_39 65
#define LABEL_43_40 67
#define LABEL_43_41 69
#define LABEL_43_7 71
#define LABEL_43_5 73
#define LABEL_43_43 75
#define LABEL_43_44 77
#define LABEL_43_45 79
#define LABEL_43_46 81
#define LABEL_43_47 83
#define LABEL_43_48 85
#define LABEL_43_50 87
#define LABEL_43_51 89
#define LABEL_43_52 91
#define LABEL_43_53 93
#define LABEL_43_54 95
#define LABEL_43_55 97
#define LABEL_43_56 99
#define LABEL_43_57 101
#define LABEL_43_49 103
#define LABEL_43_60 105
#define LABEL_43_61 107
#define LABEL_43_62 109
#define LABEL_43_63 111
#define LABEL_43_64 113
#define LABEL_43_58 115
#define LABEL_43_65 117
#define ENVIRONMENT_LABEL_43_3 143
#define DEBUGGING_LABEL_43_2 142
#define OBJECT_43_10 141
#define OBJECT_43_9 140
#define OBJECT_43_8 139
#define OBJECT_43_7 138
#define OBJECT_43_6 137
#define OBJECT_43_5 136
#define OBJECT_43_4 135
#define OBJECT_43_3 134
#define OBJECT_43_2 133
#define OBJECT_43_1 132
#define OBJECT_43_0 131
#define EXECUTE_CACHE_43_66 119
#define EXECUTE_CACHE_43_59 121
#define EXECUTE_CACHE_43_42 123
#define EXECUTE_CACHE_43_14 125
#define EXECUTE_CACHE_43_8 127
#define FREE_REFERENCE_43_0 130
#define FREE_REFERENCES_LABEL_43_0 118
#define NUMBER_OF_LINKER_SECTIONS_43_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
unsyn_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd115;
  machine_word Wrd113;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd109;
  machine_word Wrd106;
  machine_word Wrd100;
  machine_word Wrd101;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd93;
  machine_word Wrd94;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd79;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd72;
  machine_word Wrd73;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd62;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd341;
  machine_word Wrd336;
  machine_word Wrd335;
  machine_word Wrd337;
  machine_word Wrd334;
  machine_word Wrd328;
  machine_word Wrd329;
  machine_word Wrd330;
  machine_word Wrd327;
  machine_word Wrd319;
  machine_word Wrd321;
  machine_word Wrd323;
  machine_word Wrd322;
  machine_word Wrd318;
  machine_word Wrd315;
  machine_word Wrd314;
  machine_word Wrd308;
  machine_word Wrd309;
  machine_word Wrd310;
  machine_word Wrd307;
  machine_word Wrd301;
  machine_word Wrd302;
  machine_word Wrd303;
  machine_word Wrd300;
  machine_word Wrd292;
  machine_word Wrd294;
  machine_word Wrd296;
  machine_word Wrd295;
  machine_word Wrd291;
  machine_word Wrd286;
  machine_word Wrd285;
  machine_word Wrd287;
  machine_word Wrd284;
  machine_word Wrd278;
  machine_word Wrd279;
  machine_word Wrd280;
  machine_word Wrd277;
  machine_word Wrd271;
  machine_word Wrd272;
  machine_word Wrd273;
  machine_word Wrd270;
  machine_word Wrd262;
  machine_word Wrd264;
  machine_word Wrd266;
  machine_word Wrd265;
  machine_word Wrd261;
  machine_word Wrd260;
  machine_word Wrd254;
  machine_word Wrd255;
  machine_word Wrd256;
  machine_word Wrd253;
  machine_word Wrd245;
  machine_word Wrd247;
  machine_word Wrd249;
  machine_word Wrd248;
  machine_word Wrd243;
  machine_word Wrd235;
  machine_word Wrd237;
  machine_word Wrd233;
  machine_word Wrd232;
  machine_word Wrd231;
  machine_word Wrd226;
  machine_word Wrd225;
  machine_word Wrd227;
  machine_word Wrd224;
  machine_word Wrd218;
  machine_word Wrd219;
  machine_word Wrd220;
  machine_word Wrd217;
  machine_word Wrd209;
  machine_word Wrd211;
  machine_word Wrd213;
  machine_word Wrd212;
  machine_word Wrd199;
  machine_word Wrd203;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd207;
  machine_word Wrd197;
  machine_word Wrd351;
  machine_word Wrd348;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd346;
  machine_word Wrd343;
  machine_word Wrd192;
  machine_word Wrd187;
  machine_word Wrd186;
  machine_word Wrd188;
  machine_word Wrd185;
  machine_word Wrd179;
  machine_word Wrd180;
  machine_word Wrd181;
  machine_word Wrd178;
  machine_word Wrd172;
  machine_word Wrd173;
  machine_word Wrd174;
  machine_word Wrd171;
  machine_word Wrd163;
  machine_word Wrd165;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd162;
  machine_word Wrd158;
  machine_word Wrd152;
  machine_word Wrd153;
  machine_word Wrd154;
  machine_word Wrd151;
  machine_word Wrd143;
  machine_word Wrd145;
  machine_word Wrd147;
  machine_word Wrd146;
  machine_word Wrd141;
  machine_word Wrd133;
  machine_word Wrd135;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd131;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd382;
  machine_word Wrd387;
  machine_word Wrd386;
  machine_word Wrd383;
  machine_word Wrd380;
  machine_word Wrd374;
  machine_word Wrd375;
  machine_word Wrd376;
  machine_word Wrd373;
  machine_word Wrd367;
  machine_word Wrd368;
  machine_word Wrd369;
  machine_word Wrd366;
  machine_word Wrd358;
  machine_word Wrd360;
  machine_word Wrd362;
  machine_word Wrd361;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto rewrite_named_let_69;

    case 1:
      current_block = (Rpc - LABEL_43_6);
      goto label_71;

    case 2:
      current_block = (Rpc - LABEL_43_9);
      goto continuation_38;

    case 3:
      current_block = (Rpc - LABEL_43_10);
      goto label_116;

    case 4:
      current_block = (Rpc - LABEL_43_11);
      goto label_117;

    case 5:
      current_block = (Rpc - LABEL_43_12);
      goto label_118;

    case 6:
      current_block = (Rpc - LABEL_43_13);
      goto label_119;

    case 7:
      current_block = (Rpc - LABEL_43_15);
      goto continuation_15;

    case 8:
      current_block = (Rpc - LABEL_43_16);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_43_17);
      goto label_91;

    case 10:
      current_block = (Rpc - LABEL_43_18);
      goto label_92;

    case 11:
      current_block = (Rpc - LABEL_43_19);
      goto label_93;

    case 12:
      current_block = (Rpc - LABEL_43_20);
      goto label_94;

    case 13:
      current_block = (Rpc - LABEL_43_21);
      goto label_95;

    case 14:
      current_block = (Rpc - LABEL_43_22);
      goto label_96;

    case 15:
      current_block = (Rpc - LABEL_43_23);
      goto label_97;

    case 16:
      current_block = (Rpc - LABEL_43_24);
      goto label_98;

    case 17:
      current_block = (Rpc - LABEL_43_25);
      goto label_115;

    case 18:
      current_block = (Rpc - LABEL_43_26);
      goto label_99;

    case 19:
      current_block = (Rpc - LABEL_43_27);
      goto label_100;

    case 20:
      current_block = (Rpc - LABEL_43_28);
      goto label_101;

    case 21:
      current_block = (Rpc - LABEL_43_29);
      goto label_102;

    case 22:
      current_block = (Rpc - LABEL_43_30);
      goto label_103;

    case 23:
      current_block = (Rpc - LABEL_43_31);
      goto label_104;

    case 24:
      current_block = (Rpc - LABEL_43_32);
      goto label_105;

    case 25:
      current_block = (Rpc - LABEL_43_33);
      goto label_106;

    case 26:
      current_block = (Rpc - LABEL_43_34);
      goto label_107;

    case 27:
      current_block = (Rpc - LABEL_43_35);
      goto label_108;

    case 28:
      current_block = (Rpc - LABEL_43_36);
      goto label_109;

    case 29:
      current_block = (Rpc - LABEL_43_37);
      goto label_110;

    case 30:
      current_block = (Rpc - LABEL_43_38);
      goto label_111;

    case 31:
      current_block = (Rpc - LABEL_43_39);
      goto label_112;

    case 32:
      current_block = (Rpc - LABEL_43_40);
      goto label_113;

    case 33:
      current_block = (Rpc - LABEL_43_41);
      goto label_114;

    case 34:
      current_block = (Rpc - LABEL_43_7);
      goto continuation_3;

    case 35:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_2;

    case 36:
      current_block = (Rpc - LABEL_43_43);
      goto label_72;

    case 37:
      current_block = (Rpc - LABEL_43_44);
      goto label_73;

    case 38:
      current_block = (Rpc - LABEL_43_45);
      goto label_74;

    case 39:
      current_block = (Rpc - LABEL_43_46);
      goto label_75;

    case 40:
      current_block = (Rpc - LABEL_43_47);
      goto label_76;

    case 41:
      current_block = (Rpc - LABEL_43_48);
      goto label_77;

    case 42:
      current_block = (Rpc - LABEL_43_50);
      goto label_78;

    case 43:
      current_block = (Rpc - LABEL_43_51);
      goto label_79;

    case 44:
      current_block = (Rpc - LABEL_43_52);
      goto label_80;

    case 45:
      current_block = (Rpc - LABEL_43_53);
      goto label_81;

    case 46:
      current_block = (Rpc - LABEL_43_54);
      goto label_82;

    case 47:
      current_block = (Rpc - LABEL_43_55);
      goto label_83;

    case 48:
      current_block = (Rpc - LABEL_43_56);
      goto label_84;

    case 49:
      current_block = (Rpc - LABEL_43_57);
      goto label_85;

    case 50:
      current_block = (Rpc - LABEL_43_49);
      goto continuation_60;

    case 51:
      current_block = (Rpc - LABEL_43_60);
      goto label_86;

    case 52:
      current_block = (Rpc - LABEL_43_61);
      goto label_87;

    case 53:
      current_block = (Rpc - LABEL_43_62);
      goto label_88;

    case 54:
      current_block = (Rpc - LABEL_43_63);
      goto label_89;

    case 55:
      current_block = (Rpc - LABEL_43_64);
      goto label_90;

    case 56:
      current_block = (Rpc - LABEL_43_58);
      goto lambda_51;

    case 57:
      current_block = (Rpc - LABEL_43_65);
      goto continuation_49;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (rewrite_named_let_121)
DEFLABEL (rewrite_named_let_69)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_123;
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_123)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_193;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_192)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_43_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_125;
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_16]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (Wrd123.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd123.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_42]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_43_16);
  (Wrd126.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd126.uLng) == 26))
    goto label_191;
  if (Rvl == (current_block [OBJECT_43_2]))
    goto label_126;

DEFLABEL (label_125)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_124)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_126)
  (Wrd136.Obj) = (Rsp [0]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if (! ((Wrd137.uLng) == 1))
    goto label_190;
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd136.Obj));
  (Wrd133.Obj) = ((Wrd135.pObj) [0]);

DEFLABEL (label_189)
  if (! ((Wrd133.Obj) == (current_block [OBJECT_43_3])))
    goto label_125;
  (Wrd146.Obj) = (Rsp [0]);
  (Wrd147.uLng) = (OBJECT_TYPE (Wrd146.Obj));
  if (! ((Wrd147.uLng) == 1))
    goto label_188;
  (Wrd145.pObj) = (OBJECT_ADDRESS (Wrd146.Obj));
  (Wrd143.Obj) = ((Wrd145.pObj) [1]);

DEFLABEL (label_187)
  (Wrd154.uLng) = (OBJECT_TYPE (Wrd143.Obj));
  if (! ((Wrd154.uLng) == 1))
    goto label_186;
  (Wrd153.pObj) = (OBJECT_ADDRESS (Wrd143.Obj));
  (Wrd152.Obj) = ((Wrd153.pObj) [0]);

DEFLABEL (label_185)
  if (! ((Wrd152.Obj) == (current_block [OBJECT_43_4])))
    goto label_125;
  (Wrd162.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_15]))));
  (* (--Rsp)) = (Wrd162.Obj);
  (Wrd166.Obj) = (Rsp [1]);
  (Wrd167.uLng) = (OBJECT_TYPE (Wrd166.Obj));
  if (! ((Wrd167.uLng) == 1))
    goto label_184;
  (Wrd165.pObj) = (OBJECT_ADDRESS (Wrd166.Obj));
  (Wrd163.Obj) = ((Wrd165.pObj) [1]);

DEFLABEL (label_183)
  (Wrd174.uLng) = (OBJECT_TYPE (Wrd163.Obj));
  if (! ((Wrd174.uLng) == 1))
    goto label_182;
  (Wrd173.pObj) = (OBJECT_ADDRESS (Wrd163.Obj));
  (Wrd172.Obj) = ((Wrd173.pObj) [1]);

DEFLABEL (label_181)
  (Wrd181.uLng) = (OBJECT_TYPE (Wrd172.Obj));
  if (! ((Wrd181.uLng) == 1))
    goto label_180;
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd172.Obj));
  (Wrd179.Obj) = ((Wrd180.pObj) [1]);

DEFLABEL (label_179)
  (Wrd188.uLng) = (OBJECT_TYPE (Wrd179.Obj));
  if (! ((Wrd188.uLng) == 1))
    goto label_178;
  (Wrd186.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  (Wrd187.Obj) = ((Wrd186.pObj) [0]);
  (* (--Rsp)) = (Wrd187.Obj);

DEFLABEL (label_177)
  (Wrd343.Obj) = (current_block [OBJECT_43_5]);
  (Wrd346.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd346.Lng))))
    goto label_176;
  (Wrd194.uLng) = (OBJECT_DATUM (Wrd343.Obj));
  (Wrd195.Obj) = (Rsp [0]);
  (Wrd196.uLng) = (OBJECT_TYPE (Wrd195.Obj));
  if ((Wrd194.Obj) == (Wrd196.Obj))
    goto label_175;

DEFLABEL (label_174)
  (Wrd197.Obj) = (current_block [OBJECT_43_7]);
  (* (--Rsp)) = (Wrd197.Obj);
  (Wrd207.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd207.Lng)))
    goto label_127;
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_6]), 2);

DEFLABEL (label_127)
  (Wrd201.uLng) = (OBJECT_DATUM (Wrd197.Obj));
  (Wrd202.Obj) = (Rsp [1]);
  (Wrd203.uLng) = (OBJECT_TYPE (Wrd202.Obj));
  if ((Wrd201.Obj) == (Wrd203.Obj))
    goto label_129;
  (Wrd199.Obj) = (current_block [OBJECT_43_9]);
  goto label_128;

DEFLABEL (label_129)
  (Wrd199.Obj) = (current_block [OBJECT_43_8]);

DEFLABEL (label_128)
DEFLABEL (label_173)
  Rsp = (& (Rsp [3]));
  if ((Wrd199.Obj) == ((SCHEME_OBJECT) 0))
    goto label_125;

DEFLABEL (label_172)
  (Wrd212.Obj) = (Rsp [0]);
  (Wrd213.uLng) = (OBJECT_TYPE (Wrd212.Obj));
  if (! ((Wrd213.uLng) == 1))
    goto label_171;
  (Wrd211.pObj) = (OBJECT_ADDRESS (Wrd212.Obj));
  (Wrd209.Obj) = ((Wrd211.pObj) [1]);

DEFLABEL (label_170)
  (Wrd220.uLng) = (OBJECT_TYPE (Wrd209.Obj));
  if (! ((Wrd220.uLng) == 1))
    goto label_169;
  (Wrd219.pObj) = (OBJECT_ADDRESS (Wrd209.Obj));
  (Wrd218.Obj) = ((Wrd219.pObj) [1]);

DEFLABEL (label_168)
  (Wrd227.uLng) = (OBJECT_TYPE (Wrd218.Obj));
  if (! ((Wrd227.uLng) == 1))
    goto label_167;
  (Wrd225.pObj) = (OBJECT_ADDRESS (Wrd218.Obj));
  (Wrd226.Obj) = ((Wrd225.pObj) [0]);
  (* (--Rsp)) = (Wrd226.Obj);

DEFLABEL (label_166)
  (Wrd232.Obj) = (Rsp [0]);
  (Wrd233.uLng) = (OBJECT_TYPE (Wrd232.Obj));
  if ((Wrd233.uLng) == 1)
    goto label_131;

DEFLABEL (label_130)
  Rsp = (& (Rsp [3]));
  goto label_124;

DEFLABEL (label_131)
  if (! ((Wrd233.uLng) == 1))
    goto label_165;
  (Wrd237.pObj) = (OBJECT_ADDRESS (Wrd232.Obj));
  (Wrd235.Obj) = ((Wrd237.pObj) [0]);

DEFLABEL (label_164)
  if (! ((Wrd235.Obj) == (current_block [OBJECT_43_10])))
    goto label_130;
  (Wrd248.Obj) = (Rsp [0]);
  (Wrd249.uLng) = (OBJECT_TYPE (Wrd248.Obj));
  if (! ((Wrd249.uLng) == 1))
    goto label_163;
  (Wrd247.pObj) = (OBJECT_ADDRESS (Wrd248.Obj));
  (Wrd245.Obj) = ((Wrd247.pObj) [1]);

DEFLABEL (label_162)
  (Wrd256.uLng) = (OBJECT_TYPE (Wrd245.Obj));
  if (! ((Wrd256.uLng) == 1))
    goto label_161;
  (Wrd255.pObj) = (OBJECT_ADDRESS (Wrd245.Obj));
  (Wrd254.Obj) = ((Wrd255.pObj) [0]);

DEFLABEL (label_160)
  (Wrd261.uLng) = (OBJECT_TYPE (Wrd254.Obj));
  if (! ((Wrd261.uLng) == 1))
    goto label_130;
  (Wrd265.Obj) = (Rsp [1]);
  (Wrd266.uLng) = (OBJECT_TYPE (Wrd265.Obj));
  if (! ((Wrd266.uLng) == 1))
    goto label_159;
  (Wrd264.pObj) = (OBJECT_ADDRESS (Wrd265.Obj));
  (Wrd262.Obj) = ((Wrd264.pObj) [1]);

DEFLABEL (label_158)
  (Wrd273.uLng) = (OBJECT_TYPE (Wrd262.Obj));
  if (! ((Wrd273.uLng) == 1))
    goto label_157;
  (Wrd272.pObj) = (OBJECT_ADDRESS (Wrd262.Obj));
  (Wrd271.Obj) = ((Wrd272.pObj) [1]);

DEFLABEL (label_156)
  (Wrd280.uLng) = (OBJECT_TYPE (Wrd271.Obj));
  if (! ((Wrd280.uLng) == 1))
    goto label_155;
  (Wrd279.pObj) = (OBJECT_ADDRESS (Wrd271.Obj));
  (Wrd278.Obj) = ((Wrd279.pObj) [1]);

DEFLABEL (label_154)
  (Wrd287.uLng) = (OBJECT_TYPE (Wrd278.Obj));
  if (! ((Wrd287.uLng) == 1))
    goto label_153;
  (Wrd285.pObj) = (OBJECT_ADDRESS (Wrd278.Obj));
  (Wrd286.Obj) = ((Wrd285.pObj) [0]);
  (* (--Rsp)) = (Wrd286.Obj);

DEFLABEL (label_152)
  (Wrd295.Obj) = (Rsp [1]);
  (Wrd296.uLng) = (OBJECT_TYPE (Wrd295.Obj));
  if (! ((Wrd296.uLng) == 1))
    goto label_151;
  (Wrd294.pObj) = (OBJECT_ADDRESS (Wrd295.Obj));
  (Wrd292.Obj) = ((Wrd294.pObj) [1]);

DEFLABEL (label_150)
  (Wrd303.uLng) = (OBJECT_TYPE (Wrd292.Obj));
  if (! ((Wrd303.uLng) == 1))
    goto label_149;
  (Wrd302.pObj) = (OBJECT_ADDRESS (Wrd292.Obj));
  (Wrd301.Obj) = ((Wrd302.pObj) [0]);

DEFLABEL (label_148)
  (Wrd310.uLng) = (OBJECT_TYPE (Wrd301.Obj));
  if (! ((Wrd310.uLng) == 1))
    goto label_147;
  (Wrd309.pObj) = (OBJECT_ADDRESS (Wrd301.Obj));
  (Wrd308.Obj) = ((Wrd309.pObj) [0]);

DEFLABEL (label_146)
  (Wrd315.Obj) = (* (Rsp++));
  if (! ((Wrd308.Obj) == (Wrd315.Obj)))
    goto label_130;
  (Wrd318.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_9]))));
  (* (--Rsp)) = (Wrd318.Obj);
  (Wrd322.Obj) = (Rsp [1]);
  (Wrd323.uLng) = (OBJECT_TYPE (Wrd322.Obj));
  if (! ((Wrd323.uLng) == 1))
    goto label_145;
  (Wrd321.pObj) = (OBJECT_ADDRESS (Wrd322.Obj));
  (Wrd319.Obj) = ((Wrd321.pObj) [1]);

DEFLABEL (label_144)
  (Wrd330.uLng) = (OBJECT_TYPE (Wrd319.Obj));
  if (! ((Wrd330.uLng) == 1))
    goto label_143;
  (Wrd329.pObj) = (OBJECT_ADDRESS (Wrd319.Obj));
  (Wrd328.Obj) = ((Wrd329.pObj) [0]);

DEFLABEL (label_142)
  (Wrd337.uLng) = (OBJECT_TYPE (Wrd328.Obj));
  if (! ((Wrd337.uLng) == 1))
    goto label_141;
  (Wrd335.pObj) = (OBJECT_ADDRESS (Wrd328.Obj));
  (Wrd336.Obj) = ((Wrd335.pObj) [1]);
  (* (--Rsp)) = (Wrd336.Obj);

DEFLABEL (label_140)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_8]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_43_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_130;
  (Wrd361.Obj) = (Rsp [0]);
  (Wrd362.uLng) = (OBJECT_TYPE (Wrd361.Obj));
  if (! ((Wrd362.uLng) == 1))
    goto label_139;
  (Wrd360.pObj) = (OBJECT_ADDRESS (Wrd361.Obj));
  (Wrd358.Obj) = ((Wrd360.pObj) [1]);

DEFLABEL (label_138)
  (Wrd369.uLng) = (OBJECT_TYPE (Wrd358.Obj));
  if (! ((Wrd369.uLng) == 1))
    goto label_137;
  (Wrd368.pObj) = (OBJECT_ADDRESS (Wrd358.Obj));
  (Wrd367.Obj) = ((Wrd368.pObj) [0]);

DEFLABEL (label_136)
  (Wrd376.uLng) = (OBJECT_TYPE (Wrd367.Obj));
  if (! ((Wrd376.uLng) == 1))
    goto label_135;
  (Wrd375.pObj) = (OBJECT_ADDRESS (Wrd367.Obj));
  (Wrd374.Obj) = ((Wrd375.pObj) [1]);

DEFLABEL (label_134)
  (Rsp [0]) = (Wrd374.Obj);
  (Wrd383.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_43_0]));
  (Wrd386.Obj) = ((Wrd383.pObj) [0]);
  (Wrd387.uLng) = (OBJECT_TYPE (Wrd386.Obj));
  if ((Wrd387.uLng) == 50)
    goto label_133;
  Wrd382 = Wrd386;

DEFLABEL (label_132)
  (Rsp [1]) = (Wrd382.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_14]));

DEFLABEL (label_133)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_43_13])), (Wrd383.pObj));

DEFLABEL (label_119)
  (Wrd382.Obj) = Rvl;
  goto label_132;

DEFLABEL (label_135)
  (Wrd380.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_12]))));
  (* (--Rsp)) = (Wrd380.Obj);
  (* (--Rsp)) = (Wrd367.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_118)
  (Wrd374.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  (Wrd373.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_11]))));
  (* (--Rsp)) = (Wrd373.Obj);
  (* (--Rsp)) = (Wrd358.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_117)
  (Wrd367.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  (Wrd366.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_10]))));
  (* (--Rsp)) = (Wrd366.Obj);
  (* (--Rsp)) = (Wrd361.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_116)
  (Wrd358.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  (Wrd341.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_41]))));
  (* (--Rsp)) = (Wrd341.Obj);
  (* (--Rsp)) = (Wrd328.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_114)
  (* (--Rsp)) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  (Wrd334.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_40]))));
  (* (--Rsp)) = (Wrd334.Obj);
  (* (--Rsp)) = (Wrd319.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_113)
  (Wrd328.Obj) = Rvl;
  goto label_142;

DEFLABEL (label_145)
  (Wrd327.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_39]))));
  (* (--Rsp)) = (Wrd327.Obj);
  (* (--Rsp)) = (Wrd322.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_112)
  (Wrd319.Obj) = Rvl;
  goto label_144;

DEFLABEL (label_147)
  (Wrd314.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_38]))));
  (* (--Rsp)) = (Wrd314.Obj);
  (* (--Rsp)) = (Wrd301.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_111)
  (Wrd308.Obj) = Rvl;
  goto label_146;

DEFLABEL (label_149)
  (Wrd307.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_37]))));
  (* (--Rsp)) = (Wrd307.Obj);
  (* (--Rsp)) = (Wrd292.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_110)
  (Wrd301.Obj) = Rvl;
  goto label_148;

DEFLABEL (label_151)
  (Wrd300.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_36]))));
  (* (--Rsp)) = (Wrd300.Obj);
  (* (--Rsp)) = (Wrd295.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_109)
  (Wrd292.Obj) = Rvl;
  goto label_150;

DEFLABEL (label_153)
  (Wrd291.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_35]))));
  (* (--Rsp)) = (Wrd291.Obj);
  (* (--Rsp)) = (Wrd278.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_108)
  (* (--Rsp)) = Rvl;
  goto label_152;

DEFLABEL (label_155)
  (Wrd284.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_34]))));
  (* (--Rsp)) = (Wrd284.Obj);
  (* (--Rsp)) = (Wrd271.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_107)
  (Wrd278.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  (Wrd277.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_33]))));
  (* (--Rsp)) = (Wrd277.Obj);
  (* (--Rsp)) = (Wrd262.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_106)
  (Wrd271.Obj) = Rvl;
  goto label_156;

DEFLABEL (label_159)
  (Wrd270.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_32]))));
  (* (--Rsp)) = (Wrd270.Obj);
  (* (--Rsp)) = (Wrd265.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_105)
  (Wrd262.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_161)
  (Wrd260.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_31]))));
  (* (--Rsp)) = (Wrd260.Obj);
  (* (--Rsp)) = (Wrd245.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_104)
  (Wrd254.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_163)
  (Wrd253.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_30]))));
  (* (--Rsp)) = (Wrd253.Obj);
  (* (--Rsp)) = (Wrd248.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_103)
  (Wrd245.Obj) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  (Wrd243.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_29]))));
  (* (--Rsp)) = (Wrd243.Obj);
  (* (--Rsp)) = (Wrd232.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_102)
  (Wrd235.Obj) = Rvl;
  goto label_164;

DEFLABEL (label_167)
  (Wrd231.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_28]))));
  (* (--Rsp)) = (Wrd231.Obj);
  (* (--Rsp)) = (Wrd218.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_101)
  (* (--Rsp)) = Rvl;
  goto label_166;

DEFLABEL (label_169)
  (Wrd224.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_27]))));
  (* (--Rsp)) = (Wrd224.Obj);
  (* (--Rsp)) = (Wrd209.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_100)
  (Wrd218.Obj) = Rvl;
  goto label_168;

DEFLABEL (label_171)
  (Wrd217.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_26]))));
  (* (--Rsp)) = (Wrd217.Obj);
  (* (--Rsp)) = (Wrd212.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_99)
  (Wrd209.Obj) = Rvl;
  goto label_170;

DEFLABEL (label_175)
  Rsp = (& (Rsp [2]));
  goto label_172;

DEFLABEL (label_176)
  (Wrd348.Obj) = (Rsp [0]);
  (Wrd351.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_25]))));
  (* (--Rsp)) = (Wrd351.Obj);
  (* (--Rsp)) = (Wrd348.Obj);
  (* (--Rsp)) = (Wrd343.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_6]), 2);

DEFLABEL (label_115)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_174;
  goto label_175;

DEFLABEL (label_178)
  (Wrd192.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_24]))));
  (* (--Rsp)) = (Wrd192.Obj);
  (* (--Rsp)) = (Wrd179.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_98)
  (* (--Rsp)) = Rvl;
  goto label_177;

DEFLABEL (label_180)
  (Wrd185.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_23]))));
  (* (--Rsp)) = (Wrd185.Obj);
  (* (--Rsp)) = (Wrd172.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_97)
  (Wrd179.Obj) = Rvl;
  goto label_179;

DEFLABEL (label_182)
  (Wrd178.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_22]))));
  (* (--Rsp)) = (Wrd178.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_96)
  (Wrd172.Obj) = Rvl;
  goto label_181;

DEFLABEL (label_184)
  (Wrd171.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_21]))));
  (* (--Rsp)) = (Wrd171.Obj);
  (* (--Rsp)) = (Wrd166.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_95)
  (Wrd163.Obj) = Rvl;
  goto label_183;

DEFLABEL (label_186)
  (Wrd158.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_20]))));
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd143.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_94)
  (Wrd152.Obj) = Rvl;
  goto label_185;

DEFLABEL (label_188)
  (Wrd151.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_19]))));
  (* (--Rsp)) = (Wrd151.Obj);
  (* (--Rsp)) = (Wrd146.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_93)
  (Wrd143.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_18]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd136.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_92)
  (Wrd133.Obj) = Rvl;
  goto label_189;

DEFLABEL (label_191)
  (Wrd127.Obj) = (current_block [OBJECT_43_2]);
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_17]))));
  (* (--Rsp)) = (Wrd131.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_91)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_125;
  goto label_126;

DEFLABEL (label_193)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_192;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_43_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_125;
  goto label_172;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_43_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_124;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_231;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_230)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_229;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_228)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_227;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_226)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_225;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_224)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_223;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_222)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_221;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_220)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_49]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd57.Obj) = (Rsp [2]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_219;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [1]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_218)
  (Wrd66.Obj) = (Rsp [3]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 1))
    goto label_217;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd63.Obj) = ((Wrd65.pObj) [0]);

DEFLABEL (label_216)
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd74.uLng) == 1))
    goto label_215;
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd72.Obj) = ((Wrd73.pObj) [1]);

DEFLABEL (label_214)
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_213;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  (Wrd79.Obj) = ((Wrd80.pObj) [1]);

DEFLABEL (label_212)
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd88.uLng) == 1))
    goto label_211;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd86.Obj) = ((Wrd87.pObj) [0]);

DEFLABEL (label_210)
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if (! ((Wrd95.uLng) == 1))
    goto label_209;
  (Wrd94.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd93.Obj) = ((Wrd94.pObj) [1]);

DEFLABEL (label_208)
  (Wrd102.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd102.uLng) == 1))
    goto label_207;
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd100.Obj) = ((Wrd101.pObj) [0]);

DEFLABEL (label_206)
  (Wrd109.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd109.uLng) == 1))
    goto label_205;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [1]);
  (* (--Rsp)) = (Wrd108.Obj);

DEFLABEL (label_204)
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_58]))));
  (* (--Rsp)) = (Wrd115.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_59]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_43_49);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_203;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_202)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_201;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd19.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_200)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_199;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_198)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_197;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd33.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_196)
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_195;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd40.Obj) = ((Wrd41.pObj) [0]);

DEFLABEL (label_194)
  (Wrd47.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd47.Obj);
  (Wrd50.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd50.pObj)));
  (Wrd55.Obj) = (current_block [OBJECT_43_3]);
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_195)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_64]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_90)
  (Wrd40.Obj) = Rvl;
  goto label_194;

DEFLABEL (label_197)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_63]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_89)
  (Wrd33.Obj) = Rvl;
  goto label_196;

DEFLABEL (label_199)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_62]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_88)
  (Wrd26.Obj) = Rvl;
  goto label_198;

DEFLABEL (label_201)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_61]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_87)
  (Wrd19.Obj) = Rvl;
  goto label_200;

DEFLABEL (label_203)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_60]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_86)
  (Wrd10.Obj) = Rvl;
  goto label_202;

DEFLABEL (label_205)
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_57]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_85)
  (* (--Rsp)) = Rvl;
  goto label_204;

DEFLABEL (label_207)
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_56]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_84)
  (Wrd100.Obj) = Rvl;
  goto label_206;

DEFLABEL (label_209)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_55]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_83)
  (Wrd93.Obj) = Rvl;
  goto label_208;

DEFLABEL (label_211)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_54]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_82)
  (Wrd86.Obj) = Rvl;
  goto label_210;

DEFLABEL (label_213)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_53]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_81)
  (Wrd79.Obj) = Rvl;
  goto label_212;

DEFLABEL (label_215)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_52]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_80)
  (Wrd72.Obj) = Rvl;
  goto label_214;

DEFLABEL (label_217)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_51]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_79)
  (Wrd63.Obj) = Rvl;
  goto label_216;

DEFLABEL (label_219)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_50]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_78)
  (* (--Rsp)) = Rvl;
  goto label_218;

DEFLABEL (label_221)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_48]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_77)
  (* (--Rsp)) = Rvl;
  goto label_220;

DEFLABEL (label_223)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_47]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_76)
  (Wrd37.Obj) = Rvl;
  goto label_222;

DEFLABEL (label_225)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_46]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_75)
  (Wrd30.Obj) = Rvl;
  goto label_224;

DEFLABEL (label_227)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_45]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_74)
  (Wrd23.Obj) = Rvl;
  goto label_226;

DEFLABEL (label_229)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_44]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 1);

DEFLABEL (label_73)
  (Wrd16.Obj) = Rvl;
  goto label_228;

DEFLABEL (label_231)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_43]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_72)
  (Wrd7.Obj) = Rvl;
  goto label_230;

DEFLABEL (lambda_122)
DEFLABEL (lambda_51)
  INTERRUPT_CHECK (26, LABEL_43_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_65]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_66]));

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_43_65);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_233;
  (Wrd7.Obj) = (current_block [OBJECT_43_4]);
  goto label_232;

DEFLABEL (label_233)
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.Obj) = (current_block [OBJECT_43_4]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));

DEFLABEL (label_232)
DEFLABEL (label_234)
  (Wrd12.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_7 7
#define LABEL_8 9
#define ENVIRONMENT_LABEL_3 21
#define DEBUGGING_LABEL_2 20
#define PURIFICATION_ROOT 19
#define OBJECT_5 18
#define OBJECT_4 17
#define OBJECT_3 16
#define OBJECT_2 15
#define OBJECT_1 14
#define OBJECT_0 13
#define GLOBAL_EXECUTE_CACHE_5 11
#define FREE_REFERENCES_LABEL_0 10
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
unsyn_so_cbffa850f2c333ab (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_8);
      goto expression_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_4)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_7])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_8)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_7)
  {
    static const short sections [] =
      {
	0,
	2,
	1,
	2,
	2,
	1,
	2,
	1,
	0,
	2,
	2,
	2,
	1,
	1,
	2,
	1,
	2,
	2,
	2,
	0,
	1,
	2,
	2,
	2,
	1,
	1,
	2,
	1,
	2,
	1,
	2,
	2,
	2,
	1,
	1,
	1,
	1,
	2,
	3,
	2,
	2,
	2,
	3,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 43)
      goto label_6;
    blocks = (current_block [OBJECT_5]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_6)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd5.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_4]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_unsyn_so_cbffa850f2c333ab [43] =
  {
    { "unsyn_so_code_1", 20, unsyn_so_code_1 },
    { "unsyn_so_code_2", 10, unsyn_so_code_2 },
    { "unsyn_so_code_3", 4, unsyn_so_code_3 },
    { "unsyn_so_code_4", 3, unsyn_so_code_4 },
    { "unsyn_so_code_5", 9, unsyn_so_code_5 },
    { "unsyn_so_code_6", 10, unsyn_so_code_6 },
    { "unsyn_so_code_7", 4, unsyn_so_code_7 },
    { "unsyn_so_code_8", 5, unsyn_so_code_8 },
    { "unsyn_so_code_9", 11, unsyn_so_code_9 },
    { "unsyn_so_code_10", 3, unsyn_so_code_10 },
    { "unsyn_so_code_11", 1, unsyn_so_code_11 },
    { "unsyn_so_code_12", 10, unsyn_so_code_12 },
    { "unsyn_so_code_13", 12, unsyn_so_code_13 },
    { "unsyn_so_code_14", 2, unsyn_so_code_14 },
    { "unsyn_so_code_15", 3, unsyn_so_code_15 },
    { "unsyn_so_code_16", 17, unsyn_so_code_16 },
    { "unsyn_so_code_17", 3, unsyn_so_code_17 },
    { "unsyn_so_code_18", 5, unsyn_so_code_18 },
    { "unsyn_so_code_19", 3, unsyn_so_code_19 },
    { "unsyn_so_code_20", 2, unsyn_so_code_20 },
    { "unsyn_so_code_21", 5, unsyn_so_code_21 },
    { "unsyn_so_code_22", 25, unsyn_so_code_22 },
    { "unsyn_so_code_23", 4, unsyn_so_code_23 },
    { "unsyn_so_code_24", 3, unsyn_so_code_24 },
    { "unsyn_so_code_25", 1, unsyn_so_code_25 },
    { "unsyn_so_code_26", 7, unsyn_so_code_26 },
    { "unsyn_so_code_27", 6, unsyn_so_code_27 },
    { "unsyn_so_code_28", 4, unsyn_so_code_28 },
    { "unsyn_so_code_29", 4, unsyn_so_code_29 },
    { "unsyn_so_code_30", 12, unsyn_so_code_30 },
    { "unsyn_so_code_31", 4, unsyn_so_code_31 },
    { "unsyn_so_code_32", 3, unsyn_so_code_32 },
    { "unsyn_so_code_33", 9, unsyn_so_code_33 },
    { "unsyn_so_code_34", 13, unsyn_so_code_34 },
    { "unsyn_so_code_35", 9, unsyn_so_code_35 },
    { "unsyn_so_code_36", 1, unsyn_so_code_36 },
    { "unsyn_so_code_37", 4, unsyn_so_code_37 },
    { "unsyn_so_code_38", 7, unsyn_so_code_38 },
    { "unsyn_so_code_39", 7, unsyn_so_code_39 },
    { "unsyn_so_code_40", 39, unsyn_so_code_40 },
    { "unsyn_so_code_41", 2, unsyn_so_code_41 },
    { "unsyn_so_code_42", 2, unsyn_so_code_42 },
    { "unsyn_so_code_43", 58, unsyn_so_code_43 }
  };

int
decl_unsyn_so_cbffa850f2c333ab (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_unsyn_so_cbffa850f2c333ab);
  return (0);
}

DECLARE_COMPILED_CODE ("unsyn.so", 4, decl_unsyn_so_cbffa850f2c333ab, unsyn_so_cbffa850f2c333ab)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_unsyn_so_data_cbffa850f2c333ab [6962] =
  "\xbd\x01\x63\xab\x0e\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x0d\xb9"
  "\x0d\x0d\x0d\xba\x0d\x0d\x0d\x0d\xbb\x0d\x0d\xbc\x0d\xbd\x0d\x0d"
  "\x0d\xbe\x0d\x08\x0d\xbf\x25\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x24\x28\x0d\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x82\x88\x1d\x0c\x0d"
  "\x1c\x0d\x1c\x25\x1b\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\xc1\x1c"
  "\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x84\x88\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\xc2\x08\x1b\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86"
  "\x88\x1d\x08\x1b\x25\x1b\x24\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb7\x24\x28"
  "\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xc1\x1c\x08\x1b\x28\x0d\x1c\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x1c\x0d\x85\x02\x08\x06\x07\x02\x86\x02\x02\xc2\x1c\x02"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x08\x28\x0d\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x23\x22"
  "\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\xb1\x1b\x1b\x1b\x1b\x24\x28"
  "\x0d\xb9\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x08\x07\x1b\x1b\x24\x28\x1b\x28\x0d\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x1c\x24\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x08\x07\x1b\x1b"
  "\x0d\x1c\x24\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb2\x08\x0d\xba\x24\x28\x0d"
  "\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x08\x28\x0d\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1b"
  "\x07\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1b\x07"
  "\x1b\x1b\x1b\x24\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb5\x07\x1b\x24\x28"
  "\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\xbd\x1d\xb0\x02\x88\xb3\x08\x28\x0d\xbb\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb6\x08\x88\x22"
  "\x29\x21\x9d\x2b\xbe\x1d\xb0\x02\x88\x08\x0d\x07\x1b\x0d\x1c\x24"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1b\x24\x28"
  "\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x0d\x1c\x0d"
  "\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x08\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xc1\x0d\x0d"
  "\x08\x1d\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0d\x08\x1d\x1b\x0d\x1c\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08"
  "\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x08\x1b\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\xb4\x0d\xbc\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x08\x0c\x0d"
  "\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x0d\x0d\x0d\x24\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x1b\x28\x0d\x28\x0d\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\xb4\x0d\x08\x0d\xc2\x07"
  "\x82\x1b\x1b\x1b\x1b\x1b\x0d\x24\x28\x0d\x28\x0d\xbc\x28\xb3\x28"
  "\x0d\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x02\x88\x0d\x1c\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x06"
  "\x07\x85\x1b\x02\x08\x1b\x84\x1b\x1b\x0d\x24\x28\x0d\x28\x0d\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c"
  "\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a\xb3\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\x1b\x2a\xb5\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x08\x06\x06\x07\x1b\x2a\x17\xb4\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\xb1\x1b\x1b\x1b"
  "\x1b\x1b\xb7\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\xb2\x1b\x0d\x17\xc3"
  "\x1b\x08\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02"
  "\x46\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f\x6d\x69"
  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30\x2e\x31"
  "\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x75\x6e\x73"
  "\x79\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63"
  "\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x02\x07\x61\x63"
  "\x63\x65\x73\x73\x0b\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0c"
  "\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x08\x63\x6f\x6d\x6d"
  "\x65\x6e\x74\x0c\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x0c"
  "\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x0b\x64\x65\x66\x69"
  "\x6e\x69\x74\x69\x6f\x6e\x06\x64\x65\x6c\x61\x79\x0c\x64\x69\x73"
  "\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x07\x6c\x61\x6d\x62\x64\x61\x0b"
  "\x6f\x70\x65\x6e\x2d\x62\x6c\x6f\x63\x6b\x0a\x71\x75\x6f\x74\x61"
  "\x74\x69\x6f\x6e\x09\x73\x65\x71\x75\x65\x6e\x63\x65\x10\x74\x68"
  "\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x09\x76\x61"
  "\x72\x69\x61\x62\x6c\x65\x18\x75\x6e\x73\x79\x6e\x74\x61\x78\x65"
  "\x72\x2f\x73\x63\x6f\x64\x65\x2d\x77\x61\x6c\x6b\x65\x72\x02\x19"
  "\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x76\x61\x72\x69\x61\x62\x6c"
  "\x65\x2d\x6f\x62\x6a\x65\x63\x74\x09\x20\x75\x6e\x73\x79\x6e\x74"
  "\x61\x78\x2d\x74\x68\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x2d\x6f\x62\x6a\x65\x63\x74\x0a\x19\x75\x6e\x73\x79\x6e"
  "\x74\x61\x78\x2d\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x6f\x62\x6a"
  "\x65\x63\x74\x0b\x13\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x71\x75"
  "\x6f\x74\x61\x74\x69\x6f\x6e\x0c\x1b\x75\x6e\x73\x79\x6e\x74\x61"
  "\x78\x2d\x6f\x70\x65\x6e\x2d\x62\x6c\x6f\x63\x6b\x2d\x6f\x62\x6a"
  "\x65\x63\x74\x0d\x17\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x6c\x61"
  "\x6d\x62\x64\x61\x2d\x6f\x62\x6a\x65\x63\x74\x0e\x1c\x75\x6e\x73"
  "\x79\x6e\x74\x61\x78\x2d\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f"
  "\x6e\x2d\x6f\x62\x6a\x65\x63\x74\x0f\x16\x75\x6e\x73\x79\x6e\x74"
  "\x61\x78\x2d\x64\x65\x6c\x61\x79\x2d\x6f\x62\x6a\x65\x63\x74\x10"
  "\x1b\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x64\x65\x66\x69\x6e\x69"
  "\x74\x69\x6f\x6e\x2d\x6f\x62\x6a\x65\x63\x74\x11\x1c\x75\x6e\x73"
  "\x79\x6e\x74\x61\x78\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f"
  "\x6e\x2d\x6f\x62\x6a\x65\x63\x74\x12\x1c\x75\x6e\x73\x79\x6e\x74"
  "\x61\x78\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x6f"
  "\x62\x6a\x65\x63\x74\x13\x18\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d"
  "\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x6f\x62\x6a\x65\x63\x74\x14\x1c"
  "\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x63\x6f\x6d\x62\x69\x6e\x61"
  "\x74\x69\x6f\x6e\x2d\x6f\x62\x6a\x65\x63\x74\x15\x1b\x75\x6e\x73"
  "\x79\x6e\x74\x61\x78\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74"
  "\x2d\x6f\x62\x6a\x65\x63\x74\x16\x17\x75\x6e\x73\x79\x6e\x74\x61"
  "\x78\x2d\x61\x63\x63\x65\x73\x73\x2d\x6f\x62\x6a\x65\x63\x74\x17"
  "\x12\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x63\x6f\x6e\x73\x74\x61"
  "\x6e\x74\x18\x11\x11\x05\x6c\x69\x73\x74\x04\x12\x6d\x61\x6b\x65"
  "\x2d\x73\x63\x6f\x64\x65\x2d\x77\x61\x6c\x6b\x65\x72\x03\x18\x2a"
  "\x81\x85\x02\x17\x28\x81\x83\x02\x16\x26\x81\x81\x02\x15\x24\x81"
  "\x81\x02\x14\x22\x81\xa1\x02\x13\x20\x81\x9f\x02\x12\x1e\x81\x9d"
  "\x02\x11\x1c\x81\x9b\x02\x10\x1a\x81\x99\x02\x0f\x18\x81\x97\x02"
  "\x0e\x16\x81\x95\x02\x0d\x14\x81\x93\x02\x0c\x12\x81\x91\x02\x0b"
  "\x10\x81\x8f\x02\x0a\x0e\x81\x8d\x02\x09\x0c\x81\x8b\x02\x08\x0a"
  "\x81\x89\x02\x07\x08\x81\x87\x02\x06\x06\x81\x85\x02\x05\x04\x82"
  "\x02\x29\x55\x19\x02\x02\x06\x61\x6c\x69\x73\x74\x1c\x75\x6e\x73"
  "\x79\x6e\x74\x61\x78\x2d\x77\x69\x74\x68\x2d\x73\x75\x62\x73\x74"
  "\x69\x74\x75\x74\x69\x6f\x6e\x73\x1a\x0e\x73\x75\x62\x73\x74\x69"
  "\x74\x75\x74\x69\x6f\x6e\x73\x1b\x02\x1b\x02\x03\x07\x61\x6c\x69"
  "\x73\x74\x3f\x05\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67"
  "\x2d\x74\x79\x70\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x1c\x05"
  "\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62"
  "\x69\x6e\x64\x1d\x03\x09\x75\x6e\x73\x79\x6e\x74\x61\x78\x1e\x05"
  "\x22\x16\x81\x87\x02\x21\x14\x81\x85\x02\x20\x12\x81\x83\x02\x1f"
  "\x10\x81\x87\x02\x1e\x0e\x81\x85\x02\x1d\x0c\x81\x83\x02\x1c\x0a"
  "\x81\x83\x02\x1b\x08\x81\x85\x02\x1a\x06\x81\x85\x02\x19\x04\x84"
  "\x06\x15\x28\x1f\x02\x04\x63\x64\x72\x20\x1b\x02\x04\x05\x61\x73"
  "\x73\x71\x21\x02\x26\x0a\x81\x87\x02\x25\x08\x81\x87\x02\x24\x06"
  "\x84\x06\x23\x04\x81\x85\x02\x09\x12\x22\x02\x1b\x02\x04\x21\x02"
  "\x29\x08\x81\x85\x02\x28\x06\x81\x83\x02\x27\x04\x83\x04\x07\x0f"
  "\x23\x02\x09\x73\x65\x74\x2d\x63\x64\x72\x21\x20\x22\x75\x6e\x73"
  "\x79\x6e\x74\x61\x78\x65\x72\x3a\x65\x6c\x69\x64\x65\x2d\x67\x6c"
  "\x6f\x62\x61\x6c\x2d\x61\x63\x63\x65\x73\x73\x65\x73\x3f\x24\x15"
  "\x75\x6e\x73\x79\x6e\x74\x61\x78\x65\x72\x3a\x6d\x61\x63\x72\x6f"
  "\x69\x7a\x65\x3f\x25\x06\x62\x6f\x75\x6e\x64\x26\x04\x06\x07\x61"
  "\x70\x70\x65\x6e\x64\x27\x02\x32\x14\x81\x91\x02\x31\x12\x81\x8f"
  "\x02\x30\x10\x81\x8f\x02\x2f\x0e\x81\x8f\x02\x2e\x0c\x81\x8d\x02"
  "\x2d\x0a\x81\x8b\x02\x2c\x08\x81\x8b\x02\x2b\x06\x81\x8b\x02\x2a"
  "\x04\x87\x0c\x13\x20\x28\x02\x02\x26\x02\x26\x02\x05\x1d\x03\x0b"
  "\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x3f\x03\x11\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x2d\x6c\x61\x6d\x62\x64\x61\x03\x10\x75\x6e"
  "\x73\x79\x6e\x74\x61\x78\x2d\x6f\x62\x6a\x65\x63\x74\x1d\x05\x3c"
  "\x16\x81\x83\x02\x3b\x14\x81\x85\x02\x3a\x12\x81\x87\x02\x39\x10"
  "\x81\x85\x02\x38\x0e\x81\x83\x02\x37\x0c\x81\x83\x02\x36\x0a\x81"
  "\x87\x02\x35\x08\x81\x85\x02\x34\x06\x81\x83\x02\x33\x04\x83\x04"
  "\x15\x27\x29\x02\x08\x02\x04\x11\x6d\x61\x79\x62\x65\x2d\x73\x75"
  "\x62\x73\x74\x69\x74\x75\x74\x65\x2a\x04\x0b\x73\x63\x6f\x64\x65"
  "\x2d\x77\x61\x6c\x6b\x03\x40\x0a\x81\x83\x02\x3f\x08\x81\x87\x02"
  "\x3e\x06\x83\x04\x3d\x04\x83\x04\x09\x13\x2b\x02\x09\x04\x63\x61"
  "\x72\x2c\x20\x03\x11\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x6f\x62"
  "\x6a\x65\x63\x74\x73\x2d\x03\x1d\x03\x45\x0c\x81\x85\x02\x44\x0a"
  "\x81\x87\x02\x43\x08\x81\x83\x02\x42\x06\x81\x85\x02\x41\x04\x83"
  "\x04\x0b\x16\x2e\x02\x0a\x0c\x73\x63\x6f\x64\x65\x2d\x71\x75\x6f"
  "\x74\x65\x2f\x06\x71\x75\x6f\x74\x65\x1e\x3d\x3b\x0f\x0d\x6f\x62"
  "\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x30\x1b\x03\x09\x62\x6f"
  "\x6f\x6c\x65\x61\x6e\x3f\x03\x15\x63\x6f\x6d\x70\x69\x6c\x65\x64"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3f\x03\x1a\x63\x6f"
  "\x6d\x70\x69\x6c\x65\x64\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x2f\x73\x63\x6f\x64\x65\x03\x1d\x05\x50\x18\x81\x83\x02\x4f"
  "\x16\x81\x83\x02\x4e\x14\x81\x83\x02\x4d\x12\x81\x83\x02\x4c\x10"
  "\x81\x83\x02\x4b\x0e\x81\x83\x02\x4a\x0c\x81\x83\x02\x49\x0a\x81"
  "\x83\x02\x48\x08\x81\x83\x02\x47\x06\x81\x83\x02\x46\x04\x83\x04"
  "\x17\x30\x31\x02\x0b\x2f\x03\x15\x71\x75\x6f\x74\x61\x74\x69\x6f"
  "\x6e\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x03\x1d\x03\x53"
  "\x08\x81\x85\x02\x52\x06\x81\x83\x02\x51\x04\x83\x04\x07\x11\x2f"
  "\x02\x0c\x03\x0e\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x6e\x61\x6d"
  "\x65\x02\x54\x04\x83\x04\x03\x32\x02\x0d\x20\x24\x25\x26\x04\x03"
  "\x10\x75\x6e\x65\x78\x70\x61\x6e\x64\x2d\x61\x63\x63\x65\x73\x73"
  "\x04\x12\x61\x63\x63\x65\x73\x73\x2d\x63\x6f\x6d\x70\x6f\x6e\x65"
  "\x6e\x74\x73\x33\x04\x05\x6d\x65\x6d\x71\x04\x5e\x16\x81\x85\x02"
  "\x5d\x14\x81\x83\x02\x5c\x12\x81\x85\x02\x5b\x10\x81\x87\x02\x5a"
  "\x0e\x81\x87\x02\x59\x0c\x84\x06\x58\x0a\x81\x85\x02\x57\x08\x81"
  "\x83\x02\x56\x06\x83\x04\x55\x04\x81\x83\x02\x15\x25\x34\x02\x0e"
  "\x1b\x25\x03\x03\x1d\x03\x08\x61\x63\x63\x65\x73\x73\x3f\x04\x21"
  "\x04\x33\x05\x6a\x1a\x81\x85\x02\x69\x18\x81\x85\x02\x68\x16\x81"
  "\x85\x02\x67\x14\x81\x87\x02\x66\x12\x84\x06\x65\x10\x81\x85\x02"
  "\x64\x0e\x81\x87\x02\x63\x0c\x81\x85\x02\x62\x0a\x81\x85\x02\x61"
  "\x08\x81\x85\x02\x60\x06\x81\x85\x02\x5f\x04\x83\x04\x19\x2a\x33"
  "\x02\x0f\x14\x75\x6e\x65\x78\x70\x61\x6e\x64\x2d\x64\x65\x66\x69"
  "\x6e\x69\x74\x69\x6f\x6e\x35\x02\x04\x16\x64\x65\x66\x69\x6e\x69"
  "\x74\x69\x6f\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x02"
  "\x6c\x06\x81\x85\x02\x6b\x04\x83\x04\x05\x0d\x36\x02\x10\x05\x73"
  "\x65\x74\x21\x04\x16\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d"
  "\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x03\x17\x75\x6e\x65\x78"
  "\x70\x61\x6e\x64\x2d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x76\x61\x6c"
  "\x75\x65\x37\x03\x6f\x08\x81\x85\x02\x6e\x06\x84\x06\x6d\x04\x83"
  "\x04\x07\x10\x38\x02\x11\x07\x64\x65\x66\x69\x6e\x65\x39\x0e\x64"
  "\x65\x66\x69\x6e\x65\x2d\x73\x79\x6e\x74\x61\x78\x25\x1b\x12\x75"
  "\x6e\x73\x79\x6e\x74\x61\x78\x2d\x73\x65\x71\x75\x65\x6e\x63\x65"
  "\x3a\x04\x03\x21\x6d\x61\x63\x72\x6f\x2d\x72\x65\x66\x65\x72\x65"
  "\x6e\x63\x65\x2d\x74\x72\x61\x70\x2d\x65\x78\x70\x72\x65\x73\x73"
  "\x69\x6f\x6e\x3f\x03\x08\x6c\x61\x6d\x62\x64\x61\x3f\x3b\x03\x37"
  "\x03\x2c\x6d\x61\x63\x72\x6f\x2d\x72\x65\x66\x65\x72\x65\x6e\x63"
  "\x65\x2d\x74\x72\x61\x70\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72\x03\x1d\x04"
  "\x21\x04\x14\x6c\x61\x6d\x62\x64\x61\x2d\x63\x6f\x6d\x70\x6f\x6e"
  "\x65\x6e\x74\x73\x2a\x2a\x3c\x07\x0e\x77\x69\x74\x68\x2d\x62\x69"
  "\x6e\x64\x69\x6e\x67\x73\x3d\x06\x0c\x6c\x61\x6d\x62\x64\x61\x2d"
  "\x6c\x69\x73\x74\x3e\x0a\x80\x01\x24\x81\x8f\x02\x7f\x22\x81\x85"
  "\x02\x7e\x20\x81\x8d\x02\x7d\x1e\x81\x8d\x02\x7c\x1c\x81\x85\x02"
  "\x7b\x1a\x81\x91\x02\x7a\x18\x81\x8d\x02\x79\x16\x81\x87\x02\x78"
  "\x14\x81\x85\x02\x77\x12\x81\x85\x02\x76\x10\x81\x85\x02\x75\x0e"
  "\x81\x85\x02\x74\x0c\x81\x87\x02\x73\x0a\x81\x85\x02\x72\x08\x81"
  "\x85\x02\x71\x06\x81\x85\x02\x70\x04\x84\x06\x23\x41\x3f\x02\x12"
  "\x03\x1b\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x72\x65\x66"
  "\x65\x72\x65\x6e\x63\x65\x2d\x74\x72\x61\x70\x3f\x40\x03\x1d\x03"
  "\x83\x01\x08\x81\x83\x02\x82\x01\x06\x81\x83\x02\x81\x01\x04\x83"
  "\x04\x07\x10\x41\x02\x13\x1a\x75\x6e\x73\x79\x6e\x74\x61\x78\x65"
  "\x72\x3a\x73\x68\x6f\x77\x2d\x63\x6f\x6d\x6d\x65\x6e\x74\x73\x3f"
  "\x02\x03\x13\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x03\x0d\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x74"
  "\x65\x78\x74\x03\x1d\x04\x88\x01\x0c\x81\x85\x02\x87\x01\x0a\x81"
  "\x85\x02\x86\x01\x08\x81\x85\x02\x85\x01\x06\x81\x83\x02\x84\x01"
  "\x04\x83\x04\x0b\x19\x42\x02\x14\x0e\x6c\x6f\x63\x61\x6c\x2d\x64"
  "\x65\x63\x6c\x61\x72\x65\x04\x17\x64\x65\x63\x6c\x61\x72\x61\x74"
  "\x69\x6f\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x03\x1d"
  "\x03\x8b\x01\x08\x81\x85\x02\x8a\x01\x06\x84\x06\x89\x01\x04\x83"
  "\x04\x07\x11\x43\x02\x15\x06\x62\x65\x67\x69\x6e\x44\x03\x1a\x75"
  "\x6e\x73\x79\x6e\x74\x61\x78\x2d\x73\x65\x71\x75\x65\x6e\x63\x65"
  "\x2d\x61\x63\x74\x69\x6f\x6e\x73\x45\x02\x8d\x01\x06\x81\x83\x02"
  "\x8c\x01\x04\x83\x04\x05\x0c\x46\x02\x16\x44\x25\x02\x03\x0a\x73"
  "\x65\x71\x75\x65\x6e\x63\x65\x3f\x44\x03\x1d\x03\x45\x04\x92\x01"
  "\x0c\x81\x83\x02\x91\x01\x0a\x81\x83\x02\x90\x01\x08\x81\x83\x02"
  "\x8f\x01\x06\x81\x83\x02\x8e\x01\x04\x83\x04\x0b\x1a\x47\x02\x17"
  "\x20\x2c\x1b\x25\x03\x03\x1b\x73\x65\x71\x75\x65\x6e\x63\x65\x2d"
  "\x69\x6d\x6d\x65\x64\x69\x61\x74\x65\x2d\x61\x63\x74\x69\x6f\x6e"
  "\x73\x04\x21\x03\x44\x03\x1d\x03\x45\x04\x27\x07\xab\x01\x34\xfd"
  "\xff\x03\xaa\x01\x32\xfd\xff\x03\xa9\x01\x30\xfd\xff\x03\xa8\x01"
  "\x2e\xfd\xff\x03\xa7\x01\x2c\xfd\xff\x03\xa6\x01\x2a\xfd\xff\x03"
  "\xa5\x01\x28\xfd\xff\x03\xa4\x01\x26\xfd\xff\x03\xa3\x01\x24\xfd"
  "\xff\x03\xa2\x01\x22\xfd\xff\x03\xa1\x01\x20\xfd\xff\x03\xa0\x01"
  "\x1e\xfd\xff\x03\x9f\x01\x1c\xfd\xff\x03\x9e\x01\x1a\xfd\xff\x03"
  "\x9d\x01\x18\xfd\xff\x03\x9c\x01\x16\xfd\xff\x03\x9b\x01\x14\xfd"
  "\xff\x03\x9a\x01\x12\xfd\xff\x03\x99\x01\x10\x81\x87\x02\x98\x01"
  "\x0e\x81\x85\x02\x97\x01\x0c\x81\x85\x02\x96\x01\x0a\x81\x83\x02"
  "\x95\x01\x08\x81\x83\x02\x94\x01\x06\x81\x83\x02\x93\x01\x04\x83"
  "\x04\x33\x4a\x44\x02\x18\x25\x02\x04\x16\x6f\x70\x65\x6e\x2d\x62"
  "\x6c\x6f\x63\x6b\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x03"
  "\x0b\x03\x3a\x04\xaf\x01\x0a\x81\x87\x02\xae\x01\x08\x85\x08\xad"
  "\x01\x06\x81\x83\x02\xac\x01\x04\x83\x04\x09\x17\x02\x19\x03\x11"
  "\x64\x65\x6c\x61\x79\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x03\x1d\x03\xb2\x01\x08\x81\x85\x02\xb1\x01\x06\x81\x83\x02\xb0"
  "\x01\x04\x83\x04\x07\x11\x48\x02\x1a\xb3\x01\x04\x83\x04\x03\x02"
  "\x1b\x03\x6f\x72\x25\x15\x75\x6e\x65\x78\x70\x61\x6e\x64\x2d\x64"
  "\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x49\x03\x04\x17\x64\x69"
  "\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e"
  "\x65\x6e\x74\x73\x4a\x03\x1d\x03\xba\x01\x10\x81\x87\x02\xb9\x01"
  "\x0e\x81\x85\x02\xb8\x01\x0c\x84\x06\xb7\x01\x0a\x81\x83\x02\xb6"
  "\x01\x08\x81\x85\x02\xb5\x01\x06\x81\x85\x02\xb4\x01\x04\x83\x04"
  "\x0f\x1d\x4b\x02\x1c\x49\x02\x03\x0d\x64\x69\x73\x6a\x75\x6e\x63"
  "\x74\x69\x6f\x6e\x3f\x4c\x03\x1d\x04\x4a\x04\xc0\x01\x0e\x81\x87"
  "\x02\xbf\x01\x0c\x81\x87\x02\xbe\x01\x0a\x81\x87\x02\xbd\x01\x08"
  "\x81\x85\x02\xbc\x01\x06\x81\x87\x02\xbb\x01\x04\x84\x06\x0d\x1a"
  "\x4d\x02\x1d\x25\x15\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x4e\x1d\x75\x6e\x73\x79\x6e"
  "\x74\x61\x78\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2f"
  "\x64\x65\x66\x61\x75\x6c\x74\x4f\x04\x04\x17\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x61\x6c\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74"
  "\x73\x50\x02\xc4\x01\x0a\x81\x85\x02\xc3\x01\x08\x81\x85\x02\xc2"
  "\x01\x06\x81\x85\x02\xc1\x01\x04\x83\x04\x09\x14\x51\x02\x1e\x03"
  "\x69\x66\x52\x03\x1d\x02\xc8\x01\x0a\x81\x89\x02\xc7\x01\x08\x81"
  "\x89\x02\xc6\x01\x06\x81\x87\x02\xc5\x01\x04\x85\x08\x09\x11\x53"
  "\x02\x1f\x52\x04\x6e\x6f\x74\x05\x63\x6f\x6e\x64\x04\x61\x6e\x64"
  "\x02\x1b\x02\x04\x15\x75\x6e\x65\x78\x70\x61\x6e\x64\x2d\x63\x6f"
  "\x6e\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x52\x03\x1d\x03\x0d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x3f\x54\x05\x4f\x04\x21\x05"
  "\x1a\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x63\x6f\x6e\x64\x2d\x63"
  "\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x55\x07\xd4\x01\x1a\x81"
  "\x87\x02\xd3\x01\x18\x81\x89\x02\xd2\x01\x16\x81\x89\x02\xd1\x01"
  "\x14\x81\x87\x02\xd0\x01\x12\x81\x87\x02\xcf\x01\x10\x81\x87\x02"
  "\xce\x01\x0e\x81\x87\x02\xcd\x01\x0c\x81\x87\x02\xcc\x01\x0a\x81"
  "\x89\x02\xcb\x01\x08\x81\x87\x02\xca\x01\x06\x81\x87\x02\xc9\x01"
  "\x04\x85\x08\x19\x31\x56\x02\x20\x03\x1a\x75\x6e\x73\x79\x6e\x74"
  "\x61\x78\x2d\x63\x6f\x6e\x64\x2d\x61\x6c\x74\x65\x72\x6e\x61\x74"
  "\x69\x76\x65\x57\x03\x3a\x03\x1d\x04\xd8\x01\x0a\x81\x8b\x02\xd7"
  "\x01\x08\x81\x89\x02\xd6\x01\x06\x81\x87\x02\xd5\x01\x04\x85\x08"
  "\x09\x13\x58\x02\x21\x03\x57\x03\x1d\x03\xdb\x01\x08\x81\x87\x02"
  "\xda\x01\x06\x81\x85\x02\xd9\x01\x04\x84\x06\x07\x10\x59\x02\x22"
  "\x05\x65\x6c\x73\x65\x02\x1b\x1a\x75\x6e\x73\x79\x6e\x74\x61\x78"
  "\x2d\x63\x6f\x6e\x64\x2d\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f"
  "\x6e\x5a\x55\x04\x04\x21\x03\x4c\x03\x54\x04\x4a\x03\x3a\x04\x50"
  "\x07\xe4\x01\x14\x81\x85\x02\xe3\x01\x12\x81\x85\x02\xe2\x01\x10"
  "\x81\x85\x02\xe1\x01\x0e\x81\x85\x02\xe0\x01\x0c\x81\x85\x02\xdf"
  "\x01\x0a\x81\x85\x02\xde\x01\x08\x81\x85\x02\xdd\x01\x06\x83\x04"
  "\xdc\x01\x04\x81\x83\x02\x13\x2a\x4c\x02\x23\x1b\x02\x03\x54\x03"
  "\x1d\x04\x21\x04\x50\x04\x52\x05\x4e\x07\xf1\x01\x1c\x81\x87\x02"
  "\xf0\x01\x1a\x81\x87\x02\xef\x01\x18\x81\x85\x02\xee\x01\x16\x81"
  "\x87\x02\xed\x01\x14\x81\x87\x02\xec\x01\x12\x81\x85\x02\xeb\x01"
  "\x10\x85\x08\xea\x01\x0e\x81\x85\x02\xe9\x01\x0c\x81\x87\x02\xe8"
  "\x01\x0a\x81\x85\x02\xe7\x01\x08\x81\x85\x02\xe6\x01\x06\x81\x85"
  "\x02\xe5\x01\x04\x84\x06\x1b\x2e\x54\x02\x24\x08\x64\x65\x63\x6c"
  "\x61\x72\x65\x25\x3a\x03\x04\x12\x6c\x61\x6d\x62\x64\x61\x2d\x63"
  "\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x50\x04\x3c\x07\x3d\x03\x3a"
  "\x06\x3e\x05\x0f\x63\x6f\x6c\x6c\x65\x63\x74\x2d\x6c\x61\x6d\x62"
  "\x64\x61\x4a\x07\xfa\x01\x14\x81\x8f\x02\xf9\x01\x12\x81\x8b\x02"
  "\xf8\x01\x10\x81\x8f\x02\xf7\x01\x0e\x81\x8b\x02\xf6\x01\x0c\x89"
  "\x10\xf5\x01\x0a\x81\x8f\x02\xf4\x01\x08\x87\x0c\xf3\x01\x06\x81"
  "\x83\x02\xf2\x01\x04\x83\x04\x13\x28\x5b\x02\x25\x0d\x6e\x61\x6d"
  "\x65\x64\x2d\x6c\x61\x6d\x62\x64\x61\x15\x23\x5b\x75\x6e\x6e\x61"
  "\x6d\x65\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x5d\xfb\x01"
  "\x04\x85\x08\x03\x5c\x02\x26\x0d\x53\x43\x6f\x64\x65\x20\x6c\x61"
  "\x6d\x62\x64\x61\x15\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d\x6c\x61"
  "\x6d\x62\x64\x61\x2d\x6c\x69\x73\x74\x5d\x03\x3b\x05\x1c\x04\x3c"
  "\x06\x3e\x05\xff\x01\x0a\x87\x0c\xfe\x01\x08\x81\x83\x02\xfd\x01"
  "\x06\x81\x83\x02\xfc\x01\x04\x83\x04\x09\x18\x1c\x02\x27\x10\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x72\x65\x73\x74\x14\x6c"
  "\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x6f\x70\x74\x69\x6f\x6e"
  "\x61\x6c\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x61\x75"
  "\x78\x04\x04\x27\x02\x86\x02\x10\x81\x8d\x02\x85\x02\x0e\x81\x8f"
  "\x02\x84\x02\x0c\x81\x8d\x02\x83\x02\x0a\x81\x91\x02\x82\x02\x08"
  "\x81\x8b\x02\x81\x02\x06\x81\x89\x02\x80\x02\x04\x86\x0a\x0f\x1a"
  "\x27\x02\x28\x04\x50\x04\x0d\x73\x63\x61\x6e\x2d\x64\x65\x66\x69"
  "\x6e\x65\x73\x05\x0f\x75\x6e\x73\x63\x61\x6e\x2d\x64\x65\x66\x69"
  "\x6e\x65\x73\x07\x3d\x05\x8d\x02\x10\x81\x85\x02\x8c\x02\x0e\x81"
  "\x87\x02\x8b\x02\x0c\x81\x89\x02\x8a\x02\x0a\x81\x93\x02\x89\x02"
  "\x08\x81\x93\x02\x88\x02\x06\x81\x93\x02\x87\x02\x04\x84\x06\x0f"
  "\x1c\x50\x02\x29\x04\x6c\x65\x74\x5e\x0c\x63\x6f\x6e\x73\x2d\x73"
  "\x74\x72\x65\x61\x6d\x05\x63\x6f\x6e\x73\x05\x63\x6f\x6e\x73\x2c"
  "\x20\x1b\x25\x3a\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a"
  "\x6c\x65\x74\x05\x04\x17\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f"
  "\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x03\x12\x72\x65"
  "\x77\x72\x69\x74\x65\x2d\x6e\x61\x6d\x65\x64\x2d\x6c\x65\x74\x03"
  "\x03\x07\x64\x65\x6c\x61\x79\x3f\x03\x3b\x04\x21\x03\x07\x6c\x65"
  "\x6e\x67\x74\x68\x3b\x04\x17\x61\x62\x73\x6f\x6c\x75\x74\x65\x2d"
  "\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x74\x6f\x3f\x03\x2d\x03"
  "\x1d\x04\x3c\x07\x3d\x04\x16\x75\x6e\x73\x79\x6e\x74\x61\x78\x2d"
  "\x6c\x65\x74\x2d\x62\x69\x6e\x64\x69\x6e\x67\x73\x21\x0e\xb4\x02"
  "\x50\x81\x8f\x02\xb3\x02\x4e\x81\x8f\x02\xb2\x02\x4c\x81\x8d\x02"
  "\xb1\x02\x4a\x81\x8d\x02\xb0\x02\x48\x81\x91\x02\xaf\x02\x46\x81"
  "\x8d\x02\xae\x02\x44\x81\x91\x02\xad\x02\x42\x81\x8d\x02\xac\x02"
  "\x40\x81\x8f\x02\xab\x02\x3e\x81\x89\x02\xaa\x02\x3c\x81\x8d\x02"
  "\xa9\x02\x3a\x81\x89\x02\xa8\x02\x38\x81\x8b\x02\xa7\x02\x36\x81"
  "\x87\x02\xa6\x02\x34\x81\x8d\x02\xa5\x02\x32\x81\x85\x02\xa4\x02"
  "\x30\x81\x87\x02\xa3\x02\x2e\x81\x83\x02\xa2\x02\x2c\x81\x83\x02"
  "\xa1\x02\x2a\x81\x89\x02\xa0\x02\x28\x81\x87\x02\x9f\x02\x26\x81"
  "\x87\x02\x9e\x02\x24\x84\x06\x9d\x02\x22\x81\x87\x02\x9c\x02\x20"
  "\x81\x89\x02\x9b\x02\x1e\x81\x89\x02\x9a\x02\x1c\x81\x87\x02\x99"
  "\x02\x1a\x81\x87\x02\x98\x02\x18\x81\x87\x02\x97\x02\x16\x81\x8b"
  "\x02\x96\x02\x14\x81\x8b\x02\x95\x02\x12\x81\x8b\x02\x94\x02\x10"
  "\x81\x8b\x02\x93\x02\x0e\x81\x89\x02\x92\x02\x0c\x81\x87\x02\x91"
  "\x02\x0a\x81\x87\x02\x90\x02\x08\x81\x87\x02\x8f\x02\x06\x81\x83"
  "\x02\x8e\x02\x04\x83\x04\x4f\x7c\x02\x2a\x15\x75\x6e\x73\x79\x6e"
  "\x74\x61\x78\x2d\x6c\x65\x74\x2d\x62\x69\x6e\x64\x69\x6e\x67\x5f"
  "\x02\x05\x04\x6d\x61\x70\x60\x02\xb6\x02\x06\x81\x85\x02\xb5\x02"
  "\x04\x84\x06\x05\x0d\x61\x02\x2b\x03\x37\x02\xb8\x02\x06\x81\x85"
  "\x02\xb7\x02\x04\x84\x06\x05\x0b\x62\x02\x2c\x39\x30\x1e\x5e\x20"
  "\x2c\x08\x73\x79\x6d\x62\x6f\x6c\x3f\x02\x03\x06\x6c\x69\x73\x74"
  "\x3f\x04\x09\x66\x6f\x72\x2d\x61\x6c\x6c\x3f\x03\x3b\x05\x60\x03"
  "\x40\x06\xf2\x02\x76\x81\x85\x02\xf1\x02\x74\x84\x06\xf0\x02\x72"
  "\x81\x85\x02\xef\x02\x70\x81\x85\x02\xee\x02\x6e\x81\x85\x02\xed"
  "\x02\x6c\x81\x85\x02\xec\x02\x6a\x81\x85\x02\xeb\x02\x68\x81\x85"
  "\x02\xea\x02\x66\x81\x89\x02\xe9\x02\x64\x81\x89\x02\xe8\x02\x62"
  "\x81\x89\x02\xe7\x02\x60\x81\x89\x02\xe6\x02\x5e\x81\x89\x02\xe5"
  "\x02\x5c\x81\x89\x02\xe4\x02\x5a\x81\x89\x02\xe3\x02\x58\x81\x87"
  "\x02\xe2\x02\x56\x81\x83\x02\xe1\x02\x54\x81\x83\x02\xe0\x02\x52"
  "\x81\x83\x02\xdf\x02\x50\x81\x83\x02\xde\x02\x4e\x81\x83\x02\xdd"
  "\x02\x4c\x81\x83\x02\xdc\x02\x4a\x81\x83\x02\xdb\x02\x48\x81\x83"
  "\x02\xda\x02\x46\x81\x87\x02\xd9\x02\x44\x81\x87\x02\xd8\x02\x42"
  "\x81\x87\x02\xd7\x02\x40\x81\x87\x02\xd6\x02\x3e\x81\x87\x02\xd5"
  "\x02\x3c\x81\x87\x02\xd4\x02\x3a\x81\x85\x02\xd3\x02\x38\x81\x85"
  "\x02\xd2\x02\x36\x81\x85\x02\xd1\x02\x34\x81\x85\x02\xd0\x02\x32"
  "\x81\x85\x02\xcf\x02\x30\x81\x85\x02\xce\x02\x2e\x81\x85\x02\xcd"
  "\x02\x2c\x81\x83\x02\xcc\x02\x2a\x81\x83\x02\xcb\x02\x28\x81\x83"
  "\x02\xca\x02\x26\x81\x83\x02\xc9\x02\x24\x81\x85\x02\xc8\x02\x22"
  "\x81\x85\x02\xc7\x02\x20\x81\x85\x02\xc6\x02\x1e\x81\x85\x02\xc5"
  "\x02\x1c\x81\x83\x02\xc4\x02\x1a\x81\x83\x02\xc3\x02\x18\x81\x83"
  "\x02\xc2\x02\x16\x81\x83\x02\xc1\x02\x14\x81\x83\x02\xc0\x02\x12"
  "\x81\x83\x02\xbf\x02\x10\x81\x85\x02\xbe\x02\x0e\x81\x85\x02\xbd"
  "\x02\x0c\x81\x85\x02\xbc\x02\x0a\x81\x85\x02\xbb\x02\x08\x81\x85"
  "\x02\xba\x02\x06\x81\x85\x02\xb9\x02\x04\x83\x04\x75\x90\x01\x60"
  "\x2c\x5e\x5e\x60\x04\x62\x04\x61\x04\x04\x50\x04\x27\x04\x1c\x04"
  "\x5c\x04\x5b\x04\x54\x04\x4c\x06\x59\x04\x58\x04\x56\x04\x53\x04"
  "\x51\x04\x4d\x04\x4b\x04\x04\x48\x04\x04\x44\x04\x47\x04\x46\x04"
  "\x43\x04\x42\x04\x41\x04\x3f\x04\x38\x04\x36\x04\x33\x04\x34\x06"
  "\x32\x04\x2f\x04\x31\x04\x2e\x04\x2b\x04\x29\x04\x28\x04\x23\x04"
  "\x22\x06\x1f\x04\x19\x04\x31\x5f\x21\x15\x3c\x3e\x5d\x4a\x0e\x52"
  "\x57\x5a\x55\x4e\x4f\x13\x49\x0f\x0a\x10\x0d\x45\x3a\x0b\x12\x14"
  "\x37\x35\x16\x11\x17\x09\x0c\x18\x2d\x1d\x1e\x3d\x12\x68\x61\x73"
  "\x2d\x73\x75\x62\x73\x74\x69\x74\x75\x74\x69\x6f\x6e\x3f\x2a\x1a"
  "\x1b\x24\x25\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x70"
  "\x61\x63\x6b\x61\x67\x65\x21\x31\x11\x6c\x6f\x63\x61\x6c\x2d\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x26\x05\x10\x64\x65\x66\x69"
  "\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x04\x0a\x80\x80"
  "\x04\x03\x08\x81\x81\x02\x02\x06\x81\x81\x02\x01\x04\x81\x83\x02"
  "\x09\x16";

SCHEME_OBJECT *
unsyn_so_data_cbffa850f2c333ab (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_unsyn_so_data_cbffa850f2c333ab [0]))), (sizeof (prog_unsyn_so_data_cbffa850f2c333ab)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_8]));
}

DECLARE_COMPILED_DATA_NS ("unsyn.so", unsyn_so_data_cbffa850f2c333ab)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("unsyn.so", "f2745da91efa762d")
