/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:28-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define ENVIRONMENT_LABEL_1_3 9
#define DEBUGGING_LABEL_1_2 8
#define FREE_REFERENCE_1_0 7
#define FREE_REFERENCES_LABEL_1_0 6
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto integrate_get_top_level_block_0;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_get_top_level_block_4)
DEFLABEL (integrate_get_top_level_block_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  Rvl = (Wrd5.Obj);
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define ENVIRONMENT_LABEL_2_3 12
#define DEBUGGING_LABEL_2_2 11
#define OBJECT_2_1 10
#define OBJECT_2_0 9
#define EXECUTE_CACHE_2_6 7
#define FREE_REFERENCES_LABEL_2_0 6
#define NUMBER_OF_LINKER_SECTIONS_2_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto integrate_top_level_1;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_top_level_5)
DEFLABEL (integrate_top_level_1)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_6)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_2_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define TAG_3_6 1
#define LABEL_3_7 7
#define TAG_3_8 2
#define LABEL_3_15 9
#define LABEL_3_16 11
#define LABEL_3_17 13
#define LABEL_3_18 15
#define LABEL_3_9 17
#define TAG_3_10 7
#define LABEL_3_19 19
#define LABEL_3_20 21
#define LABEL_3_21 23
#define LABEL_3_22 25
#define LABEL_3_12 27
#define LABEL_3_13 29
#define LABEL_3_23 31
#define TAG_3_24 14
#define LABEL_3_25 33
#define LABEL_3_27 35
#define LABEL_3_29 37
#define LABEL_3_34 39
#define LABEL_3_31 41
#define TAG_3_32 19
#define LABEL_3_33 43
#define LABEL_3_37 45
#define LABEL_3_38 47
#define TAG_3_39 22
#define LABEL_3_41 49
#define LABEL_3_43 51
#define TAG_3_44 24
#define ENVIRONMENT_LABEL_3_3 83
#define DEBUGGING_LABEL_3_2 82
#define OBJECT_3_4 81
#define OBJECT_3_3 80
#define OBJECT_3_2 79
#define OBJECT_3_1 78
#define OBJECT_3_0 77
#define EXECUTE_CACHE_3_42 53
#define EXECUTE_CACHE_3_40 55
#define EXECUTE_CACHE_3_36 57
#define EXECUTE_CACHE_3_35 59
#define EXECUTE_CACHE_3_30 61
#define EXECUTE_CACHE_3_28 63
#define EXECUTE_CACHE_3_26 65
#define EXECUTE_CACHE_3_14 67
#define EXECUTE_CACHE_3_11 69
#define FREE_REFERENCE_3_1 72
#define FREE_REFERENCE_3_0 73
#define FREE_ASSIGNMENT_3_1 75
#define FREE_ASSIGNMENT_3_0 76
#define FREE_REFERENCES_LABEL_3_0 52
#define NUMBER_OF_LINKER_SECTIONS_3_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto integrate_top_level__45;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto lambda_59;

    case 2:
      current_block = (Rpc - LABEL_3_7);
      goto lambda_60;

    case 3:
      current_block = (Rpc - LABEL_3_15);
      goto label_47;

    case 4:
      current_block = (Rpc - LABEL_3_16);
      goto label_48;

    case 5:
      current_block = (Rpc - LABEL_3_17);
      goto label_49;

    case 6:
      current_block = (Rpc - LABEL_3_18);
      goto label_50;

    case 7:
      current_block = (Rpc - LABEL_3_9);
      goto lambda_61;

    case 8:
      current_block = (Rpc - LABEL_3_19);
      goto label_51;

    case 9:
      current_block = (Rpc - LABEL_3_20);
      goto label_52;

    case 10:
      current_block = (Rpc - LABEL_3_21);
      goto label_53;

    case 11:
      current_block = (Rpc - LABEL_3_22);
      goto label_54;

    case 12:
      current_block = (Rpc - LABEL_3_12);
      goto continuation_19;

    case 13:
      current_block = (Rpc - LABEL_3_13);
      goto continuation_18;

    case 14:
      current_block = (Rpc - LABEL_3_23);
      goto lambda_62;

    case 15:
      current_block = (Rpc - LABEL_3_25);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_3_27);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_3_29);
      goto continuation_20;

    case 18:
      current_block = (Rpc - LABEL_3_34);
      goto label_55;

    case 19:
      current_block = (Rpc - LABEL_3_31);
      goto lambda_63;

    case 20:
      current_block = (Rpc - LABEL_3_33);
      goto continuation_22;

    case 21:
      current_block = (Rpc - LABEL_3_37);
      goto label_56;

    case 22:
      current_block = (Rpc - LABEL_3_38);
      goto lambda_64;

    case 23:
      current_block = (Rpc - LABEL_3_41);
      goto continuation_24;

    case 24:
      current_block = (Rpc - LABEL_3_43);
      goto lambda_65;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_top_level__58)
DEFLABEL (integrate_top_level__45)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_3_0]);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd22.pObj) = (& (Rhp [-1]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd27.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_5])));
  Rhp += 3;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd27.pObj)));
  Wrd32 = Wrd27;
  (Wrd33.Obj) = (Rsp [6]);
  ((Wrd32.pObj) [2]) = (Wrd33.Obj);
  ((Wrd32.pObj) [3]) = (Wrd24.Obj);
  (Wrd29.Obj) = (Rsp [4]);
  ((Wrd32.pObj) [4]) = (Wrd29.Obj);
  (Rsp [5]) = (Wrd26.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd36.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_7])));
  Rhp += 4;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd36.pObj)));
  Wrd43 = Wrd36;
  ((Wrd43.pObj) [2]) = (Wrd7.Obj);
  ((Wrd43.pObj) [3]) = (Wrd13.Obj);
  ((Wrd43.pObj) [4]) = (Wrd19.Obj);
  ((Wrd43.pObj) [5]) = (Wrd23.Obj);
  (Rsp [4]) = (Wrd35.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_9])));
  Rhp += 4;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  Wrd54 = Wrd47;
  ((Wrd54.pObj) [2]) = (Wrd7.Obj);
  ((Wrd54.pObj) [3]) = (Wrd13.Obj);
  ((Wrd54.pObj) [4]) = (Wrd19.Obj);
  ((Wrd54.pObj) [5]) = (Wrd23.Obj);
  (Rsp [6]) = (Wrd46.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_11]));

DEFLABEL (lambda_59)
  CLOSURE_HEADER (LABEL_3_5);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_14]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_3_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_26]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_3_25);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_30]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_3_29);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_66;
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (label_66)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_33]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_70;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd27.Lng))))
    goto label_70;
  (Wrd19.Obj) = ((Wrd25.pObj) [5]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_69)
  (Wrd39.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_35]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_3_33);
  (* (--Rsp)) = Rvl;
  (Wrd18.Obj) = (Rsp [4]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_68;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd17.Lng))))
    goto label_68;
  (Wrd5.Obj) = ((Wrd15.pObj) [7]);

DEFLABEL (label_67)
  (Rsp [1]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_39);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_38])));
  Rhp += 3;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd36 = Wrd31;
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [2]);
  ((Wrd36.pObj) [2]) = (Wrd39.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  ((Wrd36.pObj) [3]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [0]);
  ((Wrd36.pObj) [4]) = (Wrd33.Obj);
  (Rsp [2]) = (Wrd30.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_40]));

DEFLABEL (label_68)
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [3]);
  (Wrd25.Obj) = (current_block [OBJECT_3_4]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_37]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_3]), 2);

DEFLABEL (label_56)
  (Wrd5.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd33.Obj) = (Rsp [4]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [3]);
  (Wrd35.Obj) = (current_block [OBJECT_3_2]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_34]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_3]), 2);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_69;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_3_12);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_24);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_23])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd14.pObj) [4]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_60)
  CLOSURE_HEADER (LABEL_3_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_82;

DEFLABEL (label_81)
  Wrd19 = Wrd23;

DEFLABEL (label_80)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_79;

DEFLABEL (label_78)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_77)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_76;

DEFLABEL (label_75)
  Wrd63 = Wrd67;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_73;

DEFLABEL (label_72)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_71)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [2]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_3_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_73)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_72;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_18])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_50)
  goto label_71;

DEFLABEL (label_76)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_75;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_3_17])), (Wrd64.pObj));

DEFLABEL (label_49)
  (Wrd63.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_79)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_78;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_16])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_48)
  goto label_77;

DEFLABEL (label_82)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_81;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_3_15])), (Wrd20.pObj));

DEFLABEL (label_47)
  (Wrd19.Obj) = Rvl;
  goto label_80;

DEFLABEL (lambda_61)
  CLOSURE_HEADER (LABEL_3_9);

DEFLABEL (lambda_43)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_94;

DEFLABEL (label_93)
  Wrd19 = Wrd23;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_91;

DEFLABEL (label_90)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_89)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_88;

DEFLABEL (label_87)
  Wrd63 = Wrd67;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_85;

DEFLABEL (label_84)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_83)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_3_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_85)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_84;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_22])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_54)
  goto label_83;

DEFLABEL (label_88)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_87;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_3_21])), (Wrd64.pObj));

DEFLABEL (label_53)
  (Wrd63.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_91)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_90;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_20])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_52)
  goto label_89;

DEFLABEL (label_94)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_93;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_3_19])), (Wrd20.pObj));

DEFLABEL (label_51)
  (Wrd19.Obj) = Rvl;
  goto label_92;

DEFLABEL (lambda_62)
  CLOSURE_HEADER (LABEL_3_23);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_28]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_3_27);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_31])));
  Rhp += 3;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd13 = Wrd8;
  (Wrd14.Obj) = (Rsp [2]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [4]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_63)
  CLOSURE_HEADER (LABEL_3_31);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_64)
  CLOSURE_HEADER (LABEL_3_38);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_41]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_42]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_3_41);
  (Rsp [2]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_44);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_43])));
  Rhp += 3;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd13 = Wrd8;
  ((Wrd13.pObj) [2]) = Rvl;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [4]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_65)
  CLOSURE_HEADER (LABEL_3_43);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define TAG_4_6 1
#define ENVIRONMENT_LABEL_4_3 12
#define DEBUGGING_LABEL_4_2 11
#define EXECUTE_CACHE_4_8 7
#define EXECUTE_CACHE_4_7 9
#define FREE_REFERENCES_LABEL_4_0 6
#define NUMBER_OF_LINKER_SECTIONS_4_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto integrate_expressions_1;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_expressions_4)
DEFLABEL (integrate_expressions_1)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_4_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_8]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define LABEL_5_6 7
#define LABEL_5_7 9
#define LABEL_5_8 11
#define ENVIRONMENT_LABEL_5_3 18
#define DEBUGGING_LABEL_5_2 17
#define OBJECT_5_2 16
#define OBJECT_5_1 15
#define OBJECT_5_0 14
#define FREE_REFERENCE_5_0 13
#define FREE_REFERENCES_LABEL_5_0 12
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd56;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd51;
  machine_word Wrd41;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto integrate_expression_3;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_5_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_5_7);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_5_8);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_expression_10)
DEFLABEL (integrate_expression_3)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_18;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_18;
  (Wrd5.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_17)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_16;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_16;
  (Wrd22.Obj) = ((Wrd25.pObj) [3]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_15)
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd39.Obj) = ((Wrd36.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_14;
  Wrd35 = Wrd39;

DEFLABEL (label_13)
  Wrd34 = Wrd35;
  (Wrd41.Obj) = (* (Rsp++));
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_12;
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd46.uLng) == 26))
    goto label_12;
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) (Wrd47.Lng)) < ((unsigned long) (Wrd50.Lng))))
    goto label_12;
  (Wrd42.uLng) = (OBJECT_DATUM (Wrd41.Obj));
  (Wrd44.pObj) = (& ((Wrd48.pObj) [(Wrd42.Lng)]));
  (Wrd45.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_11)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_12)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_8]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_7])), (Wrd36.pObj));

DEFLABEL (label_7)
  (Wrd35.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd30.Obj) = (current_block [OBJECT_5_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_5_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define LABEL_6_6 7
#define LABEL_6_7 9
#define LABEL_6_8 11
#define TAG_6_9 4
#define LABEL_6_13 13
#define LABEL_6_14 15
#define LABEL_6_15 17
#define LABEL_6_11 19
#define LABEL_6_19 21
#define LABEL_6_18 23
#define LABEL_6_21 25
#define LABEL_6_22 27
#define ENVIRONMENT_LABEL_6_3 53
#define DEBUGGING_LABEL_6_2 52
#define OBJECT_6_10 51
#define OBJECT_6_9 50
#define OBJECT_6_8 49
#define OBJECT_6_7 48
#define OBJECT_6_6 47
#define OBJECT_6_5 46
#define OBJECT_6_4 45
#define OBJECT_6_3 44
#define OBJECT_6_2 43
#define OBJECT_6_1 42
#define OBJECT_6_0 41
#define EXECUTE_CACHE_6_23 29
#define EXECUTE_CACHE_6_20 31
#define EXECUTE_CACHE_6_17 33
#define EXECUTE_CACHE_6_16 35
#define EXECUTE_CACHE_6_12 37
#define EXECUTE_CACHE_6_10 39
#define FREE_REFERENCES_LABEL_6_0 28
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd41;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd40;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd67;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd66;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto lambda_17;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto label_19;

    case 2:
      current_block = (Rpc - LABEL_6_6);
      goto continuation_10;

    case 3:
      current_block = (Rpc - LABEL_6_7);
      goto lambda_9;

    case 4:
      current_block = (Rpc - LABEL_6_8);
      goto lambda_28;

    case 5:
      current_block = (Rpc - LABEL_6_13);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_6_14);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_6_15);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_6_11);
      goto continuation_11;

    case 9:
      current_block = (Rpc - LABEL_6_19);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_6_18);
      goto continuation_15;

    case 11:
      current_block = (Rpc - LABEL_6_21);
      goto label_24;

    case 12:
      current_block = (Rpc - LABEL_6_22);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_27)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_37;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_37;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_36)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd27.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_8])));
  Rhp += 1;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd27.pObj)));
  Wrd28 = Wrd27;
  (Wrd29.Obj) = (Rsp [2]);
  ((Wrd28.pObj) [2]) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd31.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_6_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_12]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_6_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_35;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_35;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_34)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_20]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_6_18);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_33;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_33;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_32)
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd21.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_31;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_31;
  (Wrd22.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_30)
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd38.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_23]));

DEFLABEL (label_31)
  (Wrd33.Obj) = (Rsp [4]);
  (Wrd34.Obj) = (current_block [OBJECT_6_10]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_22]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_25)
  (Wrd22.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_6_5]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_21]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_24)
  (Wrd5.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.Obj) = (current_block [OBJECT_6_9]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_19]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_6_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (lambda_29)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_6_7);
  Rvl = (current_block [OBJECT_6_2]);
  goto pop_return;

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_6_8);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_6_3]))
    goto label_45;
  if ((Wrd5.Obj) == (current_block [OBJECT_6_6]))
    goto label_42;
  if ((Wrd5.Obj) == (current_block [OBJECT_6_7]))
    goto label_38;
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_6_8]);
  (Rsp [1]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_17]));

DEFLABEL (label_38)
  (Wrd14.Obj) = (current_block [OBJECT_6_4]);
  (Rsp [1]) = (Wrd14.Obj);
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_41;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_41;
  (Wrd15.Obj) = ((Wrd25.pObj) [3]);

DEFLABEL (label_40)
  (Rsp [2]) = (Wrd15.Obj);

DEFLABEL (label_39)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (label_41)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [2]);
  (Wrd35.Obj) = (current_block [OBJECT_6_5]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_15]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_20)
  (Wrd15.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_42)
  (Wrd40.Obj) = (current_block [OBJECT_6_4]);
  (Rsp [1]) = (Wrd40.Obj);
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [2]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 10))
    goto label_44;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd53.Lng))))
    goto label_44;
  (Wrd41.Obj) = ((Wrd51.pObj) [3]);

DEFLABEL (label_43)
  (Rsp [2]) = (Wrd41.Obj);
  goto label_39;

DEFLABEL (label_44)
  (Wrd59.Obj) = (Rsp [0]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [2]);
  (Wrd61.Obj) = (current_block [OBJECT_6_5]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_14]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_21)
  (Wrd41.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  (Wrd66.Obj) = (current_block [OBJECT_6_4]);
  (Rsp [1]) = (Wrd66.Obj);
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [2]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 10))
    goto label_47;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [0]);
  (Wrd79.Lng) = (FIXNUM_TO_LONG (Wrd78.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd79.Lng))))
    goto label_47;
  (Wrd67.Obj) = ((Wrd77.pObj) [3]);

DEFLABEL (label_46)
  (Rsp [2]) = (Wrd67.Obj);
  goto label_39;

DEFLABEL (label_47)
  (Wrd85.Obj) = (Rsp [0]);
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd85.Obj));
  (Wrd84.Obj) = ((Wrd86.pObj) [2]);
  (Wrd87.Obj) = (current_block [OBJECT_6_5]);
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_13]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_22)
  (Wrd67.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_12 7
#define TAG_7_13 2
#define LABEL_7_14 9
#define TAG_7_15 3
#define LABEL_7_22 11
#define LABEL_7_10 13
#define TAG_7_11 5
#define LABEL_7_8 15
#define TAG_7_9 6
#define LABEL_7_6 17
#define TAG_7_7 7
#define LABEL_7_18 19
#define LABEL_7_17 21
#define LABEL_7_23 23
#define LABEL_7_25 25
#define ENVIRONMENT_LABEL_7_3 50
#define DEBUGGING_LABEL_7_2 49
#define OBJECT_7_7 48
#define OBJECT_7_6 47
#define OBJECT_7_5 46
#define OBJECT_7_4 45
#define OBJECT_7_3 44
#define OBJECT_7_2 43
#define OBJECT_7_1 42
#define OBJECT_7_0 41
#define EXECUTE_CACHE_7_26 27
#define EXECUTE_CACHE_7_24 29
#define EXECUTE_CACHE_7_21 31
#define EXECUTE_CACHE_7_20 33
#define EXECUTE_CACHE_7_19 35
#define EXECUTE_CACHE_7_16 37
#define FREE_REFERENCE_7_0 40
#define FREE_REFERENCES_LABEL_7_0 26
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd5;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd63;
  machine_word Wrd66;
  machine_word Wrd68;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto lambda_17;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto label_19;

    case 2:
      current_block = (Rpc - LABEL_7_12);
      goto lambda_26;

    case 3:
      current_block = (Rpc - LABEL_7_14);
      goto lambda_27;

    case 4:
      current_block = (Rpc - LABEL_7_22);
      goto label_20;

    case 5:
      current_block = (Rpc - LABEL_7_10);
      goto lambda_25;

    case 6:
      current_block = (Rpc - LABEL_7_8);
      goto lambda_24;

    case 7:
      current_block = (Rpc - LABEL_7_6);
      goto lambda_14;

    case 8:
      current_block = (Rpc - LABEL_7_18);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_7_17);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_7_23);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_7_25);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_22)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_29;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_29;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_28)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd74.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_6])));
  Rhp += 5;
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd74.pObj)));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd72.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_8])));
  Rhp += 2;
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd72.pObj)));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd70.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_10])));
  Rhp += 1;
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd70.pObj)));
  (* (--Rsp)) = (Wrd71.Obj);
  Wrd47 = Wrd70;
  (Wrd48.Obj) = (Rsp [3]);
  ((Wrd47.pObj) [2]) = (Wrd48.Obj);
  Wrd53 = Wrd72;
  (Wrd54.Obj) = (Rsp [6]);
  ((Wrd53.pObj) [2]) = (Wrd54.Obj);
  ((Wrd53.pObj) [3]) = (Wrd48.Obj);
  Wrd68 = Wrd74;
  ((Wrd68.pObj) [2]) = (Wrd54.Obj);
  (Wrd66.Obj) = (Rsp [5]);
  ((Wrd68.pObj) [3]) = (Wrd66.Obj);
  (Wrd63.Obj) = (Rsp [4]);
  ((Wrd68.pObj) [4]) = (Wrd63.Obj);
  ((Wrd68.pObj) [5]) = (Wrd73.Obj);
  ((Wrd68.pObj) [6]) = (Wrd71.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_12])));
  Rhp += 6;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  Wrd34 = Wrd23;
  ((Wrd34.pObj) [2]) = (Wrd54.Obj);
  ((Wrd34.pObj) [3]) = (Wrd66.Obj);
  ((Wrd34.pObj) [4]) = (Wrd48.Obj);
  ((Wrd34.pObj) [5]) = (Wrd75.Obj);
  ((Wrd34.pObj) [6]) = (Wrd73.Obj);
  ((Wrd34.pObj) [7]) = (Wrd71.Obj);
  (Rsp [5]) = (Wrd22.Obj);
  (Rsp [4]) = (Wrd48.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd40.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_14])));
  Rhp += 2;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd40.pObj)));
  Wrd43 = Wrd40;
  ((Wrd43.pObj) [2]) = (Wrd75.Obj);
  ((Wrd43.pObj) [3]) = (Wrd73.Obj);
  (Rsp [6]) = (Wrd39.Obj);
  (Rsp [3]) = (Wrd63.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_16]));

DEFLABEL (label_29)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_7_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_7_12);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_7_2]))
    goto label_34;
  if ((Wrd5.Obj) == (current_block [OBJECT_7_3]))
    goto label_32;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_7_4])))
    goto label_30;
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = ((Wrd22.pObj) [7]);
  (Rsp [4]) = (Wrd27.Obj);
  (Wrd30.Obj) = ((Wrd22.pObj) [6]);
  (Rsp [5]) = (Wrd30.Obj);
  (Wrd33.Obj) = ((Wrd22.pObj) [3]);
  (Rsp [3]) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_20]));

DEFLABEL (label_30)
  if ((Wrd5.Obj) == (current_block [OBJECT_7_5]))
    goto label_31;
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_7_6]);
  (Rsp [1]) = (Wrd14.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_21]));

DEFLABEL (label_31)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [5]);
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_14;

DEFLABEL (label_32)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_18]))));
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_33)
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [4]);
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_19]));

DEFLABEL (label_34)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_17]))));
  (* (--Rsp)) = (Wrd44.Obj);
  goto label_33;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_7_18);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_7_17);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_7_14);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_37;
  Wrd5 = Wrd9;

DEFLABEL (label_36)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_14;

DEFLABEL (label_35)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [3]);
  (Rsp [0]) = (Wrd15.Obj);
  goto lambda_13;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_22])), (Wrd6.pObj));

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_36;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_7_10);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_24]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_7_23);
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_7_8);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_19]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_7_25);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_23)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_7_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [6]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_7_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = ((Wrd6.pObj) [5]);
  (Rsp [6]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_26]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define LABEL_8_6 7
#define LABEL_8_8 9
#define LABEL_8_9 11
#define LABEL_8_10 13
#define TAG_8_11 5
#define LABEL_8_12 15
#define TAG_8_13 6
#define LABEL_8_14 17
#define TAG_8_15 7
#define LABEL_8_16 19
#define TAG_8_17 8
#define LABEL_8_19 21
#define LABEL_8_25 23
#define LABEL_8_21 25
#define LABEL_8_23 27
#define LABEL_8_24 29
#define LABEL_8_27 31
#define LABEL_8_30 33
#define ENVIRONMENT_LABEL_8_3 56
#define DEBUGGING_LABEL_8_2 55
#define OBJECT_8_3 54
#define OBJECT_8_2 53
#define OBJECT_8_1 52
#define OBJECT_8_0 51
#define EXECUTE_CACHE_8_31 35
#define EXECUTE_CACHE_8_29 37
#define EXECUTE_CACHE_8_28 39
#define EXECUTE_CACHE_8_26 41
#define EXECUTE_CACHE_8_22 43
#define EXECUTE_CACHE_8_20 45
#define EXECUTE_CACHE_8_18 47
#define EXECUTE_CACHE_8_7 49
#define FREE_REFERENCES_LABEL_8_0 34
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd58;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd54;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd25;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd68;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto integrate_name_if_safe_17;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto label_19;

    case 2:
      current_block = (Rpc - LABEL_8_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_8_8);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_8_9);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_8_10);
      goto lambda_8;

    case 6:
      current_block = (Rpc - LABEL_8_12);
      goto lambda_26;

    case 7:
      current_block = (Rpc - LABEL_8_14);
      goto lambda_27;

    case 8:
      current_block = (Rpc - LABEL_8_16);
      goto lambda_28;

    case 9:
      current_block = (Rpc - LABEL_8_19);
      goto continuation_4;

    case 10:
      current_block = (Rpc - LABEL_8_25);
      goto label_22;

    case 11:
      current_block = (Rpc - LABEL_8_21);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_8_23);
      goto continuation_7;

    case 13:
      current_block = (Rpc - LABEL_8_24);
      goto continuation_6;

    case 14:
      current_block = (Rpc - LABEL_8_27);
      goto continuation_10;

    case 15:
      current_block = (Rpc - LABEL_8_30);
      goto continuation_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_name_if_safe_24)
DEFLABEL (integrate_name_if_safe_17)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_36;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_36;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_35)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_8_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;

DEFLABEL (label_29)
  Rsp = (& (Rsp [7]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_30)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_34;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_34;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_33)
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd68.uLng) == 10))
    goto label_32;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd67.Lng))))
    goto label_32;
  (Wrd25.Obj) = ((Wrd65.pObj) [4]);
  if ((Wrd25.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;

DEFLABEL (label_31)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 10));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_10])));
  Rhp += 7;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd42 = Wrd29;
  (Wrd43.Obj) = (Rsp [7]);
  ((Wrd42.pObj) [2]) = (Wrd43.Obj);
  (Wrd41.Obj) = (Rsp [6]);
  ((Wrd42.pObj) [3]) = (Wrd41.Obj);
  (Wrd39.Obj) = (Rsp [5]);
  ((Wrd42.pObj) [4]) = (Wrd39.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  ((Wrd42.pObj) [5]) = (Wrd37.Obj);
  (Wrd35.Obj) = (Rsp [3]);
  ((Wrd42.pObj) [6]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  ((Wrd42.pObj) [7]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  ((Wrd42.pObj) [8]) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd44.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd44.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_12])));
  Rhp += 2;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  Wrd50 = Wrd47;
  ((Wrd50.pObj) [2]) = (Wrd43.Obj);
  ((Wrd50.pObj) [3]) = (Wrd28.Obj);
  (Rsp [6]) = (Wrd46.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd54.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_14])));
  Rhp += 1;
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd54.pObj)));
  ((Wrd54.pObj) [2]) = (Wrd43.Obj);
  (Rsp [7]) = (Wrd53.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd59.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_16])));
  Rhp += 1;
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd59.pObj)));
  ((Wrd59.pObj) [2]) = (Wrd43.Obj);
  (Rsp [8]) = (Wrd58.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_18]));

DEFLABEL (label_32)
  (Wrd70.Obj) = (current_block [OBJECT_8_0]);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_9]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_21)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto label_31;

DEFLABEL (label_34)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_8_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_20)
  (Wrd8.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_8_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (lambda_25)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_8_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd9.pObj) [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_20]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_8_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_37;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [2]);
  (Rsp [1]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_37)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_23]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_24]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [7]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 10))
    goto label_39;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd26.Lng))))
    goto label_39;
  (Wrd18.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_38)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_26]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_8_24);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [8]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_29]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_8_23);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_39)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [7]);
  (Wrd34.Obj) = (current_block [OBJECT_8_3]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_25]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_8_12);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_22]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_8_21);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_40;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [0]) = (Wrd11.Obj);
  goto lambda_8;

DEFLABEL (label_40)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_27]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_28]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_8_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_41)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_31]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_8_30);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_8;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_8_14);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_8_16);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_6 7
#define ENVIRONMENT_LABEL_9_3 14
#define DEBUGGING_LABEL_9_2 13
#define OBJECT_9_1 12
#define OBJECT_9_0 11
#define EXECUTE_CACHE_9_7 9
#define FREE_REFERENCES_LABEL_9_0 8
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd13;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd9;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto reassign_2;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_9_6);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reassign_7)
DEFLABEL (reassign_2)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_9;

DEFLABEL (label_8)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_13;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd34.Lng))))
    goto label_13;
  (Wrd9.Obj) = ((Wrd32.pObj) [2]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_8;

DEFLABEL (label_12)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_11;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd21.Lng))))
    goto label_11;
  (Wrd13.Obj) = ((Wrd19.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_7]));

DEFLABEL (label_11)
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.Obj) = (current_block [OBJECT_9_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_6]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_4)
  (Wrd13.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (current_block [OBJECT_9_0]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 2);

DEFLABEL (label_5)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define TAG_10_6 1
#define LABEL_10_7 7
#define LABEL_10_9 9
#define LABEL_10_11 11
#define LABEL_10_12 13
#define LABEL_10_13 15
#define LABEL_10_14 17
#define TAG_10_15 7
#define LABEL_10_17 19
#define LABEL_10_20 21
#define LABEL_10_21 23
#define LABEL_10_22 25
#define TAG_10_23 11
#define LABEL_10_24 27
#define LABEL_10_25 29
#define TAG_10_26 13
#define LABEL_10_28 31
#define LABEL_10_29 33
#define ENVIRONMENT_LABEL_10_3 52
#define DEBUGGING_LABEL_10_2 51
#define OBJECT_10_3 50
#define OBJECT_10_2 49
#define OBJECT_10_1 48
#define OBJECT_10_0 47
#define EXECUTE_CACHE_10_27 35
#define EXECUTE_CACHE_10_19 37
#define EXECUTE_CACHE_10_18 39
#define EXECUTE_CACHE_10_16 41
#define EXECUTE_CACHE_10_10 43
#define EXECUTE_CACHE_10_8 45
#define FREE_REFERENCES_LABEL_10_0 34
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd45;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd26;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd20;
  machine_word Wrd19;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto safely_integrable_valueP_20;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto check_18;

    case 2:
      current_block = (Rpc - LABEL_10_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_10_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_10_11);
      goto label_22;

    case 5:
      current_block = (Rpc - LABEL_10_12);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_10_13);
      goto lambda_5;

    case 7:
      current_block = (Rpc - LABEL_10_14);
      goto lambda_28;

    case 8:
      current_block = (Rpc - LABEL_10_17);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_10_20);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_10_21);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_10_22);
      goto lambda_30;

    case 12:
      current_block = (Rpc - LABEL_10_24);
      goto lambda_14;

    case 13:
      current_block = (Rpc - LABEL_10_25);
      goto lambda_31;

    case 14:
      current_block = (Rpc - LABEL_10_28);
      goto lambda_11;

    case 15:
      current_block = (Rpc - LABEL_10_29);
      goto lambda_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safely_integrable_valueP_26)
DEFLABEL (safely_integrable_valueP_20)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_5])));
  Rhp += 3;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  (* (--Rsp)) = (Wrd20.Obj);
  Wrd17 = Wrd19;
  (Wrd18.Obj) = (Rsp [4]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [3]) = (Wrd15.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd17.pObj) [4]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd20.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_10_0]);
  (Rsp [3]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  goto check_18;

DEFLABEL (check_27)
DEFLABEL (check_18)
  INTERRUPT_CHECK (26, LABEL_10_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_10_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  Rvl = Rvl;
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_10_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd7.Obj) = (Rsp [3]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_44;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_44;
  (Wrd9.Obj) = ((Wrd15.pObj) [4]);

DEFLABEL (label_43)
  (Rsp [0]) = (Wrd9.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_12]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_13]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_14])));
  Rhp += 1;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd32 = Wrd31;
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd39.Obj) = ((Wrd34.pObj) [3]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_10_12);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  Rvl = Rvl;
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_36)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_18]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_10_17);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;

DEFLABEL (label_37)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_38)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_42;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd17.Lng))))
    goto label_42;
  (Wrd9.Obj) = ((Wrd15.pObj) [2]);

DEFLABEL (label_41)
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd54.uLng) == 10))
    goto label_40;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd53.Lng))))
    goto label_40;
  (Wrd26.Obj) = ((Wrd51.pObj) [4]);
  if ((Wrd26.Obj) == ((SCHEME_OBJECT) 0))
    goto label_37;

DEFLABEL (label_39)
  (Wrd31.Obj) = (Rsp [2]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [4]);
  (Rsp [0]) = (Wrd30.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_22])));
  Rhp += 2;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd38 = Wrd35;
  (Wrd41.Obj) = ((Wrd32.pObj) [3]);
  ((Wrd38.pObj) [2]) = (Wrd41.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  ((Wrd38.pObj) [3]) = (Wrd37.Obj);
  (Rsp [3]) = (Wrd34.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_24]))));
  (Rsp [4]) = (Wrd42.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd46.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_25])));
  Rhp += 1;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd46.pObj)));
  ((Wrd46.pObj) [2]) = (Wrd31.Obj);
  (Rsp [2]) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_27]));

DEFLABEL (label_40)
  (Wrd56.Obj) = (current_block [OBJECT_10_1]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_21]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 2);

DEFLABEL (label_24)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_39;

DEFLABEL (label_42)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_10_3]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 2);

DEFLABEL (label_23)
  (Wrd9.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_10_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_11]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 2);

DEFLABEL (label_22)
  (Wrd9.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  Rvl = (current_block [OBJECT_10_0]);

DEFLABEL (label_46)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_47)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_46;

DEFLABEL (lambda_29)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_10_13);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_10_14);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_19]));

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_10_22);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_28]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_29]))));
  (Rsp [3]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_16]));

DEFLABEL (lambda_32)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_10_24);
  Rvl = (current_block [OBJECT_10_0]);
  goto pop_return;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_10_25);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  goto check_18;

DEFLABEL (lambda_33)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_10_28);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_34)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_10_29);
  Rvl = (current_block [OBJECT_10_0]);
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_14 7
#define TAG_11_15 2
#define LABEL_11_20 9
#define LABEL_11_16 11
#define TAG_11_17 4
#define LABEL_11_24 13
#define LABEL_11_12 15
#define TAG_11_13 6
#define LABEL_11_10 17
#define TAG_11_11 7
#define LABEL_11_8 19
#define TAG_11_9 8
#define LABEL_11_6 21
#define TAG_11_7 9
#define LABEL_11_21 23
#define TAG_11_22 10
#define LABEL_11_26 25
#define LABEL_11_28 27
#define LABEL_11_30 29
#define ENVIRONMENT_LABEL_11_3 61
#define DEBUGGING_LABEL_11_2 60
#define OBJECT_11_8 59
#define OBJECT_11_7 58
#define OBJECT_11_6 57
#define OBJECT_11_5 56
#define OBJECT_11_4 55
#define OBJECT_11_3 54
#define OBJECT_11_2 53
#define OBJECT_11_1 52
#define OBJECT_11_0 51
#define EXECUTE_CACHE_11_33 31
#define EXECUTE_CACHE_11_32 33
#define EXECUTE_CACHE_11_31 35
#define EXECUTE_CACHE_11_29 37
#define EXECUTE_CACHE_11_27 39
#define EXECUTE_CACHE_11_25 41
#define EXECUTE_CACHE_11_23 43
#define EXECUTE_CACHE_11_19 45
#define EXECUTE_CACHE_11_18 47
#define FREE_REFERENCE_11_0 50
#define FREE_REFERENCES_LABEL_11_0 30
#define NUMBER_OF_LINKER_SECTIONS_11_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd58;
  machine_word Wrd62;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd28;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd67;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd103;
  machine_word Wrd105;
  machine_word Wrd5;
  machine_word Wrd49;
  machine_word Wrd45;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd104;
  machine_word Wrd78;
  machine_word Wrd81;
  machine_word Wrd86;
  machine_word Wrd60;
  machine_word Wrd63;
  machine_word Wrd66;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto integrate_reference_operator_19;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto label_21;

    case 2:
      current_block = (Rpc - LABEL_11_14);
      goto lambda_30;

    case 3:
      current_block = (Rpc - LABEL_11_20);
      goto label_22;

    case 4:
      current_block = (Rpc - LABEL_11_16);
      goto lambda_31;

    case 5:
      current_block = (Rpc - LABEL_11_24);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_11_12);
      goto lambda_11;

    case 7:
      current_block = (Rpc - LABEL_11_10);
      goto lambda_28;

    case 8:
      current_block = (Rpc - LABEL_11_8);
      goto lambda_27;

    case 9:
      current_block = (Rpc - LABEL_11_6);
      goto lambda_16;

    case 10:
      current_block = (Rpc - LABEL_11_21);
      goto lambda_32;

    case 11:
      current_block = (Rpc - LABEL_11_26);
      goto continuation_12;

    case 12:
      current_block = (Rpc - LABEL_11_28);
      goto continuation_14;

    case 13:
      current_block = (Rpc - LABEL_11_30);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_reference_operator_25)
DEFLABEL (integrate_reference_operator_19)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_34;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_34;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_33)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd112.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_6])));
  Rhp += 6;
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd112.pObj)));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd110.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_8])));
  Rhp += 6;
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd110.pObj)));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd108.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_10])));
  Rhp += 5;
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd108.pObj)));
  (* (--Rsp)) = (Wrd109.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd106.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_12])));
  Rhp += 1;
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd106.pObj)));
  (* (--Rsp)) = (Wrd107.Obj);
  Wrd53 = Wrd106;
  (Wrd54.Obj) = (Rsp [4]);
  ((Wrd53.pObj) [2]) = (Wrd54.Obj);
  Wrd68 = Wrd108;
  (Wrd69.Obj) = (Rsp [10]);
  ((Wrd68.pObj) [2]) = (Wrd69.Obj);
  (Wrd66.Obj) = (Rsp [9]);
  ((Wrd68.pObj) [3]) = (Wrd66.Obj);
  (Wrd63.Obj) = (Rsp [8]);
  ((Wrd68.pObj) [4]) = (Wrd63.Obj);
  (Wrd60.Obj) = (Rsp [5]);
  ((Wrd68.pObj) [5]) = (Wrd60.Obj);
  ((Wrd68.pObj) [6]) = (Wrd54.Obj);
  Wrd86 = Wrd110;
  ((Wrd86.pObj) [2]) = (Wrd69.Obj);
  ((Wrd86.pObj) [3]) = (Wrd63.Obj);
  (Wrd81.Obj) = (Rsp [7]);
  ((Wrd86.pObj) [4]) = (Wrd81.Obj);
  (Wrd78.Obj) = (Rsp [6]);
  ((Wrd86.pObj) [5]) = (Wrd78.Obj);
  ((Wrd86.pObj) [6]) = (Wrd60.Obj);
  ((Wrd86.pObj) [7]) = (Wrd107.Obj);
  Wrd104 = Wrd112;
  ((Wrd104.pObj) [2]) = (Wrd66.Obj);
  ((Wrd104.pObj) [3]) = (Wrd81.Obj);
  ((Wrd104.pObj) [4]) = (Wrd78.Obj);
  ((Wrd104.pObj) [5]) = (Wrd60.Obj);
  ((Wrd104.pObj) [6]) = (Wrd111.Obj);
  ((Wrd104.pObj) [7]) = (Wrd109.Obj);
  (Rsp [8]) = (Wrd54.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 12));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_14])));
  Rhp += 9;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd41 = Wrd24;
  ((Wrd41.pObj) [2]) = (Wrd69.Obj);
  ((Wrd41.pObj) [3]) = (Wrd66.Obj);
  ((Wrd41.pObj) [4]) = (Wrd81.Obj);
  ((Wrd41.pObj) [5]) = (Wrd78.Obj);
  ((Wrd41.pObj) [6]) = (Wrd60.Obj);
  ((Wrd41.pObj) [7]) = (Wrd113.Obj);
  ((Wrd41.pObj) [8]) = (Wrd111.Obj);
  ((Wrd41.pObj) [9]) = (Wrd109.Obj);
  ((Wrd41.pObj) [10]) = (Wrd107.Obj);
  (Rsp [9]) = (Wrd23.Obj);
  (Rsp [7]) = (Wrd78.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd46.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_16])));
  Rhp += 2;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd46.pObj)));
  Wrd49 = Wrd46;
  ((Wrd49.pObj) [2]) = (Wrd113.Obj);
  ((Wrd49.pObj) [3]) = (Wrd109.Obj);
  (Rsp [10]) = (Wrd45.Obj);
  Rsp = (& (Rsp [7]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_18]));

DEFLABEL (label_34)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_11_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_11_14);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_35;
  (Wrd104.Obj) = (Rsp [0]);
  (Wrd105.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd103.Obj) = ((Wrd105.pObj) [9]);
  (Rsp [2]) = (Wrd103.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_13;

DEFLABEL (label_35)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_11_2])))
    goto label_37;

DEFLABEL (label_36)
  (Wrd87.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd87.Obj);
  (Wrd88.Obj) = (Rsp [1]);
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd90.Obj) = ((Wrd89.pObj) [3]);
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd93.Obj) = ((Wrd89.pObj) [6]);
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd94.Obj) = ((Wrd89.pObj) [8]);
  (Rsp [4]) = (Wrd94.Obj);
  (Wrd97.Obj) = ((Wrd89.pObj) [9]);
  (Rsp [5]) = (Wrd97.Obj);
  (Wrd100.Obj) = ((Wrd89.pObj) [4]);
  (Rsp [3]) = (Wrd100.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_19]));

DEFLABEL (label_37)
  if ((Wrd5.Obj) == (current_block [OBJECT_11_3]))
    goto label_36;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_11_4])))
    goto label_38;
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd67.Obj) = ((Wrd69.pObj) [7]);
  (Rsp [2]) = (Wrd67.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_16;

DEFLABEL (label_38)
  if ((Wrd5.Obj) == (current_block [OBJECT_11_5]))
    goto label_39;
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_11_7]);
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_23]));

DEFLABEL (label_39)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = ((Wrd19.pObj) [6]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = ((Wrd19.pObj) [9]);
  (Rsp [4]) = (Wrd25.Obj);
  (Wrd43.Obj) = ((Wrd19.pObj) [3]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_41;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd40.Lng))))
    goto label_41;
  (Wrd28.Obj) = ((Wrd38.pObj) [3]);

DEFLABEL (label_40)
  (Rsp [5]) = (Wrd28.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd54.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_21])));
  Rhp += 3;
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd54.pObj)));
  Wrd63 = Wrd54;
  (Wrd64.Obj) = (Rsp [3]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [4]);
  ((Wrd63.pObj) [2]) = (Wrd66.Obj);
  (Wrd62.Obj) = ((Wrd65.pObj) [5]);
  ((Wrd63.pObj) [3]) = (Wrd62.Obj);
  (Wrd58.Obj) = ((Wrd65.pObj) [10]);
  ((Wrd63.pObj) [4]) = (Wrd58.Obj);
  (Rsp [3]) = (Wrd53.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 6);
  }

DEFLABEL (label_41)
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [3]);
  (Wrd48.Obj) = (current_block [OBJECT_11_6]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_20]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 2);

DEFLABEL (label_22)
  (Wrd28.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_11_16);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_44;
  Wrd5 = Wrd9;

DEFLABEL (label_43)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_42;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_16;

DEFLABEL (label_42)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [3]);
  (Rsp [0]) = (Wrd15.Obj);
  goto lambda_13;

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_24])), (Wrd6.pObj));

DEFLABEL (label_23)
  (Wrd5.Obj) = Rvl;
  goto label_43;

DEFLABEL (lambda_29)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_11_12);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_25]));

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_11_10);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_27]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_11_26);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_31]));

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_11_8);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_11;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_11_28);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd6.pObj) [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  (Wrd20.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd20.Obj);
  (Rsp [5]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_32]));

DEFLABEL (lambda_26)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_11_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [6]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = ((Wrd6.pObj) [7]);
  (Rsp [6]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_29]));

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_11_21);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_11;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_11_30);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_33]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define LABEL_12_6 7
#define LABEL_12_8 9
#define LABEL_12_7 11
#define LABEL_12_13 13
#define LABEL_12_9 15
#define LABEL_12_11 17
#define TAG_12_12 7
#define LABEL_12_17 19
#define LABEL_12_16 21
#define LABEL_12_19 23
#define TAG_12_20 10
#define LABEL_12_22 25
#define LABEL_12_24 27
#define LABEL_12_25 29
#define LABEL_12_21 31
#define LABEL_12_26 33
#define LABEL_12_27 35
#define LABEL_12_29 37
#define LABEL_12_31 39
#define LABEL_12_28 41
#define LABEL_12_33 43
#define LABEL_12_35 45
#define TAG_12_36 21
#define LABEL_12_37 47
#define LABEL_12_39 49
#define ENVIRONMENT_LABEL_12_3 82
#define DEBUGGING_LABEL_12_2 81
#define OBJECT_12_9 80
#define OBJECT_12_8 79
#define OBJECT_12_7 78
#define OBJECT_12_6 77
#define OBJECT_12_5 76
#define OBJECT_12_4 75
#define OBJECT_12_3 74
#define OBJECT_12_2 73
#define OBJECT_12_1 72
#define OBJECT_12_0 71
#define EXECUTE_CACHE_12_40 51
#define EXECUTE_CACHE_12_38 53
#define EXECUTE_CACHE_12_34 55
#define EXECUTE_CACHE_12_32 57
#define EXECUTE_CACHE_12_30 59
#define EXECUTE_CACHE_12_23 61
#define EXECUTE_CACHE_12_18 63
#define EXECUTE_CACHE_12_15 65
#define EXECUTE_CACHE_12_14 67
#define EXECUTE_CACHE_12_10 69
#define FREE_REFERENCES_LABEL_12_0 50
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd126;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd73;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd89;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd117;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd137;
  machine_word Wrd134;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd132;
  machine_word Wrd5;
  machine_word Wrd35;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd6;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto integrate_open_block_26;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto label_28;

    case 2:
      current_block = (Rpc - LABEL_12_6);
      goto label_29;

    case 3:
      current_block = (Rpc - LABEL_12_8);
      goto label_30;

    case 4:
      current_block = (Rpc - LABEL_12_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_12_13);
      goto label_31;

    case 6:
      current_block = (Rpc - LABEL_12_9);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_12_11);
      goto lambda_41;

    case 8:
      current_block = (Rpc - LABEL_12_17);
      goto label_32;

    case 9:
      current_block = (Rpc - LABEL_12_16);
      goto continuation_22;

    case 10:
      current_block = (Rpc - LABEL_12_19);
      goto lambda_42;

    case 11:
      current_block = (Rpc - LABEL_12_22);
      goto label_33;

    case 12:
      current_block = (Rpc - LABEL_12_24);
      goto continuation_13;

    case 13:
      current_block = (Rpc - LABEL_12_25);
      goto continuation_16;

    case 14:
      current_block = (Rpc - LABEL_12_21);
      goto continuation_7;

    case 15:
      current_block = (Rpc - LABEL_12_26);
      goto label_34;

    case 16:
      current_block = (Rpc - LABEL_12_27);
      goto label_37;

    case 17:
      current_block = (Rpc - LABEL_12_29);
      goto label_36;

    case 18:
      current_block = (Rpc - LABEL_12_31);
      goto label_35;

    case 19:
      current_block = (Rpc - LABEL_12_28);
      goto continuation_15;

    case 20:
      current_block = (Rpc - LABEL_12_33);
      goto lambda_12;

    case 21:
      current_block = (Rpc - LABEL_12_35);
      goto lambda_43;

    case 22:
      current_block = (Rpc - LABEL_12_37);
      goto continuation_10;

    case 23:
      current_block = (Rpc - LABEL_12_39);
      goto label_38;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_open_block_40)
DEFLABEL (integrate_open_block_26)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_52;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_52;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_51)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_50;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd29.Lng))))
    goto label_50;
  (Wrd23.Obj) = ((Wrd27.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_49)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_48;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd48.Lng))))
    goto label_48;
  (Wrd42.Obj) = ((Wrd46.pObj) [5]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_47)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd60.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_12_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_12_7);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_11])));
  Rhp += 5;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [5]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [4]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [5]) = (Wrd11.Obj);
  ((Wrd16.pObj) [6]) = Rvl;
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_46;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd26.Lng))))
    goto label_46;
  (Wrd18.Obj) = ((Wrd24.pObj) [7]);

DEFLABEL (label_45)
  (Rsp [4]) = (Wrd18.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_14]));

DEFLABEL (label_46)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.Obj) = (current_block [OBJECT_12_4]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_31)
  (Wrd18.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.Obj) = (current_block [OBJECT_12_3]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (current_block [OBJECT_12_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_12_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (lambda_41)
  CLOSURE_HEADER (LABEL_12_11);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_54;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd20.Lng))))
    goto label_54;
  (Wrd12.Obj) = ((Wrd18.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_53)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [5]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = ((Wrd33.pObj) [3]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.Obj) = ((Wrd33.pObj) [6]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_18]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_12_16);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_19])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd20 = Wrd7;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  ((Wrd20.pObj) [2]) = (Wrd23.Obj);
  (Wrd19.Obj) = ((Wrd22.pObj) [4]);
  ((Wrd20.pObj) [3]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd22.pObj) [5]);
  ((Wrd20.pObj) [4]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd22.pObj) [6]);
  ((Wrd20.pObj) [5]) = (Wrd11.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_54)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [2]);
  (Wrd28.Obj) = (current_block [OBJECT_12_3]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_17]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (lambda_42)
  CLOSURE_HEADER (LABEL_12_19);

DEFLABEL (lambda_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_68;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd20.Lng))))
    goto label_68;
  (Wrd12.Obj) = ((Wrd18.pObj) [6]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_67)
  (Wrd32.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [5]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_23]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_12_21);
  (* (--Rsp)) = Rvl;
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_66;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_66;
  (Wrd5.Obj) = ((Wrd15.pObj) [3]);

DEFLABEL (label_65)
  (Wrd132.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd132.uLng) == 10))
    goto label_64;
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd130.Obj) = ((Wrd129.pObj) [0]);
  (Wrd131.Lng) = (FIXNUM_TO_LONG (Wrd130.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd131.Lng))))
    goto label_64;
  (Wrd30.Obj) = ((Wrd129.pObj) [4]);
  if ((Wrd30.Obj) == ((SCHEME_OBJECT) 0))
    goto label_62;

DEFLABEL (label_63)
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_24]))));
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd122.Obj) = (Rsp [2]);
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd122.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [4]);
  (* (--Rsp)) = (Wrd124.Obj);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_33]))));
  (* (--Rsp)) = (Wrd126.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_34]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_12_24);

DEFLABEL (label_62)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_28]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd107.Obj) = (Rsp [2]);
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd109.Obj) = ((Wrd108.pObj) [2]);
  (Wrd110.uLng) = (OBJECT_TYPE (Wrd109.Obj));
  if (! ((Wrd110.uLng) == 10))
    goto label_61;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [0]);
  (Wrd106.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd106.Lng))))
    goto label_61;
  (Wrd39.Obj) = ((Wrd104.pObj) [7]);
  if (! ((Wrd39.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_56;

DEFLABEL (label_55)
  (Wrd41.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd49.Obj) = ((Wrd43.pObj) [4]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd52.Obj) = ((Wrd43.pObj) [3]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd55.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd55.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_30]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_12_28);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [5]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_35])));
  Rhp += 3;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd16 = Wrd11;
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  ((Wrd16.pObj) [4]) = (Wrd13.Obj);
  Rvl = (Wrd10.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd56.Obj) = (current_block [OBJECT_12_6]);
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd57.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [5]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [4]);
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd64.Obj) = ((Wrd60.pObj) [3]);
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_25]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd70.Obj) = ((Wrd60.pObj) [2]);
  if ((Wrd70.Obj) == ((SCHEME_OBJECT) 0))
    goto label_60;
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd89.uLng) == 10))
    goto label_59;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd84.Obj) = ((Wrd83.pObj) [0]);
  (Wrd85.Lng) = (FIXNUM_TO_LONG (Wrd84.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd85.Lng))))
    goto label_59;
  (Wrd73.Obj) = ((Wrd83.pObj) [2]);

DEFLABEL (label_58)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd73.Obj);

DEFLABEL (label_57)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_32]));

DEFLABEL (label_59)
  (Wrd91.Obj) = (Rsp [8]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [2]);
  (Wrd93.Obj) = (current_block [OBJECT_12_7]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_31]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_35)
  (Wrd73.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_60)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_57;

DEFLABEL (label_61)
  (Wrd112.Obj) = (Rsp [2]);
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd111.Obj) = ((Wrd113.pObj) [2]);
  (Wrd114.Obj) = (current_block [OBJECT_12_4]);
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_29]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_36)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  goto label_56;

DEFLABEL (label_64)
  (Wrd134.Obj) = (current_block [OBJECT_12_2]);
  (Wrd137.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_27]))));
  (* (--Rsp)) = (Wrd137.Obj);
  (* (--Rsp)) = (Wrd134.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_37)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  goto label_63;

DEFLABEL (label_66)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [2]);
  (Wrd25.Obj) = (current_block [OBJECT_12_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_26]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_34)
  (Wrd5.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [2]);
  (Wrd28.Obj) = (current_block [OBJECT_12_5]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_22]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_12_25);
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (lambda_44)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_12_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_38]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_12_37);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_69;
  Rvl = (current_block [OBJECT_12_8]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_69)
  (Wrd7.Obj) = (current_block [OBJECT_12_9]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_71;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_71;
  (Wrd8.Obj) = ((Wrd14.pObj) [3]);

DEFLABEL (label_70)
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_40]));

DEFLABEL (label_71)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_12_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_39]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_38)
  (Wrd8.Obj) = Rvl;
  goto label_70;

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_12_35);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_7 7
#define ENVIRONMENT_LABEL_13_3 12
#define DEBUGGING_LABEL_13_2 11
#define EXECUTE_CACHE_13_6 9
#define FREE_REFERENCES_LABEL_13_0 8
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_13_7);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_6)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_13_7);
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_36 7
#define TAG_14_37 2
#define LABEL_14_44 9
#define LABEL_14_38 11
#define TAG_14_39 4
#define LABEL_14_46 13
#define LABEL_14_47 15
#define LABEL_14_40 17
#define TAG_14_41 7
#define LABEL_14_48 19
#define LABEL_14_49 21
#define LABEL_14_30 23
#define TAG_14_31 10
#define LABEL_14_50 25
#define LABEL_14_32 27
#define TAG_14_33 12
#define LABEL_14_51 29
#define LABEL_14_52 31
#define LABEL_14_34 33
#define TAG_14_35 15
#define LABEL_14_53 35
#define LABEL_14_54 37
#define LABEL_14_24 39
#define TAG_14_25 18
#define LABEL_14_55 41
#define LABEL_14_26 43
#define TAG_14_27 20
#define LABEL_14_56 45
#define LABEL_14_57 47
#define LABEL_14_28 49
#define TAG_14_29 23
#define LABEL_14_58 51
#define LABEL_14_59 53
#define LABEL_14_18 55
#define TAG_14_19 26
#define LABEL_14_60 57
#define LABEL_14_20 59
#define TAG_14_21 28
#define LABEL_14_61 61
#define LABEL_14_62 63
#define LABEL_14_22 65
#define TAG_14_23 31
#define LABEL_14_63 67
#define LABEL_14_64 69
#define LABEL_14_12 71
#define TAG_14_13 34
#define LABEL_14_65 73
#define LABEL_14_14 75
#define TAG_14_15 36
#define LABEL_14_66 77
#define LABEL_14_67 79
#define LABEL_14_16 81
#define TAG_14_17 39
#define LABEL_14_68 83
#define LABEL_14_69 85
#define LABEL_14_6 87
#define TAG_14_7 42
#define LABEL_14_70 89
#define LABEL_14_8 91
#define TAG_14_9 44
#define LABEL_14_71 93
#define LABEL_14_72 95
#define LABEL_14_10 97
#define TAG_14_11 47
#define LABEL_14_73 99
#define LABEL_14_74 101
#define ENVIRONMENT_LABEL_14_3 130
#define DEBUGGING_LABEL_14_2 129
#define OBJECT_14_11 128
#define OBJECT_14_10 127
#define OBJECT_14_9 126
#define OBJECT_14_8 125
#define OBJECT_14_7 124
#define OBJECT_14_6 123
#define OBJECT_14_5 122
#define OBJECT_14_4 121
#define OBJECT_14_3 120
#define OBJECT_14_2 119
#define OBJECT_14_1 118
#define OBJECT_14_0 117
#define EXECUTE_CACHE_14_45 103
#define EXECUTE_CACHE_14_43 105
#define EXECUTE_CACHE_14_42 107
#define FREE_REFERENCE_14_2 110
#define FREE_REFERENCE_14_1 111
#define FREE_REFERENCE_14_0 112
#define FREE_ASSIGNMENT_14_2 114
#define FREE_ASSIGNMENT_14_1 115
#define FREE_ASSIGNMENT_14_0 116
#define FREE_REFERENCES_LABEL_14_0 102
#define NUMBER_OF_LINKER_SECTIONS_14_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd28;
  machine_word Wrd56;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd45;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd89;
  machine_word Wrd85;
  machine_word Wrd86;
  machine_word Wrd82;
  machine_word Wrd78;
  machine_word Wrd79;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd67;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd122;
  machine_word Wrd118;
  machine_word Wrd119;
  machine_word Wrd115;
  machine_word Wrd111;
  machine_word Wrd112;
  machine_word Wrd107;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd100;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd155;
  machine_word Wrd151;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd144;
  machine_word Wrd145;
  machine_word Wrd140;
  machine_word Wrd142;
  machine_word Wrd141;
  machine_word Wrd137;
  machine_word Wrd138;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd133;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd132;
  machine_word Wrd188;
  machine_word Wrd184;
  machine_word Wrd185;
  machine_word Wrd181;
  machine_word Wrd177;
  machine_word Wrd178;
  machine_word Wrd173;
  machine_word Wrd175;
  machine_word Wrd174;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd193;
  machine_word Wrd192;
  machine_word Wrd166;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd221;
  machine_word Wrd217;
  machine_word Wrd218;
  machine_word Wrd214;
  machine_word Wrd210;
  machine_word Wrd211;
  machine_word Wrd206;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd203;
  machine_word Wrd204;
  machine_word Wrd226;
  machine_word Wrd225;
  machine_word Wrd199;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd198;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto process_block_flags_112;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto label_114;

    case 2:
      current_block = (Rpc - LABEL_14_36);
      goto lambda_162;

    case 3:
      current_block = (Rpc - LABEL_14_44);
      goto label_115;

    case 4:
      current_block = (Rpc - LABEL_14_38);
      goto lambda_163;

    case 5:
      current_block = (Rpc - LABEL_14_46);
      goto label_116;

    case 6:
      current_block = (Rpc - LABEL_14_47);
      goto label_117;

    case 7:
      current_block = (Rpc - LABEL_14_40);
      goto lambda_164;

    case 8:
      current_block = (Rpc - LABEL_14_48);
      goto label_118;

    case 9:
      current_block = (Rpc - LABEL_14_49);
      goto label_119;

    case 10:
      current_block = (Rpc - LABEL_14_30);
      goto lambda_159;

    case 11:
      current_block = (Rpc - LABEL_14_50);
      goto label_120;

    case 12:
      current_block = (Rpc - LABEL_14_32);
      goto lambda_160;

    case 13:
      current_block = (Rpc - LABEL_14_51);
      goto label_121;

    case 14:
      current_block = (Rpc - LABEL_14_52);
      goto label_122;

    case 15:
      current_block = (Rpc - LABEL_14_34);
      goto lambda_161;

    case 16:
      current_block = (Rpc - LABEL_14_53);
      goto label_123;

    case 17:
      current_block = (Rpc - LABEL_14_54);
      goto label_124;

    case 18:
      current_block = (Rpc - LABEL_14_24);
      goto lambda_156;

    case 19:
      current_block = (Rpc - LABEL_14_55);
      goto label_125;

    case 20:
      current_block = (Rpc - LABEL_14_26);
      goto lambda_157;

    case 21:
      current_block = (Rpc - LABEL_14_56);
      goto label_126;

    case 22:
      current_block = (Rpc - LABEL_14_57);
      goto label_127;

    case 23:
      current_block = (Rpc - LABEL_14_28);
      goto lambda_158;

    case 24:
      current_block = (Rpc - LABEL_14_58);
      goto label_128;

    case 25:
      current_block = (Rpc - LABEL_14_59);
      goto label_129;

    case 26:
      current_block = (Rpc - LABEL_14_18);
      goto lambda_153;

    case 27:
      current_block = (Rpc - LABEL_14_60);
      goto label_130;

    case 28:
      current_block = (Rpc - LABEL_14_20);
      goto lambda_154;

    case 29:
      current_block = (Rpc - LABEL_14_61);
      goto label_131;

    case 30:
      current_block = (Rpc - LABEL_14_62);
      goto label_132;

    case 31:
      current_block = (Rpc - LABEL_14_22);
      goto lambda_155;

    case 32:
      current_block = (Rpc - LABEL_14_63);
      goto label_133;

    case 33:
      current_block = (Rpc - LABEL_14_64);
      goto label_134;

    case 34:
      current_block = (Rpc - LABEL_14_12);
      goto lambda_150;

    case 35:
      current_block = (Rpc - LABEL_14_65);
      goto label_135;

    case 36:
      current_block = (Rpc - LABEL_14_14);
      goto lambda_151;

    case 37:
      current_block = (Rpc - LABEL_14_66);
      goto label_136;

    case 38:
      current_block = (Rpc - LABEL_14_67);
      goto label_137;

    case 39:
      current_block = (Rpc - LABEL_14_16);
      goto lambda_152;

    case 40:
      current_block = (Rpc - LABEL_14_68);
      goto label_138;

    case 41:
      current_block = (Rpc - LABEL_14_69);
      goto label_139;

    case 42:
      current_block = (Rpc - LABEL_14_6);
      goto lambda_147;

    case 43:
      current_block = (Rpc - LABEL_14_70);
      goto label_140;

    case 44:
      current_block = (Rpc - LABEL_14_8);
      goto lambda_148;

    case 45:
      current_block = (Rpc - LABEL_14_71);
      goto label_141;

    case 46:
      current_block = (Rpc - LABEL_14_72);
      goto label_142;

    case 47:
      current_block = (Rpc - LABEL_14_10);
      goto lambda_149;

    case 48:
      current_block = (Rpc - LABEL_14_73);
      goto label_143;

    case 49:
      current_block = (Rpc - LABEL_14_74);
      goto label_144;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (process_block_flags_146)
DEFLABEL (process_block_flags_112)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_14_0])))
    goto label_165;
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_165)
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_174;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_173)
  (Wrd16.Obj) = (Rsp [0]);
  if ((Wrd16.Obj) == (current_block [OBJECT_14_2]))
    goto label_172;
  if ((Wrd16.Obj) == (current_block [OBJECT_14_4]))
    goto label_171;
  if ((Wrd16.Obj) == (current_block [OBJECT_14_5]))
    goto label_170;
  if ((Wrd16.Obj) == (current_block [OBJECT_14_6]))
    goto label_169;
  if ((Wrd16.Obj) == (current_block [OBJECT_14_7]))
    goto label_168;
  if ((Wrd16.Obj) == (current_block [OBJECT_14_8]))
    goto label_166;
  (Wrd28.Obj) = (current_block [OBJECT_14_9]);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_43]));

DEFLABEL (label_166)
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd31.pObj) = (& (Rhp [-1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd31.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd34.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd34.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd60.pObj) = (& (Rhp [-1]));
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd60.pObj)));
  (Rsp [1]) = (Wrd61.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd39.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_37);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_36])));
  Rhp += 2;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd39.pObj)));
  Wrd42 = Wrd39;
  (Wrd43.Obj) = (Rsp [3]);
  ((Wrd42.pObj) [2]) = (Wrd43.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  ((Wrd42.pObj) [3]) = (Wrd41.Obj);
  (Rsp [2]) = (Wrd38.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd46.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_39);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_38])));
  Rhp += 2;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd46.pObj)));
  Wrd49 = Wrd46;
  ((Wrd49.pObj) [2]) = (Wrd61.Obj);
  ((Wrd49.pObj) [3]) = (Wrd32.Obj);
  (Rsp [3]) = (Wrd45.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd53.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_41);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_40])));
  Rhp += 2;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd53.pObj)));
  Wrd56 = Wrd53;
  ((Wrd56.pObj) [2]) = (Wrd61.Obj);
  ((Wrd56.pObj) [3]) = (Wrd32.Obj);
  (Rsp [1]) = (Wrd52.Obj);

DEFLABEL (label_167)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_42]));

DEFLABEL (label_168)
  (Wrd66.Obj) = (current_block [OBJECT_14_3]);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd64.pObj) = (& (Rhp [-1]));
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd64.pObj)));
  (* (--Rsp)) = (Wrd65.Obj);
  (Wrd67.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd67.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd93.pObj) = (& (Rhp [-1]));
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd93.pObj)));
  (Rsp [1]) = (Wrd94.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd72.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_31);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_30])));
  Rhp += 2;
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd72.pObj)));
  Wrd75 = Wrd72;
  (Wrd76.Obj) = (Rsp [3]);
  ((Wrd75.pObj) [2]) = (Wrd76.Obj);
  (Wrd74.Obj) = (Rsp [2]);
  ((Wrd75.pObj) [3]) = (Wrd74.Obj);
  (Rsp [2]) = (Wrd71.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd79.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_32])));
  Rhp += 2;
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd79.pObj)));
  Wrd82 = Wrd79;
  ((Wrd82.pObj) [2]) = (Wrd94.Obj);
  ((Wrd82.pObj) [3]) = (Wrd65.Obj);
  (Rsp [3]) = (Wrd78.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd86.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_34])));
  Rhp += 2;
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd86.pObj)));
  Wrd89 = Wrd86;
  ((Wrd89.pObj) [2]) = (Wrd94.Obj);
  ((Wrd89.pObj) [3]) = (Wrd65.Obj);
  (Rsp [1]) = (Wrd85.Obj);
  goto label_167;

DEFLABEL (label_169)
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd97.pObj) = (& (Rhp [-1]));
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd97.pObj)));
  (* (--Rsp)) = (Wrd98.Obj);
  (Wrd100.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd100.Obj);
  (Wrd126.pObj) = (& (Rhp [-1]));
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd126.pObj)));
  (Rsp [1]) = (Wrd127.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd105.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_24])));
  Rhp += 2;
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd105.pObj)));
  Wrd108 = Wrd105;
  (Wrd109.Obj) = (Rsp [3]);
  ((Wrd108.pObj) [2]) = (Wrd109.Obj);
  (Wrd107.Obj) = (Rsp [2]);
  ((Wrd108.pObj) [3]) = (Wrd107.Obj);
  (Rsp [2]) = (Wrd104.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd112.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_26])));
  Rhp += 2;
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd112.pObj)));
  Wrd115 = Wrd112;
  ((Wrd115.pObj) [2]) = (Wrd127.Obj);
  ((Wrd115.pObj) [3]) = (Wrd98.Obj);
  (Rsp [3]) = (Wrd111.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd119.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_29);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_28])));
  Rhp += 2;
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd119.pObj)));
  Wrd122 = Wrd119;
  ((Wrd122.pObj) [2]) = (Wrd127.Obj);
  ((Wrd122.pObj) [3]) = (Wrd98.Obj);
  (Rsp [1]) = (Wrd118.Obj);
  goto label_167;

DEFLABEL (label_170)
  (Wrd132.Obj) = (current_block [OBJECT_14_3]);
  (* (Rhp++)) = (Wrd132.Obj);
  (Wrd130.pObj) = (& (Rhp [-1]));
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd130.pObj)));
  (* (--Rsp)) = (Wrd131.Obj);
  (Wrd133.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd133.Obj);
  (* (Rhp++)) = (Wrd133.Obj);
  (Wrd159.pObj) = (& (Rhp [-1]));
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd159.pObj)));
  (Rsp [1]) = (Wrd160.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd138.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_18])));
  Rhp += 2;
  (Wrd137.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd138.pObj)));
  Wrd141 = Wrd138;
  (Wrd142.Obj) = (Rsp [3]);
  ((Wrd141.pObj) [2]) = (Wrd142.Obj);
  (Wrd140.Obj) = (Rsp [2]);
  ((Wrd141.pObj) [3]) = (Wrd140.Obj);
  (Rsp [2]) = (Wrd137.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd145.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_20])));
  Rhp += 2;
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd145.pObj)));
  Wrd148 = Wrd145;
  ((Wrd148.pObj) [2]) = (Wrd160.Obj);
  ((Wrd148.pObj) [3]) = (Wrd131.Obj);
  (Rsp [3]) = (Wrd144.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd152.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_22])));
  Rhp += 2;
  (Wrd151.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd152.pObj)));
  Wrd155 = Wrd152;
  ((Wrd155.pObj) [2]) = (Wrd160.Obj);
  ((Wrd155.pObj) [3]) = (Wrd131.Obj);
  (Rsp [1]) = (Wrd151.Obj);
  goto label_167;

DEFLABEL (label_171)
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd163.pObj) = (& (Rhp [-1]));
  (Wrd164.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd163.pObj)));
  (* (--Rsp)) = (Wrd164.Obj);
  (Wrd166.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd166.Obj);
  (* (Rhp++)) = (Wrd166.Obj);
  (Wrd192.pObj) = (& (Rhp [-1]));
  (Wrd193.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd192.pObj)));
  (Rsp [1]) = (Wrd193.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd171.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_12])));
  Rhp += 2;
  (Wrd170.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd171.pObj)));
  Wrd174 = Wrd171;
  (Wrd175.Obj) = (Rsp [3]);
  ((Wrd174.pObj) [2]) = (Wrd175.Obj);
  (Wrd173.Obj) = (Rsp [2]);
  ((Wrd174.pObj) [3]) = (Wrd173.Obj);
  (Rsp [2]) = (Wrd170.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd178.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_14])));
  Rhp += 2;
  (Wrd177.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd178.pObj)));
  Wrd181 = Wrd178;
  ((Wrd181.pObj) [2]) = (Wrd193.Obj);
  ((Wrd181.pObj) [3]) = (Wrd164.Obj);
  (Rsp [3]) = (Wrd177.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd185.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_16])));
  Rhp += 2;
  (Wrd184.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd185.pObj)));
  Wrd188 = Wrd185;
  ((Wrd188.pObj) [2]) = (Wrd193.Obj);
  ((Wrd188.pObj) [3]) = (Wrd164.Obj);
  (Rsp [1]) = (Wrd184.Obj);
  goto label_167;

DEFLABEL (label_172)
  (Wrd198.Obj) = (current_block [OBJECT_14_3]);
  (* (Rhp++)) = (Wrd198.Obj);
  (Wrd196.pObj) = (& (Rhp [-1]));
  (Wrd197.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd196.pObj)));
  (* (--Rsp)) = (Wrd197.Obj);
  (Wrd199.Obj) = (MAKE_OBJECT (50, 0));
  (Rsp [1]) = (Wrd199.Obj);
  (* (Rhp++)) = (Wrd199.Obj);
  (Wrd225.pObj) = (& (Rhp [-1]));
  (Wrd226.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd225.pObj)));
  (Rsp [1]) = (Wrd226.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd204.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_6])));
  Rhp += 2;
  (Wrd203.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd204.pObj)));
  Wrd207 = Wrd204;
  (Wrd208.Obj) = (Rsp [3]);
  ((Wrd207.pObj) [2]) = (Wrd208.Obj);
  (Wrd206.Obj) = (Rsp [2]);
  ((Wrd207.pObj) [3]) = (Wrd206.Obj);
  (Rsp [2]) = (Wrd203.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd211.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_8])));
  Rhp += 2;
  (Wrd210.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd211.pObj)));
  Wrd214 = Wrd211;
  ((Wrd214.pObj) [2]) = (Wrd226.Obj);
  ((Wrd214.pObj) [3]) = (Wrd197.Obj);
  (Rsp [3]) = (Wrd210.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd218.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_10])));
  Rhp += 2;
  (Wrd217.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd218.pObj)));
  Wrd221 = Wrd218;
  ((Wrd221.pObj) [2]) = (Wrd226.Obj);
  ((Wrd221.pObj) [3]) = (Wrd197.Obj);
  (Rsp [1]) = (Wrd217.Obj);
  goto label_167;

DEFLABEL (label_174)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_114)
  (* (--Rsp)) = Rvl;
  goto label_173;

DEFLABEL (lambda_162)
  CLOSURE_HEADER (LABEL_14_36);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_176;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_175)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_176)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_44]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_115)
  (* (--Rsp)) = Rvl;
  goto label_175;

DEFLABEL (lambda_163)
  CLOSURE_HEADER (LABEL_14_38);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_182;

DEFLABEL (label_181)
  Wrd19 = Wrd23;

DEFLABEL (label_180)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_179;

DEFLABEL (label_178)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_177)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_179)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_178;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_47])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_117)
  goto label_177;

DEFLABEL (label_182)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_181;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_46])), (Wrd20.pObj));

DEFLABEL (label_116)
  (Wrd19.Obj) = Rvl;
  goto label_180;

DEFLABEL (lambda_164)
  CLOSURE_HEADER (LABEL_14_40);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_188;

DEFLABEL (label_187)
  Wrd19 = Wrd23;

DEFLABEL (label_186)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_185;

DEFLABEL (label_184)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_183)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_185)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_184;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_49])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_119)
  goto label_183;

DEFLABEL (label_188)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_187;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_48])), (Wrd20.pObj));

DEFLABEL (label_118)
  (Wrd19.Obj) = Rvl;
  goto label_186;

DEFLABEL (lambda_159)
  CLOSURE_HEADER (LABEL_14_30);

DEFLABEL (lambda_33)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_190;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_189)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_190)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_50]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_120)
  (* (--Rsp)) = Rvl;
  goto label_189;

DEFLABEL (lambda_160)
  CLOSURE_HEADER (LABEL_14_32);

DEFLABEL (lambda_40)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_196;

DEFLABEL (label_195)
  Wrd19 = Wrd23;

DEFLABEL (label_194)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_193;

DEFLABEL (label_192)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_191)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_193)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_192;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_52])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_122)
  goto label_191;

DEFLABEL (label_196)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_195;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_51])), (Wrd20.pObj));

DEFLABEL (label_121)
  (Wrd19.Obj) = Rvl;
  goto label_194;

DEFLABEL (lambda_161)
  CLOSURE_HEADER (LABEL_14_34);

DEFLABEL (lambda_31)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_202;

DEFLABEL (label_201)
  Wrd19 = Wrd23;

DEFLABEL (label_200)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_199;

DEFLABEL (label_198)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_197)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_199)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_198;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_54])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_124)
  goto label_197;

DEFLABEL (label_202)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_201;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_53])), (Wrd20.pObj));

DEFLABEL (label_123)
  (Wrd19.Obj) = Rvl;
  goto label_200;

DEFLABEL (lambda_156)
  CLOSURE_HEADER (LABEL_14_24);

DEFLABEL (lambda_50)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_204;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_203)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_204)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_55]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_125)
  (* (--Rsp)) = Rvl;
  goto label_203;

DEFLABEL (lambda_157)
  CLOSURE_HEADER (LABEL_14_26);

DEFLABEL (lambda_57)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_210;

DEFLABEL (label_209)
  Wrd19 = Wrd23;

DEFLABEL (label_208)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_207;

DEFLABEL (label_206)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_205)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_207)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_206;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_57])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_127)
  goto label_205;

DEFLABEL (label_210)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_209;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_56])), (Wrd20.pObj));

DEFLABEL (label_126)
  (Wrd19.Obj) = Rvl;
  goto label_208;

DEFLABEL (lambda_158)
  CLOSURE_HEADER (LABEL_14_28);

DEFLABEL (lambda_48)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_216;

DEFLABEL (label_215)
  Wrd19 = Wrd23;

DEFLABEL (label_214)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_213;

DEFLABEL (label_212)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_211)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_213)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_212;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_59])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_129)
  goto label_211;

DEFLABEL (label_216)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_215;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_58])), (Wrd20.pObj));

DEFLABEL (label_128)
  (Wrd19.Obj) = Rvl;
  goto label_214;

DEFLABEL (lambda_153)
  CLOSURE_HEADER (LABEL_14_18);

DEFLABEL (lambda_67)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_218;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_217)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_218)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_60]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_130)
  (* (--Rsp)) = Rvl;
  goto label_217;

DEFLABEL (lambda_154)
  CLOSURE_HEADER (LABEL_14_20);

DEFLABEL (lambda_74)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_224;

DEFLABEL (label_223)
  Wrd19 = Wrd23;

DEFLABEL (label_222)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_221;

DEFLABEL (label_220)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_219)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_221)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_220;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_62])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_132)
  goto label_219;

DEFLABEL (label_224)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_223;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_61])), (Wrd20.pObj));

DEFLABEL (label_131)
  (Wrd19.Obj) = Rvl;
  goto label_222;

DEFLABEL (lambda_155)
  CLOSURE_HEADER (LABEL_14_22);

DEFLABEL (lambda_65)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_230;

DEFLABEL (label_229)
  Wrd19 = Wrd23;

DEFLABEL (label_228)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_227;

DEFLABEL (label_226)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_225)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_227)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_226;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_64])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_134)
  goto label_225;

DEFLABEL (label_230)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_229;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_63])), (Wrd20.pObj));

DEFLABEL (label_133)
  (Wrd19.Obj) = Rvl;
  goto label_228;

DEFLABEL (lambda_150)
  CLOSURE_HEADER (LABEL_14_12);

DEFLABEL (lambda_84)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_232;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_231)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_232)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_65]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_135)
  (* (--Rsp)) = Rvl;
  goto label_231;

DEFLABEL (lambda_151)
  CLOSURE_HEADER (LABEL_14_14);

DEFLABEL (lambda_91)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_238;

DEFLABEL (label_237)
  Wrd19 = Wrd23;

DEFLABEL (label_236)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_235;

DEFLABEL (label_234)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_233)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_235)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_234;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_67])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_137)
  goto label_233;

DEFLABEL (label_238)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_237;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_66])), (Wrd20.pObj));

DEFLABEL (label_136)
  (Wrd19.Obj) = Rvl;
  goto label_236;

DEFLABEL (lambda_152)
  CLOSURE_HEADER (LABEL_14_16);

DEFLABEL (lambda_82)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_244;

DEFLABEL (label_243)
  Wrd19 = Wrd23;

DEFLABEL (label_242)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_241;

DEFLABEL (label_240)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_239)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_241)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_240;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_69])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_139)
  goto label_239;

DEFLABEL (label_244)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_243;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_68])), (Wrd20.pObj));

DEFLABEL (label_138)
  (Wrd19.Obj) = Rvl;
  goto label_242;

DEFLABEL (lambda_147)
  CLOSURE_HEADER (LABEL_14_6);

DEFLABEL (lambda_101)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_246;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_245)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [2]);
  (Rsp [1]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_45]));

DEFLABEL (label_246)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_70]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_10]), 1);

DEFLABEL (label_140)
  (* (--Rsp)) = Rvl;
  goto label_245;

DEFLABEL (lambda_148)
  CLOSURE_HEADER (LABEL_14_8);

DEFLABEL (lambda_108)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_252;

DEFLABEL (label_251)
  Wrd19 = Wrd23;

DEFLABEL (label_250)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_249;

DEFLABEL (label_248)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_247)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_249)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_248;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_72])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_142)
  goto label_247;

DEFLABEL (label_252)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_251;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_71])), (Wrd20.pObj));

DEFLABEL (label_141)
  (Wrd19.Obj) = Rvl;
  goto label_250;

DEFLABEL (lambda_149)
  CLOSURE_HEADER (LABEL_14_10);

DEFLABEL (lambda_99)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_2]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_258;

DEFLABEL (label_257)
  Wrd19 = Wrd23;

DEFLABEL (label_256)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_2]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_255;

DEFLABEL (label_254)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_253)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_11]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_255)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_254;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_74])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_144)
  goto label_253;

DEFLABEL (label_258)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_257;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_73])), (Wrd20.pObj));

DEFLABEL (label_143)
  (Wrd19.Obj) = Rvl;
  goto label_256;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define LABEL_15_7 7
#define LABEL_15_9 9
#define ENVIRONMENT_LABEL_15_3 19
#define DEBUGGING_LABEL_15_2 18
#define OBJECT_15_0 17
#define EXECUTE_CACHE_15_10 11
#define EXECUTE_CACHE_15_8 13
#define EXECUTE_CACHE_15_6 15
#define FREE_REFERENCES_LABEL_15_0 10
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto variable_unreferencedP_3;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_15_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_15_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (variable_unreferencedP_6)
DEFLABEL (variable_unreferencedP_3)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_15_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_15_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_9;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_15_0]);

DEFLABEL (label_9)
DEFLABEL (label_11)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define ENVIRONMENT_LABEL_16_3 12
#define DEBUGGING_LABEL_16_2 11
#define EXECUTE_CACHE_16_7 7
#define EXECUTE_CACHE_16_6 9
#define FREE_REFERENCES_LABEL_16_0 6
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define LABEL_17_6 7
#define LABEL_17_7 9
#define LABEL_17_8 11
#define LABEL_17_9 13
#define LABEL_17_10 15
#define LABEL_17_11 17
#define TAG_17_12 7
#define LABEL_17_18 19
#define LABEL_17_13 21
#define TAG_17_14 9
#define LABEL_17_22 23
#define LABEL_17_23 25
#define LABEL_17_15 27
#define TAG_17_16 12
#define LABEL_17_24 29
#define LABEL_17_25 31
#define LABEL_17_19 33
#define TAG_17_20 15
#define LABEL_17_27 35
#define LABEL_17_29 37
#define LABEL_17_33 39
#define LABEL_17_26 41
#define LABEL_17_34 43
#define LABEL_17_35 45
#define LABEL_17_36 47
#define LABEL_17_37 49
#define LABEL_17_28 51
#define LABEL_17_30 53
#define LABEL_17_31 55
#define LABEL_17_39 57
#define LABEL_17_46 59
#define LABEL_17_47 61
#define LABEL_17_49 63
#define LABEL_17_51 65
#define LABEL_17_52 67
#define LABEL_17_53 69
#define LABEL_17_54 71
#define LABEL_17_41 73
#define LABEL_17_48 75
#define LABEL_17_57 77
#define LABEL_17_58 79
#define LABEL_17_62 81
#define LABEL_17_55 83
#define LABEL_17_59 85
#define LABEL_17_66 87
#define LABEL_17_67 89
#define LABEL_17_60 91
#define LABEL_17_61 93
#define LABEL_17_70 95
#define LABEL_17_71 97
#define LABEL_17_64 99
#define LABEL_17_73 101
#define LABEL_17_74 103
#define LABEL_17_69 105
#define ENVIRONMENT_LABEL_17_3 160
#define DEBUGGING_LABEL_17_2 159
#define OBJECT_17_10 158
#define OBJECT_17_9 157
#define OBJECT_17_8 156
#define OBJECT_17_7 155
#define OBJECT_17_6 154
#define OBJECT_17_5 153
#define OBJECT_17_4 152
#define OBJECT_17_3 151
#define OBJECT_17_2 150
#define OBJECT_17_1 149
#define OBJECT_17_0 148
#define EXECUTE_CACHE_17_76 107
#define EXECUTE_CACHE_17_75 109
#define EXECUTE_CACHE_17_72 111
#define EXECUTE_CACHE_17_68 113
#define EXECUTE_CACHE_17_65 115
#define EXECUTE_CACHE_17_63 117
#define EXECUTE_CACHE_17_56 119
#define EXECUTE_CACHE_17_50 121
#define EXECUTE_CACHE_17_45 123
#define EXECUTE_CACHE_17_44 125
#define EXECUTE_CACHE_17_43 127
#define EXECUTE_CACHE_17_40 129
#define EXECUTE_CACHE_17_38 131
#define EXECUTE_CACHE_17_42 133
#define EXECUTE_CACHE_17_32 135
#define EXECUTE_CACHE_17_21 137
#define EXECUTE_CACHE_17_17 139
#define FREE_REFERENCE_17_3 142
#define FREE_REFERENCE_17_2 143
#define FREE_REFERENCE_17_1 144
#define FREE_REFERENCE_17_0 145
#define FREE_ASSIGNMENT_17_0 147
#define FREE_REFERENCES_LABEL_17_0 106
#define NUMBER_OF_LINKER_SECTIONS_17_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd83;
  machine_word Wrd77;
  machine_word Wrd218;
  machine_word Wrd220;
  machine_word Wrd219;
  machine_word Wrd217;
  machine_word Wrd41;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd106;
  machine_word Wrd101;
  machine_word Wrd86;
  machine_word Wrd98;
  machine_word Wrd157;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd142;
  machine_word Wrd148;
  machine_word Wrd147;
  machine_word Wrd146;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd139;
  machine_word Wrd10;
  machine_word Wrd216;
  machine_word Wrd213;
  machine_word Wrd210;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd197;
  machine_word Wrd205;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd209;
  machine_word Wrd208;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd186;
  machine_word Wrd183;
  machine_word Wrd185;
  machine_word Wrd184;
  machine_word Wrd170;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd165;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd160;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd108;
  machine_word Wrd82;
  machine_word Wrd72;
  machine_word Wrd66;
  machine_word Wrd38;
  machine_word Wrd125;
  machine_word Wrd118;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd84;
  machine_word Wrd73;
  machine_word Wrd78;
  machine_word Wrd85;
  machine_word Wrd69;
  machine_word Wrd67;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd40;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd35;
  machine_word Wrd51;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd9;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd130;
  machine_word Wrd126;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd119;
  machine_word Wrd120;
  machine_word Wrd105;
  machine_word Wrd107;
  machine_word Wrd109;
  machine_word Wrd111;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd102;
  machine_word Wrd103;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd81;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd75;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd76;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd74;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto integrate_procedure_63;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto label_65;

    case 2:
      current_block = (Rpc - LABEL_17_6);
      goto label_66;

    case 3:
      current_block = (Rpc - LABEL_17_7);
      goto label_67;

    case 4:
      current_block = (Rpc - LABEL_17_8);
      goto label_68;

    case 5:
      current_block = (Rpc - LABEL_17_9);
      goto label_69;

    case 6:
      current_block = (Rpc - LABEL_17_10);
      goto label_70;

    case 7:
      current_block = (Rpc - LABEL_17_11);
      goto lambda_100;

    case 8:
      current_block = (Rpc - LABEL_17_18);
      goto label_71;

    case 9:
      current_block = (Rpc - LABEL_17_13);
      goto lambda_101;

    case 10:
      current_block = (Rpc - LABEL_17_22);
      goto label_72;

    case 11:
      current_block = (Rpc - LABEL_17_23);
      goto label_73;

    case 12:
      current_block = (Rpc - LABEL_17_15);
      goto lambda_102;

    case 13:
      current_block = (Rpc - LABEL_17_24);
      goto label_74;

    case 14:
      current_block = (Rpc - LABEL_17_25);
      goto label_75;

    case 15:
      current_block = (Rpc - LABEL_17_19);
      goto lambda_103;

    case 16:
      current_block = (Rpc - LABEL_17_27);
      goto label_76;

    case 17:
      current_block = (Rpc - LABEL_17_29);
      goto label_77;

    case 18:
      current_block = (Rpc - LABEL_17_33);
      goto continuation_27;

    case 19:
      current_block = (Rpc - LABEL_17_26);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_17_34);
      goto label_81;

    case 21:
      current_block = (Rpc - LABEL_17_35);
      goto label_78;

    case 22:
      current_block = (Rpc - LABEL_17_36);
      goto label_79;

    case 23:
      current_block = (Rpc - LABEL_17_37);
      goto label_80;

    case 24:
      current_block = (Rpc - LABEL_17_28);
      goto continuation_18;

    case 25:
      current_block = (Rpc - LABEL_17_30);
      goto continuation_16;

    case 26:
      current_block = (Rpc - LABEL_17_31);
      goto continuation_15;

    case 27:
      current_block = (Rpc - LABEL_17_39);
      goto continuation_30;

    case 28:
      current_block = (Rpc - LABEL_17_46);
      goto label_87;

    case 29:
      current_block = (Rpc - LABEL_17_47);
      goto label_88;

    case 30:
      current_block = (Rpc - LABEL_17_49);
      goto label_86;

    case 31:
      current_block = (Rpc - LABEL_17_51);
      goto label_84;

    case 32:
      current_block = (Rpc - LABEL_17_52);
      goto label_85;

    case 33:
      current_block = (Rpc - LABEL_17_53);
      goto label_82;

    case 34:
      current_block = (Rpc - LABEL_17_54);
      goto label_83;

    case 35:
      current_block = (Rpc - LABEL_17_41);
      goto continuation_25;

    case 36:
      current_block = (Rpc - LABEL_17_48);
      goto continuation_40;

    case 37:
      current_block = (Rpc - LABEL_17_57);
      goto label_90;

    case 38:
      current_block = (Rpc - LABEL_17_58);
      goto label_91;

    case 39:
      current_block = (Rpc - LABEL_17_62);
      goto label_89;

    case 40:
      current_block = (Rpc - LABEL_17_55);
      goto lambda_24;

    case 41:
      current_block = (Rpc - LABEL_17_59);
      goto continuation_48;

    case 42:
      current_block = (Rpc - LABEL_17_66);
      goto label_92;

    case 43:
      current_block = (Rpc - LABEL_17_67);
      goto label_93;

    case 44:
      current_block = (Rpc - LABEL_17_60);
      goto continuation_47;

    case 45:
      current_block = (Rpc - LABEL_17_61);
      goto continuation_46;

    case 46:
      current_block = (Rpc - LABEL_17_70);
      goto label_94;

    case 47:
      current_block = (Rpc - LABEL_17_71);
      goto label_95;

    case 48:
      current_block = (Rpc - LABEL_17_64);
      goto continuation_22;

    case 49:
      current_block = (Rpc - LABEL_17_73);
      goto label_96;

    case 50:
      current_block = (Rpc - LABEL_17_74);
      goto label_97;

    case 51:
      current_block = (Rpc - LABEL_17_69);
      goto continuation_44;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_procedure_99)
DEFLABEL (integrate_procedure_63)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_116;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_116;
  (Wrd7.Obj) = ((Wrd11.pObj) [7]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_115)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_114;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd29.Lng))))
    goto label_114;
  (Wrd23.Obj) = ((Wrd27.pObj) [6]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_113)
  (Wrd46.Obj) = (Rsp [4]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_112;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_112;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_111)
  (Wrd62.Obj) = (Rsp [5]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_110;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_110;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_109)
  (Wrd74.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd70.pObj) = (& (Rhp [-1]));
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd70.pObj)));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd76.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd79.Obj) = ((Wrd76.pObj) [0]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if ((Wrd80.uLng) == 50)
    goto label_108;
  Wrd75 = Wrd79;

DEFLABEL (label_107)
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd90.Obj) = (Rsp [8]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd91.uLng) == 10))
    goto label_106;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd88.Obj) = ((Wrd87.pObj) [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd89.Lng))))
    goto label_106;
  (Wrd81.Obj) = ((Wrd87.pObj) [4]);

DEFLABEL (label_105)
  (Wrd97.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd81.Obj);
  (* (Rhp++)) = (Wrd97.Obj);
  (Wrd99.pObj) = (& (Rhp [-2]));
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd99.pObj)));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd100.Obj);
  (Wrd134.pObj) = (& (Rhp [-1]));
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd134.pObj)));
  (Rsp [0]) = (Wrd135.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 10));
  (Wrd103.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_17_11])));
  Rhp += 7;
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd103.pObj)));
  Wrd116 = Wrd103;
  (Wrd117.Obj) = (Rsp [8]);
  ((Wrd116.pObj) [2]) = (Wrd117.Obj);
  (Wrd115.Obj) = (Rsp [7]);
  ((Wrd116.pObj) [3]) = (Wrd115.Obj);
  (Wrd113.Obj) = (Rsp [6]);
  ((Wrd116.pObj) [4]) = (Wrd113.Obj);
  (Wrd111.Obj) = (Rsp [5]);
  ((Wrd116.pObj) [5]) = (Wrd111.Obj);
  (Wrd109.Obj) = (Rsp [4]);
  ((Wrd116.pObj) [6]) = (Wrd109.Obj);
  (Wrd107.Obj) = (Rsp [3]);
  ((Wrd116.pObj) [7]) = (Wrd107.Obj);
  (Wrd105.Obj) = (Rsp [2]);
  ((Wrd116.pObj) [8]) = (Wrd105.Obj);
  (Rsp [7]) = (Wrd102.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd120.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_17_13])));
  Rhp += 2;
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd120.pObj)));
  Wrd123 = Wrd120;
  (Wrd124.Obj) = (Rsp [1]);
  ((Wrd123.pObj) [2]) = (Wrd124.Obj);
  ((Wrd123.pObj) [3]) = (Wrd135.Obj);
  (Rsp [6]) = (Wrd119.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd127.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_17_15])));
  Rhp += 2;
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd127.pObj)));
  Wrd130 = Wrd127;
  ((Wrd130.pObj) [2]) = (Wrd124.Obj);
  ((Wrd130.pObj) [3]) = (Wrd135.Obj);
  (Rsp [8]) = (Wrd126.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_17]));

DEFLABEL (label_106)
  (Wrd92.Obj) = (Rsp [8]);
  (Wrd93.Obj) = (current_block [OBJECT_17_5]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_10]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_70)
  (Wrd81.Obj) = Rvl;
  goto label_105;

DEFLABEL (label_108)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_9])), (Wrd76.pObj));

DEFLABEL (label_69)
  (Wrd75.Obj) = Rvl;
  goto label_107;

DEFLABEL (label_110)
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.Obj) = (current_block [OBJECT_17_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_8]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_68)
  (* (--Rsp)) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.Obj) = (current_block [OBJECT_17_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_67)
  (* (--Rsp)) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (current_block [OBJECT_17_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_66)
  (* (--Rsp)) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_17_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_65)
  (* (--Rsp)) = Rvl;
  goto label_115;

DEFLABEL (lambda_100)
  CLOSURE_HEADER (LABEL_17_11);

DEFLABEL (lambda_53)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [8]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_118;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd17.Lng))))
    goto label_118;
  (Wrd9.Obj) = ((Wrd15.pObj) [7]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_117)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 10));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_17_19])));
  Rhp += 7;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd56 = Wrd31;
  (Wrd57.Obj) = (Rsp [1]);
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [2]);
  ((Wrd56.pObj) [2]) = (Wrd59.Obj);
  (Wrd55.Obj) = ((Wrd58.pObj) [3]);
  ((Wrd56.pObj) [3]) = (Wrd55.Obj);
  (Wrd51.Obj) = ((Wrd58.pObj) [4]);
  ((Wrd56.pObj) [4]) = (Wrd51.Obj);
  (Wrd47.Obj) = ((Wrd58.pObj) [5]);
  ((Wrd56.pObj) [5]) = (Wrd47.Obj);
  (Wrd43.Obj) = ((Wrd58.pObj) [6]);
  ((Wrd56.pObj) [6]) = (Wrd43.Obj);
  (Wrd39.Obj) = ((Wrd58.pObj) [7]);
  ((Wrd56.pObj) [7]) = (Wrd39.Obj);
  (Wrd35.Obj) = ((Wrd58.pObj) [8]);
  ((Wrd56.pObj) [8]) = (Wrd35.Obj);
  (Rsp [1]) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_21]));

DEFLABEL (label_118)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [8]);
  (Wrd25.Obj) = (current_block [OBJECT_17_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_18]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_117;

DEFLABEL (lambda_101)
  CLOSURE_HEADER (LABEL_17_13);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_124;

DEFLABEL (label_123)
  Wrd19 = Wrd23;

DEFLABEL (label_122)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_17_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_121;

DEFLABEL (label_120)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_119)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_17_6]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_121)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_120;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_17_23])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_73)
  goto label_119;

DEFLABEL (label_124)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_123;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_17_22])), (Wrd20.pObj));

DEFLABEL (label_72)
  (Wrd19.Obj) = Rvl;
  goto label_122;

DEFLABEL (lambda_102)
  CLOSURE_HEADER (LABEL_17_15);

DEFLABEL (lambda_60)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_130;

DEFLABEL (label_129)
  Wrd19 = Wrd23;

DEFLABEL (label_128)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_17_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_127;

DEFLABEL (label_126)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_125)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_17_6]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_127)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_126;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_17_25])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_75)
  goto label_125;

DEFLABEL (label_130)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_129;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_17_24])), (Wrd20.pObj));

DEFLABEL (label_74)
  (Wrd19.Obj) = Rvl;
  goto label_128;

DEFLABEL (lambda_103)
  CLOSURE_HEADER (LABEL_17_19);

DEFLABEL (lambda_52)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_164;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd20.Lng))))
    goto label_164;
  (Wrd12.Obj) = ((Wrd18.pObj) [8]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_163)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [3]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_28]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd53.Obj) = ((Wrd33.pObj) [8]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 10))
    goto label_162;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd50.Lng))))
    goto label_162;
  (Wrd42.Obj) = ((Wrd48.pObj) [5]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_161)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_30]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_31]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd68.Obj) = (Rsp [7]);
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd70.Obj) = ((Wrd69.pObj) [5]);
  if ((Wrd70.Obj) == ((SCHEME_OBJECT) 0))
    goto label_132;
  (Wrd78.Obj) = (current_block [OBJECT_17_8]);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd73.pObj) = (& (Rhp [-2]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd73.pObj)));
  (* (--Rsp)) = (Wrd74.Obj);
  goto label_131;

DEFLABEL (label_132)
  (Wrd85.Obj) = (current_block [OBJECT_17_8]);
  (* (--Rsp)) = (Wrd85.Obj);

DEFLABEL (label_131)
DEFLABEL (label_160)
  (Wrd79.Obj) = (Rsp [8]);
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd81.Obj) = ((Wrd80.pObj) [6]);
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd84.Obj) = ((Wrd80.pObj) [7]);
  (* (--Rsp)) = (Wrd84.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_32]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_17_31);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [7]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_45]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_17_30);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_44]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_17_28);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_43]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_17_26);
  (* (--Rsp)) = Rvl;
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd121.pObj) = (OBJECT_ADDRESS (Wrd120.Obj));
  (Wrd122.Obj) = ((Wrd121.pObj) [8]);
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if (! ((Wrd123.uLng) == 10))
    goto label_159;
  (Wrd117.pObj) = (OBJECT_ADDRESS (Wrd122.Obj));
  (Wrd118.Obj) = ((Wrd117.pObj) [0]);
  (Wrd119.Lng) = (FIXNUM_TO_LONG (Wrd118.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd119.Lng))))
    goto label_159;
  (Wrd9.Obj) = ((Wrd117.pObj) [4]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_156;

DEFLABEL (label_158)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_33]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_41]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (Wrd89.Obj) = (Rsp [3]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [5]);
  if ((Wrd91.Obj) == ((SCHEME_OBJECT) 0))
    goto label_157;
  (Wrd99.Obj) = (current_block [OBJECT_17_8]);
  (* (Rhp++)) = (Wrd91.Obj);
  (* (Rhp++)) = (Wrd99.Obj);
  (Wrd94.pObj) = (& (Rhp [-2]));
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd94.pObj)));
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd102.Obj) = ((Wrd90.pObj) [6]);
  (* (--Rsp)) = (Wrd102.Obj);
  (Wrd105.Obj) = ((Wrd90.pObj) [7]);
  (* (--Rsp)) = (Wrd105.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_32]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_17_41);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_55]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_56]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_17_33);

DEFLABEL (label_156)
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_155;
  Wrd11 = Wrd15;

DEFLABEL (label_154)
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_149;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_39]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_40]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_17_39);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_145;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [6]);
  (Wrd10.Obj) = (current_block [OBJECT_17_8]);
  if ((Wrd9.Obj) == (Wrd10.Obj))
    goto label_138;
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = ((Wrd8.pObj) [7]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd32.Obj) = ((Wrd8.pObj) [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_137;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd29.Lng))))
    goto label_137;
  (Wrd21.Obj) = ((Wrd27.pObj) [4]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_136)
  (Wrd41.Obj) = (Rsp [4]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [8]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd59.Obj) = ((Wrd42.pObj) [2]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 10))
    goto label_134;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd56.Lng))))
    goto label_134;
  (Wrd48.Obj) = ((Wrd54.pObj) [2]);
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_133)
  (Wrd217.Obj) = (Rsp [5]);
  (Wrd219.Obj) = (Rsp [6]);
  (Wrd220.pObj) = (OBJECT_ADDRESS (Wrd219.Obj));
  (Wrd218.Obj) = ((Wrd220.pObj) [5]);
  (Rsp [5]) = (Wrd218.Obj);
  (Rsp [6]) = (Wrd217.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_38]));

DEFLABEL (label_134)
  (Wrd62.Obj) = (Rsp [5]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd61.Obj) = ((Wrd63.pObj) [2]);
  (Wrd64.Obj) = (current_block [OBJECT_17_9]);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_54]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_83)
DEFLABEL (label_135)
  (* (--Rsp)) = Rvl;
  goto label_133;

DEFLABEL (label_137)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [2]);
  (Wrd37.Obj) = (current_block [OBJECT_17_5]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_53]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_82)
  (* (--Rsp)) = Rvl;
  goto label_136;

DEFLABEL (label_138)
  (Wrd74.Obj) = ((Wrd8.pObj) [5]);
  if ((Wrd74.Obj) == (Wrd10.Obj))
    goto label_142;
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd81.Obj) = ((Wrd8.pObj) [7]);
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd97.Obj) = ((Wrd8.pObj) [2]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd98.uLng) == 10))
    goto label_141;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd94.Lng))))
    goto label_141;
  (Wrd86.Obj) = ((Wrd92.pObj) [4]);
  (* (--Rsp)) = (Wrd86.Obj);

DEFLABEL (label_140)
  (Wrd106.Obj) = (Rsp [4]);
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [8]);
  (* (--Rsp)) = (Wrd108.Obj);
  (Wrd124.Obj) = ((Wrd107.pObj) [2]);
  (Wrd125.uLng) = (OBJECT_TYPE (Wrd124.Obj));
  if (! ((Wrd125.uLng) == 10))
    goto label_139;
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd124.Obj));
  (Wrd120.Obj) = ((Wrd119.pObj) [0]);
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd120.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd121.Lng))))
    goto label_139;
  (Wrd113.Obj) = ((Wrd119.pObj) [2]);
  (* (--Rsp)) = (Wrd113.Obj);
  goto label_133;

DEFLABEL (label_139)
  (Wrd127.Obj) = (Rsp [5]);
  (Wrd128.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd126.Obj) = ((Wrd128.pObj) [2]);
  (Wrd129.Obj) = (current_block [OBJECT_17_9]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_52]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd126.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_85)
  goto label_135;

DEFLABEL (label_141)
  (Wrd100.Obj) = (Rsp [3]);
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd99.Obj) = ((Wrd101.pObj) [2]);
  (Wrd102.Obj) = (current_block [OBJECT_17_5]);
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_51]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_84)
  (* (--Rsp)) = Rvl;
  goto label_140;

DEFLABEL (label_142)
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_48]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (Wrd149.Obj) = (Rsp [1]);
  (Wrd150.uLng) = (OBJECT_TYPE (Wrd149.Obj));
  if (! ((Wrd150.uLng) == 10))
    goto label_144;
  (Wrd146.pObj) = (OBJECT_ADDRESS (Wrd149.Obj));
  (Wrd147.Obj) = ((Wrd146.pObj) [0]);
  (Wrd148.Lng) = (FIXNUM_TO_LONG (Wrd147.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd148.Lng))))
    goto label_144;
  (Wrd142.Obj) = ((Wrd146.pObj) [5]);
  (* (--Rsp)) = (Wrd142.Obj);

DEFLABEL (label_143)
  (Wrd156.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd156.Obj);
  (Wrd158.Obj) = (Rsp [4]);
  (Wrd159.pObj) = (OBJECT_ADDRESS (Wrd158.Obj));
  (Wrd157.Obj) = ((Wrd159.pObj) [7]);
  (Rsp [1]) = (Wrd157.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_50]));

DEFLABEL (label_144)
  (Wrd151.Obj) = (Rsp [1]);
  (Wrd152.Obj) = (current_block [OBJECT_17_3]);
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_49]))));
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd152.Obj);
  (* (--Rsp)) = (Wrd151.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_86)
  (* (--Rsp)) = Rvl;
  goto label_143;

DEFLABEL (label_145)
  (Wrd160.Obj) = (Rsp [1]);
  (Wrd161.pObj) = (OBJECT_ADDRESS (Wrd160.Obj));
  (Wrd162.Obj) = ((Wrd161.pObj) [6]);
  (* (--Rsp)) = (Wrd162.Obj);
  (Wrd165.Obj) = ((Wrd161.pObj) [7]);
  (* (--Rsp)) = (Wrd165.Obj);
  (Wrd181.Obj) = ((Wrd161.pObj) [2]);
  (Wrd182.uLng) = (OBJECT_TYPE (Wrd181.Obj));
  if (! ((Wrd182.uLng) == 10))
    goto label_148;
  (Wrd176.pObj) = (OBJECT_ADDRESS (Wrd181.Obj));
  (Wrd177.Obj) = ((Wrd176.pObj) [0]);
  (Wrd178.Lng) = (FIXNUM_TO_LONG (Wrd177.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd178.Lng))))
    goto label_148;
  (Wrd170.Obj) = ((Wrd176.pObj) [4]);
  (* (--Rsp)) = (Wrd170.Obj);

DEFLABEL (label_147)
  (Wrd190.Obj) = (Rsp [4]);
  (Wrd191.pObj) = (OBJECT_ADDRESS (Wrd190.Obj));
  (Wrd192.Obj) = ((Wrd191.pObj) [8]);
  (* (--Rsp)) = (Wrd192.Obj);
  (Wrd208.Obj) = ((Wrd191.pObj) [2]);
  (Wrd209.uLng) = (OBJECT_TYPE (Wrd208.Obj));
  if (! ((Wrd209.uLng) == 10))
    goto label_146;
  (Wrd203.pObj) = (OBJECT_ADDRESS (Wrd208.Obj));
  (Wrd204.Obj) = ((Wrd203.pObj) [0]);
  (Wrd205.Lng) = (FIXNUM_TO_LONG (Wrd204.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd205.Lng))))
    goto label_146;
  (Wrd197.Obj) = ((Wrd203.pObj) [2]);
  (* (--Rsp)) = (Wrd197.Obj);
  goto label_133;

DEFLABEL (label_146)
  (Wrd211.Obj) = (Rsp [5]);
  (Wrd212.pObj) = (OBJECT_ADDRESS (Wrd211.Obj));
  (Wrd210.Obj) = ((Wrd212.pObj) [2]);
  (Wrd213.Obj) = (current_block [OBJECT_17_9]);
  (Wrd216.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_47]))));
  (* (--Rsp)) = (Wrd216.Obj);
  (* (--Rsp)) = (Wrd213.Obj);
  (* (--Rsp)) = (Wrd210.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_88)
  goto label_135;

DEFLABEL (label_148)
  (Wrd184.Obj) = (Rsp [3]);
  (Wrd185.pObj) = (OBJECT_ADDRESS (Wrd184.Obj));
  (Wrd183.Obj) = ((Wrd185.pObj) [2]);
  (Wrd186.Obj) = (current_block [OBJECT_17_5]);
  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_46]))));
  (* (--Rsp)) = (Wrd189.Obj);
  (* (--Rsp)) = (Wrd186.Obj);
  (* (--Rsp)) = (Wrd183.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_87)
  (* (--Rsp)) = Rvl;
  goto label_147;

DEFLABEL (label_149)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [6]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = ((Wrd23.pObj) [7]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = ((Wrd23.pObj) [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_153;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd40.Lng))))
    goto label_153;
  (Wrd32.Obj) = ((Wrd38.pObj) [4]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_152)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [8]);
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd70.Obj) = ((Wrd53.pObj) [2]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 10))
    goto label_151;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd67.Lng))))
    goto label_151;
  (Wrd59.Obj) = ((Wrd65.pObj) [2]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_150)
  (Wrd79.Obj) = (Rsp [5]);
  (Wrd81.Obj) = (Rsp [6]);
  (Wrd82.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd80.Obj) = ((Wrd82.pObj) [5]);
  (Rsp [5]) = (Wrd80.Obj);
  (Rsp [6]) = (Wrd79.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_38]));

DEFLABEL (label_151)
  (Wrd73.Obj) = (Rsp [5]);
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd72.Obj) = ((Wrd74.pObj) [2]);
  (Wrd75.Obj) = (current_block [OBJECT_17_9]);
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_37]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_80)
  (* (--Rsp)) = Rvl;
  goto label_150;

DEFLABEL (label_153)
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [2]);
  (Wrd48.Obj) = (current_block [OBJECT_17_5]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_36]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_79)
  (* (--Rsp)) = Rvl;
  goto label_152;

DEFLABEL (label_155)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_35])), (Wrd12.pObj));

DEFLABEL (label_78)
  (Wrd11.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  (Wrd108.Obj) = ((Wrd90.pObj) [6]);
  (* (--Rsp)) = (Wrd108.Obj);
  (Wrd111.Obj) = ((Wrd90.pObj) [7]);
  (* (--Rsp)) = (Wrd111.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_42]));

DEFLABEL (label_159)
  (Wrd125.Obj) = (Rsp [1]);
  (Wrd126.pObj) = (OBJECT_ADDRESS (Wrd125.Obj));
  (Wrd124.Obj) = ((Wrd126.pObj) [8]);
  (Wrd127.Obj) = (current_block [OBJECT_17_5]);
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_34]))));
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  (* (--Rsp)) = (Wrd124.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_81)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_156;
  goto label_158;

DEFLABEL (label_162)
  (Wrd56.Obj) = (Rsp [4]);
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [8]);
  (Wrd58.Obj) = (current_block [OBJECT_17_3]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_29]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_77)
  (* (--Rsp)) = Rvl;
  goto label_161;

DEFLABEL (label_164)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [2]);
  (Wrd28.Obj) = (current_block [OBJECT_17_7]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_27]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_76)
  (* (--Rsp)) = Rvl;
  goto label_163;

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_17_48);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_178;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_59]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_60]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_61]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_177;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd24.Lng))))
    goto label_177;
  (Wrd18.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_176)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_63]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_17_61);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_69]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_175;
  Wrd11 = Wrd15;

DEFLABEL (label_174)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_3]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_173;
  Wrd17 = Wrd21;

DEFLABEL (label_172)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_72]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_17_69);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_76]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_17_60);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_68]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_17_59);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_167;
  (Wrd7.Obj) = (current_block [OBJECT_17_5]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_166;

DEFLABEL (label_165)
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_166)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_165;
  Rvl = ((Wrd15.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_167)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = ((Wrd21.pObj) [7]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd41.Obj) = ((Wrd21.pObj) [2]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 10))
    goto label_171;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd38.Lng))))
    goto label_171;
  (Wrd30.Obj) = ((Wrd36.pObj) [4]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_170)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [8]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd68.Obj) = ((Wrd51.pObj) [2]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_169;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd65.Lng))))
    goto label_169;
  (Wrd57.Obj) = ((Wrd63.pObj) [2]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_168)
  (Wrd77.Obj) = (Rsp [5]);
  (Wrd79.Obj) = (Rsp [6]);
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd78.Obj) = ((Wrd80.pObj) [5]);
  (Rsp [5]) = (Wrd78.Obj);
  (Rsp [6]) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_38]));

DEFLABEL (label_169)
  (Wrd71.Obj) = (Rsp [5]);
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd70.Obj) = ((Wrd72.pObj) [2]);
  (Wrd73.Obj) = (current_block [OBJECT_17_9]);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_67]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_93)
  (* (--Rsp)) = Rvl;
  goto label_168;

DEFLABEL (label_171)
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [2]);
  (Wrd46.Obj) = (current_block [OBJECT_17_5]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_66]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_92)
  (* (--Rsp)) = Rvl;
  goto label_170;

DEFLABEL (label_173)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_71])), (Wrd18.pObj));

DEFLABEL (label_95)
  (Wrd17.Obj) = Rvl;
  goto label_172;

DEFLABEL (label_175)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_70])), (Wrd12.pObj));

DEFLABEL (label_94)
  (Wrd11.Obj) = Rvl;
  goto label_174;

DEFLABEL (label_177)
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.Obj) = (current_block [OBJECT_17_5]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_62]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_89)
  (* (--Rsp)) = Rvl;
  goto label_176;

DEFLABEL (label_178)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [6]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = ((Wrd33.pObj) [7]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd53.Obj) = ((Wrd33.pObj) [2]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 10))
    goto label_182;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd50.Lng))))
    goto label_182;
  (Wrd42.Obj) = ((Wrd48.pObj) [4]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_181)
  (Wrd62.Obj) = (Rsp [4]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [8]);
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd80.Obj) = ((Wrd63.pObj) [2]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 10))
    goto label_180;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd77.Lng))))
    goto label_180;
  (Wrd69.Obj) = ((Wrd75.pObj) [2]);
  (* (--Rsp)) = (Wrd69.Obj);

DEFLABEL (label_179)
  (Wrd89.Obj) = (Rsp [5]);
  (Wrd91.Obj) = (Rsp [6]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [5]);
  (Rsp [5]) = (Wrd90.Obj);
  (Rsp [6]) = (Wrd89.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_38]));

DEFLABEL (label_180)
  (Wrd83.Obj) = (Rsp [5]);
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [2]);
  (Wrd85.Obj) = (current_block [OBJECT_17_9]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_58]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_91)
  (* (--Rsp)) = Rvl;
  goto label_179;

DEFLABEL (label_182)
  (Wrd56.Obj) = (Rsp [3]);
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [2]);
  (Wrd58.Obj) = (current_block [OBJECT_17_5]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_57]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_90)
  (* (--Rsp)) = Rvl;
  goto label_181;

DEFLABEL (lambda_104)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_17_55);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_65]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_17_64);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_183;
  Rvl = (current_block [OBJECT_17_6]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_183)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_187;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_187;
  (Wrd9.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_186)
  (Wrd23.Obj) = (current_block [OBJECT_17_10]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_185;
  Wrd25 = Wrd29;

DEFLABEL (label_184)
  (Rsp [2]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_75]));

DEFLABEL (label_185)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_74])), (Wrd26.pObj));

DEFLABEL (label_97)
  (Wrd25.Obj) = Rvl;
  goto label_184;

DEFLABEL (label_187)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_17_4]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_73]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_96)
  (* (--Rsp)) = Rvl;
  goto label_186;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_6 7
#define LABEL_18_7 9
#define LABEL_18_9 11
#define LABEL_18_10 13
#define LABEL_18_11 15
#define ENVIRONMENT_LABEL_18_3 28
#define DEBUGGING_LABEL_18_2 27
#define OBJECT_18_5 26
#define OBJECT_18_4 25
#define OBJECT_18_3 24
#define OBJECT_18_2 23
#define OBJECT_18_1 22
#define OBJECT_18_0 21
#define EXECUTE_CACHE_18_12 17
#define EXECUTE_CACHE_18_8 19
#define FREE_REFERENCES_LABEL_18_0 16
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd34;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto match_upP_10;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_18_6);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_18_7);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_18_9);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_18_10);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_18_11);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (match_upP_18)
DEFLABEL (match_upP_10)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_18_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_33;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_31;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_30;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_29)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_28;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_18_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_20;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_26;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_26;
  (Wrd7.Obj) = ((Wrd13.pObj) [4]);

DEFLABEL (label_25)
  (Wrd23.Obj) = (Rsp [1]);
  if (! ((Wrd7.Obj) == (Wrd23.Obj)))
    goto label_19;
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_24;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_23)
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_22;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [3]) = (Wrd35.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_12]));

DEFLABEL (label_22)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_11]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_5]), 1);

DEFLABEL (label_16)
  (Wrd35.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_10]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_5]), 1);

DEFLABEL (label_15)
  (Wrd26.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_18_3]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_4]), 2);

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_2]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_2]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_31)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_32)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd34.Obj) = (Rsp [1]);
  if (! ((Wrd34.Obj) == (Wrd6.Obj)))
    goto label_31;
  Rvl = (current_block [OBJECT_18_1]);
  goto label_32;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_6 5
#define LABEL_19_5 7
#define LABEL_19_8 9
#define LABEL_19_9 11
#define ENVIRONMENT_LABEL_19_3 22
#define DEBUGGING_LABEL_19_2 21
#define OBJECT_19_3 20
#define OBJECT_19_2 19
#define OBJECT_19_1 18
#define OBJECT_19_0 17
#define EXECUTE_CACHE_19_10 13
#define EXECUTE_CACHE_19_7 15
#define FREE_REFERENCES_LABEL_19_0 12
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto lambda_4;

    case 1:
      current_block = (Rpc - LABEL_19_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_19_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_10)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_16;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd19.Lng))))
    goto label_16;
  (Wrd13.Obj) = ((Wrd17.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_15)
  (Wrd27.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_19_5);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [6]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_14;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_14;
  (Wrd5.Obj) = ((Wrd11.pObj) [4]);

DEFLABEL (label_13)
  (Rsp [5]) = (Wrd5.Obj);
  (Wrd30.Obj) = (Rsp [6]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_12;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_12;
  (Wrd21.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_11)
  (Rsp [4]) = (Wrd21.Obj);
  (Wrd37.Obj) = (* (Rsp++));
  (Rsp [5]) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_10]));

DEFLABEL (label_12)
  (Wrd32.Obj) = (Rsp [6]);
  (Wrd33.Obj) = (current_block [OBJECT_19_3]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_8)
  (Wrd21.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [6]);
  (Wrd17.Obj) = (current_block [OBJECT_19_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd22.Obj) = (Rsp [6]);
  (Wrd23.Obj) = (current_block [OBJECT_19_0]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define LABEL_20_10 7
#define LABEL_20_7 9
#define LABEL_20_15 11
#define LABEL_20_14 13
#define LABEL_20_18 15
#define LABEL_20_19 17
#define LABEL_20_20 19
#define LABEL_20_23 21
#define LABEL_20_24 23
#define LABEL_20_12 25
#define LABEL_20_30 27
#define LABEL_20_32 29
#define LABEL_20_26 31
#define LABEL_20_34 33
#define LABEL_20_27 35
#define LABEL_20_28 37
#define LABEL_20_37 39
#define LABEL_20_36 41
#define ENVIRONMENT_LABEL_20_3 79
#define DEBUGGING_LABEL_20_2 78
#define OBJECT_20_4 77
#define OBJECT_20_3 76
#define OBJECT_20_2 75
#define OBJECT_20_1 74
#define OBJECT_20_0 73
#define EXECUTE_CACHE_20_38 43
#define EXECUTE_CACHE_20_35 45
#define EXECUTE_CACHE_20_33 47
#define EXECUTE_CACHE_20_31 49
#define EXECUTE_CACHE_20_29 51
#define EXECUTE_CACHE_20_25 53
#define EXECUTE_CACHE_20_22 55
#define EXECUTE_CACHE_20_21 57
#define EXECUTE_CACHE_20_17 59
#define EXECUTE_CACHE_20_16 61
#define EXECUTE_CACHE_20_13 63
#define EXECUTE_CACHE_20_11 65
#define EXECUTE_CACHE_20_9 67
#define EXECUTE_CACHE_20_8 69
#define EXECUTE_CACHE_20_6 71
#define FREE_REFERENCES_LABEL_20_0 42
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd79;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd82;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd41;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd40;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd12;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto integrate_combination_25;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_20_10);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_20_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_20_15);
      goto label_27;

    case 5:
      current_block = (Rpc - LABEL_20_14);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_20_18);
      goto continuation_21;

    case 7:
      current_block = (Rpc - LABEL_20_19);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_20_20);
      goto label_29;

    case 9:
      current_block = (Rpc - LABEL_20_23);
      goto label_30;

    case 10:
      current_block = (Rpc - LABEL_20_24);
      goto label_31;

    case 11:
      current_block = (Rpc - LABEL_20_12);
      goto continuation_5;

    case 12:
      current_block = (Rpc - LABEL_20_30);
      goto label_28;

    case 13:
      current_block = (Rpc - LABEL_20_32);
      goto continuation_15;

    case 14:
      current_block = (Rpc - LABEL_20_26);
      goto continuation_9;

    case 15:
      current_block = (Rpc - LABEL_20_34);
      goto continuation_13;

    case 16:
      current_block = (Rpc - LABEL_20_27);
      goto continuation_11;

    case 17:
      current_block = (Rpc - LABEL_20_28);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_20_37);
      goto lambda_8;

    case 19:
      current_block = (Rpc - LABEL_20_36);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_combination_33)
DEFLABEL (integrate_combination_25)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_9]));

DEFLABEL (label_35)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_55;

DEFLABEL (label_54)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_12]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_20_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_42;

DEFLABEL (label_41)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_26]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_27]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_28]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_29]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_20_28);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd7.pObj) = (& (Rsp [2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_8;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_20_27);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_38)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_35]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_20_32);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  (Wrd11.pObj) = (& (Rsp [3]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (Rsp [1]) = (Wrd13.Obj);
  goto lambda_8;

DEFLABEL (label_36)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [3]));

DEFLABEL (label_37)
  (Rsp [4]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_33]));

DEFLABEL (label_39)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_36]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_16]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_20_36);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_29]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_20_34);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Wrd12.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = (& (Rsp [4]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  goto lambda_8;

DEFLABEL (label_40)
  (Wrd18.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd18.Obj);
  goto label_38;

DEFLABEL (label_42)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_53;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_53;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_52)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_31]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_20_19);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_18]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd50.Obj) = (Rsp [5]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_51;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_51;
  (Wrd41.Obj) = ((Wrd47.pObj) [3]);

DEFLABEL (label_50)
  if (! ((Wrd41.Obj) == (current_block [OBJECT_20_2])))
    goto label_49;
  (Wrd82.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd82.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_21]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_20_18);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_48)
  (Wrd60.Obj) = (Rsp [0]);
  if (! ((Wrd60.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_43;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_22]));

DEFLABEL (label_43)
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_47;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_46)
  (Rsp [5]) = (Wrd62.Obj);
  (Wrd74.Obj) = (Rsp [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 1))
    goto label_45;
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd71.Obj) = ((Wrd73.pObj) [1]);

DEFLABEL (label_44)
  (Rsp [6]) = (Wrd71.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_25]));

DEFLABEL (label_45)
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_24]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_4]), 1);

DEFLABEL (label_31)
  (Wrd71.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_23]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_3]), 1);

DEFLABEL (label_30)
  (Wrd62.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_48;

DEFLABEL (label_51)
  (Wrd52.Obj) = (Rsp [5]);
  (Wrd53.Obj) = (current_block [OBJECT_20_0]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_20]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_29)
  (Wrd41.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.Obj) = (current_block [OBJECT_20_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_30]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_14]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_57;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd21.Lng))))
    goto label_57;
  (Wrd15.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_56)
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_20_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_20_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (label_57)
  (Wrd24.Obj) = (Rsp [6]);
  (Wrd25.Obj) = (current_block [OBJECT_20_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_15]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_20_26);
  (Wrd5.Obj) = Rvl;
  goto label_37;

DEFLABEL (lambda_34)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_20_37);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [5]);
  (Rsp [4]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_38]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define ENVIRONMENT_LABEL_21_3 12
#define DEBUGGING_LABEL_21_2 11
#define EXECUTE_CACHE_21_7 7
#define EXECUTE_CACHE_21_6 9
#define FREE_REFERENCES_LABEL_21_0 6
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto integrate_procedure_operator_1;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_procedure_operator_4)
DEFLABEL (integrate_procedure_operator_1)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd6.Obj);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_9 5
#define LABEL_22_5 7
#define TAG_22_6 2
#define LABEL_22_7 9
#define TAG_22_8 3
#define LABEL_22_12 11
#define TAG_22_13 4
#define ENVIRONMENT_LABEL_22_3 26
#define DEBUGGING_LABEL_22_2 25
#define OBJECT_22_3 24
#define OBJECT_22_2 23
#define OBJECT_22_1 22
#define OBJECT_22_0 21
#define EXECUTE_CACHE_22_15 13
#define EXECUTE_CACHE_22_14 15
#define EXECUTE_CACHE_22_11 17
#define EXECUTE_CACHE_22_10 19
#define FREE_REFERENCES_LABEL_22_0 12
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd36;
  machine_word Wrd7;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd31;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto integrate_primitive_operator_7;

    case 1:
      current_block = (Rpc - LABEL_22_9);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_22_5);
      goto lambda_12;

    case 3:
      current_block = (Rpc - LABEL_22_7);
      goto lambda_13;

    case 4:
      current_block = (Rpc - LABEL_22_12);
      goto lambda_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_primitive_operator_11)
DEFLABEL (integrate_primitive_operator_7)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_22_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_22_5])));
  Rhp += 4;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd13 = Wrd6;
  (Wrd14.Obj) = (Rsp [5]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  ((Wrd13.pObj) [4]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [5]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_22_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_22_7])));
  Rhp += 6;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd27 = Wrd16;
  ((Wrd27.pObj) [2]) = (Wrd14.Obj);
  ((Wrd27.pObj) [3]) = (Wrd10.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  ((Wrd27.pObj) [4]) = (Wrd24.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  ((Wrd27.pObj) [5]) = (Wrd22.Obj);
  ((Wrd27.pObj) [6]) = (Wrd8.Obj);
  ((Wrd27.pObj) [7]) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (Rsp [4]) = (Wrd22.Obj);
  (Rsp [7]) = (Wrd5.Obj);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd41.uLng) == 10))
    goto label_16;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd39.Lng))))
    goto label_16;
  (Wrd31.Obj) = ((Wrd37.pObj) [3]);

DEFLABEL (label_15)
  (Rsp [5]) = (Wrd31.Obj);
  (Wrd47.Obj) = (* (Rsp++));
  (Rsp [5]) = (Wrd47.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (label_16)
  (Wrd42.Obj) = (Rsp [6]);
  (Wrd43.Obj) = (current_block [OBJECT_22_0]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_9]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 2);

DEFLABEL (label_9)
  (Wrd31.Obj) = Rvl;
  goto label_15;

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_22_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_11]));

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_22_7);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_17;
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [7]);
  (Rsp [2]) = (Wrd36.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_0;

DEFLABEL (label_17)
  if ((Wrd5.Obj) == (current_block [OBJECT_22_2]))
    goto label_18;
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_22_3]);
  (Rsp [1]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_14]));

DEFLABEL (label_18)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd13.pObj) [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = ((Wrd13.pObj) [7]);
  (Rsp [4]) = (Wrd19.Obj);
  (Wrd22.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [5]) = (Wrd22.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd27.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_22_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_22_12])));
  Rhp += 2;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd27.pObj)));
  Wrd32 = Wrd27;
  (Wrd35.Obj) = ((Wrd13.pObj) [4]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (Wrd31.Obj) = ((Wrd13.pObj) [5]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (Rsp [3]) = (Wrd26.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 6);
  }

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_22_12);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_15]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_6 5
#define LABEL_23_5 7
#define LABEL_23_8 9
#define LABEL_23_10 11
#define LABEL_23_11 13
#define LABEL_23_16 15
#define LABEL_23_15 17
#define LABEL_23_18 19
#define LABEL_23_21 21
#define LABEL_23_13 23
#define LABEL_23_24 25
#define LABEL_23_19 27
#define TAG_23_20 12
#define LABEL_23_29 29
#define LABEL_23_25 31
#define LABEL_23_32 33
#define LABEL_23_22 35
#define LABEL_23_36 37
#define LABEL_23_27 39
#define LABEL_23_28 41
#define LABEL_23_30 43
#define LABEL_23_39 45
#define LABEL_23_41 47
#define LABEL_23_43 49
#define LABEL_23_31 51
#define LABEL_23_34 53
#define TAG_23_35 25
#define LABEL_23_38 55
#define LABEL_23_46 57
#define LABEL_23_42 59
#define LABEL_23_49 61
#define LABEL_23_44 63
#define LABEL_23_47 65
#define TAG_23_48 31
#define LABEL_23_50 67
#define LABEL_23_51 69
#define ENVIRONMENT_LABEL_23_3 105
#define DEBUGGING_LABEL_23_2 104
#define OBJECT_23_6 103
#define OBJECT_23_5 102
#define OBJECT_23_4 101
#define OBJECT_23_3 100
#define OBJECT_23_2 99
#define OBJECT_23_1 98
#define OBJECT_23_0 97
#define EXECUTE_CACHE_23_52 71
#define EXECUTE_CACHE_23_45 73
#define EXECUTE_CACHE_23_40 75
#define EXECUTE_CACHE_23_37 77
#define EXECUTE_CACHE_23_33 79
#define EXECUTE_CACHE_23_26 81
#define EXECUTE_CACHE_23_23 83
#define EXECUTE_CACHE_23_17 85
#define EXECUTE_CACHE_23_14 87
#define EXECUTE_CACHE_23_12 89
#define EXECUTE_CACHE_23_9 91
#define EXECUTE_CACHE_23_7 93
#define FREE_REFERENCE_23_0 96
#define FREE_REFERENCES_LABEL_23_0 70
#define NUMBER_OF_LINKER_SECTIONS_23_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto integrate_compound_operator_39;

    case 1:
      current_block = (Rpc - LABEL_23_6);
      goto label_41;

    case 2:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_23_8);
      goto lambda_1;

    case 4:
      current_block = (Rpc - LABEL_23_10);
      goto scan_operator_38;

    case 5:
      current_block = (Rpc - LABEL_23_11);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_23_16);
      goto label_42;

    case 7:
      current_block = (Rpc - LABEL_23_15);
      goto continuation_28;

    case 8:
      current_block = (Rpc - LABEL_23_18);
      goto label_43;

    case 9:
      current_block = (Rpc - LABEL_23_21);
      goto label_44;

    case 10:
      current_block = (Rpc - LABEL_23_13);
      goto continuation_9;

    case 11:
      current_block = (Rpc - LABEL_23_24);
      goto label_45;

    case 12:
      current_block = (Rpc - LABEL_23_19);
      goto lambda_56;

    case 13:
      current_block = (Rpc - LABEL_23_29);
      goto scan_body_7;

    case 14:
      current_block = (Rpc - LABEL_23_25);
      goto continuation_22;

    case 15:
      current_block = (Rpc - LABEL_23_32);
      goto label_46;

    case 16:
      current_block = (Rpc - LABEL_23_22);
      goto continuation_10;

    case 17:
      current_block = (Rpc - LABEL_23_36);
      goto label_47;

    case 18:
      current_block = (Rpc - LABEL_23_27);
      goto continuation_34;

    case 19:
      current_block = (Rpc - LABEL_23_28);
      goto continuation_33;

    case 20:
      current_block = (Rpc - LABEL_23_30);
      goto continuation_2;

    case 21:
      current_block = (Rpc - LABEL_23_39);
      goto label_48;

    case 22:
      current_block = (Rpc - LABEL_23_41);
      goto lambda_20;

    case 23:
      current_block = (Rpc - LABEL_23_43);
      goto label_49;

    case 24:
      current_block = (Rpc - LABEL_23_31);
      goto continuation_24;

    case 25:
      current_block = (Rpc - LABEL_23_34);
      goto lambda_58;

    case 26:
      current_block = (Rpc - LABEL_23_38);
      goto continuation_4;

    case 27:
      current_block = (Rpc - LABEL_23_46);
      goto label_50;

    case 28:
      current_block = (Rpc - LABEL_23_42);
      goto continuation_15;

    case 29:
      current_block = (Rpc - LABEL_23_49);
      goto label_51;

    case 30:
      current_block = (Rpc - LABEL_23_44);
      goto continuation_12;

    case 31:
      current_block = (Rpc - LABEL_23_47);
      goto lambda_60;

    case 32:
      current_block = (Rpc - LABEL_23_50);
      goto continuation_18;

    case 33:
      current_block = (Rpc - LABEL_23_51);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_compound_operator_53)
DEFLABEL (integrate_compound_operator_39)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_63;
  Wrd8 = Wrd12;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_61;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_8]))));
  (Rsp [1]) = (Wrd7.Obj);
  goto scan_operator_38;

DEFLABEL (label_61)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_6])), (Wrd9.pObj));

DEFLABEL (label_41)
  (Wrd8.Obj) = Rvl;
  goto label_62;

DEFLABEL (lambda_54)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_23_8);
  (Wrd6.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_9]));

DEFLABEL (scan_operator_55)
DEFLABEL (scan_operator_38)
  INTERRUPT_CHECK (26, LABEL_23_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_23_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_74;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_13]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_23_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_67;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_22]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_23]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_23_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_64;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_64)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_34])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_66;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_66;
  (Wrd14.Obj) = ((Wrd20.pObj) [4]);

DEFLABEL (label_65)
  (Rsp [0]) = (Wrd14.Obj);
  goto scan_body_7;

DEFLABEL (label_66)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.Obj) = (current_block [OBJECT_23_4]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_36]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_47)
  (Wrd14.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_67)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_73;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_73;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_72)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_25]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_26]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_23_25);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_68;
  goto lambda_20;

DEFLABEL (label_68)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_31]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_71;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_71;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_70)
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_33]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_23_31);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;
  goto lambda_20;

DEFLABEL (label_69)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_71)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_23_5]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_32]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_23_4]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_24]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_45)
  (* (--Rsp)) = Rvl;
  goto label_72;

DEFLABEL (label_74)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_80;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_80;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_79)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_17]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_23_15);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_78;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_77)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_19])));
  Rhp += 3;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd21 = Wrd16;
  (Wrd22.Obj) = (Rsp [3]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  ((Wrd21.pObj) [4]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd15.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_76;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [0]);

DEFLABEL (label_75)
  (Rsp [1]) = (Wrd24.Obj);
  Rsp = (& (Rsp [1]));
  goto scan_body_7;

DEFLABEL (label_76)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_21]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_3]), 1);

DEFLABEL (label_44)
  (Wrd24.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 1);

DEFLABEL (label_43)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_23_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_16]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (lambda_56)
  CLOSURE_HEADER (LABEL_23_19);

DEFLABEL (lambda_35)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_28]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [4]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_17]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_23_28);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_37]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_23_27);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto pop_return;

DEFLABEL (scan_body_57)
DEFLABEL (scan_body_7)
  INTERRUPT_CHECK (26, LABEL_23_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_26]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_23_30);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_81;
  goto scan_operator_38;

DEFLABEL (label_81)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_38]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_86;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd18.Lng))))
    goto label_86;
  (Wrd12.Obj) = ((Wrd16.pObj) [8]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_85)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_40]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_23_38);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_82;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_82)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_84;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd17.Lng))))
    goto label_84;
  (Wrd11.Obj) = ((Wrd15.pObj) [8]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  goto pop_return;

DEFLABEL (label_84)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.Obj) = (current_block [OBJECT_23_6]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_46]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_23_6]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_39]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (lambda_59)
DEFLABEL (lambda_20)
  INTERRUPT_CHECK (26, LABEL_23_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_91;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_91;
  (Wrd10.Obj) = ((Wrd14.pObj) [8]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_90)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_40]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_23_42);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_87)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_48);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_47])));
  Rhp += 3;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd16 = Wrd11;
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  ((Wrd16.pObj) [4]) = (Wrd13.Obj);
  (Rsp [2]) = (Wrd10.Obj);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_89;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd26.Lng))))
    goto label_89;
  (Wrd18.Obj) = ((Wrd24.pObj) [8]);

DEFLABEL (label_88)
  (Rsp [1]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  goto scan_body_7;

DEFLABEL (label_89)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.Obj) = (current_block [OBJECT_23_6]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_49]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_51)
  (Wrd18.Obj) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_23_6]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_43]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_90;

DEFLABEL (lambda_58)
  CLOSURE_HEADER (LABEL_23_34);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_45]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_23_44);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto pop_return;

DEFLABEL (lambda_60)
  CLOSURE_HEADER (LABEL_23_47);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_51]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_9]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_23_51);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_52]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_23_50);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_6 7
#define LABEL_24_7 9
#define ENVIRONMENT_LABEL_24_3 18
#define DEBUGGING_LABEL_24_2 17
#define OBJECT_24_3 16
#define OBJECT_24_2 15
#define OBJECT_24_1 14
#define OBJECT_24_0 13
#define EXECUTE_CACHE_24_8 11
#define FREE_REFERENCES_LABEL_24_0 10
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto combination_with_operator_3;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_24_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_24_7);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_with_operator_9)
DEFLABEL (combination_with_operator_3)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_14)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_13;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_13;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_12)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_11;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_11;
  (Wrd37.Obj) = ((Wrd43.pObj) [5]);

DEFLABEL (label_10)
  (Wrd53.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd53.Obj);
  (Rsp [3]) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_8]));

DEFLABEL (label_11)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.Obj) = (current_block [OBJECT_24_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 2);

DEFLABEL (label_7)
  (Wrd37.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_24_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_24_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_6 7
#define ENVIRONMENT_LABEL_25_3 15
#define DEBUGGING_LABEL_25_2 14
#define OBJECT_25_2 13
#define OBJECT_25_1 12
#define OBJECT_25_0 11
#define EXECUTE_CACHE_25_7 9
#define FREE_REFERENCES_LABEL_25_0 8
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto declaration_with_expression_2;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_25_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (declaration_with_expression_7)
DEFLABEL (declaration_with_expression_2)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_10)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_9;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [1]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_7]));

DEFLABEL (label_9)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_25_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_25_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_6 5
#define LABEL_26_7 7
#define LABEL_26_5 9
#define LABEL_26_10 11
#define LABEL_26_11 13
#define LABEL_26_12 15
#define LABEL_26_9 17
#define LABEL_26_13 19
#define LABEL_26_14 21
#define LABEL_26_15 23
#define LABEL_26_16 25
#define LABEL_26_17 27
#define LABEL_26_18 29
#define LABEL_26_19 31
#define ENVIRONMENT_LABEL_26_3 49
#define DEBUGGING_LABEL_26_2 48
#define OBJECT_26_6 47
#define OBJECT_26_5 46
#define OBJECT_26_4 45
#define OBJECT_26_3 44
#define OBJECT_26_2 43
#define OBJECT_26_1 42
#define OBJECT_26_0 41
#define EXECUTE_CACHE_26_21 33
#define EXECUTE_CACHE_26_20 35
#define EXECUTE_CACHE_26_8 37
#define FREE_REFERENCE_26_0 40
#define FREE_REFERENCES_LABEL_26_0 32
#define NUMBER_OF_LINKER_SECTIONS_26_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd122;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd107;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd93;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd77;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd61;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd45;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto procedure_with_body_13;

    case 1:
      current_block = (Rpc - LABEL_26_6);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_26_7);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_26_10);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_26_11);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_26_12);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_26_9);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_26_13);
      goto label_19;

    case 9:
      current_block = (Rpc - LABEL_26_14);
      goto label_20;

    case 10:
      current_block = (Rpc - LABEL_26_15);
      goto label_21;

    case 11:
      current_block = (Rpc - LABEL_26_16);
      goto label_22;

    case 12:
      current_block = (Rpc - LABEL_26_17);
      goto label_23;

    case 13:
      current_block = (Rpc - LABEL_26_18);
      goto label_24;

    case 14:
      current_block = (Rpc - LABEL_26_19);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (procedure_with_body_27)
DEFLABEL (procedure_with_body_13)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_51;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_51;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_50)
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_49;
  Wrd24 = Wrd28;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_26_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_47;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_47;
  (Wrd10.Obj) = ((Wrd14.pObj) [6]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_46)
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_45;
  Wrd24 = Wrd28;

DEFLABEL (label_44)
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_26_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_43;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_43;
  (Wrd10.Obj) = ((Wrd14.pObj) [7]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_42)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_28;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_21]));

DEFLABEL (label_28)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_41)
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_40;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd35.Lng))))
    goto label_40;
  (Wrd29.Obj) = ((Wrd33.pObj) [6]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_39)
  (Wrd52.Obj) = (Rsp [1]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 10))
    goto label_38;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [0]);
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd51.Lng))))
    goto label_38;
  (Wrd45.Obj) = ((Wrd49.pObj) [5]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_37)
  (Wrd68.Obj) = (Rsp [2]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_36;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd67.Lng))))
    goto label_36;
  (Wrd61.Obj) = ((Wrd65.pObj) [4]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_35)
  (Wrd84.Obj) = (Rsp [3]);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd84.Obj));
  if (! ((Wrd85.uLng) == 10))
    goto label_34;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [0]);
  (Wrd83.Lng) = (FIXNUM_TO_LONG (Wrd82.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd83.Lng))))
    goto label_34;
  (Wrd77.Obj) = ((Wrd81.pObj) [3]);
  (* (--Rsp)) = (Wrd77.Obj);

DEFLABEL (label_33)
  (Wrd100.Obj) = (Rsp [4]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 10))
    goto label_32;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [0]);
  (Wrd99.Lng) = (FIXNUM_TO_LONG (Wrd98.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd99.Lng))))
    goto label_32;
  (Wrd93.Obj) = ((Wrd97.pObj) [2]);
  (* (--Rsp)) = (Wrd93.Obj);

DEFLABEL (label_31)
  (Wrd116.Obj) = (Rsp [5]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if (! ((Wrd117.uLng) == 10))
    goto label_30;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd116.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd115.Lng))))
    goto label_30;
  (Wrd107.Obj) = ((Wrd113.pObj) [7]);

DEFLABEL (label_29)
  (Rsp [5]) = (Wrd107.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_20]));

DEFLABEL (label_30)
  (Wrd118.Obj) = (Rsp [5]);
  (Wrd119.Obj) = (current_block [OBJECT_26_3]);
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_19]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_25)
  (Wrd107.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd102.Obj) = (Rsp [4]);
  (Wrd103.Obj) = (current_block [OBJECT_26_6]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_18]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd86.Obj) = (Rsp [3]);
  (Wrd87.Obj) = (current_block [OBJECT_26_5]);
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_17]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd70.Obj) = (Rsp [2]);
  (Wrd71.Obj) = (current_block [OBJECT_26_4]);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_16]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd54.Obj) = (Rsp [1]);
  (Wrd55.Obj) = (current_block [OBJECT_26_0]);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_15]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.Obj) = (current_block [OBJECT_26_2]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_14]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_43)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_26_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_13]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26_11])), (Wrd25.pObj));

DEFLABEL (label_18)
  (Wrd24.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_26_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26_7])), (Wrd25.pObj));

DEFLABEL (label_16)
  (Wrd24.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_26_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_26_12);
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_7 5
#define LABEL_27_5 7
#define LABEL_27_6 9
#define ENVIRONMENT_LABEL_27_3 20
#define DEBUGGING_LABEL_27_2 19
#define OBJECT_27_3 18
#define OBJECT_27_2 17
#define OBJECT_27_1 16
#define OBJECT_27_0 15
#define EXECUTE_CACHE_27_9 11
#define EXECUTE_CACHE_27_8 13
#define FREE_REFERENCES_LABEL_27_0 10
#define NUMBER_OF_LINKER_SECTIONS_27_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto hackify_variable_3;

    case 1:
      current_block = (Rpc - LABEL_27_7);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_27_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hackify_variable_7)
DEFLABEL (hackify_variable_3)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (current_block [OBJECT_27_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_11;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd21.Lng))))
    goto label_11;
  (Wrd15.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_10)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_27_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (Rsp [2]) = Rvl;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_9;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_3]), 3);

DEFLABEL (label_9)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_8;
  ((Wrd14.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_27_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_27_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define ENVIRONMENT_LABEL_28_3 12
#define DEBUGGING_LABEL_28_2 11
#define OBJECT_28_1 10
#define OBJECT_28_0 9
#define EXECUTE_CACHE_28_6 7
#define FREE_REFERENCES_LABEL_28_0 6
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto sequence_with_actions_1;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequence_with_actions_5)
DEFLABEL (sequence_with_actions_1)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_28_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define ENVIRONMENT_LABEL_29_3 12
#define DEBUGGING_LABEL_29_2 11
#define EXECUTE_CACHE_29_7 7
#define EXECUTE_CACHE_29_6 9
#define FREE_REFERENCES_LABEL_29_0 6
#define NUMBER_OF_LINKER_SECTIONS_29_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto non_side_effectingP_2;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (non_side_effectingP_5)
DEFLABEL (non_side_effectingP_2)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_6;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_6 7
#define LABEL_30_7 9
#define LABEL_30_10 11
#define LABEL_30_8 13
#define ENVIRONMENT_LABEL_30_3 26
#define DEBUGGING_LABEL_30_2 25
#define OBJECT_30_3 24
#define OBJECT_30_2 23
#define OBJECT_30_1 22
#define OBJECT_30_0 21
#define EXECUTE_CACHE_30_12 15
#define EXECUTE_CACHE_30_11 17
#define EXECUTE_CACHE_30_9 19
#define FREE_REFERENCES_LABEL_30_0 14
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto lambda_6;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_30_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_30_7);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_30_10);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_30_8);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_12)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_18;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_18;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_17)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_16;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_16;
  (Wrd23.Obj) = ((Wrd27.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_15)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_8]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_30_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_30_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_14;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_14;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_13)
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd22.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd22.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_11]));

DEFLABEL (label_14)
  (Wrd17.Obj) = (Rsp [5]);
  (Wrd18.Obj) = (current_block [OBJECT_30_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_10]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_10)
  (Wrd6.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (current_block [OBJECT_30_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_30_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define ENVIRONMENT_LABEL_31_3 5
#define DEBUGGING_LABEL_31_2 4
#define FREE_REFERENCES_LABEL_31_0 4
#define NUMBER_OF_LINKER_SECTIONS_31_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_31_4);
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define ENVIRONMENT_LABEL_32_3 5
#define DEBUGGING_LABEL_32_2 4
#define FREE_REFERENCES_LABEL_32_0 4
#define NUMBER_OF_LINKER_SECTIONS_32_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_32_4);
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 8
#define DEBUGGING_LABEL_33_2 7
#define EXECUTE_CACHE_33_5 5
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_33_4);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_6 5
#define LABEL_34_5 7
#define LABEL_34_9 9
#define LABEL_34_8 11
#define LABEL_34_11 13
#define LABEL_34_10 15
#define LABEL_34_12 17
#define LABEL_34_13 19
#define LABEL_34_17 21
#define LABEL_34_15 23
#define LABEL_34_22 25
#define LABEL_34_20 27
#define LABEL_34_21 29
#define LABEL_34_25 31
#define LABEL_34_27 33
#define LABEL_34_18 35
#define LABEL_34_28 37
#define LABEL_34_31 39
#define LABEL_34_26 41
#define LABEL_34_30 43
#define LABEL_34_33 45
#define LABEL_34_35 47
#define LABEL_34_36 49
#define LABEL_34_34 51
#define LABEL_34_40 53
#define LABEL_34_41 55
#define LABEL_34_42 57
#define LABEL_34_38 59
#define LABEL_34_39 61
#define LABEL_34_44 63
#define ENVIRONMENT_LABEL_34_3 96
#define DEBUGGING_LABEL_34_2 95
#define OBJECT_34_7 94
#define OBJECT_34_6 93
#define OBJECT_34_5 92
#define OBJECT_34_4 91
#define OBJECT_34_3 90
#define OBJECT_34_2 89
#define OBJECT_34_1 88
#define OBJECT_34_0 87
#define EXECUTE_CACHE_34_45 65
#define EXECUTE_CACHE_34_43 67
#define EXECUTE_CACHE_34_37 69
#define EXECUTE_CACHE_34_32 71
#define EXECUTE_CACHE_34_29 73
#define EXECUTE_CACHE_34_24 75
#define EXECUTE_CACHE_34_23 77
#define EXECUTE_CACHE_34_19 79
#define EXECUTE_CACHE_34_16 81
#define EXECUTE_CACHE_34_14 83
#define EXECUTE_CACHE_34_7 85
#define FREE_REFERENCES_LABEL_34_0 64
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd86;
  machine_word Wrd94;
  machine_word Wrd89;
  machine_word Wrd91;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd66;
  machine_word Wrd67;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd75;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd58;
  machine_word Wrd68;
  machine_word Wrd61;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd45;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd8;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd13;
  machine_word Wrd27;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd11;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto lambda_35;

    case 1:
      current_block = (Rpc - LABEL_34_6);
      goto label_37;

    case 2:
      current_block = (Rpc - LABEL_34_5);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_34_9);
      goto label_38;

    case 4:
      current_block = (Rpc - LABEL_34_8);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_34_11);
      goto label_39;

    case 6:
      current_block = (Rpc - LABEL_34_10);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_34_12);
      goto loop_32;

    case 8:
      current_block = (Rpc - LABEL_34_13);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_34_17);
      goto label_40;

    case 10:
      current_block = (Rpc - LABEL_34_15);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_34_22);
      goto label_41;

    case 12:
      current_block = (Rpc - LABEL_34_20);
      goto continuation_25;

    case 13:
      current_block = (Rpc - LABEL_34_21);
      goto continuation_24;

    case 14:
      current_block = (Rpc - LABEL_34_25);
      goto label_42;

    case 15:
      current_block = (Rpc - LABEL_34_27);
      goto label_43;

    case 16:
      current_block = (Rpc - LABEL_34_18);
      goto continuation_9;

    case 17:
      current_block = (Rpc - LABEL_34_28);
      goto label_45;

    case 18:
      current_block = (Rpc - LABEL_34_31);
      goto label_44;

    case 19:
      current_block = (Rpc - LABEL_34_26);
      goto continuation_27;

    case 20:
      current_block = (Rpc - LABEL_34_30);
      goto continuation_12;

    case 21:
      current_block = (Rpc - LABEL_34_33);
      goto label_48;

    case 22:
      current_block = (Rpc - LABEL_34_35);
      goto label_46;

    case 23:
      current_block = (Rpc - LABEL_34_36);
      goto label_47;

    case 24:
      current_block = (Rpc - LABEL_34_34);
      goto continuation_16;

    case 25:
      current_block = (Rpc - LABEL_34_40);
      goto label_50;

    case 26:
      current_block = (Rpc - LABEL_34_41);
      goto label_51;

    case 27:
      current_block = (Rpc - LABEL_34_42);
      goto label_49;

    case 28:
      current_block = (Rpc - LABEL_34_38);
      goto continuation_21;

    case 29:
      current_block = (Rpc - LABEL_34_39);
      goto continuation_20;

    case 30:
      current_block = (Rpc - LABEL_34_44);
      goto label_52;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_54)
DEFLABEL (lambda_35)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_61;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_61;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_60)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_34_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_59;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_59;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_58)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_34_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_57;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_57;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_56)
  (Wrd24.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_34_10);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [8]));
  goto loop_32;

DEFLABEL (label_57)
  (Wrd19.Obj) = (Rsp [5]);
  (Wrd20.Obj) = (current_block [OBJECT_34_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.Obj) = (current_block [OBJECT_34_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_34_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (loop_55)
DEFLABEL (loop_32)
  DLINK_INTERRUPT_CHECK (25, LABEL_34_12);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_34_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_90;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_15]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_34_15);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_83;
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_18]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_19]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_34_18);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_80;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_79;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_79;
  (Wrd16.Obj) = ((Wrd20.pObj) [4]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_78)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_32]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_34_30);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_75;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_34]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_74;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_74;
  (Wrd14.Obj) = ((Wrd20.pObj) [4]);

DEFLABEL (label_73)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd41.uLng) == 10))
    goto label_72;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd40.Lng))))
    goto label_72;
  (Wrd35.Obj) = ((Wrd38.pObj) [8]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_71)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_37]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_34_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd31.Obj) = ((Wrd10.pObj) [5]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_63;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd28.Lng))))
    goto label_63;
  (Wrd20.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_62)
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_29]));

DEFLABEL (label_63)
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [5]);
  (Wrd40.Obj) = (current_block [OBJECT_34_6]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_42]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_49)
  (Wrd33.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd33.Obj));
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_64)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_38]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_39]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd55.pObj)));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd67.Obj) = (Rsp [5]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if (! ((Wrd68.uLng) == 10))
    goto label_70;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd66.Lng))))
    goto label_70;
  (Wrd58.Obj) = ((Wrd64.pObj) [4]);

DEFLABEL (label_69)
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd85.uLng) == 10))
    goto label_68;
  (Wrd82.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd83.Obj) = ((Wrd82.pObj) [0]);
  (Wrd84.Lng) = (FIXNUM_TO_LONG (Wrd83.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd84.Lng))))
    goto label_68;
  (Wrd79.Obj) = ((Wrd82.pObj) [8]);
  (* (--Rsp)) = (Wrd79.Obj);

DEFLABEL (label_67)
  Rdl = (& (Rsp [2]));
  goto loop_32;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_34_39);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_66;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_66;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_65)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_45]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_34_38);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_43]));

DEFLABEL (label_66)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_34_2]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_44]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_52)
  (Wrd18.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd18.Obj));
  (* (--Rsp)) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd91.Obj) = (current_block [OBJECT_34_7]);
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd89.Obj);
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_41]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_51)
  (Wrd86.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd86.Obj));
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd73.Obj) = (Rsp [5]);
  (Wrd74.Obj) = (current_block [OBJECT_34_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_40]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_50)
  (Wrd69.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd58.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd47.Obj) = (current_block [OBJECT_34_7]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_36]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_47)
  (Wrd42.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd42.Obj));
  (* (--Rsp)) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.Obj) = (current_block [OBJECT_34_2]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_35]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_46)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd14.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_75)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [2]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd56.Obj) = ((Wrd52.pObj) [1]);
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd57.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd73.Obj) = ((Wrd52.pObj) [5]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 10))
    goto label_77;
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [0]);
  (Wrd70.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd70.Lng))))
    goto label_77;
  (Wrd62.Obj) = ((Wrd68.pObj) [2]);
  (* (--Rsp)) = (Wrd62.Obj);

DEFLABEL (label_76)
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_29]));

DEFLABEL (label_77)
  (Wrd80.Obj) = (Rsp [4]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd79.Obj) = ((Wrd81.pObj) [5]);
  (Wrd82.Obj) = (current_block [OBJECT_34_6]);
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_33]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_48)
  (Wrd75.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd75.Obj));
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.Obj) = (current_block [OBJECT_34_2]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_31]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_44)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_78;

DEFLABEL (label_80)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [2]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd39.Obj) = ((Wrd35.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd56.Obj) = ((Wrd35.pObj) [5]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 10))
    goto label_82;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd53.Lng))))
    goto label_82;
  (Wrd45.Obj) = ((Wrd51.pObj) [2]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_81)
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_29]));

DEFLABEL (label_82)
  (Wrd63.Obj) = (Rsp [4]);
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [5]);
  (Wrd65.Obj) = (current_block [OBJECT_34_6]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_28]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_45)
  (Wrd58.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd58.Obj));
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (label_83)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_20]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_21]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 10))
    goto label_89;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_89;
  (Wrd21.Obj) = ((Wrd25.pObj) [3]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_88)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_23]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_34_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 1))
    goto label_87;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_86)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_26]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [6]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_85;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_84)
  Rdl = (& (Rsp [2]));
  goto loop_32;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_34_26);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_23]));

DEFLABEL (label_85)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_27]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_5]), 1);

DEFLABEL (label_43)
  (* (--Rsp)) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_25]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_4]), 1);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.Obj) = (current_block [OBJECT_34_3]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_22]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_41)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_88;

DEFLABEL (label_90)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_95;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_95;
  (Wrd11.Obj) = ((Wrd22.pObj) [3]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_92;

DEFLABEL (label_93)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  Rvl = ((Wrd17.pObj) [1]);
  goto label_91;

DEFLABEL (label_92)
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  Rvl = ((Wrd14.pObj) [2]);

DEFLABEL (label_91)
DEFLABEL (label_94)
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_95)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.Obj) = (current_block [OBJECT_34_3]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_17]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_40)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_92;
  goto label_93;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_34_20);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_24]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_6 5
#define LABEL_35_5 7
#define LABEL_35_9 9
#define LABEL_35_8 11
#define LABEL_35_10 13
#define LABEL_35_12 15
#define LABEL_35_14 17
#define ENVIRONMENT_LABEL_35_3 30
#define DEBUGGING_LABEL_35_2 29
#define OBJECT_35_3 28
#define OBJECT_35_2 27
#define OBJECT_35_1 26
#define OBJECT_35_0 25
#define EXECUTE_CACHE_35_13 19
#define EXECUTE_CACHE_35_11 21
#define EXECUTE_CACHE_35_7 23
#define FREE_REFERENCES_LABEL_35_0 18
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd29;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto lambda_8;

    case 1:
      current_block = (Rpc - LABEL_35_6);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_35_9);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_35_8);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_35_12);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_35_14);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_15)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_27;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_27;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_26)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_25;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_25;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_24)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_35_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_20;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_20;
  (Wrd9.Obj) = ((Wrd18.pObj) [3]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_17;

DEFLABEL (label_18)
  Rvl = (Rsp [0]);
  goto label_16;

DEFLABEL (label_17)
  Rvl = (Rsp [1]);

DEFLABEL (label_16)
DEFLABEL (label_19)
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.Obj) = (current_block [OBJECT_35_2]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_14]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_18;

DEFLABEL (label_21)
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_23;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd37.Lng))))
    goto label_23;
  (Wrd29.Obj) = ((Wrd35.pObj) [2]);

DEFLABEL (label_22)
  (Rsp [2]) = (Wrd29.Obj);
  (Wrd45.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd46.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_13]));

DEFLABEL (label_23)
  (Wrd40.Obj) = (Rsp [4]);
  (Wrd41.Obj) = (current_block [OBJECT_35_3]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_13)
  (Wrd29.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.Obj) = (current_block [OBJECT_35_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_35_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_6 5
#define LABEL_36_5 7
#define ENVIRONMENT_LABEL_36_3 16
#define DEBUGGING_LABEL_36_2 15
#define OBJECT_36_1 14
#define OBJECT_36_0 13
#define EXECUTE_CACHE_36_8 9
#define EXECUTE_CACHE_36_7 11
#define FREE_REFERENCES_LABEL_36_0 8
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_36_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_36_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_8;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_8;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_7)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_36_5);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

DEFLABEL (label_8)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_36_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_5 3
#define LABEL_37_4 5
#define LABEL_37_6 7
#define LABEL_37_7 9
#define LABEL_37_8 11
#define LABEL_37_11 13
#define LABEL_37_10 15
#define LABEL_37_16 17
#define LABEL_37_14 19
#define LABEL_37_17 21
#define LABEL_37_18 23
#define LABEL_37_13 25
#define ENVIRONMENT_LABEL_37_3 43
#define DEBUGGING_LABEL_37_2 42
#define OBJECT_37_4 41
#define OBJECT_37_3 40
#define OBJECT_37_2 39
#define OBJECT_37_1 38
#define OBJECT_37_0 37
#define EXECUTE_CACHE_37_19 27
#define EXECUTE_CACHE_37_15 29
#define EXECUTE_CACHE_37_12 31
#define EXECUTE_CACHE_37_9 33
#define FREE_REFERENCE_37_0 36
#define FREE_REFERENCES_LABEL_37_0 26
#define NUMBER_OF_LINKER_SECTIONS_37_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd48;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd53;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_11;

    case 1:
      current_block = (Rpc - LABEL_37_4);
      goto integrate_actions_13;

    case 2:
      current_block = (Rpc - LABEL_37_6);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_37_7);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_37_8);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_37_11);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_37_10);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_37_16);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_37_14);
      goto continuation_3;

    case 9:
      current_block = (Rpc - LABEL_37_17);
      goto label_20;

    case 10:
      current_block = (Rpc - LABEL_37_18);
      goto label_19;

    case 11:
      current_block = (Rpc - LABEL_37_13);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_actions_22)
DEFLABEL (integrate_actions_13)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_41;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_40)
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_39;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_38)
  if ((Wrd14.Obj) == (current_block [OBJECT_37_2]))
    goto label_33;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_32;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_31)
  (Wrd36.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_12]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_37_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_37_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_16]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_26;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd24.Lng))))
    goto label_26;
  (Wrd18.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_25)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_37_16);
  (Wrd6.Obj) = (Rsp [2]);

DEFLABEL (label_24)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_23)
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.Obj) = (current_block [OBJECT_37_3]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_18]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_27)
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_37_0]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_30;
  Wrd33 = Wrd37;

DEFLABEL (label_29)
  (Wrd39.Obj) = (Rsp [2]);
  if ((Wrd39.Obj) == (Wrd33.Obj))
    goto label_28;
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd41.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_37_13);
  (Wrd6.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_28)
  Wrd6 = Wrd39;
  goto label_24;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37_17])), (Wrd34.pObj));

DEFLABEL (label_20)
  (Wrd33.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_11]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_33)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_37_0]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_37;
  Wrd42 = Wrd46;

DEFLABEL (label_36)
  (Wrd48.Obj) = (Rsp [1]);
  if ((Wrd48.Obj) == (Wrd42.Obj))
    goto label_35;
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd50.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_9]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_37_5);
  (Wrd53.Obj) = Rvl;

DEFLABEL (label_34)
  (Wrd58.Obj) = (current_block [OBJECT_37_2]);
  (* (Rhp++)) = (Wrd53.Obj);
  (* (Rhp++)) = (Wrd58.Obj);
  (Wrd56.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd56.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_35)
  Wrd53 = Wrd48;
  Rsp = (& (Rsp [1]));
  goto label_34;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37_8])), (Wrd43.pObj));

DEFLABEL (label_18)
  (Wrd42.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 1);

DEFLABEL (label_16)
  (Wrd14.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_0]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_7 5
#define LABEL_38_5 7
#define LABEL_38_8 9
#define LABEL_38_9 11
#define ENVIRONMENT_LABEL_38_3 23
#define DEBUGGING_LABEL_38_2 22
#define OBJECT_38_4 21
#define OBJECT_38_3 20
#define OBJECT_38_2 19
#define OBJECT_38_1 18
#define OBJECT_38_0 17
#define EXECUTE_CACHE_38_10 13
#define EXECUTE_CACHE_38_6 15
#define FREE_REFERENCES_LABEL_38_0 12
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd40;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto sequence_optimizing_make_5;

    case 1:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_38_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_38_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequence_optimizing_make_10)
DEFLABEL (sequence_optimizing_make_5)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_38_5);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_18;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_17)
  if ((Wrd5.Obj) == (current_block [OBJECT_38_1]))
    goto label_15;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  if ((Wrd18.Obj) == ((SCHEME_OBJECT) 0))
    goto label_14;
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_13;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd27.pObj) [2]);

DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_11)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd37.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (label_13)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.Obj) = (current_block [OBJECT_38_3]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_4]), 2);

DEFLABEL (label_8)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_14)
  (Wrd21.Obj) = ((SCHEME_OBJECT) 0);
  goto label_12;

DEFLABEL (label_15)
  (Wrd40.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd40.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_16;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  Rvl = ((Wrd43.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_2]), 1);

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_17;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_38_7);
  (Wrd21.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define LABEL_39_7 7
#define LABEL_39_6 9
#define LABEL_39_10 11
#define LABEL_39_9 13
#define LABEL_39_12 15
#define ENVIRONMENT_LABEL_39_3 25
#define DEBUGGING_LABEL_39_2 24
#define OBJECT_39_2 23
#define OBJECT_39_1 22
#define OBJECT_39_0 21
#define EXECUTE_CACHE_39_11 17
#define EXECUTE_CACHE_39_8 19
#define FREE_REFERENCES_LABEL_39_0 16
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto remove_non_side_effecting_8;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_39_7);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_39_6);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_39_10);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_39_9);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_39_12);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (remove_non_side_effecting_15)
DEFLABEL (remove_non_side_effecting_8)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_26;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_25)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_39_1])))
    goto label_16;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_24;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_39_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_22;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_21)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_39_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  Rvl = (Rsp [0]);

DEFLABEL (label_17)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_20;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_19)
  (Wrd22.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  goto label_17;

DEFLABEL (label_20)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_12]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_2]), 1);

DEFLABEL (label_13)
  (Wrd9.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_2]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_7]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_0]), 1);

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define LABEL_40_7 7
#define LABEL_40_9 9
#define LABEL_40_11 11
#define LABEL_40_13 13
#define LABEL_40_15 15
#define ENVIRONMENT_LABEL_40_3 32
#define DEBUGGING_LABEL_40_2 31
#define OBJECT_40_1 30
#define OBJECT_40_0 29
#define EXECUTE_CACHE_40_16 17
#define EXECUTE_CACHE_40_14 19
#define EXECUTE_CACHE_40_12 21
#define EXECUTE_CACHE_40_10 23
#define EXECUTE_CACHE_40_8 25
#define EXECUTE_CACHE_40_6 27
#define FREE_REFERENCES_LABEL_40_0 16
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto non_side_effecting_in_sequenceP_10;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_40_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_40_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_40_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_40_13);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_40_15);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (non_side_effecting_in_sequenceP_14)
DEFLABEL (non_side_effecting_in_sequenceP_10)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_40_7);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_40_9);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_40_11);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_13]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_40_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_19;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_21;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_21;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_20)
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_16]));

DEFLABEL (label_21)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_40_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 2);

DEFLABEL (label_12)
  (Wrd7.Obj) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_6 9
#define LABEL_41_10 11
#define LABEL_41_12 13
#define LABEL_41_9 15
#define LABEL_41_14 17
#define LABEL_41_16 19
#define LABEL_41_17 21
#define LABEL_41_18 23
#define ENVIRONMENT_LABEL_41_3 43
#define DEBUGGING_LABEL_41_2 42
#define OBJECT_41_4 41
#define OBJECT_41_3 40
#define OBJECT_41_2 39
#define OBJECT_41_1 38
#define OBJECT_41_0 37
#define EXECUTE_CACHE_41_19 25
#define EXECUTE_CACHE_41_15 27
#define EXECUTE_CACHE_41_13 29
#define EXECUTE_CACHE_41_11 31
#define EXECUTE_CACHE_41_8 33
#define FREE_REFERENCE_41_0 36
#define FREE_REFERENCES_LABEL_41_0 24
#define NUMBER_OF_LINKER_SECTIONS_41_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd24;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd18;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd48;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd5;
  machine_word Wrd75;
  machine_word Wrd69;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto lambda_12;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_41_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_41_10);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_41_12);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_41_9);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_41_14);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_41_16);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_41_17);
      goto label_17;

    case 10:
      current_block = (Rpc - LABEL_41_18);
      goto label_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_22)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_39;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_39;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_38)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [4]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_37;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_37;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_36)
  (Wrd40.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_41_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_41_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  (Wrd70.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd73.Obj) = ((Wrd70.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_34;
  Wrd69 = Wrd73;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd75.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd75.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_13]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_41_9);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_32)
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_28;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_28;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_27)
  (Rsp [2]) = (Wrd8.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_26;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_25)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_24;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd39.Lng))))
    goto label_24;
  (Wrd33.Obj) = ((Wrd37.pObj) [3]);

DEFLABEL (label_23)
  (Rsp [3]) = (Wrd33.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_19]));

DEFLABEL (label_24)
  (Wrd42.Obj) = (current_block [OBJECT_41_2]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_18]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_18)
  (Wrd33.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_17]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_4]), 1);

DEFLABEL (label_17)
  (Wrd24.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_41_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_16]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_16)
  (Wrd8.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_29)
  (Wrd57.Obj) = (Rsp [5]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 10))
    goto label_31;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd56.Lng))))
    goto label_31;
  (Wrd48.Obj) = ((Wrd54.pObj) [2]);

DEFLABEL (label_30)
  (Rsp [3]) = (Wrd48.Obj);
  (Wrd64.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd64.Obj);
  (Wrd65.Obj) = (Rsp [2]);
  (Rsp [5]) = (Wrd65.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_15]));

DEFLABEL (label_31)
  (Wrd59.Obj) = (Rsp [5]);
  (Wrd60.Obj) = (current_block [OBJECT_41_3]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_14]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_19)
  (Wrd48.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_12])), (Wrd70.pObj));

DEFLABEL (label_20)
  (Wrd69.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_35)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_32;

DEFLABEL (label_37)
  (Wrd35.Obj) = (Rsp [4]);
  (Wrd36.Obj) = (current_block [OBJECT_41_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_41_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_38;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define LABEL_42_7 7
#define ENVIRONMENT_LABEL_42_3 16
#define DEBUGGING_LABEL_42_2 15
#define OBJECT_42_1 14
#define OBJECT_42_0 13
#define EXECUTE_CACHE_42_8 9
#define EXECUTE_CACHE_42_6 11
#define FREE_REFERENCES_LABEL_42_0 8
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto constant_system_global_environmentP_2;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_42_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (constant_system_global_environmentP_6)
DEFLABEL (constant_system_global_environmentP_2)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_9;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_8]));

DEFLABEL (label_9)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_42_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_1]), 2);

DEFLABEL (label_4)
  (Wrd7.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_6 5
#define LABEL_43_5 7
#define LABEL_43_8 9
#define ENVIRONMENT_LABEL_43_3 19
#define DEBUGGING_LABEL_43_2 18
#define OBJECT_43_2 17
#define OBJECT_43_1 16
#define OBJECT_43_0 15
#define EXECUTE_CACHE_43_9 11
#define EXECUTE_CACHE_43_7 13
#define FREE_REFERENCES_LABEL_43_0 10
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_43_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_43_8);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_8)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_12;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_12;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_11)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_43_5);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_10;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_10;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_9)
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd21.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_9]));

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_43_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_43_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_6 5
#define LABEL_44_7 7
#define LABEL_44_8 9
#define LABEL_44_5 11
#define LABEL_44_10 13
#define ENVIRONMENT_LABEL_44_3 22
#define DEBUGGING_LABEL_44_2 21
#define OBJECT_44_3 20
#define OBJECT_44_2 19
#define OBJECT_44_1 18
#define OBJECT_44_0 17
#define EXECUTE_CACHE_44_9 15
#define FREE_REFERENCES_LABEL_44_0 14
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto integrate_quotation_5;

    case 1:
      current_block = (Rpc - LABEL_44_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_44_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_44_10);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_quotation_11)
DEFLABEL (integrate_quotation_5)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_18;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_18;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_17)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_16;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_16;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_15)
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_14;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd48.Lng))))
    goto label_14;
  (Wrd42.Obj) = ((Wrd46.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_44_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_10]))));
  (Rsp [1]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_14)
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.Obj) = (current_block [OBJECT_44_3]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_8]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_44_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_44_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (lambda_12)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_44_10);
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_5 3
#define LABEL_45_4 5
#define LABEL_45_8 7
#define LABEL_45_11 9
#define LABEL_45_13 11
#define LABEL_45_14 13
#define LABEL_45_6 15
#define TAG_45_7 6
#define LABEL_45_10 17
#define LABEL_45_19 19
#define LABEL_45_20 21
#define LABEL_45_21 23
#define LABEL_45_16 25
#define LABEL_45_22 27
#define LABEL_45_18 29
#define LABEL_45_25 31
#define LABEL_45_26 33
#define LABEL_45_23 35
#define ENVIRONMENT_LABEL_45_3 60
#define DEBUGGING_LABEL_45_2 59
#define OBJECT_45_5 58
#define OBJECT_45_4 57
#define OBJECT_45_3 56
#define OBJECT_45_2 55
#define OBJECT_45_1 54
#define OBJECT_45_0 53
#define EXECUTE_CACHE_45_27 37
#define EXECUTE_CACHE_45_24 39
#define EXECUTE_CACHE_45_17 41
#define EXECUTE_CACHE_45_15 43
#define EXECUTE_CACHE_45_12 45
#define EXECUTE_CACHE_45_9 47
#define FREE_REFERENCE_45_2 50
#define FREE_REFERENCE_45_1 51
#define FREE_REFERENCE_45_0 52
#define FREE_REFERENCES_LABEL_45_0 36
#define NUMBER_OF_LINKER_SECTIONS_45_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd51;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd62;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd74;
  machine_word Wrd68;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd67;
  machine_word Wrd42;
  machine_word Wrd75;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_45_4);
      goto integrate_access_operator_20;

    case 2:
      current_block = (Rpc - LABEL_45_8);
      goto label_22;

    case 3:
      current_block = (Rpc - LABEL_45_11);
      goto label_25;

    case 4:
      current_block = (Rpc - LABEL_45_13);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_45_14);
      goto label_24;

    case 6:
      current_block = (Rpc - LABEL_45_6);
      goto lambda_33;

    case 7:
      current_block = (Rpc - LABEL_45_10);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_45_19);
      goto label_27;

    case 9:
      current_block = (Rpc - LABEL_45_20);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_45_21);
      goto continuation_1;

    case 11:
      current_block = (Rpc - LABEL_45_16);
      goto continuation_2;

    case 12:
      current_block = (Rpc - LABEL_45_22);
      goto label_28;

    case 13:
      current_block = (Rpc - LABEL_45_18);
      goto continuation_8;

    case 14:
      current_block = (Rpc - LABEL_45_25);
      goto label_29;

    case 15:
      current_block = (Rpc - LABEL_45_26);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_45_23);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_access_operator_32)
DEFLABEL (integrate_access_operator_20)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_45_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_45_6])));
  Rhp += 6;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd17 = Wrd6;
  (Wrd18.Obj) = (Rsp [5]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [4]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd17.pObj) [5]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [6]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd17.pObj) [7]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd29.uLng) == 10))
    goto label_54;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd27.Lng))))
    goto label_54;
  (Wrd21.Obj) = ((Wrd25.pObj) [4]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_53)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  if (! ((Wrd38.Obj) == (current_block [OBJECT_45_2])))
    goto label_52;
  (Wrd75.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd75.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_45_5);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_51)
  (Wrd42.Obj) = (Rsp [0]);
  if ((Wrd42.Obj) == ((SCHEME_OBJECT) 0))
    goto label_38;
  (Rsp [2]) = (Wrd42.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_37;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [0]);

DEFLABEL (label_36)
  (Rsp [5]) = (Wrd45.Obj);
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_35;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd54.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_34)
  (Rsp [6]) = (Wrd54.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_15]));

DEFLABEL (label_35)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_14]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_4]), 1);

DEFLABEL (label_24)
  (Wrd54.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_13]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_3]), 1);

DEFLABEL (label_23)
  (Wrd45.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_10]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_0]));
  (Wrd72.Obj) = ((Wrd69.pObj) [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if ((Wrd73.uLng) == 50)
    goto label_50;
  Wrd68 = Wrd72;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd74.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd74.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_45_10);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_40;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_39)
  (Rsp [5]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_15]));

DEFLABEL (label_40)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_20]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_4]), 1);

DEFLABEL (label_26)
  (Wrd9.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_41)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_1]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_48;
  Wrd23 = Wrd27;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_45_18);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_42;
  (Wrd29.Obj) = (Rsp [2]);
  (Rsp [8]) = (Wrd29.Obj);
  Rsp = (& (Rsp [8]));
  goto lambda_4;

DEFLABEL (label_42)
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [7]) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [8]);
  (Rsp [5]) = (Wrd10.Obj);
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 1))
    goto label_46;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_45)
  (Rsp [3]) = (Wrd11.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45_2]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_44;
  Wrd21 = Wrd25;

DEFLABEL (label_43)
  (Rsp [6]) = (Wrd21.Obj);
  (Rsp [8]) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 6);
  }

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_26])), (Wrd22.pObj));

DEFLABEL (label_30)
  (Wrd21.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_25]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_4]), 1);

DEFLABEL (label_29)
  (Wrd11.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_19])), (Wrd24.pObj));

DEFLABEL (label_27)
  (Wrd23.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45_11])), (Wrd69.pObj));

DEFLABEL (label_25)
  (Wrd68.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_51;

DEFLABEL (label_54)
  (Wrd30.Obj) = (Rsp [5]);
  (Wrd31.Obj) = (current_block [OBJECT_45_0]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_8]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_45_6);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd9.pObj) [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_45_16);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_21]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [7]);
  if ((Wrd13.Obj) == ((SCHEME_OBJECT) 0))
    goto label_58;
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_57;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd28.Lng))))
    goto label_57;
  (Wrd16.Obj) = ((Wrd26.pObj) [2]);

DEFLABEL (label_56)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_55)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_23]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [4]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [2]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd48.Obj) = ((Wrd44.pObj) [5]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd51.Obj) = ((Wrd44.pObj) [6]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_24]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_45_23);
  (Rsp [3]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_27]));

DEFLABEL (label_57)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [7]);
  (Wrd36.Obj) = (current_block [OBJECT_45_5]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_22]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_28)
  (Wrd16.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_58)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_55;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_45_21);
  (* (--Rsp)) = Rvl;
  goto label_55;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_10 7
#define LABEL_46_6 9
#define TAG_46_7 3
#define LABEL_46_9 11
#define LABEL_46_13 13
#define LABEL_46_18 15
#define LABEL_46_14 17
#define TAG_46_15 7
#define LABEL_46_17 19
#define LABEL_46_19 21
#define TAG_46_20 9
#define ENVIRONMENT_LABEL_46_3 38
#define DEBUGGING_LABEL_46_2 37
#define OBJECT_46_2 36
#define OBJECT_46_1 35
#define OBJECT_46_0 34
#define EXECUTE_CACHE_46_16 23
#define EXECUTE_CACHE_46_12 25
#define EXECUTE_CACHE_46_11 27
#define EXECUTE_CACHE_46_8 29
#define FREE_REFERENCE_46_1 32
#define FREE_REFERENCE_46_0 33
#define FREE_REFERENCES_LABEL_46_0 22
#define NUMBER_OF_LINKER_SECTIONS_46_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto environment_recursive_bind_10;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_46_10);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_46_6);
      goto lambda_16;

    case 4:
      current_block = (Rpc - LABEL_46_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_46_13);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_46_18);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_46_14);
      goto lambda_17;

    case 8:
      current_block = (Rpc - LABEL_46_17);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_46_19);
      goto lambda_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_recursive_bind_15)
DEFLABEL (environment_recursive_bind_10)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_6])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_22;
  Wrd10 = Wrd14;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_46_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_14])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  ((Wrd10.pObj) [2]) = Rvl;
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_16]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_46_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_17]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_20;
  Wrd10 = Wrd14;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_46_17);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [4]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_19])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_18])), (Wrd11.pObj));

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_10])), (Wrd11.pObj));

DEFLABEL (label_12)
  (Wrd10.Obj) = Rvl;
  goto label_21;

DEFLABEL (lambda_16)
  CLOSURE_HEADER (LABEL_46_6);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_12]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_46_14);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_46_0]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd22.uLng) == 10)
    goto label_24;

DEFLABEL (label_23)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_2]), 3);

DEFLABEL (label_24)
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_23;
  ((Wrd18.pObj) [3]) = (Wrd6.Obj);
  Rvl = (current_block [OBJECT_46_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_46_19);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define LABEL_47_11 7
#define LABEL_47_6 9
#define TAG_47_7 3
#define LABEL_47_14 11
#define LABEL_47_8 13
#define TAG_47_9 5
#define LABEL_47_12 15
#define LABEL_47_13 17
#define LABEL_47_16 19
#define LABEL_47_19 21
#define LABEL_47_21 23
#define ENVIRONMENT_LABEL_47_3 42
#define DEBUGGING_LABEL_47_2 41
#define OBJECT_47_3 40
#define OBJECT_47_2 39
#define OBJECT_47_1 38
#define OBJECT_47_0 37
#define EXECUTE_CACHE_47_22 25
#define EXECUTE_CACHE_47_20 27
#define EXECUTE_CACHE_47_18 29
#define EXECUTE_CACHE_47_17 31
#define EXECUTE_CACHE_47_15 33
#define EXECUTE_CACHE_47_10 35
#define FREE_REFERENCES_LABEL_47_0 24
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd10;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto integrate_name_12;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_47_11);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_47_6);
      goto lambda_4;

    case 4:
      current_block = (Rpc - LABEL_47_14);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_47_8);
      goto lambda_20;

    case 6:
      current_block = (Rpc - LABEL_47_12);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_47_13);
      goto continuation_2;

    case 8:
      current_block = (Rpc - LABEL_47_16);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_47_19);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_47_21);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_name_18)
DEFLABEL (integrate_name_12)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_25;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_25;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_24)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_47_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_47_6])));
  Rhp += 3;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd27 = Wrd22;
  (Wrd28.Obj) = (Rsp [5]);
  ((Wrd27.pObj) [2]) = (Wrd28.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  ((Wrd27.pObj) [3]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  ((Wrd27.pObj) [4]) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd29.Obj) = (Rsp [4]);
  if (! ((Wrd29.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_21;
  (Wrd42.Obj) = (Rsp [5]);
  (Rsp [3]) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [7]);
  (Rsp [6]) = (Wrd44.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd47.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_47_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_47_8])));
  Rhp += 2;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd47.pObj)));
  Wrd50 = Wrd47;
  ((Wrd50.pObj) [2]) = (Wrd44.Obj);
  ((Wrd50.pObj) [3]) = (Wrd21.Obj);
  (Rsp [5]) = (Wrd46.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_10]));

DEFLABEL (label_21)
  (Rsp [6]) = (Wrd21.Obj);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_23;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [7]) = (Wrd32.Obj);
  Rsp = (& (Rsp [6]));
  goto lambda_4;

DEFLABEL (label_23)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_11]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_2]), 1);

DEFLABEL (label_15)
  (Wrd32.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_47_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (lambda_19)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_47_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_27;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_27;
  (Wrd16.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_26)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_15]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_47_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_47_12);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_27)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [3]);
  (Wrd32.Obj) = (current_block [OBJECT_47_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_14]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_47_8);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_47_16);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_28;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [0]) = (Wrd11.Obj);
  goto lambda_4;

DEFLABEL (label_28)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_20]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_47_19);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_29)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_22]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_47_21);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_4;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define TAG_48_6 1
#define LABEL_48_7 7
#define TAG_48_8 2
#define LABEL_48_15 9
#define LABEL_48_9 11
#define TAG_48_10 4
#define LABEL_48_12 13
#define LABEL_48_14 15
#define LABEL_48_17 17
#define LABEL_48_19 19
#define ENVIRONMENT_LABEL_48_3 38
#define DEBUGGING_LABEL_48_2 37
#define OBJECT_48_3 36
#define OBJECT_48_2 35
#define OBJECT_48_1 34
#define OBJECT_48_0 33
#define EXECUTE_CACHE_48_21 21
#define EXECUTE_CACHE_48_20 23
#define EXECUTE_CACHE_48_18 25
#define EXECUTE_CACHE_48_16 27
#define EXECUTE_CACHE_48_13 29
#define EXECUTE_CACHE_48_11 31
#define FREE_REFERENCES_LABEL_48_0 20
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto variable_final_value_8;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_48_7);
      goto lambda_14;

    case 3:
      current_block = (Rpc - LABEL_48_15);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_48_9);
      goto lambda_15;

    case 5:
      current_block = (Rpc - LABEL_48_12);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_48_14);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_48_17);
      goto continuation_1;

    case 8:
      current_block = (Rpc - LABEL_48_19);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (variable_final_value_12)
DEFLABEL (variable_final_value_8)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_5])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [3]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_7])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  (Wrd17.Obj) = (Rsp [4]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_9])));
  Rhp += 1;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  ((Wrd20.pObj) [2]) = (Wrd17.Obj);
  (Rsp [3]) = (Wrd19.Obj);
  (Rsp [4]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_11]));

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_48_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_13]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_48_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [0]) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_18]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_48_17);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd7.Obj) = (current_block [OBJECT_48_3]);
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_21]));

DEFLABEL (label_17)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_19]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_20]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_48_19);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_48_7);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_19;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_19;
  (Wrd12.Obj) = ((Wrd18.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_18)
  (Wrd32.Obj) = (current_block [OBJECT_48_2]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_48_14);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_19)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [3]);
  (Wrd28.Obj) = (current_block [OBJECT_48_0]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_18;

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_48_9);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define LABEL_49_6 7
#define LABEL_49_7 9
#define LABEL_49_8 11
#define LABEL_49_9 13
#define LABEL_49_10 15
#define LABEL_49_11 17
#define LABEL_49_12 19
#define LABEL_49_13 21
#define LABEL_49_14 23
#define LABEL_49_15 25
#define LABEL_49_16 27
#define ENVIRONMENT_LABEL_49_3 38
#define DEBUGGING_LABEL_49_2 37
#define OBJECT_49_6 36
#define OBJECT_49_5 35
#define OBJECT_49_4 34
#define OBJECT_49_3 33
#define OBJECT_49_2 32
#define OBJECT_49_1 31
#define OBJECT_49_0 30
#define FREE_REFERENCE_49_0 29
#define FREE_REFERENCES_LABEL_49_0 28
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd68;
  machine_word Wrd59;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd8;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd39;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto simulate_unknown_application_18;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_49_6);
      goto bind_required_7;

    case 3:
      current_block = (Rpc - LABEL_49_7);
      goto label_24;

    case 4:
      current_block = (Rpc - LABEL_49_8);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_49_9);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_49_10);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_49_11);
      goto bind_optional_14;

    case 8:
      current_block = (Rpc - LABEL_49_12);
      goto label_28;

    case 9:
      current_block = (Rpc - LABEL_49_13);
      goto label_29;

    case 10:
      current_block = (Rpc - LABEL_49_14);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_49_15);
      goto label_26;

    case 12:
      current_block = (Rpc - LABEL_49_16);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (simulate_unknown_application_31)
DEFLABEL (simulate_unknown_application_18)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_35;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_35;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_34)
  (Wrd21.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd21.Obj);
  goto bind_required_7;

DEFLABEL (label_35)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_49_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (bind_required_32)
DEFLABEL (bind_required_7)
  INTERRUPT_CHECK (26, LABEL_49_6);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_49_2]))
    goto label_42;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_41;
  Wrd7 = Wrd11;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_39;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_38)
  (Wrd22.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd29.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_37;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_36)
  (Rsp [1]) = (Wrd30.Obj);
  goto bind_required_7;

DEFLABEL (label_37)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_10]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_5]), 1);

DEFLABEL (label_23)
  (Wrd30.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_9]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_4]), 1);

DEFLABEL (label_22)
  (Wrd13.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_49_8])), (Wrd8.pObj));

DEFLABEL (label_21)
  (Wrd7.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_42)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_44;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd47.Lng))))
    goto label_44;
  (Wrd39.Obj) = ((Wrd45.pObj) [6]);

DEFLABEL (label_43)
  (Rsp [1]) = (Wrd39.Obj);
  goto bind_optional_14;

DEFLABEL (label_44)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.Obj) = (current_block [OBJECT_49_3]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_7]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_24)
  (Wrd39.Obj) = Rvl;
  goto label_43;

DEFLABEL (bind_optional_33)
DEFLABEL (bind_optional_14)
  INTERRUPT_CHECK (26, LABEL_49_11);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_49_2]))
    goto label_51;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_50;
  Wrd7 = Wrd11;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_48;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_47)
  (Wrd22.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd29.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_46;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_45)
  (Rsp [1]) = (Wrd30.Obj);
  goto bind_optional_14;

DEFLABEL (label_46)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_16]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_5]), 1);

DEFLABEL (label_27)
  (Wrd30.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_15]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_4]), 1);

DEFLABEL (label_26)
  (Wrd13.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_49_14])), (Wrd8.pObj));

DEFLABEL (label_25)
  (Wrd7.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_51)
  (Wrd39.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd39.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_57;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd48.Lng))))
    goto label_57;
  (Wrd40.Obj) = ((Wrd46.pObj) [7]);

DEFLABEL (label_56)
  (Rsp [3]) = (Wrd40.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd56.Obj) = (Rsp [1]);
  if ((Wrd56.Obj) == (current_block [OBJECT_49_2]))
    goto label_55;
  (Wrd60.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49_0]));
  (Wrd63.Obj) = ((Wrd60.pObj) [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 50)
    goto label_54;
  Wrd59 = Wrd63;

DEFLABEL (label_53)
  (Wrd68.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd68.Obj);
  (* (Rhp++)) = (Wrd59.Obj);
  (Wrd67.pObj) = (& (Rhp [-2]));
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd67.pObj)));
  (Wrd73.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd65.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (Wrd71.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd71.pObj)));

DEFLABEL (label_52)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_49_13])), (Wrd60.pObj));

DEFLABEL (label_29)
  (Wrd59.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  Rvl = (Rsp [0]);
  goto label_52;

DEFLABEL (label_57)
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.Obj) = (current_block [OBJECT_49_6]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_12]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_28)
  (Wrd40.Obj) = Rvl;
  goto label_56;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define LABEL_50_6 7
#define LABEL_50_10 9
#define LABEL_50_8 11
#define LABEL_50_12 13
#define LABEL_50_13 15
#define LABEL_50_17 17
#define LABEL_50_15 19
#define LABEL_50_18 21
#define LABEL_50_20 23
#define LABEL_50_21 25
#define LABEL_50_19 27
#define LABEL_50_22 29
#define LABEL_50_23 31
#define LABEL_50_25 33
#define LABEL_50_26 35
#define LABEL_50_24 37
#define LABEL_50_28 39
#define ENVIRONMENT_LABEL_50_3 64
#define DEBUGGING_LABEL_50_2 63
#define OBJECT_50_9 62
#define OBJECT_50_8 61
#define OBJECT_50_7 60
#define OBJECT_50_6 59
#define OBJECT_50_5 58
#define OBJECT_50_4 57
#define OBJECT_50_3 56
#define OBJECT_50_2 55
#define OBJECT_50_1 54
#define OBJECT_50_0 53
#define EXECUTE_CACHE_50_27 41
#define EXECUTE_CACHE_50_16 43
#define EXECUTE_CACHE_50_14 45
#define EXECUTE_CACHE_50_11 47
#define EXECUTE_CACHE_50_9 49
#define EXECUTE_CACHE_50_7 51
#define FREE_REFERENCES_LABEL_50_0 40
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd67;
  machine_word Wrd62;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd28;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd66;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto integrate_hack_applyP_28;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_50_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_50_10);
      goto label_30;

    case 4:
      current_block = (Rpc - LABEL_50_8);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_50_12);
      goto check_27;

    case 6:
      current_block = (Rpc - LABEL_50_13);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_50_17);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_50_15);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_50_18);
      goto label_32;

    case 10:
      current_block = (Rpc - LABEL_50_20);
      goto continuation_11;

    case 11:
      current_block = (Rpc - LABEL_50_21);
      goto continuation_15;

    case 12:
      current_block = (Rpc - LABEL_50_19);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_50_22);
      goto label_33;

    case 14:
      current_block = (Rpc - LABEL_50_23);
      goto label_34;

    case 15:
      current_block = (Rpc - LABEL_50_25);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_50_26);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_50_24);
      goto continuation_19;

    case 18:
      current_block = (Rpc - LABEL_50_28);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (integrate_hack_applyP_39)
DEFLABEL (integrate_hack_applyP_28)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_50_0])))
    goto label_41;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_41)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_50_6);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_44;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_43)
  goto check_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_50_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == (current_block [OBJECT_50_1])))
    goto label_42;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_50_8);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_11]));

DEFLABEL (label_44)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_10]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_2]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (check_40)
DEFLABEL (check_27)
  INTERRUPT_CHECK (26, LABEL_50_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_50_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_15]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_50_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_45;
  Rvl = (current_block [OBJECT_50_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_62;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_62;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_61)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_19]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_14]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_50_19);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_60;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_59;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_59;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_58)
  if ((Wrd7.Obj) == (current_block [OBJECT_50_7]))
    goto label_47;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_21]))));
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_46)
  (Wrd67.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd67.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_27]));

DEFLABEL (label_47)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_57;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd36.Lng))))
    goto label_57;
  (Wrd28.Obj) = ((Wrd34.pObj) [5]);

DEFLABEL (label_56)
  (Rsp [1]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_24]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd50.Obj) = (Rsp [1]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_55;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd47.Obj) = ((Wrd49.pObj) [1]);

DEFLABEL (label_54)
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_53;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [0]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_52)
  goto check_27;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_50_24);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_50_1]);
  if (Rvl == (Wrd6.Obj))
    goto label_51;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_50;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_49)
  (Wrd20.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));

DEFLABEL (label_48)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_50)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_28]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_2]), 1);

DEFLABEL (label_37)
  (Wrd7.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_51)
  Rvl = (Wrd6.Obj);
  goto label_48;

DEFLABEL (label_53)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_26]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_2]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_25]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_9]), 1);

DEFLABEL (label_35)
  (Wrd47.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.Obj) = (current_block [OBJECT_50_8]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_23]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_4]), 2);

DEFLABEL (label_34)
  (Wrd28.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_50_3]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_22]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_4]), 2);

DEFLABEL (label_33)
  (Wrd7.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_60)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_20]))));
  (* (--Rsp)) = (Wrd66.Obj);
  goto label_46;

DEFLABEL (label_62)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_50_5]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_4]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_63)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_68;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_68;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_67)
  (Wrd23.Obj) = (current_block [OBJECT_50_0]);
  if ((Wrd7.Obj) == (Wrd23.Obj))
    goto label_65;
  Rvl = (current_block [OBJECT_50_1]);
  goto label_64;

DEFLABEL (label_65)
  Rvl = (Wrd23.Obj);

DEFLABEL (label_64)
DEFLABEL (label_66)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_68)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_50_3]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_17]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_4]), 2);

DEFLABEL (label_31)
  (Wrd7.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_50_21);

DEFLABEL (label_69)
  if (Rvl == (current_block [OBJECT_50_6]))
    goto label_47;
  Rvl = (current_block [OBJECT_50_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_50_20);
  goto label_69;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define LABEL_51_6 7
#define LABEL_51_7 9
#define LABEL_51_9 11
#define LABEL_51_10 13
#define LABEL_51_11 15
#define LABEL_51_12 17
#define LABEL_51_8 19
#define LABEL_51_14 21
#define LABEL_51_15 23
#define LABEL_51_16 25
#define LABEL_51_18 27
#define LABEL_51_19 29
#define LABEL_51_20 31
#define LABEL_51_21 33
#define LABEL_51_22 35
#define LABEL_51_23 37
#define LABEL_51_25 39
#define LABEL_51_27 41
#define LABEL_51_28 43
#define LABEL_51_29 45
#define LABEL_51_30 47
#define LABEL_51_31 49
#define LABEL_51_32 51
#define LABEL_51_33 53
#define LABEL_51_17 55
#define LABEL_51_34 57
#define LABEL_51_35 59
#define LABEL_51_36 61
#define LABEL_51_39 63
#define LABEL_51_38 65
#define LABEL_51_37 67
#define LABEL_51_41 69
#define LABEL_51_42 71
#define LABEL_51_44 73
#define LABEL_51_43 75
#define LABEL_51_45 77
#define ENVIRONMENT_LABEL_51_3 107
#define DEBUGGING_LABEL_51_2 106
#define OBJECT_51_14 105
#define OBJECT_51_13 104
#define OBJECT_51_12 103
#define OBJECT_51_11 102
#define OBJECT_51_10 101
#define OBJECT_51_9 100
#define OBJECT_51_8 99
#define OBJECT_51_7 98
#define OBJECT_51_6 97
#define OBJECT_51_5 96
#define OBJECT_51_4 95
#define OBJECT_51_3 94
#define OBJECT_51_2 93
#define OBJECT_51_1 92
#define OBJECT_51_0 91
#define EXECUTE_CACHE_51_46 79
#define EXECUTE_CACHE_51_40 81
#define EXECUTE_CACHE_51_26 83
#define EXECUTE_CACHE_51_24 85
#define EXECUTE_CACHE_51_13 87
#define FREE_REFERENCE_51_0 90
#define FREE_REFERENCES_LABEL_51_0 78
#define NUMBER_OF_LINKER_SECTIONS_51_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd23;
  machine_word Wrd9;
  machine_word Wrd62;
  machine_word Wrd85;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd79;
  machine_word Wrd128;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd113;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd80;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd63;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd36;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd98;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd83;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd52;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd7;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd58;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd6;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto simulate_application_62;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto label_64;

    case 2:
      current_block = (Rpc - LABEL_51_6);
      goto match_required_30;

    case 3:
      current_block = (Rpc - LABEL_51_7);
      goto label_69;

    case 4:
      current_block = (Rpc - LABEL_51_9);
      goto label_65;

    case 5:
      current_block = (Rpc - LABEL_51_10);
      goto label_66;

    case 6:
      current_block = (Rpc - LABEL_51_11);
      goto label_67;

    case 7:
      current_block = (Rpc - LABEL_51_12);
      goto label_68;

    case 8:
      current_block = (Rpc - LABEL_51_8);
      goto continuation_28;

    case 9:
      current_block = (Rpc - LABEL_51_14);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_51_15);
      goto procedure__pretty_19;

    case 11:
      current_block = (Rpc - LABEL_51_16);
      goto label_77;

    case 12:
      current_block = (Rpc - LABEL_51_18);
      goto label_75;

    case 13:
      current_block = (Rpc - LABEL_51_19);
      goto label_74;

    case 14:
      current_block = (Rpc - LABEL_51_20);
      goto label_70;

    case 15:
      current_block = (Rpc - LABEL_51_21);
      goto label_71;

    case 16:
      current_block = (Rpc - LABEL_51_22);
      goto label_72;

    case 17:
      current_block = (Rpc - LABEL_51_23);
      goto label_73;

    case 18:
      current_block = (Rpc - LABEL_51_25);
      goto label_76;

    case 19:
      current_block = (Rpc - LABEL_51_27);
      goto match_optional_41;

    case 20:
      current_block = (Rpc - LABEL_51_28);
      goto label_83;

    case 21:
      current_block = (Rpc - LABEL_51_29);
      goto label_82;

    case 22:
      current_block = (Rpc - LABEL_51_30);
      goto label_78;

    case 23:
      current_block = (Rpc - LABEL_51_31);
      goto label_79;

    case 24:
      current_block = (Rpc - LABEL_51_32);
      goto label_80;

    case 25:
      current_block = (Rpc - LABEL_51_33);
      goto label_81;

    case 26:
      current_block = (Rpc - LABEL_51_17);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_51_34);
      goto label_85;

    case 28:
      current_block = (Rpc - LABEL_51_35);
      goto label_84;

    case 29:
      current_block = (Rpc - LABEL_51_36);
      goto match_rest_61;

    case 30:
      current_block = (Rpc - LABEL_51_39);
      goto continuation_42;

    case 31:
      current_block = (Rpc - LABEL_51_38);
      goto continuation_59;

    case 32:
      current_block = (Rpc - LABEL_51_37);
      goto continuation_58;

    case 33:
      current_block = (Rpc - LABEL_51_41);
      goto continuation_44;

    case 34:
      current_block = (Rpc - LABEL_51_42);
      goto walk_52;

    case 35:
      current_block = (Rpc - LABEL_51_44);
      goto label_86;

    case 36:
      current_block = (Rpc - LABEL_51_43);
      goto continuation_49;

    case 37:
      current_block = (Rpc - LABEL_51_45);
      goto label_87;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (simulate_application_89)
DEFLABEL (simulate_application_62)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_96;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd14.Lng))))
    goto label_96;
  (Wrd8.Obj) = ((Wrd12.pObj) [5]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_95)
  (Wrd22.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto match_required_30;

DEFLABEL (label_96)
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.Obj) = (current_block [OBJECT_51_0]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_64)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (match_required_90)
DEFLABEL (match_required_30)
  INTERRUPT_CHECK (26, LABEL_51_6);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_51_2]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_106;
  (Wrd7.Obj) = (Rsp [2]);
  if (! ((Wrd7.Obj) == (Wrd6.Obj)))
    goto label_97;
  (Wrd53.Obj) = (current_block [OBJECT_51_4]);
  (Rsp [4]) = (Wrd53.Obj);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_8]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd57.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd57.Obj);
  goto procedure__pretty_19;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_51_8);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_13]));

DEFLABEL (label_97)
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_105;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_104)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_103;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_102)
  (Wrd27.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (Wrd34.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd33.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd33.pObj)));
  (Rsp [0]) = (Wrd31.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_101;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_100)
  (Rsp [1]) = (Wrd35.Obj);
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_99;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_98)
  (Rsp [2]) = (Wrd44.Obj);
  goto match_required_30;

DEFLABEL (label_99)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_12]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_6]), 1);

DEFLABEL (label_68)
  (Wrd44.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_11]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_6]), 1);

DEFLABEL (label_67)
  (Wrd35.Obj) = Rvl;
  goto label_100;

DEFLABEL (label_103)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_5]), 1);

DEFLABEL (label_66)
  (Wrd18.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_5]), 1);

DEFLABEL (label_65)
  (* (--Rsp)) = Rvl;
  goto label_104;

DEFLABEL (label_106)
  (Wrd67.Obj) = (Rsp [5]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if (! ((Wrd68.uLng) == 10))
    goto label_108;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd66.Lng))))
    goto label_108;
  (Wrd58.Obj) = ((Wrd64.pObj) [6]);

DEFLABEL (label_107)
  (Rsp [1]) = (Wrd58.Obj);
  goto match_optional_41;

DEFLABEL (label_108)
  (Wrd69.Obj) = (Rsp [5]);
  (Wrd70.Obj) = (current_block [OBJECT_51_3]);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_7]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_69)
  (Wrd58.Obj) = Rvl;
  goto label_107;

DEFLABEL (procedure__pretty_91)
DEFLABEL (procedure__pretty_19)
  INTERRUPT_CHECK (26, LABEL_51_15);
  (Wrd135.Obj) = (Rsp [0]);
  (Wrd136.uLng) = (OBJECT_TYPE (Wrd135.Obj));
  if (! ((Wrd136.uLng) == 10))
    goto label_135;
  (Wrd132.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  (Wrd133.Obj) = ((Wrd132.pObj) [0]);
  (Wrd134.Lng) = (FIXNUM_TO_LONG (Wrd133.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd134.Lng))))
    goto label_135;
  (Wrd7.Obj) = ((Wrd132.pObj) [2]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_112;

DEFLABEL (label_111)
  (Wrd122.Obj) = (Rsp [0]);
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if (! ((Wrd123.uLng) == 10))
    goto label_110;
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd122.Obj));
  (Wrd120.Obj) = ((Wrd119.pObj) [0]);
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd120.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd121.Lng))))
    goto label_110;
  (Wrd113.Obj) = ((Wrd119.pObj) [2]);

DEFLABEL (label_109)
  (Rsp [0]) = (Wrd113.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_26]));

DEFLABEL (label_110)
  (Wrd124.Obj) = (Rsp [0]);
  (Wrd125.Obj) = (current_block [OBJECT_51_7]);
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_25]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd124.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_76)
  (Wrd113.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_14]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd105.Obj) = (Rsp [2]);
  (Wrd106.uLng) = (OBJECT_TYPE (Wrd105.Obj));
  if (! ((Wrd106.uLng) == 10))
    goto label_134;
  (Wrd102.pObj) = (OBJECT_ADDRESS (Wrd105.Obj));
  (Wrd103.Obj) = ((Wrd102.pObj) [0]);
  (Wrd104.Lng) = (FIXNUM_TO_LONG (Wrd103.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd104.Lng))))
    goto label_134;
  (Wrd17.Obj) = ((Wrd102.pObj) [7]);
  if ((Wrd17.Obj) == ((SCHEME_OBJECT) 0))
    goto label_133;

DEFLABEL (label_132)
  (Wrd92.Obj) = (Rsp [2]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if (! ((Wrd93.uLng) == 10))
    goto label_131;
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  (Wrd90.Obj) = ((Wrd89.pObj) [0]);
  (Wrd91.Lng) = (FIXNUM_TO_LONG (Wrd90.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd91.Lng))))
    goto label_131;
  (Wrd83.Obj) = ((Wrd89.pObj) [7]);

DEFLABEL (label_130)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd83.Obj);

DEFLABEL (label_129)
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_128;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd29.Lng))))
    goto label_128;
  (Wrd21.Obj) = ((Wrd27.pObj) [6]);

DEFLABEL (label_127)
  (Wrd37.Obj) = (current_block [OBJECT_51_2]);
  if ((Wrd21.Obj) == (Wrd37.Obj))
    goto label_126;
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_125;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd46.Lng))))
    goto label_125;
  (Wrd40.Obj) = ((Wrd44.pObj) [6]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_124)
  (Wrd56.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_51_0]));
  (Wrd59.Obj) = ((Wrd56.pObj) [0]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if ((Wrd60.uLng) == 50)
    goto label_123;
  Wrd55 = Wrd59;

DEFLABEL (label_122)
  (Wrd61.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd61.Obj);
  (Wrd63.pObj) = (& (Rhp [-2]));
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd63.pObj)));
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_121)
  (Wrd74.Obj) = (Rsp [3]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 10))
    goto label_120;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd72.Obj) = ((Wrd71.pObj) [0]);
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd72.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd73.Lng))))
    goto label_120;
  (Wrd67.Obj) = ((Wrd71.pObj) [5]);
  (* (--Rsp)) = (Wrd67.Obj);

DEFLABEL (label_119)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_24]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_51_17);
  (* (--Rsp)) = Rvl;
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_118;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd61.Lng))))
    goto label_118;
  (Wrd7.Obj) = ((Wrd59.pObj) [4]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_117;

DEFLABEL (label_116)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_115;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd31.Lng))))
    goto label_115;
  (Wrd23.Obj) = ((Wrd29.pObj) [4]);

DEFLABEL (label_114)
  (Wrd42.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd42.Obj);
  (Wrd41.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd41.pObj)));
  (Wrd46.Obj) = (current_block [OBJECT_51_10]);
  (Wrd47.Obj) = (current_block [OBJECT_51_2]);
  (* (Rhp++)) = (Wrd46.Obj);
  (* (Rhp++)) = (Wrd47.Obj);
  (Wrd45.pObj) = (& (Rhp [-2]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd45.pObj)));
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd43.Obj);
  (Wrd50.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd50.pObj)));
  (Wrd55.Obj) = (current_block [OBJECT_51_12]);
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd48.Obj);

DEFLABEL (label_113)
  (Wrd20.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_115)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_51_9]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_35]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_84)
  (Wrd23.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd12.Obj) = (current_block [OBJECT_51_10]);
  (Wrd13.Obj) = (current_block [OBJECT_51_2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (Wrd17.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd22.Obj) = (current_block [OBJECT_51_11]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  goto label_113;

DEFLABEL (label_118)
  (Wrd64.Obj) = (Rsp [1]);
  (Wrd65.Obj) = (current_block [OBJECT_51_9]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_34]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_85)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_117;
  goto label_116;

DEFLABEL (label_120)
  (Wrd76.Obj) = (Rsp [3]);
  (Wrd77.Obj) = (current_block [OBJECT_51_0]);
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_23]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_119;

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_51_22])), (Wrd56.pObj));

DEFLABEL (label_72)
  (Wrd55.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (current_block [OBJECT_51_3]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_21]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_124;

DEFLABEL (label_126)
  (* (--Rsp)) = (Wrd37.Obj);
  goto label_121;

DEFLABEL (label_128)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.Obj) = (current_block [OBJECT_51_3]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_20]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_70)
  (Wrd21.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_131)
  (Wrd94.Obj) = (Rsp [2]);
  (Wrd95.Obj) = (current_block [OBJECT_51_8]);
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_19]))));
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_74)
  (Wrd83.Obj) = Rvl;
  goto label_130;

DEFLABEL (label_133)
  (Wrd20.Obj) = (current_block [OBJECT_51_2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd20.Obj);
  goto label_129;

DEFLABEL (label_134)
  (Wrd107.Obj) = (Rsp [2]);
  (Wrd108.Obj) = (current_block [OBJECT_51_8]);
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_18]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (--Rsp)) = (Wrd108.Obj);
  (* (--Rsp)) = (Wrd107.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_75)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_133;
  goto label_132;

DEFLABEL (label_135)
  (Wrd137.Obj) = (Rsp [0]);
  (Wrd138.Obj) = (current_block [OBJECT_51_7]);
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_16]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  (* (--Rsp)) = (Wrd137.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_77)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_112;
  goto label_111;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_51_14);
  (* (--Rsp)) = Rvl;
  goto label_129;

DEFLABEL (match_optional_92)
DEFLABEL (match_optional_41)
  INTERRUPT_CHECK (26, LABEL_51_27);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_51_2]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_147;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_144;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_143;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_142)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_141;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_140)
  (Wrd27.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (Wrd34.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd33.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd33.pObj)));
  (Rsp [0]) = (Wrd31.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_139;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_138)
  (Rsp [1]) = (Wrd35.Obj);
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_137;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_136)
  (Rsp [2]) = (Wrd44.Obj);
  goto match_optional_41;

DEFLABEL (label_137)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_33]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_6]), 1);

DEFLABEL (label_81)
  (Wrd44.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_32]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_6]), 1);

DEFLABEL (label_80)
  (Wrd35.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_31]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_5]), 1);

DEFLABEL (label_79)
  (Wrd18.Obj) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_30]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_5]), 1);

DEFLABEL (label_78)
  (* (--Rsp)) = Rvl;
  goto label_142;

DEFLABEL (label_144)
  (Wrd62.Obj) = (Rsp [5]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_146;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd61.Lng))))
    goto label_146;
  (Wrd53.Obj) = ((Wrd59.pObj) [7]);

DEFLABEL (label_145)
  (Rsp [1]) = (Wrd53.Obj);
  (Wrd69.Obj) = (current_block [OBJECT_51_2]);
  (Rsp [2]) = (Wrd69.Obj);
  goto match_rest_61;

DEFLABEL (label_146)
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.Obj) = (current_block [OBJECT_51_8]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_29]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_82)
  (Wrd53.Obj) = Rvl;
  goto label_145;

DEFLABEL (label_147)
  (Wrd79.Obj) = (Rsp [5]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd80.uLng) == 10))
    goto label_149;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd78.Lng))))
    goto label_149;
  (Wrd70.Obj) = ((Wrd76.pObj) [7]);

DEFLABEL (label_148)
  (Rsp [1]) = (Wrd70.Obj);
  goto match_rest_61;

DEFLABEL (label_149)
  (Wrd81.Obj) = (Rsp [5]);
  (Wrd82.Obj) = (current_block [OBJECT_51_8]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_28]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_83)
  (Wrd70.Obj) = Rvl;
  goto label_148;

DEFLABEL (match_rest_93)
DEFLABEL (match_rest_61)
  INTERRUPT_CHECK (26, LABEL_51_36);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_152;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_38]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_51_2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_40]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_51_39);
  (* (--Rsp)) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  if ((Wrd15.Obj) == (current_block [OBJECT_51_2]))
    goto label_150;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_41]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_51_14]);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_40]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_51_41);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [5]));
  goto walk_52;

DEFLABEL (label_150)
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [3]));

DEFLABEL (label_151)
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_152)
  (Wrd16.Obj) = (Rsp [2]);
  if (! ((Wrd16.Obj) == (current_block [OBJECT_51_2])))
    goto label_153;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_153)
  (Wrd18.Obj) = (current_block [OBJECT_51_13]);
  (Rsp [4]) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_37]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto procedure__pretty_19;

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_51_37);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_13]));

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_51_38);
  (Wrd5.Obj) = Rvl;
  goto label_151;

DEFLABEL (walk_94)
DEFLABEL (walk_52)
  DLINK_INTERRUPT_CHECK (25, LABEL_51_42);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_51_2])))
    goto label_154;
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  Rvl = ((Wrd31.pObj) [1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_154)
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_43]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_158;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_157)
  Rdl = (& (Rsp [2]));
  goto walk_52;

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_51_43);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = (current_block [OBJECT_51_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_156;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_155)
  (Wrd25.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd34.Obj) = ((Wrd30.pObj) [8]);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_46]));

DEFLABEL (label_156)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_45]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_5]), 1);

DEFLABEL (label_87)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd12.Obj) = Rvl;
  goto label_155;

DEFLABEL (label_158)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_44]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_6]), 1);

DEFLABEL (label_86)
  (Wrd21.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd21.Obj));
  (* (--Rsp)) = Rvl;
  goto label_157;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define ENVIRONMENT_LABEL_52_3 6
#define DEBUGGING_LABEL_52_2 5
#define OBJECT_52_0 4
#define FREE_REFERENCES_LABEL_52_0 4
#define NUMBER_OF_LINKER_SECTIONS_52_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto environment_make_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_make_3)
DEFLABEL (environment_make_0)
  INTERRUPT_CHECK (26, LABEL_52_4);
  Rvl = (current_block [OBJECT_52_0]);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define ENVIRONMENT_LABEL_53_3 5
#define DEBUGGING_LABEL_53_2 4
#define FREE_REFERENCES_LABEL_53_0 4
#define NUMBER_OF_LINKER_SECTIONS_53_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto environment_bind_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_bind_4)
DEFLABEL (environment_bind_1)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd14.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define ENVIRONMENT_LABEL_54_3 12
#define DEBUGGING_LABEL_54_2 11
#define EXECUTE_CACHE_54_6 7
#define FREE_REFERENCE_54_0 10
#define FREE_REFERENCES_LABEL_54_0 6
#define NUMBER_OF_LINKER_SECTIONS_54_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto environment_bind_multiple_0;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_bind_multiple_4)
DEFLABEL (environment_bind_multiple_0)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define LABEL_55_7 7
#define LABEL_55_8 9
#define LABEL_55_9 11
#define ENVIRONMENT_LABEL_55_3 19
#define DEBUGGING_LABEL_55_2 18
#define OBJECT_55_0 17
#define EXECUTE_CACHE_55_6 13
#define FREE_REFERENCE_55_0 16
#define FREE_REFERENCES_LABEL_55_0 12
#define NUMBER_OF_LINKER_SECTIONS_55_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd34;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto environment_lookup_5;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_55_7);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_55_8);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_55_9);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_lookup_11)
DEFLABEL (environment_lookup_5)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;

DEFLABEL (label_12)
  Rsp = (& (Rsp [5]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_13)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_20;
  Wrd7 = Wrd11;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_18;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_17)
  (Wrd22.Obj) = (* (Rsp++));
  if ((Wrd13.Obj) == (Wrd22.Obj))
    goto label_16;
  (Wrd23.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_15;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_14)
  (Rsp [5]) = (Wrd24.Obj);
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_15)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_9]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_0]), 1);

DEFLABEL (label_9)
  (Wrd24.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_16)
  (Wrd34.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd34.Obj);
  goto label_12;

DEFLABEL (label_18)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_8]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_0]), 1);

DEFLABEL (label_8)
  (Wrd13.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_7])), (Wrd8.pObj));

DEFLABEL (label_7)
  (Wrd7.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define ENVIRONMENT_LABEL_56_3 11
#define DEBUGGING_LABEL_56_2 10
#define OBJECT_56_3 9
#define OBJECT_56_2 8
#define OBJECT_56_1 7
#define OBJECT_56_0 6
#define FREE_REFERENCES_LABEL_56_0 6
#define NUMBER_OF_LINKER_SECTIONS_56_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto delayed_integration_in_progressP_1;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delayed_integration_in_progressP_5)
DEFLABEL (delayed_integration_in_progressP_1)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_10;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_10;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_9)
  if ((Wrd5.Obj) == (current_block [OBJECT_56_2]))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_6;

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_56_3]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_56_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_5 3
#define LABEL_57_6 5
#define LABEL_57_7 7
#define LABEL_57_4 9
#define LABEL_57_8 11
#define LABEL_57_9 13
#define LABEL_57_10 15
#define LABEL_57_11 17
#define LABEL_57_12 19
#define LABEL_57_13 21
#define LABEL_57_14 23
#define LABEL_57_15 25
#define ENVIRONMENT_LABEL_57_3 43
#define DEBUGGING_LABEL_57_2 42
#define OBJECT_57_10 41
#define OBJECT_57_9 40
#define OBJECT_57_8 39
#define OBJECT_57_7 38
#define OBJECT_57_6 37
#define OBJECT_57_5 36
#define OBJECT_57_4 35
#define OBJECT_57_3 34
#define OBJECT_57_2 33
#define OBJECT_57_1 32
#define OBJECT_57_0 31
#define EXECUTE_CACHE_57_17 27
#define EXECUTE_CACHE_57_16 29
#define FREE_REFERENCES_LABEL_57_0 26
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd118;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd135;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd147;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd146;
  machine_word Wrd145;
  machine_word Wrd169;
  machine_word Wrd166;
  machine_word Wrd165;
  machine_word Wrd164;
  machine_word Wrd155;
  machine_word Wrd161;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd163;
  machine_word Wrd162;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd86;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd70;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd54;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd51;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  machine_word Wrd176;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd180;
  machine_word Wrd184;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd201;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd187;
  machine_word Wrd193;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd195;
  machine_word Wrd194;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_5);
      goto continuation_8;

    case 1:
      current_block = (Rpc - LABEL_57_6);
      goto label_27;

    case 2:
      current_block = (Rpc - LABEL_57_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_57_4);
      goto delayed_integration_force_17;

    case 4:
      current_block = (Rpc - LABEL_57_8);
      goto label_19;

    case 5:
      current_block = (Rpc - LABEL_57_9);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_57_10);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_57_11);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_57_12);
      goto label_26;

    case 9:
      current_block = (Rpc - LABEL_57_13);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_57_14);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_57_15);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delayed_integration_force_29)
DEFLABEL (delayed_integration_force_17)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_53;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_53;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_52)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == (current_block [OBJECT_57_5]))
    goto label_37;
  if ((Wrd24.Obj) == (current_block [OBJECT_57_0]))
    goto label_33;
  if ((Wrd24.Obj) == (current_block [OBJECT_57_8]))
    goto label_31;
  (Wrd30.Obj) = (current_block [OBJECT_57_10]);
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_30;

DEFLABEL (label_31)
  (Wrd32.Obj) = (current_block [OBJECT_57_9]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_30)
DEFLABEL (label_32)
  (Wrd33.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_17]));

DEFLABEL (label_33)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_36)
  (Wrd35.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_57_3]);
  (Rsp [1]) = (Wrd36.Obj);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd48.uLng) == 10)
    goto label_35;

DEFLABEL (label_34)
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_4]), 2);

DEFLABEL (label_35)
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd46.Lng))))
    goto label_34;
  Rvl = ((Wrd44.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_37)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_5]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd61.Obj) = (Rsp [3]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 10))
    goto label_51;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [0]);
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd59.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd60.Lng))))
    goto label_51;
  (Wrd54.Obj) = ((Wrd58.pObj) [5]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_50)
  (Wrd77.Obj) = (Rsp [4]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 10))
    goto label_49;
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd75.Obj) = ((Wrd74.pObj) [0]);
  (Wrd76.Lng) = (FIXNUM_TO_LONG (Wrd75.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd76.Lng))))
    goto label_49;
  (Wrd70.Obj) = ((Wrd74.pObj) [4]);
  (* (--Rsp)) = (Wrd70.Obj);

DEFLABEL (label_48)
  (Wrd93.Obj) = (Rsp [5]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 10))
    goto label_47;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [0]);
  (Wrd92.Lng) = (FIXNUM_TO_LONG (Wrd91.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd92.Lng))))
    goto label_47;
  (Wrd86.Obj) = ((Wrd90.pObj) [3]);
  (* (--Rsp)) = (Wrd86.Obj);

DEFLABEL (label_46)
  (Wrd162.Obj) = (Rsp [6]);
  (Wrd163.uLng) = (OBJECT_TYPE (Wrd162.Obj));
  if (! ((Wrd163.uLng) == 10))
    goto label_45;
  (Wrd159.pObj) = (OBJECT_ADDRESS (Wrd162.Obj));
  (Wrd160.Obj) = ((Wrd159.pObj) [0]);
  (Wrd161.Lng) = (FIXNUM_TO_LONG (Wrd160.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd161.Lng))))
    goto label_45;
  (Wrd155.Obj) = (current_block [OBJECT_57_8]);
  ((Wrd159.pObj) [2]) = (Wrd155.Obj);

DEFLABEL (label_44)
  (Wrd145.Obj) = (Rsp [6]);
  (Wrd146.uLng) = (OBJECT_TYPE (Wrd145.Obj));
  if (! ((Wrd146.uLng) == 10))
    goto label_43;
  (Wrd142.pObj) = (OBJECT_ADDRESS (Wrd145.Obj));
  (Wrd143.Obj) = ((Wrd142.pObj) [0]);
  (Wrd144.Lng) = (FIXNUM_TO_LONG (Wrd143.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd144.Lng))))
    goto label_43;
  ((Wrd142.pObj) [3]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_42)
  (Wrd128.Obj) = (Rsp [6]);
  (Wrd129.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if (! ((Wrd129.uLng) == 10))
    goto label_41;
  (Wrd125.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd126.Obj) = ((Wrd125.pObj) [0]);
  (Wrd127.Lng) = (FIXNUM_TO_LONG (Wrd126.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd127.Lng))))
    goto label_41;
  ((Wrd125.pObj) [4]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_40)
  (Wrd111.Obj) = (Rsp [6]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 10))
    goto label_39;
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd109.Obj) = ((Wrd108.pObj) [0]);
  (Wrd110.Lng) = (FIXNUM_TO_LONG (Wrd109.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd110.Lng))))
    goto label_39;
  ((Wrd108.pObj) [5]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_38)
  (Wrd100.Obj) = (Rsp [0]);
  (Wrd101.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd101.Obj);
  (Rsp [1]) = (Wrd100.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_16]));

DEFLABEL (label_39)
  (Wrd113.Obj) = (Rsp [6]);
  (Wrd114.Obj) = (current_block [OBJECT_57_3]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_15]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_23)
  goto label_38;

DEFLABEL (label_41)
  (Wrd130.Obj) = (Rsp [6]);
  (Wrd131.Obj) = (current_block [OBJECT_57_6]);
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_14]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd131.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_24)
  goto label_40;

DEFLABEL (label_43)
  (Wrd147.Obj) = (Rsp [6]);
  (Wrd148.Obj) = (current_block [OBJECT_57_7]);
  (Wrd152.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_13]))));
  (* (--Rsp)) = (Wrd152.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd147.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_25)
  goto label_42;

DEFLABEL (label_45)
  (Wrd164.Obj) = (Rsp [6]);
  (Wrd165.Obj) = (current_block [OBJECT_57_1]);
  (Wrd166.Obj) = (current_block [OBJECT_57_8]);
  (Wrd169.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_12]))));
  (* (--Rsp)) = (Wrd169.Obj);
  (* (--Rsp)) = (Wrd166.Obj);
  (* (--Rsp)) = (Wrd165.Obj);
  (* (--Rsp)) = (Wrd164.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_26)
  goto label_44;

DEFLABEL (label_47)
  (Wrd95.Obj) = (Rsp [5]);
  (Wrd96.Obj) = (current_block [OBJECT_57_7]);
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_11]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_4]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd79.Obj) = (Rsp [4]);
  (Wrd80.Obj) = (current_block [OBJECT_57_6]);
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_10]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_4]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.Obj) = (current_block [OBJECT_57_3]);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_9]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_4]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_57_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_4]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_57_5);
  (Rsp [0]) = Rvl;
  (Wrd194.Obj) = (Rsp [2]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if (! ((Wrd195.uLng) == 10))
    goto label_57;
  (Wrd191.pObj) = (OBJECT_ADDRESS (Wrd194.Obj));
  (Wrd192.Obj) = ((Wrd191.pObj) [0]);
  (Wrd193.Lng) = (FIXNUM_TO_LONG (Wrd192.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd193.Lng))))
    goto label_57;
  (Wrd187.Obj) = (current_block [OBJECT_57_0]);
  ((Wrd191.pObj) [2]) = (Wrd187.Obj);

DEFLABEL (label_56)
  (Wrd171.Obj) = (current_block [OBJECT_57_3]);
  (* (--Rsp)) = (Wrd171.Obj);
  (Wrd172.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd172.Obj);
  (Wrd184.uLng) = (OBJECT_TYPE (Wrd172.Obj));
  if ((Wrd184.uLng) == 10)
    goto label_55;

DEFLABEL (label_54)
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_55)
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd172.Obj));
  (Wrd181.Obj) = ((Wrd180.pObj) [0]);
  (Wrd182.Lng) = (FIXNUM_TO_LONG (Wrd181.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd182.Lng))))
    goto label_54;
  (Wrd176.Obj) = (Rsp [2]);
  ((Wrd180.pObj) [5]) = (Wrd176.Obj);
  Rsp = (& (Rsp [4]));
  goto label_36;

DEFLABEL (label_57)
  (Wrd196.Obj) = (Rsp [2]);
  (Wrd197.Obj) = (current_block [OBJECT_57_1]);
  (Wrd198.Obj) = (current_block [OBJECT_57_0]);
  (Wrd201.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_6]))));
  (* (--Rsp)) = (Wrd201.Obj);
  (* (--Rsp)) = (Wrd198.Obj);
  (* (--Rsp)) = (Wrd197.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 3);

DEFLABEL (label_27)
  goto label_56;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_57_7);
  goto label_36;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define ENVIRONMENT_LABEL_58_3 8
#define DEBUGGING_LABEL_58_2 7
#define EXECUTE_CACHE_58_5 5
#define FREE_REFERENCES_LABEL_58_0 4
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto foldable_constantP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (foldable_constantP_3)
DEFLABEL (foldable_constantP_0)
  INTERRUPT_CHECK (26, LABEL_58_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_6 5
#define LABEL_59_5 7
#define LABEL_59_8 9
#define ENVIRONMENT_LABEL_59_3 20
#define DEBUGGING_LABEL_59_2 19
#define OBJECT_59_3 18
#define OBJECT_59_2 17
#define OBJECT_59_1 16
#define OBJECT_59_0 15
#define EXECUTE_CACHE_59_9 11
#define EXECUTE_CACHE_59_7 13
#define FREE_REFERENCES_LABEL_59_0 10
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto foldable_constantsP_4;

    case 1:
      current_block = (Rpc - LABEL_59_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_59_8);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (foldable_constantsP_9)
DEFLABEL (foldable_constantsP_4)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_59_0])))
    goto label_10;
  Rvl = (current_block [OBJECT_59_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_59_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_13;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_9]));

DEFLABEL (label_13)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_3]), 1);

DEFLABEL (label_7)
  (Wrd7.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_6]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_2]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define ENVIRONMENT_LABEL_60_3 15
#define DEBUGGING_LABEL_60_2 14
#define OBJECT_60_2 13
#define OBJECT_60_1 12
#define OBJECT_60_0 11
#define EXECUTE_CACHE_60_7 7
#define EXECUTE_CACHE_60_6 9
#define FREE_REFERENCES_LABEL_60_0 6
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto foldable_constant_value_1;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (foldable_constant_value_4)
DEFLABEL (foldable_constant_value_1)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_60_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_5;
  (Wrd21.Obj) = (current_block [OBJECT_60_0]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_7]));

DEFLABEL (label_5)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_60_1]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_7)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_6;
  Rvl = ((Wrd16.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define LABEL_61_8 7
#define LABEL_61_7 9
#define LABEL_61_10 11
#define LABEL_61_11 13
#define ENVIRONMENT_LABEL_61_3 26
#define DEBUGGING_LABEL_61_2 25
#define OBJECT_61_1 24
#define OBJECT_61_0 23
#define EXECUTE_CACHE_61_12 15
#define EXECUTE_CACHE_61_9 17
#define EXECUTE_CACHE_61_6 19
#define FREE_REFERENCE_61_0 22
#define FREE_REFERENCES_LABEL_61_0 14
#define NUMBER_OF_LINKER_SECTIONS_61_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto foldable_operatorP_4;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_61_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_61_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_61_10);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_61_11);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (foldable_operatorP_10)
DEFLABEL (foldable_operatorP_4)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_61_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_18;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_18;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_17)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_61_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_16;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_16;
  (Wrd9.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_15)
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_61_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_14;
  Wrd24 = Wrd28;

DEFLABEL (label_13)
  (Rsp [1]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_12]));

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_61_11])), (Wrd25.pObj));

DEFLABEL (label_8)
  (Wrd24.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_61_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_10]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_61_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_61_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_61_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_7 5
#define LABEL_62_10 7
#define LABEL_62_5 9
#define LABEL_62_15 11
#define LABEL_62_16 13
#define LABEL_62_17 15
#define LABEL_62_18 17
#define LABEL_62_19 19
#define LABEL_62_12 21
#define LABEL_62_21 23
#define LABEL_62_22 25
#define LABEL_62_26 27
#define LABEL_62_8 29
#define LABEL_62_27 31
#define LABEL_62_9 33
#define LABEL_62_29 35
#define LABEL_62_30 37
#define LABEL_62_31 39
#define LABEL_62_24 41
#define LABEL_62_32 43
#define LABEL_62_34 45
#define LABEL_62_35 47
#define LABEL_62_36 49
#define LABEL_62_38 51
#define LABEL_62_40 53
#define LABEL_62_41 55
#define LABEL_62_43 57
#define LABEL_62_37 59
#define LABEL_62_44 61
#define LABEL_62_46 63
#define LABEL_62_47 65
#define LABEL_62_39 67
#define LABEL_62_49 69
#define LABEL_62_50 71
#define LABEL_62_51 73
#define LABEL_62_52 75
#define LABEL_62_45 77
#define LABEL_62_53 79
#define LABEL_62_54 81
#define LABEL_62_56 83
#define LABEL_62_57 85
#define LABEL_62_59 87
#define LABEL_62_55 89
#define LABEL_62_63 91
#define LABEL_62_64 93
#define LABEL_62_66 95
#define LABEL_62_67 97
#define LABEL_62_61 99
#define TAG_62_62 48
#define LABEL_62_70 101
#define LABEL_62_73 103
#define LABEL_62_74 105
#define LABEL_62_75 107
#define LABEL_62_76 109
#define LABEL_62_69 111
#define LABEL_62_79 113
#define LABEL_62_72 115
#define LABEL_62_80 117
#define LABEL_62_78 119
#define ENVIRONMENT_LABEL_62_3 174
#define DEBUGGING_LABEL_62_2 173
#define OBJECT_62_10 172
#define OBJECT_62_9 171
#define OBJECT_62_8 170
#define OBJECT_62_7 169
#define OBJECT_62_6 168
#define OBJECT_62_5 167
#define OBJECT_62_4 166
#define OBJECT_62_3 165
#define OBJECT_62_2 164
#define OBJECT_62_1 163
#define OBJECT_62_0 162
#define EXECUTE_CACHE_62_81 121
#define EXECUTE_CACHE_62_77 123
#define EXECUTE_CACHE_62_71 125
#define EXECUTE_CACHE_62_68 127
#define EXECUTE_CACHE_62_65 129
#define EXECUTE_CACHE_62_60 131
#define EXECUTE_CACHE_62_58 133
#define EXECUTE_CACHE_62_48 135
#define EXECUTE_CACHE_62_42 137
#define EXECUTE_CACHE_62_33 139
#define EXECUTE_CACHE_62_28 141
#define EXECUTE_CACHE_62_25 143
#define EXECUTE_CACHE_62_23 145
#define EXECUTE_CACHE_62_20 147
#define EXECUTE_CACHE_62_14 149
#define EXECUTE_CACHE_62_13 151
#define EXECUTE_CACHE_62_11 153
#define EXECUTE_CACHE_62_6 155
#define FREE_REFERENCE_62_3 158
#define FREE_REFERENCE_62_2 159
#define FREE_REFERENCE_62_1 160
#define FREE_REFERENCE_62_0 161
#define FREE_REFERENCES_LABEL_62_0 120
#define NUMBER_OF_LINKER_SECTIONS_62_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd112;
  machine_word Wrd109;
  machine_word Wrd101;
  machine_word Wrd99;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd88;
  machine_word Wrd75;
  machine_word Wrd30;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd168;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd165;
  machine_word Wrd162;
  machine_word Wrd159;
  machine_word Wrd161;
  machine_word Wrd160;
  machine_word Wrd146;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd55;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd41;
  machine_word Wrd77;
  machine_word Wrd74;
  machine_word Wrd96;
  machine_word Wrd91;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd117;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd85;
  machine_word Wrd110;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd89;
  machine_word Wrd86;
  machine_word Wrd83;
  machine_word Wrd84;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd71;
  machine_word Wrd60;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd42;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd95;
  machine_word Wrd123;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd118;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd108;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd52;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd39;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto combination_optimizing_make_52;

    case 1:
      current_block = (Rpc - LABEL_62_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_62_10);
      goto label_54;

    case 3:
      current_block = (Rpc - LABEL_62_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_62_15);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_62_16);
      goto label_71;

    case 6:
      current_block = (Rpc - LABEL_62_17);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_62_18);
      goto label_67;

    case 8:
      current_block = (Rpc - LABEL_62_19);
      goto label_66;

    case 9:
      current_block = (Rpc - LABEL_62_12);
      goto continuation_2;

    case 10:
      current_block = (Rpc - LABEL_62_21);
      goto label_55;

    case 11:
      current_block = (Rpc - LABEL_62_22);
      goto label_56;

    case 12:
      current_block = (Rpc - LABEL_62_26);
      goto continuation_48;

    case 13:
      current_block = (Rpc - LABEL_62_8);
      goto continuation_51;

    case 14:
      current_block = (Rpc - LABEL_62_27);
      goto label_57;

    case 15:
      current_block = (Rpc - LABEL_62_9);
      goto continuation_50;

    case 16:
      current_block = (Rpc - LABEL_62_29);
      goto label_58;

    case 17:
      current_block = (Rpc - LABEL_62_30);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_62_31);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_62_24);
      goto continuation_9;

    case 20:
      current_block = (Rpc - LABEL_62_32);
      goto label_65;

    case 21:
      current_block = (Rpc - LABEL_62_34);
      goto label_59;

    case 22:
      current_block = (Rpc - LABEL_62_35);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_62_36);
      goto label_60;

    case 24:
      current_block = (Rpc - LABEL_62_38);
      goto label_61;

    case 25:
      current_block = (Rpc - LABEL_62_40);
      goto label_62;

    case 26:
      current_block = (Rpc - LABEL_62_41);
      goto label_63;

    case 27:
      current_block = (Rpc - LABEL_62_43);
      goto continuation_18;

    case 28:
      current_block = (Rpc - LABEL_62_37);
      goto continuation_17;

    case 29:
      current_block = (Rpc - LABEL_62_44);
      goto label_70;

    case 30:
      current_block = (Rpc - LABEL_62_46);
      goto label_68;

    case 31:
      current_block = (Rpc - LABEL_62_47);
      goto label_69;

    case 32:
      current_block = (Rpc - LABEL_62_39);
      goto continuation_16;

    case 33:
      current_block = (Rpc - LABEL_62_49);
      goto continuation_25;

    case 34:
      current_block = (Rpc - LABEL_62_50);
      goto continuation_21;

    case 35:
      current_block = (Rpc - LABEL_62_51);
      goto continuation_24;

    case 36:
      current_block = (Rpc - LABEL_62_52);
      goto label_79;

    case 37:
      current_block = (Rpc - LABEL_62_45);
      goto continuation_20;

    case 38:
      current_block = (Rpc - LABEL_62_53);
      goto label_76;

    case 39:
      current_block = (Rpc - LABEL_62_54);
      goto label_75;

    case 40:
      current_block = (Rpc - LABEL_62_56);
      goto label_72;

    case 41:
      current_block = (Rpc - LABEL_62_57);
      goto label_73;

    case 42:
      current_block = (Rpc - LABEL_62_59);
      goto label_74;

    case 43:
      current_block = (Rpc - LABEL_62_55);
      goto continuation_28;

    case 44:
      current_block = (Rpc - LABEL_62_63);
      goto label_77;

    case 45:
      current_block = (Rpc - LABEL_62_64);
      goto label_78;

    case 46:
      current_block = (Rpc - LABEL_62_66);
      goto continuation_33;

    case 47:
      current_block = (Rpc - LABEL_62_67);
      goto label_86;

    case 48:
      current_block = (Rpc - LABEL_62_61);
      goto lambda_89;

    case 49:
      current_block = (Rpc - LABEL_62_70);
      goto label_84;

    case 50:
      current_block = (Rpc - LABEL_62_73);
      goto label_80;

    case 51:
      current_block = (Rpc - LABEL_62_74);
      goto label_81;

    case 52:
      current_block = (Rpc - LABEL_62_75);
      goto label_82;

    case 53:
      current_block = (Rpc - LABEL_62_76);
      goto label_83;

    case 54:
      current_block = (Rpc - LABEL_62_69);
      goto continuation_34;

    case 55:
      current_block = (Rpc - LABEL_62_79);
      goto continuation_35;

    case 56:
      current_block = (Rpc - LABEL_62_72);
      goto continuation_40;

    case 57:
      current_block = (Rpc - LABEL_62_80);
      goto label_85;

    case 58:
      current_block = (Rpc - LABEL_62_78);
      goto continuation_44;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_optimizing_make_88)
DEFLABEL (combination_optimizing_make_52)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_62_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_156;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_62_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_157;

DEFLABEL (label_156)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_62_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_143;

DEFLABEL (label_142)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_24]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_25]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_62_24);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_137;
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_136;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_136;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_135)
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_134;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd94.Lng))))
    goto label_134;
  (Wrd24.Obj) = ((Wrd92.pObj) [4]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_129;

DEFLABEL (label_128)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_37]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd53.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_62_2]));
  (Wrd56.Obj) = ((Wrd53.pObj) [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if ((Wrd57.uLng) == 50)
    goto label_127;
  Wrd52 = Wrd56;

DEFLABEL (label_126)
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_39]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd70.Obj) = (Rsp [5]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 10))
    goto label_125;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd69.Lng))))
    goto label_125;
  (Wrd61.Obj) = ((Wrd67.pObj) [3]);

DEFLABEL (label_124)
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd84.uLng) == 10))
    goto label_123;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [0]);
  (Wrd83.Lng) = (FIXNUM_TO_LONG (Wrd82.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd83.Lng))))
    goto label_123;
  (Wrd78.Obj) = ((Wrd81.pObj) [5]);
  (* (--Rsp)) = (Wrd78.Obj);

DEFLABEL (label_122)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_42]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_62_39);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_48]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_62_37);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_117;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_45]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_62_3]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_116;
  Wrd10 = Wrd14;

DEFLABEL (label_115)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_114;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd24.Lng))))
    goto label_114;
  (Wrd18.Obj) = ((Wrd22.pObj) [6]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_113)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_48]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_62_45);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_108;
  (Wrd71.Obj) = (Rsp [2]);
  (Wrd72.uLng) = (OBJECT_TYPE (Wrd71.Obj));
  if (! ((Wrd72.uLng) == 10))
    goto label_107;
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [0]);
  (Wrd70.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd70.Lng))))
    goto label_107;
  (Wrd9.Obj) = ((Wrd68.pObj) [7]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_98;

DEFLABEL (label_106)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_51]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd58.Obj) = (Rsp [3]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 10))
    goto label_105;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd57.Lng))))
    goto label_105;
  (Wrd51.Obj) = ((Wrd55.pObj) [7]);
  (* (--Rsp)) = (Wrd51.Obj);

DEFLABEL (label_104)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_60]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_62_51);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_99;

DEFLABEL (label_98)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_55]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_97;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd22.Lng))))
    goto label_97;
  (Wrd16.Obj) = ((Wrd20.pObj) [6]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_96)
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_95;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd38.Lng))))
    goto label_95;
  (Wrd32.Obj) = ((Wrd36.pObj) [5]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_94)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_58]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_62_55);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_62);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_61])));
  Rhp += 3;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [3]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [4]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_93;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd21.Lng))))
    goto label_93;
  (Wrd13.Obj) = ((Wrd19.pObj) [8]);

DEFLABEL (label_92)
  (Rsp [3]) = (Wrd13.Obj);
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_91;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd37.Lng))))
    goto label_91;
  (Wrd29.Obj) = ((Wrd35.pObj) [7]);

DEFLABEL (label_90)
  (Rsp [2]) = (Wrd29.Obj);
  (Wrd45.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd45.Obj);
  (Wrd46.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_65]));

DEFLABEL (label_91)
  (Wrd40.Obj) = (Rsp [4]);
  (Wrd41.Obj) = (current_block [OBJECT_62_8]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_64]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_78)
  (Wrd29.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_62_9]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_63]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_77)
  (Wrd13.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (Wrd41.Obj) = (Rsp [4]);
  (Wrd42.Obj) = (current_block [OBJECT_62_6]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_57]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.Obj) = (current_block [OBJECT_62_7]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_56]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_72)
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_49]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd107.Obj) = (Rsp [1]);
  if ((Wrd107.Obj) == ((SCHEME_OBJECT) 0))
    goto label_103;
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if (! ((Wrd120.uLng) == 10))
    goto label_102;
  (Wrd116.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd117.Obj) = ((Wrd116.pObj) [0]);
  (Wrd118.Lng) = (FIXNUM_TO_LONG (Wrd117.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd118.Lng))))
    goto label_102;
  (Wrd110.Obj) = ((Wrd116.pObj) [2]);

DEFLABEL (label_101)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_100)
  (Rsp [0]) = (Wrd110.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (label_102)
  (Wrd121.Obj) = (Rsp [1]);
  (Wrd122.Obj) = (current_block [OBJECT_62_3]);
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_52]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_79)
  (Wrd110.Obj) = Rvl;
  goto label_101;

DEFLABEL (label_103)
  (Wrd110.Obj) = ((SCHEME_OBJECT) 0);
  goto label_101;

DEFLABEL (label_105)
  (Wrd60.Obj) = (Rsp [3]);
  (Wrd61.Obj) = (current_block [OBJECT_62_8]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_59]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_74)
  (* (--Rsp)) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  (Wrd73.Obj) = (Rsp [2]);
  (Wrd74.Obj) = (current_block [OBJECT_62_8]);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_54]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_75)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_98;
  goto label_106;

DEFLABEL (label_108)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_50]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd82.Obj) = (Rsp [1]);
  if ((Wrd82.Obj) == ((SCHEME_OBJECT) 0))
    goto label_112;
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_111;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_111;
  (Wrd85.Obj) = ((Wrd91.pObj) [2]);

DEFLABEL (label_110)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_109)
  (Rsp [0]) = (Wrd85.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (label_111)
  (Wrd96.Obj) = (Rsp [1]);
  (Wrd97.Obj) = (current_block [OBJECT_62_3]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_53]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_76)
  (Wrd85.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_112)
  (Wrd85.Obj) = ((SCHEME_OBJECT) 0);
  goto label_110;

DEFLABEL (label_114)
  (Wrd27.Obj) = (Rsp [4]);
  (Wrd28.Obj) = (current_block [OBJECT_62_7]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_47]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_69)
  (* (--Rsp)) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62_46])), (Wrd11.pObj));

DEFLABEL (label_68)
  (Wrd10.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_117)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_43]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [1]);
  if ((Wrd35.Obj) == ((SCHEME_OBJECT) 0))
    goto label_121;
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_120;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd46.Lng))))
    goto label_120;
  (Wrd38.Obj) = ((Wrd44.pObj) [2]);

DEFLABEL (label_119)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_118)
  (Rsp [0]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (label_120)
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.Obj) = (current_block [OBJECT_62_3]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_44]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_70)
  (Wrd38.Obj) = Rvl;
  goto label_119;

DEFLABEL (label_121)
  (Wrd38.Obj) = ((SCHEME_OBJECT) 0);
  goto label_119;

DEFLABEL (label_123)
  (Wrd86.Obj) = (current_block [OBJECT_62_6]);
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_41]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_63)
  (* (--Rsp)) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd72.Obj) = (Rsp [5]);
  (Wrd73.Obj) = (current_block [OBJECT_62_1]);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_40]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_62)
  (Wrd61.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62_38])), (Wrd53.pObj));

DEFLABEL (label_61)
  (Wrd52.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_31]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [1]);
  if ((Wrd29.Obj) == ((SCHEME_OBJECT) 0))
    goto label_133;
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd42.uLng) == 10))
    goto label_132;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd40.Lng))))
    goto label_132;
  (Wrd32.Obj) = ((Wrd38.pObj) [2]);

DEFLABEL (label_131)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_130)
  (Rsp [0]) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (label_132)
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.Obj) = (current_block [OBJECT_62_3]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_36]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_60)
  (Wrd32.Obj) = Rvl;
  goto label_131;

DEFLABEL (label_133)
  (Wrd32.Obj) = ((SCHEME_OBJECT) 0);
  goto label_131;

DEFLABEL (label_134)
  (Wrd97.Obj) = (current_block [OBJECT_62_5]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_35]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_64)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_129;
  goto label_128;

DEFLABEL (label_136)
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (current_block [OBJECT_62_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_34]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_59)
  (Wrd7.Obj) = Rvl;
  goto label_135;

DEFLABEL (label_137)
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_30]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (Wrd105.Obj) = (Rsp [1]);
  if ((Wrd105.Obj) == ((SCHEME_OBJECT) 0))
    goto label_141;
  (Wrd118.uLng) = (OBJECT_TYPE (Wrd105.Obj));
  if (! ((Wrd118.uLng) == 10))
    goto label_140;
  (Wrd114.pObj) = (OBJECT_ADDRESS (Wrd105.Obj));
  (Wrd115.Obj) = ((Wrd114.pObj) [0]);
  (Wrd116.Lng) = (FIXNUM_TO_LONG (Wrd115.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd116.Lng))))
    goto label_140;
  (Wrd108.Obj) = ((Wrd114.pObj) [2]);

DEFLABEL (label_139)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_138)
  (Rsp [0]) = (Wrd108.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (label_140)
  (Wrd119.Obj) = (Rsp [1]);
  (Wrd120.Obj) = (current_block [OBJECT_62_3]);
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_32]))));
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd120.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_65)
  (Wrd108.Obj) = Rvl;
  goto label_139;

DEFLABEL (label_141)
  (Wrd108.Obj) = ((SCHEME_OBJECT) 0);
  goto label_139;

DEFLABEL (label_143)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_62_1]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_155;
  Wrd7 = Wrd11;

DEFLABEL (label_154)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_153;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd21.Lng))))
    goto label_153;
  (Wrd13.Obj) = ((Wrd19.pObj) [3]);

DEFLABEL (label_152)
  (Wrd29.Obj) = (* (Rsp++));
  if (! ((Wrd13.Obj) == (Wrd29.Obj)))
    goto label_142;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_17]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_23]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_62_17);
  (Wrd39.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd39.uLng) == 26))
    goto label_151;
  if (! (Rvl == (current_block [OBJECT_62_3])))
    goto label_142;

DEFLABEL (label_150)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_15]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (Rsp [4]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_149;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_148)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_20]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_62_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_142;
  (Wrd64.Obj) = (Rsp [3]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_147;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd61.Obj) = ((Wrd63.pObj) [0]);

DEFLABEL (label_146)
  (Rsp [2]) = (Wrd61.Obj);
  (Wrd70.Obj) = (current_block [OBJECT_62_1]);
  (Rsp [3]) = (Wrd70.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd81.Obj) = (Rsp [0]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if ((Wrd82.uLng) == 10)
    goto label_145;

DEFLABEL (label_144)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_145)
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd80.Lng))))
    goto label_144;
  Rvl = ((Wrd78.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_147)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_16]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_0]), 1);

DEFLABEL (label_71)
  (Wrd61.Obj) = Rvl;
  goto label_146;

DEFLABEL (label_149)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_19]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_0]), 1);

DEFLABEL (label_66)
  (* (--Rsp)) = Rvl;
  goto label_148;

DEFLABEL (label_151)
  (Wrd54.Obj) = (current_block [OBJECT_62_3]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_18]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_67)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_142;
  goto label_150;

DEFLABEL (label_153)
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.Obj) = (current_block [OBJECT_62_1]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_22]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_56)
  (Wrd13.Obj) = Rvl;
  goto label_152;

DEFLABEL (label_155)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62_21])), (Wrd8.pObj));

DEFLABEL (label_55)
  (Wrd7.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_62_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_165;
  Wrd24 = Wrd28;

DEFLABEL (label_164)
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_11]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_62_9);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_163;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_163;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_162)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_4]), 2);

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_62_8);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_161;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_160;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd20.Lng))))
    goto label_160;
  (Wrd12.Obj) = ((Wrd18.pObj) [2]);

DEFLABEL (label_159)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_158)
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_28]));

DEFLABEL (label_160)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.Obj) = (current_block [OBJECT_62_3]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_27]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_57)
  (Wrd12.Obj) = Rvl;
  goto label_159;

DEFLABEL (label_161)
  (Wrd12.Obj) = ((SCHEME_OBJECT) 0);
  goto label_159;

DEFLABEL (label_163)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_62_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_29]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62_10])), (Wrd25.pObj));

DEFLABEL (label_54)
  (Wrd24.Obj) = Rvl;
  goto label_164;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_62_49);
  (Wrd110.Obj) = Rvl;
  goto label_100;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_62_50);
  (Wrd85.Obj) = Rvl;
  goto label_109;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_62_43);
  (Wrd38.Obj) = Rvl;
  goto label_118;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_62_31);
  (Wrd32.Obj) = Rvl;
  goto label_130;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_62_30);
  (Wrd108.Obj) = Rvl;
  goto label_138;

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_62_26);
  (Wrd12.Obj) = Rvl;
  goto label_158;

DEFLABEL (lambda_89)
  CLOSURE_HEADER (LABEL_62_61);

DEFLABEL (lambda_46)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_69]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  if ((Wrd8.Obj) == (current_block [OBJECT_62_10]))
    goto label_180;

DEFLABEL (label_179)
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_72]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 10))
    goto label_178;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd26.Lng))))
    goto label_178;
  (Wrd18.Obj) = ((Wrd24.pObj) [8]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_177)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd39.Obj) = (current_block [OBJECT_62_10]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd54.Obj) = (Rsp [7]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [2]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 10))
    goto label_176;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd53.Lng))))
    goto label_176;
  (Wrd45.Obj) = ((Wrd51.pObj) [4]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_175)
  (Wrd78.Obj) = (Rsp [8]);
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [2]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 10))
    goto label_174;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd77.Lng))))
    goto label_174;
  (Wrd69.Obj) = ((Wrd75.pObj) [3]);
  (* (--Rsp)) = (Wrd69.Obj);

DEFLABEL (label_173)
  (Wrd102.Obj) = (Rsp [9]);
  (Wrd103.pObj) = (OBJECT_ADDRESS (Wrd102.Obj));
  (Wrd104.Obj) = ((Wrd103.pObj) [2]);
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if (! ((Wrd105.uLng) == 10))
    goto label_172;
  (Wrd99.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd100.Obj) = ((Wrd99.pObj) [0]);
  (Wrd101.Lng) = (FIXNUM_TO_LONG (Wrd100.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd101.Lng))))
    goto label_172;
  (Wrd93.Obj) = ((Wrd99.pObj) [2]);
  (* (--Rsp)) = (Wrd93.Obj);

DEFLABEL (label_171)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_77]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_62_72);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_79]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [4]);
  if ((Wrd13.Obj) == ((SCHEME_OBJECT) 0))
    goto label_170;
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_169;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd28.Lng))))
    goto label_169;
  (Wrd16.Obj) = ((Wrd26.pObj) [2]);

DEFLABEL (label_168)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_167)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_33]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_62_69);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (Wrd6.Obj) = (current_block [OBJECT_62_10]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_166;
  Rvl = Rvl;
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_166)
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_78]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_58]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_62_78);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_81]));

DEFLABEL (label_169)
  (Wrd34.Obj) = (Rsp [5]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [4]);
  (Wrd36.Obj) = (current_block [OBJECT_62_3]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_80]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_85)
  (Wrd16.Obj) = Rvl;
  goto label_168;

DEFLABEL (label_170)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_167;

DEFLABEL (label_172)
  (Wrd107.Obj) = (Rsp [9]);
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd106.Obj) = ((Wrd108.pObj) [2]);
  (Wrd109.Obj) = (current_block [OBJECT_62_3]);
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_76]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_83)
  (* (--Rsp)) = Rvl;
  goto label_171;

DEFLABEL (label_174)
  (Wrd83.Obj) = (Rsp [8]);
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [2]);
  (Wrd85.Obj) = (current_block [OBJECT_62_1]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_75]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_82)
  (* (--Rsp)) = Rvl;
  goto label_173;

DEFLABEL (label_176)
  (Wrd59.Obj) = (Rsp [7]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [2]);
  (Wrd61.Obj) = (current_block [OBJECT_62_5]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_74]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_81)
  (* (--Rsp)) = Rvl;
  goto label_175;

DEFLABEL (label_178)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [2]);
  (Wrd34.Obj) = (current_block [OBJECT_62_9]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_73]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_80)
  (* (--Rsp)) = Rvl;
  goto label_177;

DEFLABEL (label_180)
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_66]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (Wrd129.Obj) = (Rsp [2]);
  (Wrd130.pObj) = (OBJECT_ADDRESS (Wrd129.Obj));
  (Wrd131.Obj) = ((Wrd130.pObj) [2]);
  (Wrd132.uLng) = (OBJECT_TYPE (Wrd131.Obj));
  if (! ((Wrd132.uLng) == 10))
    goto label_184;
  (Wrd126.pObj) = (OBJECT_ADDRESS (Wrd131.Obj));
  (Wrd127.Obj) = ((Wrd126.pObj) [0]);
  (Wrd128.Lng) = (FIXNUM_TO_LONG (Wrd127.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd128.Lng))))
    goto label_184;
  (Wrd120.Obj) = ((Wrd126.pObj) [8]);
  (* (--Rsp)) = (Wrd120.Obj);

DEFLABEL (label_183)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_71]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_62_66);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_179;
  (Wrd155.Obj) = (Rsp [1]);
  (Wrd156.pObj) = (OBJECT_ADDRESS (Wrd155.Obj));
  (Wrd157.Obj) = ((Wrd156.pObj) [2]);
  (Wrd158.uLng) = (OBJECT_TYPE (Wrd157.Obj));
  if (! ((Wrd158.uLng) == 10))
    goto label_182;
  (Wrd152.pObj) = (OBJECT_ADDRESS (Wrd157.Obj));
  (Wrd153.Obj) = ((Wrd152.pObj) [0]);
  (Wrd154.Lng) = (FIXNUM_TO_LONG (Wrd153.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd154.Lng))))
    goto label_182;
  (Wrd146.Obj) = ((Wrd152.pObj) [8]);
  (* (--Rsp)) = (Wrd146.Obj);

DEFLABEL (label_181)
  (Wrd166.Obj) = (Rsp [2]);
  (Wrd167.pObj) = (OBJECT_ADDRESS (Wrd166.Obj));
  (Wrd168.Obj) = ((Wrd167.pObj) [4]);
  (* (--Rsp)) = (Wrd168.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_68]));

DEFLABEL (label_182)
  (Wrd160.Obj) = (Rsp [1]);
  (Wrd161.pObj) = (OBJECT_ADDRESS (Wrd160.Obj));
  (Wrd159.Obj) = ((Wrd161.pObj) [2]);
  (Wrd162.Obj) = (current_block [OBJECT_62_9]);
  (Wrd165.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_67]))));
  (* (--Rsp)) = (Wrd165.Obj);
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd159.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_86)
  (* (--Rsp)) = Rvl;
  goto label_181;

DEFLABEL (label_184)
  (Wrd134.Obj) = (Rsp [2]);
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd134.Obj));
  (Wrd133.Obj) = ((Wrd135.pObj) [2]);
  (Wrd136.Obj) = (current_block [OBJECT_62_9]);
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_70]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (* (--Rsp)) = (Wrd136.Obj);
  (* (--Rsp)) = (Wrd133.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_84)
  (* (--Rsp)) = Rvl;
  goto label_183;

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_62_79);
  (* (--Rsp)) = Rvl;
  goto label_167;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define LABEL_63_5 5
#define LABEL_63_7 7
#define LABEL_63_11 9
#define LABEL_63_12 11
#define LABEL_63_13 13
#define LABEL_63_17 15
#define LABEL_63_18 17
#define LABEL_63_8 19
#define LABEL_63_15 21
#define LABEL_63_20 23
#define LABEL_63_21 25
#define LABEL_63_22 27
#define LABEL_63_23 29
#define LABEL_63_24 31
#define LABEL_63_26 33
#define LABEL_63_19 35
#define ENVIRONMENT_LABEL_63_3 54
#define DEBUGGING_LABEL_63_2 53
#define OBJECT_63_3 52
#define OBJECT_63_2 51
#define OBJECT_63_1 50
#define OBJECT_63_0 49
#define EXECUTE_CACHE_63_25 37
#define EXECUTE_CACHE_63_16 39
#define EXECUTE_CACHE_63_14 41
#define EXECUTE_CACHE_63_10 43
#define EXECUTE_CACHE_63_9 45
#define EXECUTE_CACHE_63_6 47
#define FREE_REFERENCES_LABEL_63_0 36
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd23;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd32;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd35;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto delete_unreferenced_parameters_27;

    case 1:
      current_block = (Rpc - LABEL_63_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_63_7);
      goto loop_24;

    case 3:
      current_block = (Rpc - LABEL_63_11);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_63_12);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_63_13);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_63_17);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_63_18);
      goto label_32;

    case 8:
      current_block = (Rpc - LABEL_63_8);
      goto continuation_19;

    case 9:
      current_block = (Rpc - LABEL_63_15);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_63_20);
      goto label_35;

    case 11:
      current_block = (Rpc - LABEL_63_21);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_63_22);
      goto label_33;

    case 13:
      current_block = (Rpc - LABEL_63_23);
      goto label_34;

    case 14:
      current_block = (Rpc - LABEL_63_24);
      goto continuation_23;

    case 15:
      current_block = (Rpc - LABEL_63_26);
      goto continuation_22;

    case 16:
      current_block = (Rpc - LABEL_63_19);
      goto continuation_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_unreferenced_parameters_38)
DEFLABEL (delete_unreferenced_parameters_27)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_63_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_63_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_24;

DEFLABEL (loop_39)
DEFLABEL (loop_24)
  INTERRUPT_CHECK (26, LABEL_63_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_63_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_61;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_59;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_58;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_57)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_56;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_55)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_13]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_63_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_50;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_15]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_63_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_44;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_43)
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_42;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_41)
  (Rsp [3]) = (Wrd16.Obj);

DEFLABEL (label_40)
  Rsp = (& (Rsp [2]));
  goto loop_24;

DEFLABEL (label_42)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_34)
  (Wrd16.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_22]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_33)
  (Wrd7.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_49;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_48)
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_47;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_46)
  (Rsp [3]) = (Wrd35.Obj);
  (Wrd47.Obj) = (Rsp [1]);
  (Wrd48.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd47.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd46.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd46.pObj)));
  (Rsp [6]) = (Wrd44.Obj);
  goto label_40;

DEFLABEL (label_47)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_21]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_36)
  (Wrd35.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_20]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_35)
  (Wrd26.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_54;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_53)
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_52;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_51)
  (Rsp [3]) = (Wrd16.Obj);
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Rsp [4]) = (Wrd25.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (Rsp [5]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Rsp [5]) = (Wrd30.Obj);
  Rsp = (& (Rsp [2]));
  goto loop_24;

DEFLABEL (label_52)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_18]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_32)
  (Wrd16.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_17]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 1);

DEFLABEL (label_31)
  (Wrd7.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_12]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_2]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_2]), 1);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (label_59)
  (Wrd32.Obj) = (current_block [OBJECT_63_1]);
  (Rsp [9]) = (Wrd32.Obj);
  (Rsp [10]) = (Wrd5.Obj);

DEFLABEL (label_60)
  Rsp = (& (Rsp [9]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (label_61)
  (Wrd35.Obj) = (Rsp [7]);
  if ((Wrd35.Obj) == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_8]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_9]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_63_8);
  (Rsp [8]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_19]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_9]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_63_19);
  (Rsp [9]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  if ((Wrd9.Obj) == (current_block [OBJECT_63_0]))
    goto label_63;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_24]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_16]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_63_24);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd22.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_25]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_63_26);
  (Wrd16.Obj) = Rvl;

DEFLABEL (label_62)
  (Wrd17.Obj) = (Rsp [10]);
  (Rsp [7]) = (Wrd17.Obj);
  (Rsp [10]) = (Wrd16.Obj);
  Rsp = (& (Rsp [7]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_63)
  (Wrd16.Obj) = (Rsp [5]);
  Rsp = (& (Rsp [1]));
  goto label_62;

DEFLABEL (label_65)
  (Wrd41.Obj) = (Rsp [1]);
  if ((Wrd41.Obj) == (Wrd6.Obj))
    goto label_64;
  (Wrd43.Obj) = (current_block [OBJECT_63_1]);
  (Rsp [9]) = (Wrd43.Obj);
  (Rsp [10]) = (Wrd41.Obj);
  goto label_60;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_5 3
#define LABEL_64_6 5
#define LABEL_64_4 7
#define LABEL_64_7 9
#define LABEL_64_8 11
#define LABEL_64_9 13
#define LABEL_64_10 15
#define LABEL_64_13 17
#define LABEL_64_14 19
#define LABEL_64_12 21
#define LABEL_64_16 23
#define LABEL_64_18 25
#define LABEL_64_20 27
#define LABEL_64_22 29
#define LABEL_64_24 31
#define LABEL_64_26 33
#define LABEL_64_28 35
#define LABEL_64_31 37
#define LABEL_64_30 39
#define ENVIRONMENT_LABEL_64_3 72
#define DEBUGGING_LABEL_64_2 71
#define OBJECT_64_3 70
#define OBJECT_64_2 69
#define OBJECT_64_1 68
#define OBJECT_64_0 67
#define EXECUTE_CACHE_64_33 41
#define EXECUTE_CACHE_64_32 43
#define EXECUTE_CACHE_64_29 45
#define EXECUTE_CACHE_64_27 47
#define EXECUTE_CACHE_64_25 49
#define EXECUTE_CACHE_64_23 51
#define EXECUTE_CACHE_64_21 53
#define EXECUTE_CACHE_64_19 55
#define EXECUTE_CACHE_64_17 57
#define EXECUTE_CACHE_64_15 59
#define EXECUTE_CACHE_64_11 61
#define FREE_REFERENCE_64_2 64
#define FREE_REFERENCE_64_1 65
#define FREE_REFERENCE_64_0 66
#define FREE_REFERENCES_LABEL_64_0 40
#define NUMBER_OF_LINKER_SECTIONS_64_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd56;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd50;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd35;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd14;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd95;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd85;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_64_6);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_64_4);
      goto open_block_optimizing_make_17;

    case 3:
      current_block = (Rpc - LABEL_64_7);
      goto label_19;

    case 4:
      current_block = (Rpc - LABEL_64_8);
      goto label_24;

    case 5:
      current_block = (Rpc - LABEL_64_9);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_64_10);
      goto label_20;

    case 7:
      current_block = (Rpc - LABEL_64_13);
      goto label_21;

    case 8:
      current_block = (Rpc - LABEL_64_14);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_64_12);
      goto continuation_4;

    case 10:
      current_block = (Rpc - LABEL_64_16);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_64_18);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_64_20);
      goto continuation_5;

    case 13:
      current_block = (Rpc - LABEL_64_22);
      goto continuation_7;

    case 14:
      current_block = (Rpc - LABEL_64_24);
      goto continuation_8;

    case 15:
      current_block = (Rpc - LABEL_64_26);
      goto continuation_9;

    case 16:
      current_block = (Rpc - LABEL_64_28);
      goto continuation_10;

    case 17:
      current_block = (Rpc - LABEL_64_31);
      goto label_25;

    case 18:
      current_block = (Rpc - LABEL_64_30);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (open_block_optimizing_make_27)
DEFLABEL (open_block_optimizing_make_17)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_48;
  Wrd5 = Wrd9;

DEFLABEL (label_47)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_42;
  (Wrd68.Obj) = (Rsp [1]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_41;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd67.Lng))))
    goto label_41;
  (Wrd14.Obj) = ((Wrd65.pObj) [4]);
  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;

DEFLABEL (label_34)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_12]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_1]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_33;
  Wrd50 = Wrd54;

DEFLABEL (label_32)
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd57.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64_2]));
  (Wrd60.Obj) = ((Wrd57.pObj) [0]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if ((Wrd61.uLng) == 50)
    goto label_31;
  Wrd56 = Wrd60;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_64_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_17]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_64_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_19]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_64_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_21]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_64_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_23]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_64_22);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_24]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_25]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_64_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_27]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_64_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_29]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_64_28);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [10]);
  (Rsp [9]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_30]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd22.Obj) = (Rsp [8]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_29;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd21.Lng))))
    goto label_29;
  (Wrd15.Obj) = ((Wrd19.pObj) [2]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_28)
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_32]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_64_30);
  (Rsp [10]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [7]) = (Wrd6.Obj);
  Rsp = (& (Rsp [7]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_33]));

DEFLABEL (label_29)
  (Wrd24.Obj) = (Rsp [8]);
  (Wrd25.Obj) = (current_block [OBJECT_64_1]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_31]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_2]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_14])), (Wrd57.pObj));

DEFLABEL (label_22)
  (Wrd56.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_13])), (Wrd51.pObj));

DEFLABEL (label_21)
  (Wrd50.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd16.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_64_0]);
  (Rsp [6]) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  if ((Wrd22.Obj) == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_39;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_39;
  (Wrd25.Obj) = ((Wrd31.pObj) [2]);

DEFLABEL (label_38)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_37)
  (Rsp [2]) = (Wrd25.Obj);

DEFLABEL (label_36)
  (Wrd101.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd101.Obj);
  (Wrd102.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd102.Obj);
  (Wrd103.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd103.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_11]));

DEFLABEL (label_39)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_64_1]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_10]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_2]), 2);

DEFLABEL (label_20)
  (Wrd25.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_40)
  (Wrd25.Obj) = ((SCHEME_OBJECT) 0);
  goto label_38;

DEFLABEL (label_41)
  (Wrd70.Obj) = (Rsp [1]);
  (Wrd71.Obj) = (current_block [OBJECT_64_3]);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_9]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_2]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_34;

DEFLABEL (label_42)
  (Wrd76.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd76.Obj);
  (Wrd77.Obj) = (current_block [OBJECT_64_0]);
  (Rsp [6]) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd82.Obj) = (Rsp [2]);
  if ((Wrd82.Obj) == ((SCHEME_OBJECT) 0))
    goto label_46;
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_45;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_45;
  (Wrd85.Obj) = ((Wrd91.pObj) [2]);

DEFLABEL (label_44)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_43)
  (Rsp [2]) = (Wrd85.Obj);
  goto label_36;

DEFLABEL (label_45)
  (Wrd96.Obj) = (Rsp [2]);
  (Wrd97.Obj) = (current_block [OBJECT_64_1]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_8]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_2]), 2);

DEFLABEL (label_24)
  (Wrd85.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  (Wrd85.Obj) = ((SCHEME_OBJECT) 0);
  goto label_44;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_64_7])), (Wrd6.pObj));

DEFLABEL (label_19)
  (Wrd5.Obj) = Rvl;
  goto label_47;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_64_6);
  (Wrd25.Obj) = Rvl;
  goto label_37;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  (Wrd85.Obj) = Rvl;
  goto label_43;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_5 5
#define LABEL_65_8 7
#define LABEL_65_11 9
#define LABEL_65_12 11
#define LABEL_65_7 13
#define LABEL_65_10 15
#define LABEL_65_14 17
#define LABEL_65_15 19
#define ENVIRONMENT_LABEL_65_3 32
#define DEBUGGING_LABEL_65_2 31
#define OBJECT_65_3 30
#define OBJECT_65_2 29
#define OBJECT_65_1 28
#define OBJECT_65_0 27
#define EXECUTE_CACHE_65_13 21
#define EXECUTE_CACHE_65_9 23
#define EXECUTE_CACHE_65_6 25
#define FREE_REFERENCES_LABEL_65_0 20
#define NUMBER_OF_LINKER_SECTIONS_65_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto associate_vars_and_vals_12;

    case 1:
      current_block = (Rpc - LABEL_65_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_65_8);
      goto fill_table_10;

    case 3:
      current_block = (Rpc - LABEL_65_11);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_65_12);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_65_7);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_65_10);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_65_14);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_65_15);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (associate_vars_and_vals_19)
DEFLABEL (associate_vars_and_vals_12)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto fill_table_10;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_65_7);

DEFLABEL (label_21)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (fill_table_20)
DEFLABEL (fill_table_10)
  INTERRUPT_CHECK (26, LABEL_65_8);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.Obj) = (current_block [OBJECT_65_0]);
  if ((Wrd7.Obj) == (Wrd8.Obj))
    goto label_32;
  (Wrd9.Obj) = (Rsp [1]);
  if ((Wrd9.Obj) == (Wrd8.Obj))
    goto label_30;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_29;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_28)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_27;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_26)
  (Wrd32.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_65_10);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_25;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_24)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_23;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [1]) = (Wrd14.Obj);
  goto fill_table_10;

DEFLABEL (label_23)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_3]), 1);

DEFLABEL (label_17)
  (Wrd14.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_14]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_3]), 1);

DEFLABEL (label_16)
  (Wrd5.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_12]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_2]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_2]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd33.Obj) = (current_block [OBJECT_65_1]);
  (Rsp [1]) = (Wrd33.Obj);

DEFLABEL (label_31)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_9]));

DEFLABEL (label_32)
  (Wrd35.Obj) = (Rsp [1]);
  if ((Wrd35.Obj) == (Wrd8.Obj))
    goto label_33;
  (Wrd37.Obj) = (current_block [OBJECT_65_1]);
  (Rsp [1]) = (Wrd37.Obj);
  goto label_31;

DEFLABEL (label_33)
  Rsp = (& (Rsp [3]));
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define LABEL_66_5 5
#define LABEL_66_6 7
#define ENVIRONMENT_LABEL_66_3 15
#define DEBUGGING_LABEL_66_2 14
#define EXECUTE_CACHE_66_7 9
#define FREE_REFERENCE_66_1 12
#define FREE_REFERENCE_66_0 13
#define FREE_REFERENCES_LABEL_66_0 8
#define NUMBER_OF_LINKER_SECTIONS_66_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto varlist__varset_0;

    case 1:
      current_block = (Rpc - LABEL_66_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_66_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (varlist__varset_5)
DEFLABEL (varlist__varset_0)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_5 5
#define LABEL_67_6 7
#define ENVIRONMENT_LABEL_67_3 15
#define DEBUGGING_LABEL_67_2 14
#define EXECUTE_CACHE_67_7 9
#define FREE_REFERENCE_67_1 12
#define FREE_REFERENCE_67_0 13
#define FREE_REFERENCES_LABEL_67_0 8
#define NUMBER_OF_LINKER_SECTIONS_67_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto nodelist__nodeset_0;

    case 1:
      current_block = (Rpc - LABEL_67_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_67_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (nodelist__nodeset_5)
DEFLABEL (nodelist__nodeset_0)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_67_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define LABEL_68_5 5
#define LABEL_68_6 7
#define ENVIRONMENT_LABEL_68_3 15
#define DEBUGGING_LABEL_68_2 14
#define EXECUTE_CACHE_68_7 9
#define FREE_REFERENCE_68_1 12
#define FREE_REFERENCE_68_0 13
#define FREE_REFERENCES_LABEL_68_0 8
#define NUMBER_OF_LINKER_SECTIONS_68_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto empty_nodeset_0;

    case 1:
      current_block = (Rpc - LABEL_68_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_68_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (empty_nodeset_5)
DEFLABEL (empty_nodeset_0)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_68_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_68_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_68_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_68_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_4 3
#define LABEL_69_5 5
#define LABEL_69_6 7
#define ENVIRONMENT_LABEL_69_3 15
#define DEBUGGING_LABEL_69_2 14
#define EXECUTE_CACHE_69_7 9
#define FREE_REFERENCE_69_1 12
#define FREE_REFERENCE_69_0 13
#define FREE_REFERENCES_LABEL_69_0 8
#define NUMBER_OF_LINKER_SECTIONS_69_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_4);
      goto singleton_nodeset_0;

    case 1:
      current_block = (Rpc - LABEL_69_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_69_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (singleton_nodeset_5)
DEFLABEL (singleton_nodeset_0)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_5 5
#define LABEL_70_6 7
#define ENVIRONMENT_LABEL_70_3 15
#define DEBUGGING_LABEL_70_2 14
#define EXECUTE_CACHE_70_7 9
#define FREE_REFERENCE_70_1 12
#define FREE_REFERENCE_70_0 13
#define FREE_REFERENCES_LABEL_70_0 8
#define NUMBER_OF_LINKER_SECTIONS_70_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto empty_varset_0;

    case 1:
      current_block = (Rpc - LABEL_70_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_70_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (empty_varset_5)
DEFLABEL (empty_varset_0)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define LABEL_71_5 5
#define LABEL_71_6 7
#define ENVIRONMENT_LABEL_71_3 15
#define DEBUGGING_LABEL_71_2 14
#define EXECUTE_CACHE_71_7 9
#define FREE_REFERENCE_71_1 12
#define FREE_REFERENCE_71_0 13
#define FREE_REFERENCES_LABEL_71_0 8
#define NUMBER_OF_LINKER_SECTIONS_71_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto singleton_varset_0;

    case 1:
      current_block = (Rpc - LABEL_71_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_71_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (singleton_varset_5)
DEFLABEL (singleton_varset_0)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define LABEL_72_9 7
#define LABEL_72_7 9
#define TAG_72_8 3
#define LABEL_72_11 11
#define LABEL_72_13 13
#define ENVIRONMENT_LABEL_72_3 26
#define DEBUGGING_LABEL_72_2 25
#define EXECUTE_CACHE_72_15 15
#define EXECUTE_CACHE_72_14 17
#define EXECUTE_CACHE_72_12 19
#define EXECUTE_CACHE_72_10 21
#define EXECUTE_CACHE_72_6 23
#define FREE_REFERENCES_LABEL_72_0 14
#define NUMBER_OF_LINKER_SECTIONS_72_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto get_free_vars_in_bindings_7;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_72_9);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_72_7);
      goto kernel_11;

    case 4:
      current_block = (Rpc - LABEL_72_11);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_72_13);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_free_vars_in_bindings_10)
DEFLABEL (get_free_vars_in_bindings_7)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_7])));
  Rhp += 2;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  Wrd14 = Wrd16;
  (Wrd15.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  ((Wrd14.pObj) [3]) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_72_9);
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (kernel_11)
  CLOSURE_HEADER (LABEL_72_7);

DEFLABEL (kernel_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_72_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_72_13);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_15]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_5 5
#define LABEL_73_8 7
#define LABEL_73_9 9
#define LABEL_73_7 11
#define LABEL_73_11 13
#define LABEL_73_15 15
#define LABEL_73_12 17
#define LABEL_73_17 19
#define LABEL_73_13 21
#define LABEL_73_14 23
#define ENVIRONMENT_LABEL_73_3 42
#define DEBUGGING_LABEL_73_2 41
#define OBJECT_73_2 40
#define OBJECT_73_1 39
#define OBJECT_73_0 38
#define EXECUTE_CACHE_73_19 25
#define EXECUTE_CACHE_73_18 27
#define EXECUTE_CACHE_73_16 29
#define EXECUTE_CACHE_73_10 31
#define EXECUTE_CACHE_73_6 33
#define FREE_REFERENCE_73_1 36
#define FREE_REFERENCE_73_0 37
#define FREE_REFERENCES_LABEL_73_0 24
#define NUMBER_OF_LINKER_SECTIONS_73_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto get_body_free_vars_12;

    case 1:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_73_8);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_73_9);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_73_7);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_73_11);
      goto loop_9;

    case 6:
      current_block = (Rpc - LABEL_73_15);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_73_12);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_73_17);
      goto label_17;

    case 9:
      current_block = (Rpc - LABEL_73_13);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_73_14);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_body_free_vars_19)
DEFLABEL (get_body_free_vars_12)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_73_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_24;
  Wrd9 = Wrd13;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_73_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_22;
  Wrd15 = Wrd19;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_73_7);
  (Rsp [1]) = Rvl;
  goto loop_9;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_73_9])), (Wrd16.pObj));

DEFLABEL (label_15)
  (Wrd15.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_73_8])), (Wrd10.pObj));

DEFLABEL (label_14)
  (Wrd9.Obj) = Rvl;
  goto label_23;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_73_11);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_73_0])))
    goto label_25;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_13]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_14]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_29;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_73_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_73_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_73_12);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_27;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_26)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_9;

DEFLABEL (label_27)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_17]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_2]), 1);

DEFLABEL (label_17)
  (Wrd6.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_15]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_28;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_5 5
#define LABEL_74_6 7
#define LABEL_74_7 9
#define LABEL_74_9 11
#define LABEL_74_8 13
#define LABEL_74_11 15
#define ENVIRONMENT_LABEL_74_3 25
#define DEBUGGING_LABEL_74_2 24
#define OBJECT_74_2 23
#define OBJECT_74_1 22
#define OBJECT_74_0 21
#define EXECUTE_CACHE_74_10 17
#define FREE_REFERENCE_74_0 20
#define FREE_REFERENCES_LABEL_74_0 16
#define NUMBER_OF_LINKER_SECTIONS_74_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto get_body_7;

    case 1:
      current_block = (Rpc - LABEL_74_5);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_74_6);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_74_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_74_9);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_74_8);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_74_11);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_body_15)
DEFLABEL (get_body_7)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_74_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_16;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_74_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_25;
  Wrd7 = Wrd11;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_23;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_22)
  (Wrd22.Obj) = (* (Rsp++));
  if ((Wrd13.Obj) == (Wrd22.Obj))
    goto label_19;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_18;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_17)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_10]));

DEFLABEL (label_18)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_9]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_21;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_20)
  (Rsp [0]) = (Wrd35.Obj);
  goto label_17;

DEFLABEL (label_21)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_7]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 1);

DEFLABEL (label_12)
  (Wrd35.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_1]), 1);

DEFLABEL (label_10)
  (Wrd13.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_74_5])), (Wrd8.pObj));

DEFLABEL (label_9)
  (Wrd7.Obj) = Rvl;
  goto label_24;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_74_8);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_27;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_26)
  (Wrd14.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_1]), 1);

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define ENVIRONMENT_LABEL_75_3 5
#define DEBUGGING_LABEL_75_2 4
#define FREE_REFERENCES_LABEL_75_0 4
#define NUMBER_OF_LINKER_SECTIONS_75_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_75_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define ENVIRONMENT_LABEL_76_3 5
#define DEBUGGING_LABEL_76_2 4
#define FREE_REFERENCES_LABEL_76_0 4
#define NUMBER_OF_LINKER_SECTIONS_76_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_76_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define LABEL_77_5 5
#define LABEL_77_6 7
#define ENVIRONMENT_LABEL_77_3 15
#define DEBUGGING_LABEL_77_2 14
#define EXECUTE_CACHE_77_7 9
#define FREE_REFERENCE_77_1 12
#define FREE_REFERENCE_77_0 13
#define FREE_REFERENCES_LABEL_77_0 8
#define NUMBER_OF_LINKER_SECTIONS_77_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto lambda_0;

    case 1:
      current_block = (Rpc - LABEL_77_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_77_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_77_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_77_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_5 5
#define LABEL_78_6 7
#define ENVIRONMENT_LABEL_78_3 15
#define DEBUGGING_LABEL_78_2 14
#define EXECUTE_CACHE_78_7 9
#define FREE_REFERENCE_78_1 12
#define FREE_REFERENCE_78_0 13
#define FREE_REFERENCES_LABEL_78_0 8
#define NUMBER_OF_LINKER_SECTIONS_78_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto lambda_0;

    case 1:
      current_block = (Rpc - LABEL_78_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_78_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_78_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_78_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_7;
  Wrd11 = Wrd15;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_7]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_6;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define ENVIRONMENT_LABEL_79_3 5
#define DEBUGGING_LABEL_79_2 4
#define FREE_REFERENCES_LABEL_79_0 4
#define NUMBER_OF_LINKER_SECTIONS_79_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_79_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define ENVIRONMENT_LABEL_80_3 7
#define DEBUGGING_LABEL_80_2 6
#define OBJECT_80_1 5
#define OBJECT_80_0 4
#define FREE_REFERENCES_LABEL_80_0 4
#define NUMBER_OF_LINKER_SECTIONS_80_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto Z__node_type_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__node_type_3)
DEFLABEL (Z__node_type_0)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_80_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define ENVIRONMENT_LABEL_81_3 7
#define DEBUGGING_LABEL_81_2 6
#define OBJECT_81_1 5
#define OBJECT_81_0 4
#define FREE_REFERENCES_LABEL_81_0 4
#define NUMBER_OF_LINKER_SECTIONS_81_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto Z__node_vars_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__node_vars_3)
DEFLABEL (Z__node_vars_0)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_81_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define ENVIRONMENT_LABEL_82_3 7
#define DEBUGGING_LABEL_82_2 6
#define OBJECT_82_1 5
#define OBJECT_82_0 4
#define FREE_REFERENCES_LABEL_82_0 4
#define NUMBER_OF_LINKER_SECTIONS_82_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto Z__node_needs_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__node_needs_3)
DEFLABEL (Z__node_needs_0)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_82_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define ENVIRONMENT_LABEL_83_3 7
#define DEBUGGING_LABEL_83_2 6
#define OBJECT_83_1 5
#define OBJECT_83_0 4
#define FREE_REFERENCES_LABEL_83_0 4
#define NUMBER_OF_LINKER_SECTIONS_83_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto Z__node_needed_by_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__node_needed_by_3)
DEFLABEL (Z__node_needed_by_0)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_83_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define ENVIRONMENT_LABEL_84_3 7
#define DEBUGGING_LABEL_84_2 6
#define OBJECT_84_1 5
#define OBJECT_84_0 4
#define FREE_REFERENCES_LABEL_84_0 4
#define NUMBER_OF_LINKER_SECTIONS_84_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto Z__node_depth_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__node_depth_3)
DEFLABEL (Z__node_depth_0)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_84_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define ENVIRONMENT_LABEL_85_3 8
#define DEBUGGING_LABEL_85_2 7
#define OBJECT_85_2 6
#define OBJECT_85_1 5
#define OBJECT_85_0 4
#define FREE_REFERENCES_LABEL_85_0 4
#define NUMBER_OF_LINKER_SECTIONS_85_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto set__node_typeB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__node_typeB_3)
DEFLABEL (set__node_typeB_0)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_85_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [2]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_85_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_4 3
#define ENVIRONMENT_LABEL_86_3 8
#define DEBUGGING_LABEL_86_2 7
#define OBJECT_86_2 6
#define OBJECT_86_1 5
#define OBJECT_86_0 4
#define FREE_REFERENCES_LABEL_86_0 4
#define NUMBER_OF_LINKER_SECTIONS_86_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_4);
      goto set__node_needsB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__node_needsB_3)
DEFLABEL (set__node_needsB_0)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_86_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [4]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_86_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define ENVIRONMENT_LABEL_87_3 8
#define DEBUGGING_LABEL_87_2 7
#define OBJECT_87_2 6
#define OBJECT_87_1 5
#define OBJECT_87_0 4
#define FREE_REFERENCES_LABEL_87_0 4
#define NUMBER_OF_LINKER_SECTIONS_87_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto set__node_needed_byB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__node_needed_byB_3)
DEFLABEL (set__node_needed_byB_0)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_87_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_87_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define ENVIRONMENT_LABEL_88_3 8
#define DEBUGGING_LABEL_88_2 7
#define OBJECT_88_2 6
#define OBJECT_88_1 5
#define OBJECT_88_0 4
#define FREE_REFERENCES_LABEL_88_0 4
#define NUMBER_OF_LINKER_SECTIONS_88_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto set__node_depthB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set__node_depthB_3)
DEFLABEL (set__node_depthB_0)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_88_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [6]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_88_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define LABEL_89_6 5
#define LABEL_89_7 7
#define LABEL_89_5 9
#define ENVIRONMENT_LABEL_89_3 20
#define DEBUGGING_LABEL_89_2 19
#define OBJECT_89_0 18
#define EXECUTE_CACHE_89_9 11
#define EXECUTE_CACHE_89_8 13
#define FREE_REFERENCE_89_1 16
#define FREE_REFERENCE_89_0 17
#define FREE_REFERENCES_LABEL_89_0 10
#define NUMBER_OF_LINKER_SECTIONS_89_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto make_base_node_1;

    case 1:
      current_block = (Rpc - LABEL_89_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_89_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_89_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_base_node_6)
DEFLABEL (make_base_node_1)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_89_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_10;
  Wrd8 = Wrd12;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_89_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_8;
  Wrd14 = Wrd18;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_89_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89_7])), (Wrd15.pObj));

DEFLABEL (label_4)
  (Wrd14.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89_6])), (Wrd9.pObj));

DEFLABEL (label_3)
  (Wrd8.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_4 3
#define LABEL_90_6 5
#define LABEL_90_7 7
#define LABEL_90_5 9
#define ENVIRONMENT_LABEL_90_3 20
#define DEBUGGING_LABEL_90_2 19
#define OBJECT_90_0 18
#define EXECUTE_CACHE_90_9 11
#define EXECUTE_CACHE_90_8 13
#define FREE_REFERENCE_90_1 16
#define FREE_REFERENCE_90_0 17
#define FREE_REFERENCES_LABEL_90_0 10
#define NUMBER_OF_LINKER_SECTIONS_90_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_4);
      goto variable__node_1;

    case 1:
      current_block = (Rpc - LABEL_90_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_90_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (variable__node_6)
DEFLABEL (variable__node_1)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd5.Obj) = (current_block [OBJECT_90_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_10;
  Wrd10 = Wrd14;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_1]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_8;
  Wrd16 = Wrd20;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_5);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_7])), (Wrd17.pObj));

DEFLABEL (label_4)
  (Wrd16.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_6])), (Wrd11.pObj));

DEFLABEL (label_3)
  (Wrd10.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define ENVIRONMENT_LABEL_91_3 9
#define DEBUGGING_LABEL_91_2 8
#define OBJECT_91_0 7
#define EXECUTE_CACHE_91_5 5
#define FREE_REFERENCES_LABEL_91_0 4
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto make_letrec_node_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_letrec_node_3)
DEFLABEL (make_letrec_node_0)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (Wrd5.Obj) = (current_block [OBJECT_91_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_6 5
#define LABEL_92_5 7
#define ENVIRONMENT_LABEL_92_3 16
#define DEBUGGING_LABEL_92_2 15
#define OBJECT_92_3 14
#define OBJECT_92_2 13
#define OBJECT_92_1 12
#define OBJECT_92_0 11
#define EXECUTE_CACHE_92_7 9
#define FREE_REFERENCES_LABEL_92_0 8
#define NUMBER_OF_LINKER_SECTIONS_92_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto add_node_needB_2;

    case 1:
      current_block = (Rpc - LABEL_92_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_92_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (add_node_needB_6)
DEFLABEL (add_node_needB_2)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_92_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_92_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_3]), 3);

DEFLABEL (label_8)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_7;
  ((Wrd15.pObj) [4]) = Rvl;
  Rvl = (current_block [OBJECT_92_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_92_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_6 5
#define LABEL_93_5 7
#define ENVIRONMENT_LABEL_93_3 16
#define DEBUGGING_LABEL_93_2 15
#define OBJECT_93_3 14
#define OBJECT_93_2 13
#define OBJECT_93_1 12
#define OBJECT_93_0 11
#define EXECUTE_CACHE_93_7 9
#define FREE_REFERENCES_LABEL_93_0 8
#define NUMBER_OF_LINKER_SECTIONS_93_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto remove_node_needB_2;

    case 1:
      current_block = (Rpc - LABEL_93_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_93_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (remove_node_needB_6)
DEFLABEL (remove_node_needB_2)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_93_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_93_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_3]), 3);

DEFLABEL (label_8)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_7;
  ((Wrd15.pObj) [4]) = Rvl;
  Rvl = (current_block [OBJECT_93_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_93_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_6 5
#define LABEL_94_5 7
#define ENVIRONMENT_LABEL_94_3 16
#define DEBUGGING_LABEL_94_2 15
#define OBJECT_94_3 14
#define OBJECT_94_2 13
#define OBJECT_94_1 12
#define OBJECT_94_0 11
#define EXECUTE_CACHE_94_7 9
#define FREE_REFERENCES_LABEL_94_0 8
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto add_node_needed_byB_2;

    case 1:
      current_block = (Rpc - LABEL_94_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_94_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (add_node_needed_byB_6)
DEFLABEL (add_node_needed_byB_2)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_94_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_94_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_3]), 3);

DEFLABEL (label_8)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_7;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_94_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_94_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_6 5
#define LABEL_95_5 7
#define ENVIRONMENT_LABEL_95_3 16
#define DEBUGGING_LABEL_95_2 15
#define OBJECT_95_3 14
#define OBJECT_95_2 13
#define OBJECT_95_1 12
#define OBJECT_95_0 11
#define EXECUTE_CACHE_95_7 9
#define FREE_REFERENCES_LABEL_95_0 8
#define NUMBER_OF_LINKER_SECTIONS_95_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto remove_node_needed_byB_2;

    case 1:
      current_block = (Rpc - LABEL_95_6);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (remove_node_needed_byB_6)
DEFLABEL (remove_node_needed_byB_2)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_95_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_95_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_3]), 3);

DEFLABEL (label_8)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_7;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_95_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_95_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_1]), 2);

DEFLABEL (label_4)
  (* (--Rsp)) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_5 5
#define LABEL_96_9 7
#define LABEL_96_7 9
#define TAG_96_8 3
#define LABEL_96_14 11
#define LABEL_96_15 13
#define LABEL_96_12 15
#define LABEL_96_13 17
#define ENVIRONMENT_LABEL_96_3 36
#define DEBUGGING_LABEL_96_2 35
#define OBJECT_96_0 34
#define EXECUTE_CACHE_96_18 19
#define EXECUTE_CACHE_96_17 21
#define EXECUTE_CACHE_96_16 23
#define EXECUTE_CACHE_96_11 25
#define EXECUTE_CACHE_96_10 27
#define EXECUTE_CACHE_96_6 29
#define FREE_REFERENCE_96_1 32
#define FREE_REFERENCE_96_0 33
#define FREE_REFERENCES_LABEL_96_0 18
#define NUMBER_OF_LINKER_SECTIONS_96_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto build_graph_7;

    case 1:
      current_block = (Rpc - LABEL_96_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_96_9);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_96_7);
      goto kernel_13;

    case 4:
      current_block = (Rpc - LABEL_96_14);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_96_15);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_96_12);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_96_13);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (build_graph_12)
DEFLABEL (build_graph_7)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_96_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_7])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  ((Wrd13.pObj) [2]) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_96_9);
  (Wrd5.Obj) = (Rsp [5]);
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [4]);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_11]));

DEFLABEL (kernel_13)
  CLOSURE_HEADER (LABEL_96_7);

DEFLABEL (kernel_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_96_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_17;
  Wrd12 = Wrd16;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_96_1]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_15;
  Wrd18 = Wrd22;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_96_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_96_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_96_12);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = Rvl;
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_17]));

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96_15])), (Wrd19.pObj));

DEFLABEL (label_10)
  (Wrd18.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96_14])), (Wrd13.pObj));

DEFLABEL (label_9)
  (Wrd12.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define LABEL_97_6 5
#define LABEL_97_5 7
#define LABEL_97_8 9
#define LABEL_97_10 11
#define LABEL_97_9 13
#define ENVIRONMENT_LABEL_97_3 23
#define DEBUGGING_LABEL_97_2 22
#define OBJECT_97_4 21
#define OBJECT_97_3 20
#define OBJECT_97_2 19
#define OBJECT_97_1 18
#define OBJECT_97_0 17
#define EXECUTE_CACHE_97_7 15
#define FREE_REFERENCES_LABEL_97_0 14
#define NUMBER_OF_LINKER_SECTIONS_97_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd5;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto link_2_nodesB_5;

    case 1:
      current_block = (Rpc - LABEL_97_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_97_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_97_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_97_10);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_97_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (link_2_nodesB_11)
DEFLABEL (link_2_nodesB_5)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_19;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_19;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_18)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_97_5);
  (Wrd5.Obj) = Rvl;
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd34.Lng))))
    goto label_17;
  ((Wrd32.pObj) [4]) = Rvl;

DEFLABEL (label_16)
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_15;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd19.Lng))))
    goto label_15;
  (Wrd13.Obj) = ((Wrd17.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_97_9);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_97_3]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_13;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_2]), 3);

DEFLABEL (label_13)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_12;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_97_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd22.Obj) = (Rsp [4]);
  (Wrd23.Obj) = (current_block [OBJECT_97_3]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (current_block [OBJECT_97_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_2]), 3);

DEFLABEL (label_9)
  goto label_16;

DEFLABEL (label_19)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_97_0]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_4 3
#define LABEL_98_6 5
#define LABEL_98_5 7
#define LABEL_98_11 9
#define LABEL_98_7 11
#define TAG_98_8 4
#define LABEL_98_15 13
#define LABEL_98_10 15
#define LABEL_98_12 17
#define TAG_98_13 7
#define LABEL_98_18 19
#define LABEL_98_14 21
#define LABEL_98_17 23
#define ENVIRONMENT_LABEL_98_3 37
#define DEBUGGING_LABEL_98_2 36
#define OBJECT_98_6 35
#define OBJECT_98_5 34
#define OBJECT_98_4 33
#define OBJECT_98_3 32
#define OBJECT_98_2 31
#define OBJECT_98_1 30
#define OBJECT_98_0 29
#define EXECUTE_CACHE_98_16 25
#define EXECUTE_CACHE_98_9 27
#define FREE_REFERENCES_LABEL_98_0 24
#define NUMBER_OF_LINKER_SECTIONS_98_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_4);
      goto unlink_nodeB_10;

    case 1:
      current_block = (Rpc - LABEL_98_6);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_98_5);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_98_11);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_98_7);
      goto lambda_18;

    case 5:
      current_block = (Rpc - LABEL_98_15);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_98_10);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_98_12);
      goto lambda_19;

    case 8:
      current_block = (Rpc - LABEL_98_18);
      goto label_15;

    case 9:
      current_block = (Rpc - LABEL_98_14);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_98_17);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unlink_nodeB_17)
DEFLABEL (unlink_nodeB_10)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_25;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_25;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_24)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_98_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_98_7])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_98_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_23;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_23;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_22)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_98_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_98_12])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_9]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_98_10);
  (Wrd5.Obj) = (current_block [OBJECT_98_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_98_4]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd20.uLng) == 62)
    goto label_21;

DEFLABEL (label_20)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_6]), 3);

DEFLABEL (label_21)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_20;
  ((Wrd16.pObj) [2]) = (Wrd7.Obj);
  Rvl = (current_block [OBJECT_98_5]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_98_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_1]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_98_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_1]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_98_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 62))
    goto label_29;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd20.Lng))))
    goto label_29;
  (Wrd14.Obj) = ((Wrd18.pObj) [5]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_16]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_98_14);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_98_2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_27;

DEFLABEL (label_26)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_6]), 3);

DEFLABEL (label_27)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_26;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_98_5]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.Obj) = (current_block [OBJECT_98_2]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_15]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_1]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_98_12);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_17]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 62))
    goto label_33;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd20.Lng))))
    goto label_33;
  (Wrd14.Obj) = ((Wrd18.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_32)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_98_17);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_98_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_31;

DEFLABEL (label_30)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_6]), 3);

DEFLABEL (label_31)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_30;
  ((Wrd15.pObj) [4]) = Rvl;
  Rvl = (current_block [OBJECT_98_5]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.Obj) = (current_block [OBJECT_98_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_18]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_1]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_32;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_4 3
#define LABEL_99_5 5
#define ENVIRONMENT_LABEL_99_3 12
#define DEBUGGING_LABEL_99_2 11
#define EXECUTE_CACHE_99_6 7
#define FREE_REFERENCE_99_0 10
#define FREE_REFERENCES_LABEL_99_0 6
#define NUMBER_OF_LINKER_SECTIONS_99_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_4);
      goto unlink_nodesB_0;

    case 1:
      current_block = (Rpc - LABEL_99_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unlink_nodesB_4)
DEFLABEL (unlink_nodesB_0)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_99_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_4 3
#define LABEL_100_7 5
#define LABEL_100_11 7
#define LABEL_100_12 9
#define LABEL_100_5 11
#define TAG_100_6 4
#define LABEL_100_9 13
#define LABEL_100_10 15
#define LABEL_100_14 17
#define LABEL_100_15 19
#define TAG_100_16 8
#define LABEL_100_18 21
#define LABEL_100_19 23
#define TAG_100_20 10
#define LABEL_100_24 25
#define LABEL_100_25 27
#define TAG_100_26 12
#define LABEL_100_28 29
#define LABEL_100_29 31
#define TAG_100_30 14
#define LABEL_100_34 33
#define LABEL_100_31 35
#define TAG_100_32 16
#define LABEL_100_33 37
#define LABEL_100_39 39
#define LABEL_100_41 41
#define LABEL_100_36 43
#define LABEL_100_37 45
#define TAG_100_38 21
#define LABEL_100_43 47
#define LABEL_100_40 49
#define LABEL_100_42 51
#define LABEL_100_44 53
#define LABEL_100_46 55
#define LABEL_100_45 57
#define ENVIRONMENT_LABEL_100_3 89
#define DEBUGGING_LABEL_100_2 88
#define OBJECT_100_9 87
#define OBJECT_100_8 86
#define OBJECT_100_7 85
#define OBJECT_100_6 84
#define OBJECT_100_5 83
#define OBJECT_100_4 82
#define OBJECT_100_3 81
#define OBJECT_100_2 80
#define OBJECT_100_1 79
#define OBJECT_100_0 78
#define EXECUTE_CACHE_100_35 59
#define EXECUTE_CACHE_100_27 61
#define EXECUTE_CACHE_100_23 63
#define EXECUTE_CACHE_100_22 65
#define EXECUTE_CACHE_100_21 67
#define EXECUTE_CACHE_100_17 69
#define EXECUTE_CACHE_100_13 71
#define EXECUTE_CACHE_100_8 73
#define FREE_REFERENCE_100_1 76
#define FREE_REFERENCE_100_0 77
#define FREE_REFERENCES_LABEL_100_0 58
#define NUMBER_OF_LINKER_SECTIONS_100_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd52;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd14;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd20;
  machine_word Wrd19;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_4);
      goto link_nodesB_26;

    case 1:
      current_block = (Rpc - LABEL_100_7);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_100_11);
      goto label_28;

    case 3:
      current_block = (Rpc - LABEL_100_12);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_100_5);
      goto kernel_38;

    case 5:
      current_block = (Rpc - LABEL_100_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_100_10);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_100_14);
      goto lambda_24;

    case 8:
      current_block = (Rpc - LABEL_100_15);
      goto lambda_39;

    case 9:
      current_block = (Rpc - LABEL_100_18);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_100_19);
      goto lambda_40;

    case 11:
      current_block = (Rpc - LABEL_100_24);
      goto lambda_22;

    case 12:
      current_block = (Rpc - LABEL_100_25);
      goto lambda_42;

    case 13:
      current_block = (Rpc - LABEL_100_28);
      goto lambda_9;

    case 14:
      current_block = (Rpc - LABEL_100_29);
      goto lambda_43;

    case 15:
      current_block = (Rpc - LABEL_100_34);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_100_31);
      goto lambda_45;

    case 17:
      current_block = (Rpc - LABEL_100_33);
      goto continuation_4;

    case 18:
      current_block = (Rpc - LABEL_100_39);
      goto label_32;

    case 19:
      current_block = (Rpc - LABEL_100_41);
      goto label_31;

    case 20:
      current_block = (Rpc - LABEL_100_36);
      goto lambda_19;

    case 21:
      current_block = (Rpc - LABEL_100_37);
      goto lambda_47;

    case 22:
      current_block = (Rpc - LABEL_100_43);
      goto label_33;

    case 23:
      current_block = (Rpc - LABEL_100_40);
      goto continuation_7;

    case 24:
      current_block = (Rpc - LABEL_100_42);
      goto continuation_14;

    case 25:
      current_block = (Rpc - LABEL_100_44);
      goto label_35;

    case 26:
      current_block = (Rpc - LABEL_100_46);
      goto label_34;

    case 27:
      current_block = (Rpc - LABEL_100_45);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (link_nodesB_37)
DEFLABEL (link_nodesB_26)
  INTERRUPT_CHECK (26, LABEL_100_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_5])));
  Rhp += 3;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  (* (--Rsp)) = (Wrd20.Obj);
  Wrd17 = Wrd19;
  (Wrd18.Obj) = (Rsp [5]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [3]) = (Wrd15.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd17.pObj) [4]) = (Wrd12.Obj);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_100_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_52;
  Wrd11 = Wrd15;

DEFLABEL (label_51)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_50;
  Wrd17 = Wrd21;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_100_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_100_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_22]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_100_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_19])));
  Rhp += 2;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd13 = Wrd10;
  (Wrd14.Obj) = (Rsp [8]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  ((Wrd13.pObj) [3]) = Rvl;
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_21]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_100_18);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_12])), (Wrd18.pObj));

DEFLABEL (label_29)
  (Wrd17.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_11])), (Wrd12.pObj));

DEFLABEL (label_28)
  (Wrd11.Obj) = Rvl;
  goto label_51;

DEFLABEL (kernel_38)
  CLOSURE_HEADER (LABEL_100_5);

DEFLABEL (kernel_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_14]))));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_15])));
  Rhp += 4;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd24 = Wrd13;
  ((Wrd24.pObj) [2]) = (Wrd8.Obj);
  (Wrd23.Obj) = ((Wrd7.pObj) [3]);
  ((Wrd24.pObj) [3]) = (Wrd23.Obj);
  (Wrd19.Obj) = ((Wrd7.pObj) [4]);
  ((Wrd24.pObj) [4]) = (Wrd19.Obj);
  ((Wrd24.pObj) [5]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  (Rsp [3]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_17]));

DEFLABEL (lambda_41)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_100_14);
  (Wrd5.Obj) = (current_block [OBJECT_100_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_23]));

DEFLABEL (lambda_39)
  CLOSURE_HEADER (LABEL_100_15);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_24]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_25])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd11.pObj) [2]) = (Wrd14.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = ((Wrd13.pObj) [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [4]) = (Wrd18.Obj);
  (Wrd21.Obj) = ((Wrd13.pObj) [4]);
  (Rsp [3]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_27]));

DEFLABEL (lambda_40)
  CLOSURE_HEADER (LABEL_100_19);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_28]))));
  (Rsp [3]) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_29])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd7.pObj) [3]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_17]));

DEFLABEL (lambda_44)
DEFLABEL (lambda_22)
  INTERRUPT_CHECK (26, LABEL_100_24);
  (Wrd5.Obj) = (current_block [OBJECT_100_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_23]));

DEFLABEL (lambda_42)
  CLOSURE_HEADER (LABEL_100_25);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_31])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_21]));

DEFLABEL (lambda_46)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_100_28);
  (Wrd5.Obj) = (current_block [OBJECT_100_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_23]));

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_100_29);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_60;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_60;
  (Wrd13.Obj) = ((Wrd19.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_59)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_35]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_100_33);
  (Wrd5.Obj) = Rvl;
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 62))
    goto label_58;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd40.Lng))))
    goto label_58;
  ((Wrd38.pObj) [4]) = Rvl;

DEFLABEL (label_57)
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 62))
    goto label_56;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_56;
  (Wrd15.Obj) = ((Wrd19.pObj) [5]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_55)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_35]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_100_40);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_100_7]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_54;

DEFLABEL (label_53)
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_6]), 3);

DEFLABEL (label_54)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_53;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_100_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_100_7]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_41]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_5]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [2]);
  (Wrd48.Obj) = (current_block [OBJECT_100_4]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_39]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_6]), 3);

DEFLABEL (label_32)
  goto label_57;

DEFLABEL (label_60)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Wrd29.Obj) = (current_block [OBJECT_100_4]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_34]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_5]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_100_31);

DEFLABEL (lambda_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_36]))));
  (Rsp [3]) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_37])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd7.pObj) [3]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_17]));

DEFLABEL (lambda_48)
DEFLABEL (lambda_19)
  INTERRUPT_CHECK (26, LABEL_100_36);
  (Wrd5.Obj) = (current_block [OBJECT_100_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_23]));

DEFLABEL (lambda_47)
  CLOSURE_HEADER (LABEL_100_37);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_68;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_68;
  (Wrd13.Obj) = ((Wrd19.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_67)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_35]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_100_42);
  (Wrd5.Obj) = Rvl;
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 62))
    goto label_66;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd40.Lng))))
    goto label_66;
  ((Wrd38.pObj) [4]) = Rvl;

DEFLABEL (label_65)
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_45]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 62))
    goto label_64;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_64;
  (Wrd15.Obj) = ((Wrd19.pObj) [5]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_63)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_35]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_100_45);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_100_7]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_62;

DEFLABEL (label_61)
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_6]), 3);

DEFLABEL (label_62)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_61;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_100_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_64)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_100_7]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_46]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_5]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [2]);
  (Wrd48.Obj) = (current_block [OBJECT_100_4]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_44]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_6]), 3);

DEFLABEL (label_35)
  goto label_65;

DEFLABEL (label_68)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Wrd29.Obj) = (current_block [OBJECT_100_4]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_43]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_5]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_67;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_4 3
#define LABEL_101_5 5
#define TAG_101_6 1
#define LABEL_101_7 7
#define TAG_101_8 2
#define LABEL_101_9 9
#define TAG_101_10 3
#define LABEL_101_12 11
#define ENVIRONMENT_LABEL_101_3 18
#define DEBUGGING_LABEL_101_2 17
#define EXECUTE_CACHE_101_13 13
#define EXECUTE_CACHE_101_11 15
#define FREE_REFERENCES_LABEL_101_0 12
#define NUMBER_OF_LINKER_SECTIONS_101_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_4);
      goto collapse_circularitiesB_4;

    case 1:
      current_block = (Rpc - LABEL_101_5);
      goto loop_3;

    case 2:
      current_block = (Rpc - LABEL_101_7);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_101_9);
      goto lambda_10;

    case 4:
      current_block = (Rpc - LABEL_101_12);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (collapse_circularitiesB_7)
DEFLABEL (collapse_circularitiesB_4)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_5])));
  Rhp += 1;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  Wrd8 = Wrd10;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_3;

DEFLABEL (loop_8)
DEFLABEL (loop_3)
  INTERRUPT_CHECK (26, LABEL_101_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_7])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_9])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  ((Wrd14.pObj) [2]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_11]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_101_7);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_13]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_101_12);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_3;

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_101_9);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_4 3
#define LABEL_102_5 5
#define LABEL_102_6 7
#define LABEL_102_8 9
#define LABEL_102_13 11
#define LABEL_102_12 13
#define LABEL_102_10 15
#define TAG_102_11 6
#define LABEL_102_15 17
#define LABEL_102_16 19
#define TAG_102_17 8
#define LABEL_102_18 21
#define ENVIRONMENT_LABEL_102_3 35
#define DEBUGGING_LABEL_102_2 34
#define OBJECT_102_4 33
#define OBJECT_102_3 32
#define OBJECT_102_2 31
#define OBJECT_102_1 30
#define OBJECT_102_0 29
#define EXECUTE_CACHE_102_14 23
#define EXECUTE_CACHE_102_9 25
#define EXECUTE_CACHE_102_7 27
#define FREE_REFERENCES_LABEL_102_0 22
#define NUMBER_OF_LINKER_SECTIONS_102_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_4);
      goto find_circularity_16;

    case 1:
      current_block = (Rpc - LABEL_102_5);
      goto fc_15;

    case 2:
      current_block = (Rpc - LABEL_102_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_102_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_102_13);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_102_12);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_102_10);
      goto loop_11;

    case 7:
      current_block = (Rpc - LABEL_102_15);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_102_16);
      goto lambda_25;

    case 9:
      current_block = (Rpc - LABEL_102_18);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_circularity_22)
DEFLABEL (find_circularity_16)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_102_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto fc_15;

DEFLABEL (fc_23)
DEFLABEL (fc_15)
  INTERRUPT_CHECK (26, LABEL_102_5);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_102_0])))
    goto label_26;
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_26)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_102_6);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_27)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.Obj) = (current_block [OBJECT_102_0]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_102_8);
  (Rsp [0]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd36.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_10])));
  Rhp += 3;
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  Wrd34 = Wrd36;
  (Wrd35.Obj) = (Rsp [5]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  ((Wrd34.pObj) [3]) = (Wrd32.Obj);
  ((Wrd34.pObj) [4]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Rsp [3]) = (Wrd37.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_29;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd19.Lng))))
    goto label_29;
  (Wrd13.Obj) = ((Wrd17.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_102_12);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  goto loop_11;

DEFLABEL (label_29)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_102_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_2]), 2);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (loop_24)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_102_10);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_102_0])))
    goto label_30;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [2]);
  (Rsp [1]) = (Wrd29.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_30)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_32;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_31)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd21.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_16])));
  Rhp += 2;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd21.pObj)));
  Wrd24 = Wrd21;
  (Wrd25.Obj) = (Rsp [2]);
  ((Wrd24.pObj) [2]) = (Wrd25.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  ((Wrd24.pObj) [3]) = (Wrd23.Obj);
  (Rsp [3]) = (Wrd20.Obj);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [3]);
  (Rsp [2]) = (Wrd26.Obj);
  goto fc_15;

DEFLABEL (label_32)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_15]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_3]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_102_16);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_34;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_33)
  (Rsp [1]) = (Wrd8.Obj);
  goto loop_11;

DEFLABEL (label_34)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_4]), 1);

DEFLABEL (label_20)
  (Wrd8.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define LABEL_103_5 5
#define LABEL_103_9 7
#define LABEL_103_10 9
#define LABEL_103_6 11
#define LABEL_103_12 13
#define LABEL_103_8 15
#define LABEL_103_17 17
#define LABEL_103_14 19
#define LABEL_103_21 21
#define LABEL_103_15 23
#define LABEL_103_16 25
#define LABEL_103_23 27
#define LABEL_103_19 29
#define LABEL_103_27 31
#define LABEL_103_20 33
#define LABEL_103_28 35
#define LABEL_103_24 37
#define LABEL_103_25 39
#define LABEL_103_26 41
#define LABEL_103_31 43
#define LABEL_103_29 45
#define LABEL_103_32 47
#define LABEL_103_33 49
#define TAG_103_34 23
#define LABEL_103_40 51
#define LABEL_103_36 53
#define LABEL_103_42 55
#define LABEL_103_37 57
#define TAG_103_38 27
#define LABEL_103_44 59
#define LABEL_103_39 61
#define LABEL_103_45 63
#define LABEL_103_47 65
#define LABEL_103_43 67
#define LABEL_103_48 69
#define LABEL_103_50 71
#define LABEL_103_46 73
#define LABEL_103_49 75
#define ENVIRONMENT_LABEL_103_3 112
#define DEBUGGING_LABEL_103_2 111
#define OBJECT_103_9 110
#define OBJECT_103_8 109
#define OBJECT_103_7 108
#define OBJECT_103_6 107
#define OBJECT_103_5 106
#define OBJECT_103_4 105
#define OBJECT_103_3 104
#define OBJECT_103_2 103
#define OBJECT_103_1 102
#define OBJECT_103_0 101
#define EXECUTE_CACHE_103_41 77
#define EXECUTE_CACHE_103_35 79
#define EXECUTE_CACHE_103_30 81
#define EXECUTE_CACHE_103_22 83
#define EXECUTE_CACHE_103_18 85
#define EXECUTE_CACHE_103_13 87
#define EXECUTE_CACHE_103_11 89
#define EXECUTE_CACHE_103_7 91
#define FREE_REFERENCE_103_6 94
#define FREE_REFERENCE_103_5 95
#define FREE_REFERENCE_103_4 96
#define FREE_REFERENCE_103_3 97
#define FREE_REFERENCE_103_2 98
#define FREE_REFERENCE_103_1 99
#define FREE_REFERENCE_103_0 100
#define FREE_REFERENCES_LABEL_103_0 76
#define NUMBER_OF_LINKER_SECTIONS_103_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd52;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd18;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd6;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto collapse_nodelistB_31;

    case 1:
      current_block = (Rpc - LABEL_103_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_103_9);
      goto label_33;

    case 3:
      current_block = (Rpc - LABEL_103_10);
      goto label_34;

    case 4:
      current_block = (Rpc - LABEL_103_6);
      goto lambda_2;

    case 5:
      current_block = (Rpc - LABEL_103_12);
      goto label_35;

    case 6:
      current_block = (Rpc - LABEL_103_8);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_103_17);
      goto label_36;

    case 8:
      current_block = (Rpc - LABEL_103_14);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_103_21);
      goto label_37;

    case 10:
      current_block = (Rpc - LABEL_103_15);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_103_16);
      goto continuation_7;

    case 12:
      current_block = (Rpc - LABEL_103_23);
      goto label_38;

    case 13:
      current_block = (Rpc - LABEL_103_19);
      goto continuation_6;

    case 14:
      current_block = (Rpc - LABEL_103_27);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_103_20);
      goto continuation_5;

    case 16:
      current_block = (Rpc - LABEL_103_28);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_103_24);
      goto continuation_12;

    case 18:
      current_block = (Rpc - LABEL_103_25);
      goto continuation_11;

    case 19:
      current_block = (Rpc - LABEL_103_26);
      goto continuation_10;

    case 20:
      current_block = (Rpc - LABEL_103_31);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_103_29);
      goto continuation_13;

    case 22:
      current_block = (Rpc - LABEL_103_32);
      goto continuation_20;

    case 23:
      current_block = (Rpc - LABEL_103_33);
      goto lambda_52;

    case 24:
      current_block = (Rpc - LABEL_103_40);
      goto label_42;

    case 25:
      current_block = (Rpc - LABEL_103_36);
      goto continuation_27;

    case 26:
      current_block = (Rpc - LABEL_103_42);
      goto label_43;

    case 27:
      current_block = (Rpc - LABEL_103_37);
      goto lambda_53;

    case 28:
      current_block = (Rpc - LABEL_103_44);
      goto label_44;

    case 29:
      current_block = (Rpc - LABEL_103_39);
      goto continuation_15;

    case 30:
      current_block = (Rpc - LABEL_103_45);
      goto label_46;

    case 31:
      current_block = (Rpc - LABEL_103_47);
      goto label_45;

    case 32:
      current_block = (Rpc - LABEL_103_43);
      goto continuation_22;

    case 33:
      current_block = (Rpc - LABEL_103_48);
      goto label_48;

    case 34:
      current_block = (Rpc - LABEL_103_50);
      goto label_47;

    case 35:
      current_block = (Rpc - LABEL_103_46);
      goto continuation_18;

    case 36:
      current_block = (Rpc - LABEL_103_49);
      goto continuation_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (collapse_nodelistB_50)
DEFLABEL (collapse_nodelistB_31)
  INTERRUPT_CHECK (26, LABEL_103_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_103_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_71;
  Wrd9 = Wrd13;

DEFLABEL (label_70)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_69;
  Wrd15 = Wrd19;

DEFLABEL (label_68)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_103_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_16]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_2]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_67;
  Wrd16 = Wrd20;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_18]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_103_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_65;
  Wrd5 = Wrd9;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_5]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_103_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_22]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_103_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_20]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_63;
  Wrd12 = Wrd16;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_103_20);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_61;
  Wrd5 = Wrd9;

DEFLABEL (label_60)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_5]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_103_19);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_25]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_26]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_5]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_59;
  Wrd16 = Wrd20;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_18]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_103_26);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_57;
  Wrd5 = Wrd9;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_5]), 2);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_103_25);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_22]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_103_24);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_29]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_103_6]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_30]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_103_29);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_34);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_33])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  ((Wrd10.pObj) [2]) = Rvl;
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_35]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_103_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_37])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_35]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_103_36);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_6]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_55;
  Wrd6 = Wrd10;

DEFLABEL (label_54)
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_7]));

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_42])), (Wrd7.pObj));

DEFLABEL (label_43)
  (Wrd6.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_31])), (Wrd6.pObj));

DEFLABEL (label_41)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_27])), (Wrd17.pObj));

DEFLABEL (label_39)
  (Wrd16.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_28])), (Wrd6.pObj));

DEFLABEL (label_40)
  (Wrd5.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_21])), (Wrd13.pObj));

DEFLABEL (label_37)
  (Wrd12.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_23])), (Wrd6.pObj));

DEFLABEL (label_38)
  (Wrd5.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_17])), (Wrd17.pObj));

DEFLABEL (label_36)
  (Wrd16.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_10])), (Wrd16.pObj));

DEFLABEL (label_34)
  (Wrd15.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_9])), (Wrd10.pObj));

DEFLABEL (label_33)
  (Wrd9.Obj) = Rvl;
  goto label_70;

DEFLABEL (lambda_51)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_103_6);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_74;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_74;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_73)
  if ((Wrd5.Obj) == (current_block [OBJECT_103_2]))
    goto label_72;
  Rvl = (current_block [OBJECT_103_4]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_72)
  (Wrd24.Obj) = (current_block [OBJECT_103_3]);
  (Rsp [0]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_13]));

DEFLABEL (label_74)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_103_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_12]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_35)
  (Wrd5.Obj) = Rvl;
  goto label_73;

DEFLABEL (lambda_52)
  CLOSURE_HEADER (LABEL_103_33);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_82;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_82;
  (Wrd13.Obj) = ((Wrd19.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_81)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_41]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_103_39);
  (Wrd5.Obj) = Rvl;
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 62))
    goto label_80;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd40.Lng))))
    goto label_80;
  ((Wrd38.pObj) [4]) = Rvl;

DEFLABEL (label_79)
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_46]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 62))
    goto label_78;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_78;
  (Wrd15.Obj) = ((Wrd19.pObj) [5]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_77)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_41]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_103_46);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_103_9]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_76;

DEFLABEL (label_75)
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_8]), 3);

DEFLABEL (label_76)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_75;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_103_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_78)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_103_9]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_47]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_45)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [2]);
  (Wrd48.Obj) = (current_block [OBJECT_103_7]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_45]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_8]), 3);

DEFLABEL (label_46)
  goto label_79;

DEFLABEL (label_82)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Wrd29.Obj) = (current_block [OBJECT_103_7]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_40]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (lambda_53)
  CLOSURE_HEADER (LABEL_103_37);

DEFLABEL (lambda_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_90;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd19.Lng))))
    goto label_90;
  (Wrd13.Obj) = ((Wrd17.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_89)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_41]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_103_43);
  (Wrd5.Obj) = Rvl;
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 62))
    goto label_88;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd44.Lng))))
    goto label_88;
  ((Wrd42.pObj) [4]) = Rvl;

DEFLABEL (label_87)
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_49]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd29.uLng) == 62))
    goto label_86;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd25.Lng))))
    goto label_86;
  (Wrd17.Obj) = ((Wrd23.pObj) [5]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_85)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_41]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_103_49);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_103_9]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_84;

DEFLABEL (label_83)
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_8]), 3);

DEFLABEL (label_84)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_83;
  ((Wrd15.pObj) [5]) = Rvl;
  Rvl = (current_block [OBJECT_103_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_86)
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [2]);
  (Wrd33.Obj) = (current_block [OBJECT_103_9]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_50]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_47)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd47.Obj) = (Rsp [1]);
  (Wrd48.Obj) = (current_block [OBJECT_103_7]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_48]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_8]), 3);

DEFLABEL (label_48)
  goto label_87;

DEFLABEL (label_90)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_103_7]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_44]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_44)
  (* (--Rsp)) = Rvl;
  goto label_89;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define LABEL_104_6 5
#define LABEL_104_7 7
#define LABEL_104_5 9
#define LABEL_104_9 11
#define LABEL_104_10 13
#define LABEL_104_12 15
#define LABEL_104_13 17
#define TAG_104_14 7
#define LABEL_104_16 19
#define LABEL_104_20 21
#define LABEL_104_17 23
#define LABEL_104_21 25
#define LABEL_104_18 27
#define LABEL_104_22 29
#define ENVIRONMENT_LABEL_104_3 53
#define DEBUGGING_LABEL_104_2 52
#define OBJECT_104_5 51
#define OBJECT_104_4 50
#define OBJECT_104_3 49
#define OBJECT_104_2 48
#define OBJECT_104_1 47
#define OBJECT_104_0 46
#define EXECUTE_CACHE_104_23 31
#define EXECUTE_CACHE_104_19 33
#define EXECUTE_CACHE_104_15 35
#define EXECUTE_CACHE_104_11 37
#define EXECUTE_CACHE_104_8 39
#define FREE_REFERENCE_104_3 42
#define FREE_REFERENCE_104_2 43
#define FREE_REFERENCE_104_1 44
#define FREE_REFERENCE_104_0 45
#define FREE_REFERENCES_LABEL_104_0 30
#define NUMBER_OF_LINKER_SECTIONS_104_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto label_node_depthB_9;

    case 1:
      current_block = (Rpc - LABEL_104_6);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_104_7);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_104_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_104_9);
      goto label_nodesB_8;

    case 5:
      current_block = (Rpc - LABEL_104_10);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_104_12);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_104_13);
      goto lambda_19;

    case 8:
      current_block = (Rpc - LABEL_104_16);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_104_20);
      goto label_13;

    case 10:
      current_block = (Rpc - LABEL_104_17);
      goto continuation_5;

    case 11:
      current_block = (Rpc - LABEL_104_21);
      goto label_14;

    case 12:
      current_block = (Rpc - LABEL_104_18);
      goto continuation_4;

    case 13:
      current_block = (Rpc - LABEL_104_22);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (label_node_depthB_17)
DEFLABEL (label_node_depthB_9)
  INTERRUPT_CHECK (26, LABEL_104_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_23;
  Wrd9 = Wrd13;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_21;
  Wrd15 = Wrd19;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_104_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_104_0]);
  (Rsp [1]) = (Wrd5.Obj);
  goto label_nodesB_8;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_7])), (Wrd16.pObj));

DEFLABEL (label_12)
  (Wrd15.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_6])), (Wrd10.pObj));

DEFLABEL (label_11)
  (Wrd9.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_nodesB_18)
DEFLABEL (label_nodesB_8)
  INTERRUPT_CHECK (26, LABEL_104_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_104_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  Rvl = (current_block [OBJECT_104_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_12]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_104_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_104_13])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd16.Obj) = (Rsp [3]);
  ((Wrd15.pObj) [2]) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_104_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_19]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_104_18);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_3]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_30;
  Wrd5 = Wrd9;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_23]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_104_17);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_28;
  Wrd5 = Wrd9;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_104_5]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_104_16);
  (Rsp [0]) = Rvl;
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_26;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_26;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_25)
  (Rsp [1]) = (Wrd10.Obj);
  goto label_nodesB_8;

DEFLABEL (label_26)
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_21])), (Wrd6.pObj));

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_22])), (Wrd6.pObj));

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_29;

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_104_13);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_104_2]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd22.uLng) == 62)
    goto label_32;

DEFLABEL (label_31)
  INVOKE_PRIMITIVE ((current_block [OBJECT_104_4]), 3);

DEFLABEL (label_32)
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd20.Lng))))
    goto label_31;
  ((Wrd18.pObj) [6]) = (Wrd6.Obj);
  Rvl = (current_block [OBJECT_104_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_4 3
#define LABEL_105_5 5
#define LABEL_105_8 7
#define LABEL_105_9 9
#define LABEL_105_7 11
#define LABEL_105_12 13
#define LABEL_105_13 15
#define LABEL_105_11 17
#define LABEL_105_15 19
#define LABEL_105_16 21
#define LABEL_105_14 23
#define LABEL_105_17 25
#define LABEL_105_19 27
#define LABEL_105_21 29
#define LABEL_105_23 31
#define LABEL_105_24 33
#define LABEL_105_25 35
#define LABEL_105_26 37
#define LABEL_105_27 39
#define LABEL_105_28 41
#define LABEL_105_29 43
#define LABEL_105_31 45
#define LABEL_105_32 47
#define LABEL_105_34 49
#define LABEL_105_33 51
#define LABEL_105_37 53
#define LABEL_105_30 55
#define LABEL_105_39 57
#define LABEL_105_20 59
#define LABEL_105_36 61
#define LABEL_105_38 63
#define LABEL_105_41 65
#define LABEL_105_40 67
#define LABEL_105_43 69
#define LABEL_105_42 71
#define ENVIRONMENT_LABEL_105_3 100
#define DEBUGGING_LABEL_105_2 99
#define OBJECT_105_9 98
#define OBJECT_105_8 97
#define OBJECT_105_7 96
#define OBJECT_105_6 95
#define OBJECT_105_5 94
#define OBJECT_105_4 93
#define OBJECT_105_3 92
#define OBJECT_105_2 91
#define OBJECT_105_1 90
#define OBJECT_105_0 89
#define EXECUTE_CACHE_105_44 73
#define EXECUTE_CACHE_105_35 75
#define EXECUTE_CACHE_105_22 77
#define EXECUTE_CACHE_105_18 79
#define EXECUTE_CACHE_105_10 81
#define EXECUTE_CACHE_105_6 83
#define FREE_REFERENCE_105_2 86
#define FREE_REFERENCE_105_1 87
#define FREE_REFERENCE_105_0 88
#define FREE_REFERENCES_LABEL_105_0 72
#define NUMBER_OF_LINKER_SECTIONS_105_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd93;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd86;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd135;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd122;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd107;
  machine_word Wrd109;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd61;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd59;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd143;
  machine_word Wrd140;
  machine_word Wrd149;
  machine_word Wrd146;
  machine_word Wrd148;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_4);
      goto collapse_parallel_nodelist_38;

    case 1:
      current_block = (Rpc - LABEL_105_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_105_8);
      goto label_40;

    case 3:
      current_block = (Rpc - LABEL_105_9);
      goto label_41;

    case 4:
      current_block = (Rpc - LABEL_105_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_105_12);
      goto label_42;

    case 6:
      current_block = (Rpc - LABEL_105_13);
      goto label_43;

    case 7:
      current_block = (Rpc - LABEL_105_11);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_105_15);
      goto label_44;

    case 9:
      current_block = (Rpc - LABEL_105_16);
      goto label_45;

    case 10:
      current_block = (Rpc - LABEL_105_14);
      goto continuation_2;

    case 11:
      current_block = (Rpc - LABEL_105_17);
      goto continuation_1;

    case 12:
      current_block = (Rpc - LABEL_105_19);
      goto loop_36;

    case 13:
      current_block = (Rpc - LABEL_105_21);
      goto label_56;

    case 14:
      current_block = (Rpc - LABEL_105_23);
      goto label_46;

    case 15:
      current_block = (Rpc - LABEL_105_24);
      goto label_47;

    case 16:
      current_block = (Rpc - LABEL_105_25);
      goto label_48;

    case 17:
      current_block = (Rpc - LABEL_105_26);
      goto label_49;

    case 18:
      current_block = (Rpc - LABEL_105_27);
      goto label_50;

    case 19:
      current_block = (Rpc - LABEL_105_28);
      goto label_51;

    case 20:
      current_block = (Rpc - LABEL_105_29);
      goto label_54;

    case 21:
      current_block = (Rpc - LABEL_105_31);
      goto label_55;

    case 22:
      current_block = (Rpc - LABEL_105_32);
      goto label_52;

    case 23:
      current_block = (Rpc - LABEL_105_34);
      goto label_53;

    case 24:
      current_block = (Rpc - LABEL_105_33);
      goto continuation_16;

    case 25:
      current_block = (Rpc - LABEL_105_37);
      goto label_57;

    case 26:
      current_block = (Rpc - LABEL_105_30);
      goto continuation_21;

    case 27:
      current_block = (Rpc - LABEL_105_39);
      goto label_58;

    case 28:
      current_block = (Rpc - LABEL_105_20);
      goto continuation_26;

    case 29:
      current_block = (Rpc - LABEL_105_36);
      goto continuation_18;

    case 30:
      current_block = (Rpc - LABEL_105_38);
      goto continuation_23;

    case 31:
      current_block = (Rpc - LABEL_105_41);
      goto continuation_29;

    case 32:
      current_block = (Rpc - LABEL_105_40);
      goto continuation_27;

    case 33:
      current_block = (Rpc - LABEL_105_43);
      goto continuation_33;

    case 34:
      current_block = (Rpc - LABEL_105_42);
      goto continuation_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (collapse_parallel_nodelist_60)
DEFLABEL (collapse_parallel_nodelist_38)
  INTERRUPT_CHECK (26, LABEL_105_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_105_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  Rvl = (current_block [OBJECT_105_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_62)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_74;
  Wrd12 = Wrd16;

DEFLABEL (label_73)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_1]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_72;
  Wrd18 = Wrd22;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_105_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_70;
  Wrd8 = Wrd12;

DEFLABEL (label_69)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_2]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_68;
  Wrd14 = Wrd18;

DEFLABEL (label_67)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_105_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_66;
  Wrd8 = Wrd12;

DEFLABEL (label_65)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_105_2]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_64;
  Wrd14 = Wrd18;

DEFLABEL (label_63)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_105_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_18]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_105_17);
  (* (--Rsp)) = Rvl;
  goto loop_36;

DEFLABEL (label_64)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_16])), (Wrd15.pObj));

DEFLABEL (label_45)
  (Wrd14.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_15])), (Wrd9.pObj));

DEFLABEL (label_44)
  (Wrd8.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_13])), (Wrd15.pObj));

DEFLABEL (label_43)
  (Wrd14.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_12])), (Wrd9.pObj));

DEFLABEL (label_42)
  (Wrd8.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_9])), (Wrd19.pObj));

DEFLABEL (label_41)
  (Wrd18.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105_8])), (Wrd13.pObj));

DEFLABEL (label_40)
  (Wrd12.Obj) = Rvl;
  goto label_73;

DEFLABEL (loop_61)
DEFLABEL (loop_36)
  INTERRUPT_CHECK (26, LABEL_105_19);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_105_0]))
    goto label_97;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_96;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_95)
  (Wrd20.Obj) = (Rsp [5]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_94;
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  (Wrd22.Lng) = ((Wrd24.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd22.Lng)))
    goto label_94;
  (Wrd25.Obj) = (LONG_TO_FIXNUM (Wrd22.Lng));
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_93)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_92;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd34.Lng))))
    goto label_92;
  (Wrd26.Obj) = ((Wrd32.pObj) [6]);

DEFLABEL (label_91)
  (Wrd42.Obj) = (* (Rsp++));
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd43.uLng) == 26))
    goto label_90;
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd44.uLng) == 26))
    goto label_90;
  if ((Wrd26.Obj) == (Wrd42.Obj))
    goto label_78;

DEFLABEL (label_77)
  (Wrd54.Obj) = (Rsp [1]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_76;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd53.pObj) [1]);

DEFLABEL (label_75)
  (Rsp [1]) = (Wrd51.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_36;

DEFLABEL (label_76)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_27]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_4]), 1);

DEFLABEL (label_50)
  (Wrd51.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 62))
    goto label_89;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd69.Lng))))
    goto label_89;
  (Wrd61.Obj) = ((Wrd67.pObj) [2]);

DEFLABEL (label_88)
  if ((Wrd61.Obj) == (current_block [OBJECT_105_6]))
    goto label_84;
  (Wrd81.Obj) = (Rsp [1]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 1))
    goto label_83;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd78.Obj) = ((Wrd80.pObj) [1]);

DEFLABEL (label_82)
  (Rsp [1]) = (Wrd78.Obj);
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_33]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (Wrd90.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd100.Obj) = (Rsp [2]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 62))
    goto label_80;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [0]);
  (Wrd99.Lng) = (FIXNUM_TO_LONG (Wrd98.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd99.Lng))))
    goto label_80;
  (Wrd93.Obj) = ((Wrd97.pObj) [3]);
  (* (--Rsp)) = (Wrd93.Obj);

DEFLABEL (label_79)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_35]));

DEFLABEL (label_80)
  (Wrd102.Obj) = (Rsp [2]);
  (Wrd103.Obj) = (current_block [OBJECT_105_7]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_34]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_53)
DEFLABEL (label_81)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (label_83)
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_32]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_4]), 1);

DEFLABEL (label_52)
  (Wrd78.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_84)
  (Wrd110.Obj) = (Rsp [1]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 1))
    goto label_87;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd107.Obj) = ((Wrd109.pObj) [1]);

DEFLABEL (label_86)
  (Rsp [1]) = (Wrd107.Obj);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_30]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (Wrd119.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd119.Obj);
  (Wrd129.Obj) = (Rsp [2]);
  (Wrd130.uLng) = (OBJECT_TYPE (Wrd129.Obj));
  if (! ((Wrd130.uLng) == 62))
    goto label_85;
  (Wrd126.pObj) = (OBJECT_ADDRESS (Wrd129.Obj));
  (Wrd127.Obj) = ((Wrd126.pObj) [0]);
  (Wrd128.Lng) = (FIXNUM_TO_LONG (Wrd127.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd128.Lng))))
    goto label_85;
  (Wrd122.Obj) = ((Wrd126.pObj) [3]);
  (* (--Rsp)) = (Wrd122.Obj);
  goto label_79;

DEFLABEL (label_85)
  (Wrd131.Obj) = (Rsp [2]);
  (Wrd132.Obj) = (current_block [OBJECT_105_7]);
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_31]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd131.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_55)
  goto label_81;

DEFLABEL (label_87)
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_29]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd110.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_4]), 1);

DEFLABEL (label_54)
  (Wrd107.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd73.Obj) = (current_block [OBJECT_105_5]);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_28]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_51)
  (Wrd61.Obj) = Rvl;
  goto label_88;

DEFLABEL (label_90)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_26]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_49)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_77;
  goto label_78;

DEFLABEL (label_92)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (current_block [OBJECT_105_2]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_25]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_48)
  (Wrd26.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_94)
  (Wrd16.Obj) = (Rsp [5]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_24]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_47)
  (* (--Rsp)) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_23]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_1]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_97)
  (Wrd138.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_20]))));
  (* (--Rsp)) = (Wrd138.Obj);
  (Wrd139.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd139.Obj);
  (Wrd144.Obj) = (Rsp [6]);
  (Wrd145.uLng) = (OBJECT_TYPE (Wrd144.Obj));
  if (! ((Wrd145.uLng) == 26))
    goto label_103;
  (Wrd148.Lng) = (FIXNUM_TO_LONG (Wrd144.Obj));
  (Wrd146.Lng) = ((Wrd148.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd146.Lng)))
    goto label_103;
  (Wrd149.Obj) = (LONG_TO_FIXNUM (Wrd146.Lng));
  (* (--Rsp)) = (Wrd149.Obj);

DEFLABEL (label_102)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_22]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_105_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_6]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_105_40);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_101;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_41]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_18]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_105_41);
  (Wrd20.Obj) = (current_block [OBJECT_105_9]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd23.Obj) = (current_block [OBJECT_105_0]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));

DEFLABEL (label_100)
  (Rsp [4]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_42]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_6]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_105_42);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_99;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_43]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_18]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_105_43);
  (Wrd18.Obj) = (current_block [OBJECT_105_6]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd17.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_105_0]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));

DEFLABEL (label_98)
  (Rsp [5]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Rsp [6]) = (Wrd8.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_44]));

DEFLABEL (label_99)
  (Wrd7.Obj) = (current_block [OBJECT_105_0]);
  goto label_98;

DEFLABEL (label_101)
  (Wrd7.Obj) = (current_block [OBJECT_105_0]);
  goto label_100;

DEFLABEL (label_103)
  (Wrd140.Obj) = (Rsp [6]);
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_21]))));
  (* (--Rsp)) = (Wrd143.Obj);
  (* (--Rsp)) = (Wrd140.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_102;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_105_33);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_36]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_105;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_105;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_104)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_35]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_105_36);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto loop_36;

DEFLABEL (label_105)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_105_8]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_37]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_57)
  (* (--Rsp)) = Rvl;
  goto label_104;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_105_30);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_38]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_107;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_107;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_106)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_35]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_105_38);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto loop_36;

DEFLABEL (label_107)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_105_8]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_39]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_106;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define LABEL_106_5 5
#define ENVIRONMENT_LABEL_106_3 13
#define DEBUGGING_LABEL_106_2 12
#define OBJECT_106_2 11
#define OBJECT_106_1 10
#define OBJECT_106_0 9
#define EXECUTE_CACHE_106_6 7
#define FREE_REFERENCES_LABEL_106_0 6
#define NUMBER_OF_LINKER_SECTIONS_106_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto linearize_1;

    case 1:
      current_block = (Rpc - LABEL_106_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (linearize_5)
DEFLABEL (linearize_1)
  INTERRUPT_CHECK (26, LABEL_106_4);
  (Wrd5.Obj) = (current_block [OBJECT_106_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_7;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd14.Lng))))
    goto label_7;
  (Wrd6.Obj) = ((Wrd12.pObj) [4]);

DEFLABEL (label_6)
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_6]));

DEFLABEL (label_7)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_106_1]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_5]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_2]), 2);

DEFLABEL (label_3)
  (Wrd6.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define LABEL_107_5 5
#define LABEL_107_6 7
#define LABEL_107_9 9
#define LABEL_107_10 11
#define LABEL_107_11 13
#define LABEL_107_12 15
#define LABEL_107_13 17
#define LABEL_107_14 19
#define TAG_107_15 8
#define LABEL_107_18 21
#define LABEL_107_23 23
#define LABEL_107_27 25
#define LABEL_107_17 27
#define LABEL_107_30 29
#define LABEL_107_33 31
#define LABEL_107_20 33
#define LABEL_107_21 35
#define LABEL_107_24 37
#define LABEL_107_36 39
#define LABEL_107_25 41
#define LABEL_107_37 43
#define LABEL_107_26 45
#define LABEL_107_28 47
#define LABEL_107_31 49
#define LABEL_107_32 51
#define ENVIRONMENT_LABEL_107_3 89
#define DEBUGGING_LABEL_107_2 88
#define OBJECT_107_7 87
#define OBJECT_107_6 86
#define OBJECT_107_5 85
#define OBJECT_107_4 84
#define OBJECT_107_3 83
#define OBJECT_107_2 82
#define OBJECT_107_1 81
#define OBJECT_107_0 80
#define EXECUTE_CACHE_107_41 53
#define EXECUTE_CACHE_107_40 55
#define EXECUTE_CACHE_107_39 57
#define EXECUTE_CACHE_107_38 59
#define EXECUTE_CACHE_107_35 61
#define EXECUTE_CACHE_107_34 63
#define EXECUTE_CACHE_107_29 65
#define EXECUTE_CACHE_107_22 67
#define EXECUTE_CACHE_107_19 69
#define EXECUTE_CACHE_107_16 71
#define EXECUTE_CACHE_107_8 73
#define EXECUTE_CACHE_107_7 75
#define FREE_REFERENCE_107_1 78
#define FREE_REFERENCE_107_0 79
#define FREE_REFERENCES_LABEL_107_0 52
#define NUMBER_OF_LINKER_SECTIONS_107_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
subst_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto build_new_code_32;

    case 1:
      current_block = (Rpc - LABEL_107_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_107_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_107_9);
      goto loop_29;

    case 4:
      current_block = (Rpc - LABEL_107_10);
      goto label_34;

    case 5:
      current_block = (Rpc - LABEL_107_11);
      goto label_35;

    case 6:
      current_block = (Rpc - LABEL_107_12);
      goto label_36;

    case 7:
      current_block = (Rpc - LABEL_107_13);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_107_14);
      goto lambda_45;

    case 9:
      current_block = (Rpc - LABEL_107_18);
      goto continuation_12;

    case 10:
      current_block = (Rpc - LABEL_107_23);
      goto label_37;

    case 11:
      current_block = (Rpc - LABEL_107_27);
      goto label_38;

    case 12:
      current_block = (Rpc - LABEL_107_17);
      goto continuation_21;

    case 13:
      current_block = (Rpc - LABEL_107_30);
      goto label_39;

    case 14:
      current_block = (Rpc - LABEL_107_33);
      goto label_40;

    case 15:
      current_block = (Rpc - LABEL_107_20);
      goto lambda_8;

    case 16:
      current_block = (Rpc - LABEL_107_21);
      goto lambda_7;

    case 17:
      current_block = (Rpc - LABEL_107_24);
      goto continuation_19;

    case 18:
      current_block = (Rpc - LABEL_107_36);
      goto continuation_14;

    case 19:
      current_block = (Rpc - LABEL_107_25);
      goto continuation_18;

    case 20:
      current_block = (Rpc - LABEL_107_37);
      goto label_41;

    case 21:
      current_block = (Rpc - LABEL_107_26);
      goto continuation_16;

    case 22:
      current_block = (Rpc - LABEL_107_28);
      goto continuation_15;

    case 23:
      current_block = (Rpc - LABEL_107_31);
      goto continuation_24;

    case 24:
      current_block = (Rpc - LABEL_107_32);
      goto continuation_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (build_new_code_43)
DEFLABEL (build_new_code_32)
  INTERRUPT_CHECK (26, LABEL_107_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_107_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_107_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_29;

DEFLABEL (loop_44)
DEFLABEL (loop_29)
  INTERRUPT_CHECK (26, LABEL_107_9);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_107_0])))
    goto label_48;
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [8]));
  goto pop_return;

DEFLABEL (label_48)
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_57;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_56)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_55;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_54)
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_53;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_52)
  (Rsp [1]) = (Wrd25.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_13]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd39.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_107_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_107_14])));
  Rhp += 1;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd39.pObj)));
  Wrd40 = Wrd39;
  (Wrd41.Obj) = (Rsp [10]);
  ((Wrd40.pObj) [2]) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_107_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_107_3]))
    goto label_50;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_49;

DEFLABEL (label_50)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_17]))));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_49)
DEFLABEL (label_51)
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_107_4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_19]));

DEFLABEL (label_53)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_12]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_2]), 1);

DEFLABEL (label_36)
  (Wrd25.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_11]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_1]), 1);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_10]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_1]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_107_18);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_65;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_64)
  (Rsp [4]) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_24]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_107_4]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_25]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd25.Obj) = (Rsp [9]);
  (Wrd26.Obj) = (current_block [OBJECT_107_0]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_26]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_107_0]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_63;
  Wrd30 = Wrd34;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_28]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_29]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_107_28);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_40]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_107_26);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_39]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_107_25);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_36]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [14]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_61;
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_60;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_60;
  (Wrd14.Obj) = ((Wrd20.pObj) [2]);

DEFLABEL (label_59)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_58)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_38]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_107_24);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto loop_29;

DEFLABEL (label_60)
  (Wrd25.Obj) = (Rsp [14]);
  (Wrd26.Obj) = (current_block [OBJECT_107_6]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_37]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_7]), 2);

DEFLABEL (label_41)
  (Wrd14.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_61)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_58;

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107_27])), (Wrd31.pObj));

DEFLABEL (label_38)
  (Wrd30.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_23]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_2]), 1);

DEFLABEL (label_37)
  (Wrd5.Obj) = Rvl;
  goto label_64;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_107_17);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_69;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_68)
  (Rsp [4]) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_31]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_32]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd24.Obj) = (current_block [OBJECT_107_0]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_107_1]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_67;
  Wrd26 = Wrd30;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_34]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_107_32);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_41]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_107_31);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto loop_29;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107_33])), (Wrd27.pObj));

DEFLABEL (label_40)
  (Wrd26.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_107_2]), 1);

DEFLABEL (label_39)
  (Wrd5.Obj) = Rvl;
  goto label_68;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_107_36);
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_107_14);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_20]))));
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107_21]))));
  (Rsp [2]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_22]));

DEFLABEL (lambda_46)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_107_20);
  (Wrd5.Obj) = (current_block [OBJECT_107_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_35]));

DEFLABEL (lambda_47)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_107_21);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_11 7
#define LABEL_7 9
#define LABEL_9 11
#define LABEL_10 13
#define LABEL_13 15
#define LABEL_15 17
#define LABEL_16 19
#define LABEL_17 21
#define LABEL_18 23
#define LABEL_19 25
#define LABEL_20 27
#define LABEL_21 29
#define LABEL_22 31
#define LABEL_23 33
#define LABEL_24 35
#define LABEL_25 37
#define LABEL_26 39
#define LABEL_27 41
#define LABEL_28 43
#define LABEL_29 45
#define LABEL_30 47
#define LABEL_31 49
#define LABEL_32 51
#define LABEL_33 53
#define LABEL_34 55
#define LABEL_35 57
#define LABEL_38 59
#define LABEL_36 61
#define LABEL_37 63
#define LABEL_40 65
#define LABEL_41 67
#define LABEL_46 69
#define LABEL_42 71
#define LABEL_44 73
#define LABEL_45 75
#define LABEL_48 77
#define LABEL_53 79
#define LABEL_49 81
#define TAG_50 39
#define LABEL_55 83
#define LABEL_51 85
#define LABEL_52 87
#define LABEL_54 89
#define LABEL_60 91
#define LABEL_57 93
#define TAG_58 45
#define LABEL_61 95
#define LABEL_59 97
#define LABEL_62 99
#define LABEL_63 101
#define LABEL_64 103
#define ENVIRONMENT_LABEL_3 201
#define DEBUGGING_LABEL_2 200
#define PURIFICATION_ROOT 199
#define OBJECT_72 198
#define OBJECT_71 197
#define OBJECT_70 196
#define OBJECT_69 195
#define OBJECT_68 194
#define OBJECT_67 193
#define OBJECT_66 192
#define OBJECT_65 191
#define OBJECT_64 190
#define OBJECT_63 189
#define OBJECT_62 188
#define OBJECT_61 187
#define OBJECT_60 186
#define OBJECT_59 185
#define OBJECT_58 184
#define OBJECT_57 183
#define OBJECT_56 182
#define OBJECT_55 181
#define OBJECT_54 180
#define OBJECT_53 179
#define OBJECT_52 178
#define OBJECT_51 177
#define OBJECT_50 176
#define OBJECT_49 175
#define OBJECT_48 174
#define OBJECT_47 173
#define OBJECT_46 172
#define OBJECT_45 171
#define OBJECT_44 170
#define OBJECT_43 169
#define OBJECT_42 168
#define OBJECT_41 167
#define OBJECT_40 166
#define OBJECT_39 165
#define OBJECT_38 164
#define OBJECT_37 163
#define OBJECT_36 162
#define OBJECT_35 161
#define OBJECT_34 160
#define OBJECT_33 159
#define OBJECT_32 158
#define OBJECT_31 157
#define OBJECT_30 156
#define OBJECT_29 155
#define OBJECT_28 154
#define OBJECT_27 153
#define OBJECT_26 152
#define OBJECT_25 151
#define OBJECT_24 150
#define OBJECT_23 149
#define OBJECT_22 148
#define OBJECT_21 147
#define OBJECT_20 146
#define OBJECT_19 145
#define OBJECT_18 144
#define OBJECT_17 143
#define OBJECT_16 142
#define OBJECT_15 141
#define OBJECT_14 140
#define OBJECT_13 139
#define OBJECT_12 138
#define OBJECT_11 137
#define OBJECT_10 136
#define OBJECT_9 135
#define OBJECT_8 134
#define OBJECT_7 133
#define OBJECT_6 132
#define OBJECT_5 131
#define OBJECT_4 130
#define OBJECT_3 129
#define OBJECT_2 128
#define OBJECT_1 127
#define OBJECT_0 126
#define EXECUTE_CACHE_39 105
#define EXECUTE_CACHE_14 107
#define EXECUTE_CACHE_12 109
#define EXECUTE_CACHE_8 111
#define FREE_REFERENCE_2 114
#define FREE_REFERENCE_1 115
#define FREE_REFERENCE_0 116
#define GLOBAL_EXECUTE_CACHE_56 118
#define GLOBAL_EXECUTE_CACHE_47 120
#define GLOBAL_EXECUTE_CACHE_43 122
#define GLOBAL_EXECUTE_CACHE_5 124
#define FREE_REFERENCES_LABEL_0 104
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
subst_so_bc41d8446aafe0f2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_11);
      goto label_54;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_15);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_16);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_17);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_18);
      goto continuation_9;

    case 11:
      current_block = (Rpc - LABEL_19);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_20);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_21);
      goto continuation_12;

    case 14:
      current_block = (Rpc - LABEL_22);
      goto continuation_13;

    case 15:
      current_block = (Rpc - LABEL_23);
      goto continuation_14;

    case 16:
      current_block = (Rpc - LABEL_24);
      goto continuation_15;

    case 17:
      current_block = (Rpc - LABEL_25);
      goto continuation_16;

    case 18:
      current_block = (Rpc - LABEL_26);
      goto continuation_17;

    case 19:
      current_block = (Rpc - LABEL_27);
      goto continuation_18;

    case 20:
      current_block = (Rpc - LABEL_28);
      goto continuation_19;

    case 21:
      current_block = (Rpc - LABEL_29);
      goto continuation_20;

    case 22:
      current_block = (Rpc - LABEL_30);
      goto continuation_21;

    case 23:
      current_block = (Rpc - LABEL_31);
      goto continuation_22;

    case 24:
      current_block = (Rpc - LABEL_32);
      goto continuation_23;

    case 25:
      current_block = (Rpc - LABEL_33);
      goto continuation_24;

    case 26:
      current_block = (Rpc - LABEL_34);
      goto continuation_25;

    case 27:
      current_block = (Rpc - LABEL_35);
      goto continuation_26;

    case 28:
      current_block = (Rpc - LABEL_38);
      goto label_55;

    case 29:
      current_block = (Rpc - LABEL_36);
      goto continuation_28;

    case 30:
      current_block = (Rpc - LABEL_37);
      goto continuation_27;

    case 31:
      current_block = (Rpc - LABEL_40);
      goto continuation_29;

    case 32:
      current_block = (Rpc - LABEL_41);
      goto continuation_36;

    case 33:
      current_block = (Rpc - LABEL_46);
      goto label_56;

    case 34:
      current_block = (Rpc - LABEL_42);
      goto continuation_35;

    case 35:
      current_block = (Rpc - LABEL_44);
      goto continuation_43;

    case 36:
      current_block = (Rpc - LABEL_45);
      goto continuation_37;

    case 37:
      current_block = (Rpc - LABEL_48);
      goto continuation_44;

    case 38:
      current_block = (Rpc - LABEL_53);
      goto label_57;

    case 39:
      current_block = (Rpc - LABEL_49);
      goto Z__make_node_62;

    case 40:
      current_block = (Rpc - LABEL_55);
      goto label_58;

    case 41:
      current_block = (Rpc - LABEL_51);
      goto continuation_51;

    case 42:
      current_block = (Rpc - LABEL_52);
      goto continuation_45;

    case 43:
      current_block = (Rpc - LABEL_54);
      goto continuation_40;

    case 44:
      current_block = (Rpc - LABEL_60);
      goto label_59;

    case 45:
      current_block = (Rpc - LABEL_57);
      goto nodeP_63;

    case 46:
      current_block = (Rpc - LABEL_61);
      goto label_60;

    case 47:
      current_block = (Rpc - LABEL_59);
      goto continuation_39;

    case 48:
      current_block = (Rpc - LABEL_62);
      goto label_65;

    case 49:
      current_block = (Rpc - LABEL_63);
      goto label_66;

    case 50:
      current_block = (Rpc - LABEL_64);
      goto expression_53;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_53)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_63])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_66)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_65)
  {
    static const short sections [] =
      {
	0,
	2,
	1,
	2,
	2,
	2,
	1,
	1,
	2,
	2,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	2,
	2,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	2,
	2,
	0,
	0,
	2,
	2,
	1,
	2,
	2,
	2,
	2,
	2,
	2,
	1,
	2,
	1,
	2,
	2,
	1,
	1,
	1,
	1,
	0,
	2,
	2,
	0,
	0,
	2,
	1,
	1,
	1,
	1,
	2,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	0,
	0,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	3,
	1,
	1,
	3,
	1,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	3,
	1,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 107)
      goto label_64;
    blocks = (current_block [OBJECT_72]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_62])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_64)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_74;
  Wrd11 = Wrd15;

DEFLABEL (label_73)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_72;
  Wrd12 = Wrd16;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_37);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (current_block [OBJECT_52]);
  (Wrd16.Obj) = (current_block [OBJECT_53]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_54]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd24.Obj) = (current_block [OBJECT_55]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Wrd28.Obj) = (current_block [OBJECT_56]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Wrd32.Obj) = (current_block [OBJECT_57]);
  (* (Rhp++)) = (Wrd32.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_43]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_42);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_70;
  Wrd11 = Wrd15;

DEFLABEL (label_69)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_47]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_45);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_50);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_49])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_63]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_68;
  Wrd11 = Wrd15;

DEFLABEL (label_67)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_47]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_52);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_58);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_51);
  (Wrd5.Obj) = (current_block [OBJECT_65]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_66]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_53])), (Wrd12.pObj));

DEFLABEL (label_57)
  (Wrd11.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46])), (Wrd12.pObj));

DEFLABEL (label_56)
  (Wrd11.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38])), (Wrd13.pObj));

DEFLABEL (label_55)
  (Wrd12.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd12.pObj));

DEFLABEL (label_54)
  (Wrd11.Obj) = Rvl;
  goto label_73;

DEFLABEL (Z__make_node_62)
  CLOSURE_HEADER (LABEL_49);

DEFLABEL (Z__make_node_41)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_78;
  Wrd9 = Wrd13;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_56]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_54);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_68]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_76;
  Wrd9 = Wrd13;

DEFLABEL (label_75)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_56]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_59);
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd9.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd9.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_76)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd10.pObj));

DEFLABEL (label_59)
  (Wrd9.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55])), (Wrd10.pObj));

DEFLABEL (label_58)
  (Wrd9.Obj) = Rvl;
  goto label_77;

DEFLABEL (nodeP_63)
  CLOSURE_HEADER (LABEL_57);

DEFLABEL (nodeP_49)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_81;

DEFLABEL (label_80)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_79)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_81)
  if (! ((Wrd6.uLng) == 62))
    goto label_83;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_83;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_82)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_80;
  Rvl = (current_block [OBJECT_71]);
  goto label_79;

DEFLABEL (label_83)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_69]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70]), 2);

DEFLABEL (label_60)
  (Wrd9.Obj) = Rvl;
  goto label_82;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_subst_so_bc41d8446aafe0f2 [107] =
  {
    { "subst_so_code_1", 2, subst_so_code_1 },
    { "subst_so_code_2", 2, subst_so_code_2 },
    { "subst_so_code_3", 25, subst_so_code_3 },
    { "subst_so_code_4", 2, subst_so_code_4 },
    { "subst_so_code_5", 5, subst_so_code_5 },
    { "subst_so_code_6", 13, subst_so_code_6 },
    { "subst_so_code_7", 12, subst_so_code_7 },
    { "subst_so_code_8", 16, subst_so_code_8 },
    { "subst_so_code_9", 3, subst_so_code_9 },
    { "subst_so_code_10", 16, subst_so_code_10 },
    { "subst_so_code_11", 14, subst_so_code_11 },
    { "subst_so_code_12", 24, subst_so_code_12 },
    { "subst_so_code_13", 3, subst_so_code_13 },
    { "subst_so_code_14", 50, subst_so_code_14 },
    { "subst_so_code_15", 4, subst_so_code_15 },
    { "subst_so_code_16", 2, subst_so_code_16 },
    { "subst_so_code_17", 52, subst_so_code_17 },
    { "subst_so_code_18", 7, subst_so_code_18 },
    { "subst_so_code_19", 5, subst_so_code_19 },
    { "subst_so_code_20", 20, subst_so_code_20 },
    { "subst_so_code_21", 2, subst_so_code_21 },
    { "subst_so_code_22", 5, subst_so_code_22 },
    { "subst_so_code_23", 34, subst_so_code_23 },
    { "subst_so_code_24", 4, subst_so_code_24 },
    { "subst_so_code_25", 3, subst_so_code_25 },
    { "subst_so_code_26", 15, subst_so_code_26 },
    { "subst_so_code_27", 4, subst_so_code_27 },
    { "subst_so_code_28", 2, subst_so_code_28 },
    { "subst_so_code_29", 2, subst_so_code_29 },
    { "subst_so_code_30", 6, subst_so_code_30 },
    { "subst_so_code_31", 1, subst_so_code_31 },
    { "subst_so_code_32", 1, subst_so_code_32 },
    { "subst_so_code_33", 1, subst_so_code_33 },
    { "subst_so_code_34", 31, subst_so_code_34 },
    { "subst_so_code_35", 8, subst_so_code_35 },
    { "subst_so_code_36", 3, subst_so_code_36 },
    { "subst_so_code_37", 12, subst_so_code_37 },
    { "subst_so_code_38", 5, subst_so_code_38 },
    { "subst_so_code_39", 7, subst_so_code_39 },
    { "subst_so_code_40", 7, subst_so_code_40 },
    { "subst_so_code_41", 11, subst_so_code_41 },
    { "subst_so_code_42", 3, subst_so_code_42 },
    { "subst_so_code_43", 4, subst_so_code_43 },
    { "subst_so_code_44", 6, subst_so_code_44 },
    { "subst_so_code_45", 17, subst_so_code_45 },
    { "subst_so_code_46", 10, subst_so_code_46 },
    { "subst_so_code_47", 11, subst_so_code_47 },
    { "subst_so_code_48", 9, subst_so_code_48 },
    { "subst_so_code_49", 13, subst_so_code_49 },
    { "subst_so_code_50", 19, subst_so_code_50 },
    { "subst_so_code_51", 38, subst_so_code_51 },
    { "subst_so_code_52", 1, subst_so_code_52 },
    { "subst_so_code_53", 1, subst_so_code_53 },
    { "subst_so_code_54", 2, subst_so_code_54 },
    { "subst_so_code_55", 5, subst_so_code_55 },
    { "subst_so_code_56", 2, subst_so_code_56 },
    { "subst_so_code_57", 12, subst_so_code_57 },
    { "subst_so_code_58", 1, subst_so_code_58 },
    { "subst_so_code_59", 4, subst_so_code_59 },
    { "subst_so_code_60", 2, subst_so_code_60 },
    { "subst_so_code_61", 6, subst_so_code_61 },
    { "subst_so_code_62", 59, subst_so_code_62 },
    { "subst_so_code_63", 17, subst_so_code_63 },
    { "subst_so_code_64", 19, subst_so_code_64 },
    { "subst_so_code_65", 9, subst_so_code_65 },
    { "subst_so_code_66", 3, subst_so_code_66 },
    { "subst_so_code_67", 3, subst_so_code_67 },
    { "subst_so_code_68", 3, subst_so_code_68 },
    { "subst_so_code_69", 3, subst_so_code_69 },
    { "subst_so_code_70", 3, subst_so_code_70 },
    { "subst_so_code_71", 3, subst_so_code_71 },
    { "subst_so_code_72", 6, subst_so_code_72 },
    { "subst_so_code_73", 11, subst_so_code_73 },
    { "subst_so_code_74", 7, subst_so_code_74 },
    { "subst_so_code_75", 1, subst_so_code_75 },
    { "subst_so_code_76", 1, subst_so_code_76 },
    { "subst_so_code_77", 3, subst_so_code_77 },
    { "subst_so_code_78", 3, subst_so_code_78 },
    { "subst_so_code_79", 1, subst_so_code_79 },
    { "subst_so_code_80", 1, subst_so_code_80 },
    { "subst_so_code_81", 1, subst_so_code_81 },
    { "subst_so_code_82", 1, subst_so_code_82 },
    { "subst_so_code_83", 1, subst_so_code_83 },
    { "subst_so_code_84", 1, subst_so_code_84 },
    { "subst_so_code_85", 1, subst_so_code_85 },
    { "subst_so_code_86", 1, subst_so_code_86 },
    { "subst_so_code_87", 1, subst_so_code_87 },
    { "subst_so_code_88", 1, subst_so_code_88 },
    { "subst_so_code_89", 4, subst_so_code_89 },
    { "subst_so_code_90", 4, subst_so_code_90 },
    { "subst_so_code_91", 1, subst_so_code_91 },
    { "subst_so_code_92", 3, subst_so_code_92 },
    { "subst_so_code_93", 3, subst_so_code_93 },
    { "subst_so_code_94", 3, subst_so_code_94 },
    { "subst_so_code_95", 3, subst_so_code_95 },
    { "subst_so_code_96", 8, subst_so_code_96 },
    { "subst_so_code_97", 6, subst_so_code_97 },
    { "subst_so_code_98", 11, subst_so_code_98 },
    { "subst_so_code_99", 2, subst_so_code_99 },
    { "subst_so_code_100", 28, subst_so_code_100 },
    { "subst_so_code_101", 5, subst_so_code_101 },
    { "subst_so_code_102", 10, subst_so_code_102 },
    { "subst_so_code_103", 37, subst_so_code_103 },
    { "subst_so_code_104", 14, subst_so_code_104 },
    { "subst_so_code_105", 35, subst_so_code_105 },
    { "subst_so_code_106", 2, subst_so_code_106 },
    { "subst_so_code_107", 25, subst_so_code_107 }
  };

int
decl_subst_so_bc41d8446aafe0f2 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_subst_so_bc41d8446aafe0f2);
  return (0);
}

DECLARE_COMPILED_CODE ("subst.so", 51, decl_subst_so_bc41d8446aafe0f2, subst_so_bc41d8446aafe0f2)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_subst_so_data_bc41d8446aafe0f2 [17570] =
  "\xef\x01\xca\x01\x9d\x25\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9"
  "\x24\x22\x29\x22\x29\x21\x17\x2b\xba\x1d\xb0\x82\x88\xc2\xbb\x81"
  "\x28\x0d\xbc\x23\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x83\x88"
  "\x86\xb3\x84\x1d\x08\xb1\x0d\xbe\x25\xb1\xb6\x24\x28\x0d\xbf\x28"
  "\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x85\x88\x82\xb3\x80\x0d\x1c\x24\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x81\x84\x0c\x0d\x1c\x0d"
  "\x1c\x82\x0c\x0d\x1c\x0d\xb3\x83\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\x89"
  "\x0c\x1b\x1b\x1b\x1b\xb3\x83\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x0d"
  "\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x81\xb3\x83\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\x81\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x81\xb3\x83\x07\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b"
  "\x1b\x1b\x08\x8b\x0c\x82\x1b\x1b\x1b\x1b\xb3\x83\x1b\x24\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d\x81\x07\x85\x86\x84\x83\xb3"
  "\x82\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\xc1\x1c\x0c\x0d\x0d\x0d\x0d\x0d\x07"
  "\x0d\xc1\x1c\x08\x0d\x1c\x0d\x1c\x1b\x25\x1b\x1b\x1b\x24\x28\xb7"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x07\x28\x0d\x1c\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x81\x08"
  "\x02\x1d\x83\x82\x84\x85\xb3\x86\xb6\x25\xb6\x1b\x0d\x1c\x0d\x1c"
  "\x24\x28\xb7\x28\x1b\x28\x0d\xbf\x28\xb7\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x83\x1b"
  "\x07\x08\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x83\xb3"
  "\x84\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\xc2\x1c\xb3\x82\x28"
  "\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x1b\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1b\xb3\x82\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x84\x83\x1b\x1b\xb3\x82"
  "\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x84"
  "\x81\xb3\x82\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x82\xb3\x81\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x81\x82\x83\x86"
  "\x85\xb3\x84\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\xc3\x1c\x1d\xb3\x82\x28\x0d\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x81\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x81\x82\xb3\x83\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0"
  "\x02\x88\x02\x81\x1b\x1b\x82\x83\xb3\x84\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x81\x82\xb3\x83\x28\x1b\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x82\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb3\x83\x08\x1b\x1b\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb3\x81\x1b\x08\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x08"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x82\x28\x1b"
  "\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x81\x82\xb3\x83\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xb3\x82\x28\x1b\x28\x0d\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x81\xb3\x82\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x81\x82\xb3\x83\x28\xb4\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x81\x1b\x1b"
  "\x0d\xb3\x83\x1b\x0d\x0d\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d"
  "\x82\x0d\x1c\x1b\x24\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x1b\xb3\x83\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\xb3\x82\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x86\x1b\x1b\x85\x08\xb3\x84\x0d\x1c\x24\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x84\xc2\x1c\x1b\x83\xb3\x82\x1b\x0d\x08\x28\x0d\x28\x0d"
  "\x28\xb7\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0c\x0d\x0d\x0d\x83\x86\x81\x1b"
  "\x1b\x0c\x85\x08\xb3\x84\x0d\x24\x28\x1b\x28\xb7\x28\x0d\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x07\x0d\x1c\xb3\x81\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\x1b\x82\x83\x0d\xb3\x84\x1b\x81"
  "\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x07\x08\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x82"
  "\x0c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\xb3\x82\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x08\x02\x86\x85\x84\x83\x1b\x81\xb3\x82\x1b\x0d\x1c\x0d"
  "\x0d\x1b\x24\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\xb7\x28\x1b\x28"
  "\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x0c\x08\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x0d\x28\x1b\x28\xb7\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x83\xb3\x81\x07\x1b\x1b\x1b\x24\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x0c\x08\x28\x0d\x1c"
  "\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x0d\x1c\x24\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b"
  "\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08\x1b\x1b\x24"
  "\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08\x1b\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x1d\x81"
  "\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x83\x22\x29\x21"
  "\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x84\x22\x29\x21\x9f\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x1d\x85\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x1c\x1b\x1b\x24\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x1b\x1b"
  "\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x1b\x23\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1d\x1b\x83\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x1b\x83\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1d\x1b\x84\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x1b\x84\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x24\x28"
  "\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1d\x84\x1b\x1b\x83\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1d\x0d\x1c\x81\x84\x1b\x83\x28\x0d\x1c\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\x0c\x84\x1b\x1b\x83\x0c\x0c\x0c\x1b\x1b\x1b\x24\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x83\x08\x28\x1b\x28\xb7"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x84\x1b\x83\x1b\x1b\x1d\x0c\x1b\x1b\x81\x1b\x1b\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1d\x85\x08\x80\x1b"
  "\x1b\x1b\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x1c\x83\x82\x1b\x81\x1b\x1b\x85\x1b\x08\x1b\x1b"
  "\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\xb7\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83"
  "\x80\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb3\x81\x0c\x07\x1b\x1b\x1b\x08\x1b\x0d\x24\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\xb7\x28"
  "\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x07\x1b"
  "\x80\x83\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x0d\x1b\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x84\x1b"
  "\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x0d\x17\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x0d\x1c\x0c"
  "\x0d\x0d\x0d\x0d\x0d\x08\x8c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x08"
  "\x1b\x2a\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x06\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x17\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x08\x14\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x1b\x1b\x1b"
  "\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x0c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x0d\x1b\x2a\x1b"
  "\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x1b\x1b\x9b\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x9b\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d"
  "\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x0d\x1b\x2a\x1b\x1b\x1b\x9a\x1b"
  "\x2a\x1b\x2a\x06\x9a\x0d\x1b\x2a\x1b\x1b\x99\x1b\x2a\x1b\x2a\x99"
  "\x0d\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x9c\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x9c\x0d\x1b\x2a\x1b\x0d\x1c\x0d\x1b\x2a\xc3\x1b\x1b"
  "\x1b\xb4\x0d\xb6\x0d\xb1\x9e\x1b\x2a\x1b\x2a\x1b\x2a\xb5\x2a\x1e"
  "\xb2\x2a\x1e\x9e\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x0d\x1b"
  "\x24\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x02\x41\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31"
  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
  "\x30\x2e\x31\x2f\x73\x72\x63\x2f\x73\x66\x2f\x73\x75\x62\x73\x74"
  "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
  "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x12\x2a\x74\x6f\x70\x2d"
  "\x6c\x65\x76\x65\x6c\x2d\x62\x6c\x6f\x63\x6b\x2a\x02\x35\x06\x81"
  "\x81\x02\x34\x04\x82\x02\x05\x0a\x02\x0b\x76\x65\x63\x74\x6f\x72"
  "\x2d\x72\x65\x66\x05\x15\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f"
  "\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2a\x02\x37\x06\x81\x85\x02"
  "\x36\x04\x84\x06\x05\x0d\x02\x02\x16\x2a\x63\x75\x72\x72\x65\x6e"
  "\x74\x2d\x62\x6c\x6f\x63\x6b\x2d\x6e\x61\x6d\x65\x73\x2a\x03\x03"
  "\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d"
  "\x62\x69\x6e\x64\x02\x11\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2f\x6d\x61\x6b\x65\x09\x02\x10\x6f\x70\x65\x72\x61\x74\x69"
  "\x6f\x6e\x73\x2f\x6d\x61\x6b\x65\x05\x0f\x71\x75\x6f\x74\x61\x74"
  "\x69\x6f\x6e\x2f\x6d\x61\x6b\x65\x03\x0c\x6f\x70\x65\x6e\x2d\x62"
  "\x6c\x6f\x63\x6b\x3f\x0a\x04\x12\x64\x65\x63\x6c\x61\x72\x61\x74"
  "\x69\x6f\x6e\x73\x2f\x62\x69\x6e\x64\x0b\x05\x15\x69\x6e\x74\x65"
  "\x67\x72\x61\x74\x65\x2f\x6f\x70\x65\x6e\x2d\x62\x6c\x6f\x63\x6b"
  "\x0c\x04\x14\x70\x72\x6f\x63\x65\x73\x73\x2d\x62\x6c\x6f\x63\x6b"
  "\x2d\x66\x6c\x61\x67\x73\x0d\x05\x15\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x65\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x0e\x0a\x50"
  "\x34\x81\x85\x02\x4f\x32\x81\x87\x02\x4e\x30\x81\x83\x02\x4d\x2e"
  "\x81\x87\x02\x4c\x2c\x81\x85\x02\x4b\x2a\x81\x85\x02\x4a\x28\x81"
  "\x87\x02\x49\x26\x81\x85\x02\x48\x24\x81\x89\x02\x47\x22\x81\x87"
  "\x02\x46\x20\x81\x89\x02\x45\x1e\x81\x85\x02\x44\x1c\x81\x83\x02"
  "\x43\x1a\x81\x87\x02\x42\x18\x81\x85\x02\x41\x16\x81\x87\x02\x40"
  "\x14\x81\x85\x02\x3f\x12\x81\x83\x02\x3e\x10\x81\x87\x02\x3d\x0e"
  "\x81\x85\x02\x3c\x0c\x81\x87\x02\x3b\x0a\x81\x85\x02\x3a\x08\x81"
  "\x83\x02\x39\x06\x81\x83\x02\x38\x04\x85\x08\x33\x54\x0f\x02\x04"
  "\x04\x6d\x61\x70\x10\x05\x0e\x03\x52\x06\x81\x85\x02\x51\x04\x85"
  "\x08\x05\x0d\x11\x02\x10\x64\x69\x73\x70\x61\x74\x63\x68\x2d\x76"
  "\x65\x63\x74\x6f\x72\x12\x02\x57\x0c\x81\x87\x02\x56\x0a\x81\x89"
  "\x02\x55\x08\x81\x87\x02\x54\x06\x81\x87\x02\x53\x04\x85\x08\x0b"
  "\x13\x13\x02\x12\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x6f\x70\x65\x72"
  "\x61\x74\x69\x6f\x6e\x07\x65\x78\x70\x61\x6e\x64\x14\x13\x69\x6e"
  "\x74\x65\x67\x72\x61\x74\x65\x2d\x6f\x70\x65\x72\x61\x74\x6f\x72"
  "\x15\x22\x41\x74\x74\x65\x6d\x70\x74\x20\x74\x6f\x20\x61\x73\x73"
  "\x69\x67\x6e\x20\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x64\x20\x6e"
  "\x61\x6d\x65\x0a\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x16\x05\x64"
  "\x6f\x6e\x65\x06\x12\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\x2f"
  "\x6c\x6f\x6f\x6b\x75\x70\x17\x03\x14\x76\x61\x72\x69\x61\x62\x6c"
  "\x65\x2f\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x21\x18\x04\x05\x77"
  "\x61\x72\x6e\x19\x04\x06\x65\x72\x72\x6f\x72\x1a\x05\x0e\x06\x10"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2f\x6d\x61\x6b\x65\x07"
  "\x64\x1c\x81\x8b\x02\x63\x1a\x81\x8b\x02\x62\x18\x81\x89\x02\x61"
  "\x16\x81\x8b\x02\x60\x14\x81\x89\x02\x5f\x12\x81\x87\x02\x5e\x10"
  "\x81\x87\x02\x5d\x0e\x81\x87\x02\x5c\x0c\x81\x87\x02\x5b\x0a\x82"
  "\x02\x5a\x08\x81\x89\x02\x59\x06\x81\x87\x02\x58\x04\x85\x08\x1b"
  "\x36\x1b\x02\x08\x16\x11\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2d"
  "\x73\x61\x66\x65\x6c\x79\x1c\x12\x55\x6e\x6b\x6e\x6f\x77\x6e\x20"
  "\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x1c\x16\x14\x15\x1a\x2a\x65"
  "\x61\x67\x65\x72\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e"
  "\x2d\x73\x77\x69\x74\x63\x68\x1d\x02\x06\x17\x03\x18\x08\x0f\x69"
  "\x6e\x74\x65\x67\x72\x61\x74\x65\x2f\x6e\x61\x6d\x65\x1e\x04\x1a"
  "\x03\x15\x76\x61\x72\x69\x61\x62\x6c\x65\x2f\x69\x6e\x74\x65\x67"
  "\x72\x61\x74\x65\x64\x21\x1f\x09\x17\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x65\x2f\x6e\x61\x6d\x65\x2d\x69\x66\x2d\x73\x61\x66\x65\x20"
  "\x07\x70\x1a\x81\x83\x02\x6f\x18\x81\x85\x02\x6e\x16\x81\x87\x02"
  "\x6d\x14\x81\x87\x02\x6c\x12\x81\x83\x02\x6b\x10\x81\x83\x02\x6a"
  "\x0e\x81\x85\x02\x69\x0c\x81\x83\x02\x68\x0a\x81\x83\x02\x67\x08"
  "\x81\x87\x02\x66\x06\x81\x87\x02\x65\x04\x85\x08\x19\x33\x21\x02"
  "\x09\x03\x17\x76\x61\x72\x69\x61\x62\x6c\x65\x2f\x73\x69\x64\x65"
  "\x2d\x65\x66\x66\x65\x63\x74\x65\x64\x22\x07\x13\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x6c\x6f\x6f\x6b\x75\x70\x23\x06"
  "\x19\x73\x61\x66\x65\x6c\x79\x2d\x69\x6e\x74\x65\x67\x72\x61\x62"
  "\x6c\x65\x2d\x76\x61\x6c\x75\x65\x3f\x24\x03\x15\x64\x65\x6c\x61"
  "\x79\x65\x64\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x3f"
  "\x25\x04\x17\x63\x6f\x70\x79\x2f\x65\x78\x70\x72\x65\x73\x73\x69"
  "\x6f\x6e\x2f\x69\x6e\x74\x65\x72\x6e\x26\x03\x21\x64\x65\x6c\x61"
  "\x79\x65\x64\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x2f"
  "\x69\x6e\x2d\x70\x72\x6f\x67\x72\x65\x73\x73\x3f\x27\x04\x09\x72"
  "\x65\x61\x73\x73\x69\x67\x6e\x28\x03\x1a\x64\x65\x6c\x61\x79\x65"
  "\x64\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x2f\x66\x6f"
  "\x72\x63\x65\x29\x09\x80\x01\x22\x81\x85\x02\x7f\x20\x81\x85\x02"
  "\x7e\x1e\x81\x87\x02\x7d\x1c\x81\x85\x02\x7c\x1a\x81\x85\x02\x7b"
  "\x18\x81\x8b\x02\x7a\x16\x81\x85\x02\x79\x14\x81\x83\x02\x78\x12"
  "\x81\x83\x02\x77\x10\x81\x85\x02\x76\x0e\x81\x85\x02\x75\x0c\x81"
  "\x91\x02\x74\x0a\x81\x91\x02\x73\x08\x81\x91\x02\x72\x06\x81\x8f"
  "\x02\x71\x04\x89\x10\x21\x39\x2a\x02\x0a\x04\x0f\x77\x69\x74\x68"
  "\x2d\x6e\x65\x77\x2d\x73\x63\x6f\x64\x65\x02\x83\x01\x08\x81\x85"
  "\x02\x82\x01\x06\x81\x85\x02\x81\x01\x04\x84\x06\x07\x0f\x2b\x02"
  "\x0b\x03\x0a\x63\x6f\x6e\x73\x74\x61\x6e\x74\x3f\x2c\x03\x0b\x72"
  "\x65\x66\x65\x72\x65\x6e\x63\x65\x3f\x2d\x06\x17\x03\x22\x04\x05"
  "\x6d\x65\x6d\x71\x22\x07\x23\x07\x93\x01\x22\x82\x02\x92\x01\x20"
  "\x84\x06\x91\x01\x1e\x81\x85\x02\x90\x01\x1c\x82\x02\x8f\x01\x1a"
  "\x81\x83\x02\x8e\x01\x18\x81\x8b\x02\x8d\x01\x16\x81\x8b\x02\x8c"
  "\x01\x14\x81\x8b\x02\x8b\x01\x12\x81\x87\x02\x8a\x01\x10\x82\x02"
  "\x89\x01\x0e\x81\x89\x02\x88\x01\x0c\x81\x89\x02\x87\x01\x0a\x81"
  "\x89\x02\x86\x01\x08\x81\x87\x02\x85\x01\x06\x81\x87\x02\x84\x01"
  "\x04\x86\x0a\x21\x35\x2e\x02\x0c\x14\x16\x15\x1c\x12\x55\x6e\x6b"
  "\x6e\x6f\x77\x6e\x20\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x14\x1c"
  "\x15\x16\x1d\x02\x06\x17\x08\x1e\x04\x1a\x03\x1f\x03\x18\x09\x20"
  "\x06\x1c\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2f\x6f\x70"
  "\x74\x69\x6d\x69\x7a\x69\x6e\x67\x2d\x6d\x61\x6b\x65\x1f\x08\x16"
  "\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f\x63\x6f\x6d\x62\x69\x6e"
  "\x61\x74\x69\x6f\x6e\x1c\x05\x0e\x0a\xa1\x01\x1e\x81\x85\x02\xa0"
  "\x01\x1c\x81\x85\x02\x9f\x01\x1a\x81\x83\x02\x9e\x01\x18\x81\x85"
  "\x02\x9d\x01\x16\x81\x83\x02\x9c\x01\x14\x81\x85\x02\x9b\x01\x12"
  "\x81\x83\x02\x9a\x01\x10\x81\x83\x02\x99\x01\x0e\x81\x83\x02\x98"
  "\x01\x0c\x81\x83\x02\x97\x01\x0a\x81\x8d\x02\x96\x01\x08\x81\x87"
  "\x02\x95\x01\x06\x81\x8d\x02\x94\x01\x04\x88\x0e\x1d\x3e\x18\x02"
  "\x0d\x1f\x55\x6e\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x64\x20\x64"
  "\x65\x66\x69\x6e\x65\x64\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x3a"
  "\x02\x04\x12\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\x2f\x73\x68"
  "\x61\x64\x6f\x77\x16\x04\x0d\x04\x0b\x06\x1b\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x63\x75\x72\x73\x69\x76\x65"
  "\x2d\x62\x69\x6e\x64\x15\x05\x12\x69\x6e\x74\x65\x67\x72\x61\x74"
  "\x65\x2f\x61\x63\x74\x69\x6f\x6e\x73\x2f\x09\x1b\x6f\x70\x65\x6e"
  "\x2d\x62\x6c\x6f\x63\x6b\x2f\x6f\x70\x74\x69\x6d\x69\x7a\x69\x6e"
  "\x67\x2d\x6d\x61\x6b\x65\x30\x08\x10\x6f\x70\x65\x6e\x2d\x62\x6c"
  "\x6f\x63\x6b\x2f\x6d\x61\x6b\x65\x31\x04\x09\x66\x6f\x72\x2d\x65"
  "\x61\x63\x68\x32\x03\x17\x76\x61\x72\x69\x61\x62\x6c\x65\x2f\x75"
  "\x6e\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x64\x3f\x33\x04\x19\x0b"
  "\xb9\x01\x32\x81\x85\x02\xb8\x01\x30\x81\x83\x02\xb7\x01\x2e\x81"
  "\x85\x02\xb6\x01\x2c\x83\x04\xb5\x01\x2a\x81\x89\x02\xb4\x01\x28"
  "\x81\x97\x02\xb3\x01\x26\x81\x8b\x02\xb2\x01\x24\x81\x89\x02\xb1"
  "\x01\x22\x81\x89\x02\xb0\x01\x20\x81\x87\x02\xaf\x01\x1e\x81\x95"
  "\x02\xae\x01\x1c\x81\x89\x02\xad\x01\x1a\x81\x89\x02\xac\x01\x18"
  "\x81\x87\x02\xab\x01\x16\x81\x83\x02\xaa\x01\x14\x81\x85\x02\xa9"
  "\x01\x12\x81\x83\x02\xa8\x01\x10\x81\x8f\x02\xa7\x01\x0e\x81\x8d"
  "\x02\xa6\x01\x0c\x81\x8b\x02\xa5\x01\x0a\x81\x8d\x02\xa4\x01\x08"
  "\x81\x89\x02\xa3\x01\x06\x81\x87\x02\xa2\x01\x04\x85\x08\x31\x53"
  "\x34\x02\x0e\x05\x0c\x02\xbc\x01\x08\x85\x08\xbb\x01\x06\x81\x87"
  "\x02\xba\x01\x04\x85\x08\x07\x0d\x35\x02\x0f\x02\x04\x63\x64\x72"
  "\x36\x09\x42\x61\x64\x20\x66\x6c\x61\x67\x1c\x6e\x6f\x2d\x6f\x70"
  "\x65\x6e\x2d\x62\x6c\x6f\x63\x6b\x2d\x6f\x70\x74\x69\x6d\x69\x7a"
  "\x61\x74\x69\x6f\x6e\x73\x19\x6f\x70\x65\x6e\x2d\x62\x6c\x6f\x63"
  "\x6b\x2d\x6f\x70\x74\x69\x6d\x69\x7a\x61\x74\x69\x6f\x6e\x73\x14"
  "\x6e\x6f\x2d\x65\x74\x61\x2d\x73\x75\x62\x73\x74\x69\x74\x75\x74"
  "\x69\x6f\x6e\x11\x65\x74\x61\x2d\x73\x75\x62\x73\x74\x69\x74\x75"
  "\x74\x69\x6f\x6e\x1a\x6e\x6f\x2d\x61\x75\x74\x6f\x6d\x61\x67\x69"
  "\x63\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x73\x17\x61"
  "\x75\x74\x6f\x6d\x61\x67\x69\x63\x2d\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x69\x6f\x6e\x73\x04\x63\x61\x72\x37\x19\x2a\x62\x6c\x6f\x63"
  "\x6b\x2d\x6f\x70\x74\x69\x6d\x69\x7a\x69\x6e\x67\x2d\x73\x77\x69"
  "\x74\x63\x68\x38\x19\x2a\x65\x74\x61\x2d\x73\x75\x62\x73\x74\x69"
  "\x74\x75\x74\x69\x6f\x6e\x2d\x73\x77\x69\x74\x63\x68\x39\x1d\x04"
  "\x38\x39\x1d\x04\x05\x03\x1a\x04\x0d\x04\xee\x01\x66\x81\x87\x02"
  "\xed\x01\x64\x81\x85\x02\xec\x01\x62\x81\x83\x02\xeb\x01\x60\x81"
  "\x87\x02\xea\x01\x5e\x81\x85\x02\xe9\x01\x5c\x81\x83\x02\xe8\x01"
  "\x5a\x81\x83\x02\xe7\x01\x58\x81\x83\x02\xe6\x01\x56\x81\x87\x02"
  "\xe5\x01\x54\x81\x85\x02\xe4\x01\x52\x81\x83\x02\xe3\x01\x50\x81"
  "\x87\x02\xe2\x01\x4e\x81\x85\x02\xe1\x01\x4c\x81\x83\x02\xe0\x01"
  "\x4a\x81\x83\x02\xdf\x01\x48\x81\x83\x02\xde\x01\x46\x81\x87\x02"
  "\xdd\x01\x44\x81\x85\x02\xdc\x01\x42\x81\x83\x02\xdb\x01\x40\x81"
  "\x87\x02\xda\x01\x3e\x81\x85\x02\xd9\x01\x3c\x81\x83\x02\xd8\x01"
  "\x3a\x81\x83\x02\xd7\x01\x38\x81\x83\x02\xd6\x01\x36\x81\x87\x02"
  "\xd5\x01\x34\x81\x85\x02\xd4\x01\x32\x81\x83\x02\xd3\x01\x30\x81"
  "\x87\x02\xd2\x01\x2e\x81\x85\x02\xd1\x01\x2c\x81\x83\x02\xd0\x01"
  "\x2a\x81\x83\x02\xcf\x01\x28\x81\x83\x02\xce\x01\x26\x81\x87\x02"
  "\xcd\x01\x24\x81\x85\x02\xcc\x01\x22\x81\x83\x02\xcb\x01\x20\x81"
  "\x87\x02\xca\x01\x1e\x81\x85\x02\xc9\x01\x1c\x81\x83\x02\xc8\x01"
  "\x1a\x81\x83\x02\xc7\x01\x18\x81\x83\x02\xc6\x01\x16\x81\x87\x02"
  "\xc5\x01\x14\x81\x85\x02\xc4\x01\x12\x81\x83\x02\xc3\x01\x10\x81"
  "\x87\x02\xc2\x01\x0e\x81\x85\x02\xc1\x01\x0c\x81\x83\x02\xc0\x01"
  "\x0a\x81\x83\x02\xbf\x01\x08\x81\x83\x02\xbe\x01\x06\x81\x85\x02"
  "\xbd\x01\x04\x84\x06\x65\x83\x01\x3a\x02\x10\x03\x14\x76\x61\x72"
  "\x69\x61\x62\x6c\x65\x2f\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x64"
  "\x3b\x03\x14\x76\x61\x72\x69\x61\x62\x6c\x65\x2f\x72\x65\x66\x65"
  "\x72\x65\x6e\x63\x65\x64\x03\x15\x76\x61\x72\x69\x61\x62\x6c\x65"
  "\x2f\x63\x61\x6e\x2d\x69\x67\x6e\x6f\x72\x65\x3f\x04\xf2\x01\x0a"
  "\x81\x83\x02\xf1\x01\x08\x81\x83\x02\xf0\x01\x06\x81\x83\x02\xef"
  "\x01\x04\x83\x04\x09\x14\x3c\x02\x11\x04\x1d\x73\x69\x6d\x75\x6c"
  "\x61\x74\x65\x2d\x75\x6e\x6b\x6e\x6f\x77\x6e\x2d\x61\x70\x70\x6c"
  "\x69\x63\x61\x74\x69\x6f\x6e\x3d\x05\x14\x69\x6e\x74\x65\x67\x72"
  "\x61\x74\x65\x2f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x3e\x03\xf4"
  "\x01\x06\x81\x87\x02\xf3\x01\x04\x85\x08\x05\x0d\x3f\x02\x12\x1d"
  "\x55\x6e\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x64\x20\x62\x6f\x75"
  "\x6e\x64\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x3a\x08\x02\x02\x39"
  "\x04\x65\x71\x3f\x40\x0a\x76\x61\x72\x69\x61\x62\x6c\x65\x3f\x41"
  "\x05\x05\x04\x0d\x05\x07\x61\x70\x70\x65\x6e\x64\x04\x09\x0f\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2f\x6d\x61\x6b\x65\x42\x03\x0d"
  "\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3f\x43\x05\x0e\x04"
  "\x0b\x04\x16\x04\x0a\x6d\x61\x74\x63\x68\x2d\x75\x70\x3f\x16\x04"
  "\x32\x03\x10\x66\x72\x65\x65\x2f\x65\x78\x70\x72\x65\x73\x73\x69"
  "\x6f\x6e\x44\x03\x33\x03\x0b\x73\x65\x74\x2f\x65\x6d\x70\x74\x79"
  "\x3f\x45\x05\x0a\x6c\x69\x73\x74\x2d\x3e\x73\x65\x74\x46\x05\x19"
  "\x04\x11\x73\x65\x74\x2f\x69\x6e\x74\x65\x72\x73\x65\x63\x74\x69"
  "\x6f\x6e\x47\x12\xa8\x02\x6a\x81\x8b\x02\xa7\x02\x68\x81\x87\x02"
  "\xa6\x02\x66\x81\x83\x02\xa5\x02\x64\x81\x83\x02\xa4\x02\x62\x81"
  "\x91\x02\xa3\x02\x60\x81\x8f\x02\xa2\x02\x5e\x81\x89\x02\xa1\x02"
  "\x5c\x81\x87\x02\xa0\x02\x5a\x81\x8d\x02\x9f\x02\x58\x81\x89\x02"
  "\x9e\x02\x56\x81\x85\x02\x9d\x02\x54\x83\x04\x9c\x02\x52\x81\x8b"
  "\x02\x9b\x02\x50\x81\x8d\x02\x9a\x02\x4e\x81\x89\x02\x99\x02\x4c"
  "\x81\x85\x02\x98\x02\x4a\x81\x87\x02\x97\x02\x48\x81\x8d\x02\x96"
  "\x02\x46\x81\x89\x02\x95\x02\x44\x81\x8d\x02\x94\x02\x42\x81\x89"
  "\x02\x93\x02\x40\x81\x87\x02\x92\x02\x3e\x81\x8d\x02\x91\x02\x3c"
  "\x81\x89\x02\x90\x02\x3a\x81\x85\x02\x8f\x02\x38\x81\x8f\x02\x8e"
  "\x02\x36\x81\x8d\x02\x8d\x02\x34\x81\x89\x02\x8c\x02\x32\x81\x8d"
  "\x02\x8b\x02\x30\x81\x89\x02\x8a\x02\x2e\x81\x85\x02\x89\x02\x2c"
  "\x81\x85\x02\x88\x02\x2a\x81\x83\x02\x87\x02\x28\x81\x85\x02\x86"
  "\x02\x26\x81\x8b\x02\x85\x02\x24\x81\x85\x02\x84\x02\x22\x81\x83"
  "\x02\x83\x02\x20\x81\x87\x02\x82\x02\x1e\x81\x85\x02\x81\x02\x1c"
  "\x81\x83\x02\x80\x02\x1a\x81\x87\x02\xff\x01\x18\x81\x85\x02\xfe"
  "\x01\x16\x81\x83\x02\xfd\x01\x14\x81\x83\x02\xfc\x01\x12\x81\x83"
  "\x02\xfb\x01\x10\x81\x93\x02\xfa\x01\x0e\x81\x91\x02\xf9\x01\x0c"
  "\x81\x8d\x02\xf8\x01\x0a\x81\x8b\x02\xf7\x01\x08\x81\x89\x02\xf6"
  "\x01\x06\x81\x87\x02\xf5\x01\x04\x85\x08\x69\xa1\x01\x48\x02\x13"
  "\x36\x37\x03\x2d\x04\x16\x03\xaf\x02\x10\x81\x89\x02\xae\x02\x0e"
  "\x81\x89\x02\xad\x02\x0c\x81\x89\x02\xac\x02\x0a\x81\x89\x02\xab"
  "\x02\x08\x81\x87\x02\xaa\x02\x06\x81\x85\x02\xa9\x02\x04\x84\x06"
  "\x0f\x1d\x49\x02\x14\x05\x16\x69\x6e\x74\x65\x67\x72\x61\x74\x65"
  "\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x4a\x08\x1c\x03"
  "\xb4\x02\x0c\x81\x8f\x02\xb3\x02\x0a\x81\x8f\x02\xb2\x02\x08\x81"
  "\x8d\x02\xb1\x02\x06\x81\x8f\x02\xb0\x02\x04\x85\x08\x0b\x17\x4b"
  "\x02\x15\x36\x37\x06\x61\x70\x70\x6c\x79\x4c\x03\x2d\x03\x08\x61"
  "\x63\x63\x65\x73\x73\x3f\x4d\x08\x1d\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x65\x2f\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x6f\x70\x65"
  "\x72\x61\x74\x6f\x72\x4e\x08\x1a\x69\x6e\x74\x65\x67\x72\x61\x74"
  "\x65\x2f\x61\x63\x63\x65\x73\x73\x2d\x6f\x70\x65\x72\x61\x74\x6f"
  "\x72\x4f\x03\x2c\x05\x0e\x03\x24\x63\x6f\x6e\x73\x74\x61\x6e\x74"
  "\x2f\x73\x79\x73\x74\x65\x6d\x2d\x67\x6c\x6f\x62\x61\x6c\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x50\x03\x16\x69\x6e"
  "\x74\x65\x67\x72\x61\x74\x65\x2f\x68\x61\x63\x6b\x2d\x61\x70\x70"
  "\x6c\x79\x3f\x51\x08\x1d\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f"
  "\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x6f\x70\x65\x72\x61\x74"
  "\x6f\x72\x52\x08\x1c\x03\x0b\x70\x72\x6f\x63\x65\x64\x75\x72\x65"
  "\x3f\x53\x03\x15\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72"
  "\x6f\x63\x65\x64\x75\x72\x65\x3f\x54\x06\x1f\x04\x1c\x69\x6e\x74"
  "\x65\x67\x72\x61\x74\x65\x2f\x63\x6f\x6d\x70\x6f\x75\x6e\x64\x2d"
  "\x6f\x70\x65\x72\x61\x74\x6f\x72\x55\x07\x1d\x69\x6e\x74\x65\x67"
  "\x72\x61\x74\x65\x2f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x6f"
  "\x70\x65\x72\x61\x74\x6f\x72\x56\x10\xc8\x02\x2a\x81\x83\x02\xc7"
  "\x02\x28\x81\x85\x02\xc6\x02\x26\x81\x83\x02\xc5\x02\x24\x81\x81"
  "\x02\xc4\x02\x22\x81\x83\x02\xc3\x02\x20\x81\x8d\x02\xc2\x02\x1e"
  "\x81\x83\x02\xc1\x02\x1c\x81\x8f\x02\xc0\x02\x1a\x81\x8d\x02\xbf"
  "\x02\x18\x81\x8f\x02\xbe\x02\x16\x81\x8f\x02\xbd\x02\x14\x81\x8f"
  "\x02\xbc\x02\x12\x81\x8d\x02\xbb\x02\x10\x81\x8d\x02\xba\x02\x0e"
  "\x81\x8f\x02\xb9\x02\x0c\x81\x91\x02\xb8\x02\x0a\x81\x8d\x02\xb7"
  "\x02\x08\x81\x8d\x02\xb6\x02\x06\x81\x8d\x02\xb5\x02\x04\x88\x0e"
  "\x29\x50\x57\x02\x16\x06\x15\x73\x69\x6d\x75\x6c\x61\x74\x65\x2d"
  "\x61\x70\x70\x6c\x69\x63\x61\x74\x69\x6f\x6e\x58\x05\x3e\x03\xca"
  "\x02\x06\x81\x8b\x02\xc9\x02\x04\x87\x0c\x05\x0d\x59\x02\x17\x12"
  "\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x6f\x70\x65\x72\x61\x74\x69\x6f"
  "\x6e\x14\x06\x17\x06\x1f\x04\x1a\x05\x0e\x05\xcf\x02\x0c\x81\x85"
  "\x02\xce\x02\x0a\x81\x87\x02\xcd\x02\x08\x81\x83\x02\xcc\x02\x06"
  "\x81\x91\x02\xcb\x02\x04\x88\x0e\x0b\x1b\x17\x02\x18\x08\x37\x36"
  "\x14\x6e\x6f\x6e\x2d\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63\x74"
  "\x69\x6e\x67\x3f\x14\x02\x04\x09\x66\x6f\x72\x2d\x61\x6c\x6c\x3f"
  "\x5a\x04\x14\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x77\x69\x74"
  "\x68\x2d\x62\x6f\x64\x79\x5b\x03\x0a\x73\x65\x71\x75\x65\x6e\x63"
  "\x65\x3f\x5c\x03\x43\x03\x08\x72\x65\x76\x65\x72\x73\x65\x5d\x03"
  "\x0d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x3f\x03\x53\x04"
  "\x55\x04\x16\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x77\x69\x74\x68"
  "\x2d\x61\x63\x74\x69\x6f\x6e\x73\x5e\x03\x0a\x04\x1c\x64\x65\x63"
  "\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x77\x69\x74\x68\x2d\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x5f\x04\x1a\x63\x6f\x6d\x62\x69"
  "\x6e\x61\x74\x69\x6f\x6e\x2d\x77\x69\x74\x68\x2d\x6f\x70\x65\x72"
  "\x61\x74\x6f\x72\x60\x0d\xf1\x02\x46\x81\x8b\x02\xf0\x02\x44\x81"
  "\x89\x02\xef\x02\x42\x81\x89\x02\xee\x02\x40\x81\x89\x02\xed\x02"
  "\x3e\x81\x87\x02\xec\x02\x3c\x81\x87\x02\xeb\x02\x3a\x81\x85\x02"
  "\xea\x02\x38\x81\x85\x02\xe9\x02\x36\x81\x89\x02\xe8\x02\x34\x81"
  "\x87\x02\xe7\x02\x32\x81\x89\x02\xe6\x02\x30\x81\x87\x02\xe5\x02"
  "\x2e\x81\x87\x02\xe4\x02\x2c\x81\x85\x02\xe3\x02\x2a\x81\x8b\x02"
  "\xe2\x02\x28\x81\x89\x02\xe1\x02\x26\x81\x85\x02\xe0\x02\x24\x81"
  "\x85\x02\xdf\x02\x22\x81\x89\x02\xde\x02\x20\x81\x87\x02\xdd\x02"
  "\x1e\x81\x85\x02\xdc\x02\x1c\x81\x89\x02\xdb\x02\x1a\x81\x85\x02"
  "\xda\x02\x18\x81\x85\x02\xd9\x02\x16\x81\x87\x02\xd8\x02\x14\x81"
  "\x87\x02\xd7\x02\x12\x81\x85\x02\xd6\x02\x10\x81\x87\x02\xd5\x02"
  "\x0e\x81\x85\x02\xd4\x02\x0c\x81\x85\x02\xd3\x02\x0a\x83\x04\xd2"
  "\x02\x08\x81\x85\x02\xd1\x02\x06\x81\x87\x02\xd0\x02\x04\x84\x06"
  "\x45\x6a\x61\x02\x19\x06\x11\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69"
  "\x6f\x6e\x2f\x6d\x61\x6b\x65\x62\x02\xf5\x02\x0a\x81\x89\x02\xf4"
  "\x02\x08\x81\x87\x02\xf3\x02\x06\x81\x85\x02\xf2\x02\x04\x84\x06"
  "\x09\x13\x63\x02\x1a\x05\x11\x64\x65\x63\x6c\x61\x72\x61\x74\x69"
  "\x6f\x6e\x2f\x6d\x61\x6b\x65\x64\x02\xf8\x02\x08\x81\x87\x02\xf7"
  "\x02\x06\x81\x85\x02\xf6\x02\x04\x84\x06\x07\x10\x65\x02\x1b\x11"
  "\x68\x61\x63\x6b\x69\x66\x79\x2d\x76\x61\x72\x69\x61\x62\x6c\x65"
  "\x66\x02\x04\x32\x09\x42\x03\x66\x04\x87\x03\x20\x81\x8f\x02\x86"
  "\x03\x1e\x81\x8d\x02\x85\x03\x1c\x81\x8b\x02\x84\x03\x1a\x81\x89"
  "\x02\x83\x03\x18\x81\x87\x02\x82\x03\x16\x81\x85\x02\x81\x03\x14"
  "\x81\x87\x02\x80\x03\x12\x81\x85\x02\xff\x02\x10\x81\x85\x02\xfe"
  "\x02\x0e\x81\x89\x02\xfd\x02\x0c\x81\x87\x02\xfc\x02\x0a\x81\x85"
  "\x02\xfb\x02\x08\x81\x89\x02\xfa\x02\x06\x81\x87\x02\xf9\x02\x04"
  "\x84\x06\x1f\x32\x67\x02\x1c\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73"
  "\x65\x74\x21\x68\x02\x03\x0c\x73\x79\x6d\x62\x6f\x6c\x2d\x6e\x61"
  "\x6d\x65\x03\x1a\x73\x74\x72\x69\x6e\x67\x2d\x3e\x75\x6e\x69\x6e"
  "\x74\x65\x72\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x03\x8b\x03"
  "\x0a\x81\x89\x02\x8a\x03\x08\x81\x87\x02\x89\x03\x06\x81\x8b\x02"
  "\x88\x03\x04\x83\x04\x09\x15\x69\x02\x1d\x04\x0e\x73\x65\x71\x75"
  "\x65\x6e\x63\x65\x2f\x6d\x61\x6b\x65\x6a\x02\x8d\x03\x06\x81\x85"
  "\x02\x8c\x03\x04\x84\x06\x05\x0d\x6b\x02\x1e\x03\x2d\x03\x20\x6e"
  "\x6f\x6e\x2d\x73\x69\x64\x65\x2d\x65\x66\x66\x65\x63\x74\x69\x6e"
  "\x67\x2d\x69\x6e\x2d\x73\x65\x71\x75\x65\x6e\x63\x65\x3f\x6c\x03"
  "\x8f\x03\x06\x81\x83\x02\x8e\x03\x04\x83\x04\x05\x0d\x6d\x02\x1f"
  "\x04\x0b\x05\x64\x05\x0e\x04\x95\x03\x0e\x81\x91\x02\x94\x03\x0c"
  "\x81\x8d\x02\x93\x03\x0a\x81\x8b\x02\x92\x03\x08\x81\x89\x02\x91"
  "\x03\x06\x81\x87\x02\x90\x03\x04\x85\x08\x0d\x1b\x64\x02\x20\x96"
  "\x03\x04\x85\x08\x03\x0b\x02\x21\x97\x03\x04\x85\x08\x03\x6e\x02"
  "\x22\x03\x14\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f\x71\x75\x6f"
  "\x74\x61\x74\x69\x6f\x6e\x6f\x02\x98\x03\x04\x85\x08\x03\x70\x02"
  "\x23\x08\x37\x36\x05\x0e\x03\x2c\x03\x5c\x03\x43\x03\x5d\x04\x5e"
  "\x06\x11\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2f\x6d\x61"
  "\x6b\x65\x03\x53\x03\x0a\x04\x60\x04\x5b\x0c\xb7\x03\x40\xfd\xff"
  "\x03\xb6\x03\x3e\xfd\xff\x03\xb5\x03\x3c\xfd\xff\x03\xb4\x03\x3a"
  "\xfd\xff\x03\xb3\x03\x38\xfd\xff\x03\xb2\x03\x36\xfd\xff\x03\xb1"
  "\x03\x34\xfd\xff\x03\xb0\x03\x32\xfd\xff\x03\xaf\x03\x30\xfd\xff"
  "\x03\xae\x03\x2e\xfd\xff\x03\xad\x03\x2c\xfd\xff\x03\xac\x03\x2a"
  "\x81\x85\x02\xab\x03\x28\xfd\xff\x03\xaa\x03\x26\xfd\xff\x03\xa9"
  "\x03\x24\xfd\xff\x03\xa8\x03\x22\x81\x89\x02\xa7\x03\x20\x81\x83"
  "\x02\xa6\x03\x1e\xfd\xff\x03\xa5\x03\x1c\xfd\xff\x03\xa4\x03\x1a"
  "\xfd\xff\x03\xa3\x03\x18\xfd\xff\x03\xa2\x03\x16\xfd\xff\x03\xa1"
  "\x03\x14\xfd\xff\x03\xa0\x03\x12\xff\xff\x03\x9f\x03\x10\x81\x8b"
  "\x02\x9e\x03\x0e\x81\x8d\x02\x9d\x03\x0c\x81\x89\x02\x9c\x03\x0a"
  "\x81\x8b\x02\x9b\x03\x08\x81\x87\x02\x9a\x03\x06\x81\x89\x02\x99"
  "\x03\x04\x85\x08\x3f\x61\x5c\x02\x24\x05\x0e\x03\x2c\x05\x11\x64"
  "\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x2f\x6d\x61\x6b\x65\x04"
  "\xbf\x03\x12\x81\x8b\x02\xbe\x03\x10\x81\x8b\x02\xbd\x03\x0e\x81"
  "\x8b\x02\xbc\x03\x0c\x81\x89\x02\xbb\x03\x0a\x81\x8b\x02\xba\x03"
  "\x08\x81\x87\x02\xb9\x03\x06\x81\x89\x02\xb8\x03\x04\x85\x08\x11"
  "\x1f\x71\x02\x25\x05\x2f\x04\x19\x73\x65\x71\x75\x65\x6e\x63\x65"
  "\x2f\x6f\x70\x74\x69\x6d\x69\x7a\x69\x6e\x67\x2d\x6d\x61\x6b\x65"
  "\x72\x03\xc2\x03\x08\x81\x87\x02\xc1\x03\x06\x81\x89\x02\xc0\x03"
  "\x04\x85\x08\x07\x11\x73\x02\x26\x36\x37\x18\x6f\x70\x65\x6e\x2d"
  "\x62\x6c\x6f\x63\x6b\x2f\x76\x61\x6c\x75\x65\x2d\x6d\x61\x72\x6b"
  "\x65\x72\x74\x02\x05\x0e\x05\x2f\x03\x2d\x03\x15\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x2f\x63\x61\x6e\x2d\x69\x67\x6e\x6f\x72\x65\x21"
  "\x05\xce\x03\x1a\x81\x8b\x02\xcd\x03\x18\x81\x8f\x02\xcc\x03\x16"
  "\x81\x8d\x02\xcb\x03\x14\x81\x8d\x02\xca\x03\x12\x81\x8d\x02\xc9"
  "\x03\x10\x81\x89\x02\xc8\x03\x0e\x81\x8b\x02\xc7\x03\x0c\x81\x8b"
  "\x02\xc6\x03\x0a\x81\x89\x02\xc5\x03\x08\x81\x87\x02\xc4\x03\x06"
  "\x85\x08\xc3\x03\x04\x81\x89\x02\x19\x2c\x2d\x02\x27\x37\x36\x03"
  "\x1a\x72\x65\x6d\x6f\x76\x65\x2d\x6e\x6f\x6e\x2d\x73\x69\x64\x65"
  "\x2d\x65\x66\x66\x65\x63\x74\x69\x6e\x67\x75\x04\x6a\x03\xd3\x03"
  "\x0c\x81\x89\x02\xd2\x03\x0a\x81\x87\x02\xd1\x03\x08\x81\x85\x02"
  "\xd0\x03\x06\x81\x87\x02\xcf\x03\x04\x84\x06\x0b\x18\x6a\x02\x28"
  "\x37\x36\x03\x75\x03\x6c\x03\xda\x03\x10\x81\x85\x02\xd9\x03\x0e"
  "\x81\x85\x02\xd8\x03\x0c\x81\x87\x02\xd7\x03\x0a\x81\x83\x02\xd6"
  "\x03\x08\x81\x85\x02\xd5\x03\x06\x81\x83\x02\xd4\x03\x04\x83\x04"
  "\x0f\x1a\x76\x02\x29\x03\x2c\x03\x0b\x71\x75\x6f\x74\x61\x74\x69"
  "\x6f\x6e\x3f\x03\x07\x64\x65\x6c\x61\x79\x3f\x77\x03\x53\x03\x4d"
  "\x03\x6c\x07\xe1\x03\x10\x81\x85\x02\xe0\x03\x0e\x81\x85\x02\xdf"
  "\x03\x0c\x81\x85\x02\xde\x03\x0a\x81\x85\x02\xdd\x03\x08\x81\x85"
  "\x02\xdc\x03\x06\x81\x83\x02\xdb\x03\x04\x83\x04\x0f\x21\x4d\x02"
  "\x2a\x36\x22\x75\x73\x75\x61\x6c\x2d\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x69\x6f\x6e\x73\x2f\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x61"
  "\x6c\x69\x73\x74\x78\x02\x05\x0e\x03\x50\x04\x05\x61\x73\x73\x71"
  "\x79\x05\x0c\x61\x63\x63\x65\x73\x73\x2f\x6d\x61\x6b\x65\x04\x0e"
  "\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2f\x6d\x61\x6b\x65\x7a\x06\xec"
  "\x03\x18\x81\x89\x02\xeb\x03\x16\x81\x89\x02\xea\x03\x14\x81\x89"
  "\x02\xe9\x03\x12\x81\x8d\x02\xe8\x03\x10\x81\x8b\x02\xe7\x03\x0e"
  "\x81\x8d\x02\xe6\x03\x0c\x81\x8d\x02\xe5\x03\x0a\x81\x89\x02\xe4"
  "\x03\x08\x81\x8b\x02\xe3\x03\x06\x81\x87\x02\xe2\x03\x04\x85\x08"
  "\x17\x2c\x7b\x02\x2b\x03\x2c\x03\x1b\x73\x79\x73\x74\x65\x6d\x2d"
  "\x67\x6c\x6f\x62\x61\x6c\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x3f\x03\xef\x03\x08\x81\x83\x02\xee\x03\x06\x81\x83\x02"
  "\xed\x03\x04\x83\x04\x07\x11\x7c\x02\x2c\x05\x0e\x04\x0b\x64\x65"
  "\x6c\x61\x79\x2f\x6d\x61\x6b\x65\x03\xf3\x03\x0a\x81\x89\x02\xf2"
  "\x03\x08\x81\x87\x02\xf1\x03\x06\x81\x89\x02\xf0\x03\x04\x85\x08"
  "\x09\x14\x7d\x02\x2d\x05\x02\xf9\x03\x0e\x85\x08\xf8\x03\x0c\x81"
  "\x83\x02\xf7\x03\x0a\x81\x89\x02\xf6\x03\x08\x81\x87\x02\xf5\x03"
  "\x06\x81\x85\x02\xf4\x03\x04\x83\x04\x0d\x17\x7e\x02\x2e\x36\x37"
  "\x06\x61\x70\x70\x6c\x79\x78\x23\x75\x73\x75\x61\x6c\x2d\x69\x6e"
  "\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x73\x2f\x65\x78\x70\x61\x6e"
  "\x73\x69\x6f\x6e\x2d\x61\x6c\x69\x73\x74\x13\x69\x64\x65\x6e\x74"
  "\x69\x74\x79\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x04\x03\x51"
  "\x04\x79\x08\x1c\x05\x0e\x05\x4a\x06\x62\x07\x8a\x04\x24\x81\x89"
  "\x02\x89\x04\x22\x81\x93\x02\x88\x04\x20\x81\x93\x02\x87\x04\x1e"
  "\x81\x93\x02\x86\x04\x1c\x81\x89\x02\x85\x04\x1a\x81\x83\x02\x84"
  "\x04\x18\x81\x87\x02\x83\x04\x16\x81\x8f\x02\x82\x04\x14\x81\x95"
  "\x02\x81\x04\x12\x81\x93\x02\x80\x04\x10\x81\x83\x02\xff\x03\x0e"
  "\x81\x8f\x02\xfe\x03\x0c\x81\x8f\x02\xfd\x03\x0a\x81\x95\x02\xfc"
  "\x03\x08\x81\x8f\x02\xfb\x03\x06\x88\x0e\xfa\x03\x04\x81\x91\x02"
  "\x23\x3d\x78\x02\x2f\x68\x02\x05\x63\x6f\x6e\x73\x7f\x29\x03\x04"
  "\x10\x06\x05\x6d\x61\x70\x2a\x80\x01\x04\x19\x64\x65\x6c\x61\x79"
  "\x65\x64\x2d\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x2f\x6d"
  "\x61\x6b\x65\x04\x32\x05\x94\x04\x16\x81\x85\x02\x93\x04\x14\x81"
  "\x8d\x02\x92\x04\x12\x81\x85\x02\x91\x04\x10\x81\x91\x02\x90\x04"
  "\x0e\x81\x8d\x02\x8f\x04\x0c\x81\x8b\x02\x8e\x04\x0a\x81\x85\x02"
  "\x8d\x04\x08\x81\x91\x02\x8c\x04\x06\x81\x89\x02\x8b\x04\x04\x86"
  "\x0a\x15\x27\x81\x01\x02\x30\x36\x07\x23\x04\x26\x03\x25\x04\x28"
  "\x03\x27\x03\x29\x07\x9f\x04\x18\x81\x85\x02\x9e\x04\x16\x81\x85"
  "\x02\x9d\x04\x14\x81\x85\x02\x9c\x04\x12\x81\x87\x02\x9b\x04\x10"
  "\x81\x85\x02\x9a\x04\x0e\x81\x85\x02\x99\x04\x0c\x81\x8b\x02\x98"
  "\x04\x0a\x81\x85\x02\x97\x04\x08\x81\x91\x02\x96\x04\x06\x81\x8d"
  "\x02\x95\x04\x04\x88\x0e\x17\x2b\x26\x02\x31\x17\x55\x6e\x66\x69"
  "\x6e\x69\x73\x68\x65\x64\x20\x69\x6e\x74\x65\x67\x72\x61\x74\x69"
  "\x6f\x6e\x14\x55\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x69\x6e\x74"
  "\x65\x67\x72\x61\x74\x65\x07\x23\x03\x25\x04\x19\x03\x27\x03\x29"
  "\x04\x1a\x07\xa8\x04\x14\x81\x85\x02\xa7\x04\x12\x81\x85\x02\xa6"
  "\x04\x10\x81\x83\x02\xa5\x04\x0e\x81\x85\x02\xa4\x04\x0c\x81\x83"
  "\x02\xa3\x04\x0a\x81\x85\x02\xa2\x04\x08\x81\x83\x02\xa1\x04\x06"
  "\x81\x85\x02\xa0\x04\x04\x86\x0a\x13\x27\x25\x02\x32\x36\x37\x0f"
  "\x2a\x75\x6e\x6b\x6e\x6f\x77\x6e\x2d\x76\x61\x6c\x75\x65\x19\x02"
  "\xb5\x04\x1c\x81\x89\x02\xb4\x04\x1a\x81\x8b\x02\xb3\x04\x18\x81"
  "\x89\x02\xb2\x04\x16\x81\x85\x02\xb1\x04\x14\x81\x89\x02\xb0\x04"
  "\x12\x81\x89\x02\xaf\x04\x10\x81\x89\x02\xae\x04\x0e\x81\x8b\x02"
  "\xad\x04\x0c\x81\x89\x02\xac\x04\x0a\x81\x89\x02\xab\x04\x08\x81"
  "\x89\x02\xaa\x04\x06\x81\x85\x02\xa9\x04\x04\x84\x06\x1b\x27\x82"
  "\x01\x02\x33\x36\x05\x63\x6f\x6e\x73\x83\x01\x7f\x37\x05\x66\x61"
  "\x69\x6c\x03\x0a\x6c\x61\x73\x74\x2d\x70\x61\x69\x72\x03\x11\x65"
  "\x78\x63\x65\x70\x74\x2d\x6c\x61\x73\x74\x2d\x70\x61\x69\x72\x04"
  "\x03\x2c\x03\x43\x03\x0c\x67\x6c\x6f\x62\x61\x6c\x2d\x72\x65\x66"
  "\x3f\x07\xc8\x04\x28\x81\x85\x02\xc7\x04\x26\x81\x83\x02\xc6\x04"
  "\x24\x81\x85\x02\xc5\x04\x22\x81\x85\x02\xc4\x04\x20\x81\x85\x02"
  "\xc3\x04\x1e\x81\x85\x02\xc2\x04\x1c\x81\x85\x02\xc1\x04\x1a\x81"
  "\x85\x02\xc0\x04\x18\x81\x85\x02\xbf\x04\x16\x81\x83\x02\xbe\x04"
  "\x14\x81\x83\x02\xbd\x04\x12\x81\x83\x02\xbc\x04\x10\x81\x83\x02"
  "\xbb\x04\x0e\x81\x83\x02\xba\x04\x0c\x81\x87\x02\xb9\x04\x0a\x81"
  "\x85\x02\xb8\x04\x08\x81\x85\x02\xb7\x04\x06\x81\x83\x02\xb6\x04"
  "\x04\x83\x04\x27\x41\x43\x02\x34\x83\x01\x27\x54\x6f\x6f\x20\x6d"
  "\x61\x6e\x79\x20\x6f\x70\x65\x72\x61\x6e\x64\x73\x20\x69\x6e\x20"
  "\x63\x61\x6c\x6c\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x0d\x6e\x61\x6d\x65\x64\x2d\x6c\x61\x6d\x62\x64\x61\x07\x6c"
  "\x61\x6d\x62\x64\x61\x04\x2e\x2e\x2e\x36\x37\x26\x54\x6f\x6f\x20"
  "\x66\x65\x77\x20\x6f\x70\x65\x72\x61\x6e\x64\x73\x20\x69\x6e\x20"
  "\x63\x61\x6c\x6c\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x14\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x6f\x70\x74"
  "\x69\x6f\x6e\x61\x6c\x02\x05\x1a\x05\x03\x09\x75\x6e\x73\x79\x6e"
  "\x74\x61\x78\x04\x7a\x06\x62\x06\xee\x04\x4e\xfd\xff\x03\xed\x04"
  "\x4c\xfd\xff\x03\xec\x04\x4a\xfd\xff\x03\xeb\x04\x48\xff\xff\x03"
  "\xea\x04\x46\x81\x85\x02\xe9\x04\x44\x81\x8f\x02\xe8\x04\x42\x81"
  "\x8f\x02\xe7\x04\x40\x81\x83\x02\xe6\x04\x3e\x81\x8f\x02\xe5\x04"
  "\x3c\x81\x85\x02\xe4\x04\x3a\x81\x85\x02\xe3\x04\x38\x81\x83\x02"
  "\xe2\x04\x36\x81\x8f\x02\xe1\x04\x34\x81\x8f\x02\xe0\x04\x32\x81"
  "\x91\x02\xdf\x04\x30\x81\x8f\x02\xde\x04\x2e\x81\x8f\x02\xdd\x04"
  "\x2c\x81\x8f\x02\xdc\x04\x2a\x81\x8f\x02\xdb\x04\x28\x81\x83\x02"
  "\xda\x04\x26\x81\x89\x02\xd9\x04\x24\x81\x89\x02\xd8\x04\x22\x81"
  "\x87\x02\xd7\x04\x20\x81\x87\x02\xd6\x04\x1e\x81\x87\x02\xd5\x04"
  "\x1c\x81\x87\x02\xd4\x04\x1a\x81\x83\x02\xd3\x04\x18\x81\x83\x02"
  "\xd2\x04\x16\x81\x85\x02\xd1\x04\x14\x81\x8f\x02\xd0\x04\x12\x81"
  "\x8f\x02\xcf\x04\x10\x81\x8f\x02\xce\x04\x0e\x81\x91\x02\xcd\x04"
  "\x0c\x81\x8f\x02\xcc\x04\x0a\x81\x8f\x02\xcb\x04\x08\x81\x8f\x02"
  "\xca\x04\x06\x81\x8b\x02\xc9\x04\x04\x86\x0a\x4d\x6c\x83\x01\x02"
  "\x35\xef\x04\x04\x82\x02\x03\x84\x01\x02\x36\xf0\x04\x04\x85\x08"
  "\x03\x85\x01\x02\x37\x7f\x02\x06\x80\x01\x02\xf2\x04\x06\x81\x89"
  "\x02\xf1\x04\x04\x85\x08\x05\x0d\x80\x01\x02\x38\x36\x19\x02\x04"
  "\x79\x02\xf7\x04\x0c\x81\x8d\x02\xf6\x04\x0a\x81\x8f\x02\xf5\x04"
  "\x08\x81\x8d\x02\xf4\x04\x06\x81\x8b\x02\xf3\x04\x04\x87\x0c\x0b"
  "\x14\x7f\x02\x39\x11\x62\x65\x69\x6e\x67\x2d\x69\x6e\x74\x65\x67"
  "\x72\x61\x74\x65\x64\x79\xf9\x04\x06\x81\x83\x02\xf8\x04\x04\x83"
  "\x04\x05\x0c\x86\x01\x02\x3a\x26\x44\x65\x6c\x61\x79\x65\x64\x20"
  "\x69\x6e\x74\x65\x67\x72\x61\x74\x69\x6f\x6e\x20\x68\x61\x73\x20"
  "\x75\x6e\x6b\x6e\x6f\x77\x6e\x20\x73\x74\x61\x74\x65\x28\x41\x74"
  "\x74\x65\x6d\x70\x74\x20\x74\x6f\x20\x72\x65\x2d\x66\x6f\x72\x63"
  "\x65\x20\x64\x65\x6c\x61\x79\x65\x64\x20\x69\x6e\x74\x65\x67\x72"
  "\x61\x74\x69\x6f\x6e\x79\x0f\x6e\x6f\x74\x2d\x69\x6e\x74\x65\x67"
  "\x72\x61\x74\x65\x64\x68\x0b\x69\x6e\x74\x65\x67\x72\x61\x74\x65"
  "\x64\x05\x0e\x04\x1a\x03\x85\x05\x1a\x81\x87\x02\x84\x05\x18\x81"
  "\x87\x02\x83\x05\x16\x81\x87\x02\x82\x05\x14\x81\x87\x02\x81\x05"
  "\x12\x81\x89\x02\x80\x05\x10\x81\x87\x02\xff\x04\x0e\x81\x85\x02"
  "\xfe\x04\x0c\x81\x85\x02\xfd\x04\x0a\x83\x04\xfc\x04\x08\x81\x83"
  "\x02\xfb\x04\x06\x81\x83\x02\xfa\x04\x04\x81\x83\x02\x19\x2c\x79"
  "\x02\x3b\x03\x2c\x02\x86\x05\x04\x83\x04\x03\x68\x02\x3c\x36\x37"
  "\x03\x13\x66\x6f\x6c\x64\x61\x62\x6c\x65\x2d\x63\x6f\x6e\x73\x74"
  "\x61\x6e\x74\x3f\x87\x01\x03\x14\x66\x6f\x6c\x64\x61\x62\x6c\x65"
  "\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x73\x3f\x88\x01\x03\x8a\x05"
  "\x0a\x81\x83\x02\x89\x05\x08\x81\x83\x02\x88\x05\x06\x81\x85\x02"
  "\x87\x05\x04\x83\x04\x09\x15\x89\x01\x02\x3d\x26\x66\x6f\x6c\x64"
  "\x61\x62\x6c\x65\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x76\x61"
  "\x6c\x75\x65\x3a\x20\x63\x61\x6e\x27\x74\x20\x68\x61\x70\x70\x65"
  "\x6e\x03\x2c\x04\x1a\x03\x8c\x05\x06\x81\x83\x02\x8b\x05\x04\x83"
  "\x04\x05\x10\x8a\x01\x02\x3e\x1f\x2a\x66\x6f\x6c\x64\x61\x62\x6c"
  "\x65\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x73\x8b\x01\x02\x03\x2c\x03\x54\x04\x22\x04"
  "\x92\x05\x0e\x81\x85\x02\x91\x05\x0c\x81\x83\x02\x90\x05\x0a\x81"
  "\x83\x02\x8f\x05\x08\x81\x85\x02\x8e\x05\x06\x81\x83\x02\x8d\x05"
  "\x04\x83\x04\x0d\x1b\x54\x02\x3f\x08\x4c\x37\x18\x66\x6f\x6c\x64"
  "\x61\x62\x6c\x65\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x76\x61"
  "\x6c\x75\x65\x8c\x01\x06\x66\x6f\x72\x63\x65\x14\x64\x65\x63\x6c"
  "\x61\x72\x61\x74\x69\x6f\x6e\x73\x2f\x6b\x6e\x6f\x77\x6e\x3f\x3b"
  "\x05\x03\x13\x66\x6f\x6c\x64\x61\x62\x6c\x65\x2d\x6f\x70\x65\x72"
  "\x61\x74\x6f\x72\x3f\x8d\x01\x04\x10\x03\x2c\x03\x88\x01\x03\x77"
  "\x03\x07\x6c\x65\x6e\x67\x74\x68\x77\x03\x53\x04\x7a\x06\x62\x03"
  "\x16\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x73\x2f\x6f\x72"
  "\x69\x67\x69\x6e\x61\x6c\x04\x5a\x04\x03\x3b\x07\x1f\x64\x65\x6c"
  "\x65\x74\x65\x2d\x75\x6e\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x64"
  "\x2d\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x73\x7a\x04\x28\x03\x0a"
  "\x09\x42\x04\x72\x13\xcd\x05\x78\x81\x8b\x02\xcc\x05\x76\x81\x93"
  "\x02\xcb\x05\x74\x81\x8d\x02\xca\x05\x72\x81\x91\x02\xc9\x05\x70"
  "\x81\x89\x02\xc8\x05\x6e\x81\x9b\x02\xc7\x05\x6c\x81\x99\x02\xc6"
  "\x05\x6a\x81\x97\x02\xc5\x05\x68\x81\x8f\x02\xc4\x05\x66\x81\x8d"
  "\x02\xc3\x05\x64\x81\x89\x02\xc2\x05\x62\x81\x8b\x02\xc1\x05\x60"
  "\x81\x8b\x02\xc0\x05\x5e\x81\x8d\x02\xbf\x05\x5c\x81\x8d\x02\xbe"
  "\x05\x5a\x81\x89\x02\xbd\x05\x58\x81\x8b\x02\xbc\x05\x56\x81\x8d"
  "\x02\xbb\x05\x54\x81\x8b\x02\xba\x05\x52\x81\x89\x02\xb9\x05\x50"
  "\x81\x8b\x02\xb8\x05\x4e\x81\x89\x02\xb7\x05\x4c\x81\x8b\x02\xb6"
  "\x05\x4a\x81\x89\x02\xb5\x05\x48\x81\x89\x02\xb4\x05\x46\x81\x89"
  "\x02\xb3\x05\x44\x81\x8d\x02\xb2\x05\x42\x81\x8d\x02\xb1\x05\x40"
  "\x81\x8b\x02\xb0\x05\x3e\x81\x8b\x02\xaf\x05\x3c\x81\x89\x02\xae"
  "\x05\x3a\x81\x89\x02\xad\x05\x38\x81\x8f\x02\xac\x05\x36\x81\x8f"
  "\x02\xab\x05\x34\x81\x8b\x02\xaa\x05\x32\x81\x8b\x02\xa9\x05\x30"
  "\x81\x89\x02\xa8\x05\x2e\x81\x89\x02\xa7\x05\x2c\x81\x8b\x02\xa6"
  "\x05\x2a\x81\x89\x02\xa5\x05\x28\x81\x89\x02\xa4\x05\x26\x81\x89"
  "\x02\xa3\x05\x24\x81\x8d\x02\xa2\x05\x22\x81\x8b\x02\xa1\x05\x20"
  "\x81\x8b\x02\xa0\x05\x1e\x81\x89\x02\x9f\x05\x1c\x81\x89\x02\x9e"
  "\x05\x1a\x81\x8b\x02\x9d\x05\x18\x81\x89\x02\x9c\x05\x16\x81\x89"
  "\x02\x9b\x05\x14\x81\x8b\x02\x9a\x05\x12\x81\x89\x02\x99\x05\x10"
  "\x81\x89\x02\x98\x05\x0e\x81\x89\x02\x97\x05\x0c\x81\x89\x02\x96"
  "\x05\x0a\x81\x89\x02\x95\x05\x08\x81\x8f\x02\x94\x05\x06\x81\x89"
  "\x02\x93\x05\x04\x86\x0a\x77\xaf\x01\x62\x02\x40\x36\x37\x12\x41"
  "\x72\x67\x75\x6d\x65\x6e\x74\x20\x6d\x69\x73\x6d\x61\x74\x63\x68"
  "\x03\x44\x03\x5d\x04\x1a\x04\x0c\x73\x65\x74\x2f\x6d\x65\x6d\x62"
  "\x65\x72\x3f\x03\x3b\x04\x07\xde\x05\x24\x81\x97\x02\xdd\x05\x22"
  "\x81\x97\x02\xdc\x05\x20\x81\x99\x02\xdb\x05\x1e\x81\x9b\x02\xda"
  "\x05\x1c\x81\x9b\x02\xd9\x05\x1a\x81\x9b\x02\xd8\x05\x18\x81\x9b"
  "\x02\xd7\x05\x16\x81\x9b\x02\xd6\x05\x14\x81\x97\x02\xd5\x05\x12"
  "\x81\x9b\x02\xd4\x05\x10\x81\x9b\x02\xd3\x05\x0e\x81\x9b\x02\xd2"
  "\x05\x0c\x81\x99\x02\xd1\x05\x0a\x81\x97\x02\xd0\x05\x08\x81\x97"
  "\x02\xcf\x05\x06\x81\x8b\x02\xce\x05\x04\x87\x0c\x23\x37\x5d\x02"
  "\x41\x38\x40\x41\x04\x08\x31\x05\x46\x04\x18\x61\x73\x73\x6f\x63"
  "\x69\x61\x74\x65\x2d\x76\x61\x72\x73\x2d\x61\x6e\x64\x2d\x76\x61"
  "\x6c\x73\x5a\x04\x13\x67\x65\x74\x2d\x62\x6f\x64\x79\x2d\x66\x72"
  "\x65\x65\x2d\x76\x61\x72\x73\x53\x04\x1a\x67\x65\x74\x2d\x66\x72"
  "\x65\x65\x2d\x76\x61\x72\x73\x2d\x69\x6e\x2d\x62\x69\x6e\x64\x69"
  "\x6e\x67\x73\x3b\x06\x0c\x62\x75\x69\x6c\x64\x2d\x67\x72\x61\x70"
  "\x68\x2c\x03\x18\x63\x6f\x6c\x6c\x61\x70\x73\x65\x2d\x63\x69\x72"
  "\x63\x75\x6c\x61\x72\x69\x74\x69\x65\x73\x21\x0a\x03\x12\x6c\x61"
  "\x62\x65\x6c\x2d\x6e\x6f\x64\x65\x2d\x64\x65\x70\x74\x68\x21\x8e"
  "\x01\x03\x0a\x6c\x69\x6e\x65\x61\x72\x69\x7a\x65\x8f\x01\x07\x0f"
  "\x62\x75\x69\x6c\x64\x2d\x6e\x65\x77\x2d\x63\x6f\x64\x65\x90\x01"
  "\x05\x0e\x0c\xf1\x05\x28\x81\x97\x02\xf0\x05\x26\x81\x9d\x02\xef"
  "\x05\x24\x81\x95\x02\xee\x05\x22\x81\x95\x02\xed\x05\x20\x81\x95"
  "\x02\xec\x05\x1e\x81\x97\x02\xeb\x05\x1c\x81\x95\x02\xea\x05\x1a"
  "\x81\x93\x02\xe9\x05\x18\x81\x91\x02\xe8\x05\x16\x81\x8f\x02\xe7"
  "\x05\x14\x81\x95\x02\xe6\x05\x12\x81\x93\x02\xe5\x05\x10\x81\x93"
  "\x02\xe4\x05\x0e\x81\x8f\x02\xe3\x05\x0c\x81\x93\x02\xe2\x05\x0a"
  "\x81\x8f\x02\xe1\x05\x08\x89\x10\xe0\x05\x06\x81\x91\x02\xdf\x05"
  "\x04\x81\x91\x02\x27\x49\x91\x01\x02\x42\x36\x37\x09\x4d\x69\x73"
  "\x6d\x61\x74\x63\x68\x02\x17\x6d\x61\x6b\x65\x2d\x67\x65\x6e\x65"
  "\x72\x69\x63\x2d\x65\x71\x3f\x2d\x74\x61\x62\x6c\x65\x92\x01\x03"
  "\x1a\x05\x0b\x74\x61\x62\x6c\x65\x2d\x70\x75\x74\x21\x93\x01\x04"
  "\xfa\x05\x14\x81\x85\x02\xf9\x05\x12\x81\x85\x02\xf8\x05\x10\x81"
  "\x85\x02\xf7\x05\x0e\x81\x87\x02\xf6\x05\x0c\x81\x89\x02\xf5\x05"
  "\x0a\x81\x87\x02\xf4\x05\x08\x81\x85\x02\xf3\x05\x06\x81\x85\x02"
  "\xf2\x05\x04\x84\x06\x13\x21\x94\x01\x02\x43\x40\x41\x03\x05\x46"
  "\x02\xfd\x05\x08\x81\x85\x02\xfc\x05\x06\x81\x83\x02\xfb\x05\x04"
  "\x83\x04\x07\x10\x95\x01\x02\x44\x40\x06\x6e\x6f\x64\x65\x3f\x96"
  "\x01\x03\x05\x46\x02\x80\x06\x08\x81\x85\x02\xff\x05\x06\x81\x83"
  "\x02\xfe\x05\x04\x83\x04\x07\x10\x97\x01\x02\x45\x40\x96\x01\x03"
  "\x04\x0a\x65\x6d\x70\x74\x79\x2d\x73\x65\x74\x98\x01\x02\x83\x06"
  "\x08\x81\x83\x02\x82\x06\x06\x81\x81\x02\x81\x06\x04\x82\x02\x07"
  "\x10\x99\x01\x02\x46\x40\x96\x01\x03\x05\x0e\x73\x69\x6e\x67\x6c"
  "\x65\x74\x6f\x6e\x2d\x73\x65\x74\x9a\x01\x02\x86\x06\x08\x81\x85"
  "\x02\x85\x06\x06\x81\x83\x02\x84\x06\x04\x83\x04\x07\x10\x9b\x01"
  "\x02\x47\x40\x41\x03\x04\x98\x01\x02\x89\x06\x08\x81\x83\x02\x88"
  "\x06\x06\x81\x81\x02\x87\x06\x04\x82\x02\x07\x10\x9c\x01\x02\x48"
  "\x40\x41\x03\x05\x9a\x01\x02\x8c\x06\x08\x81\x85\x02\x8b\x06\x06"
  "\x81\x83\x02\x8a\x06\x04\x83\x04\x07\x10\x9d\x01\x02\x49\x02\x92"
  "\x01\x04\x32\x03\x44\x04\x47\x05\x93\x01\x06\x92\x06\x0e\x81\x87"
  "\x02\x91\x06\x0c\x81\x85\x02\x90\x06\x0a\x81\x85\x02\x8f\x06\x08"
  "\x81\x89\x02\x8e\x06\x06\x81\x85\x02\x8d\x06\x04\x84\x06\x0d\x1b"
  "\x9e\x01\x02\x4a\x36\x37\x40\x41\x03\x03\x09\x67\x65\x74\x2d\x62"
  "\x6f\x64\x79\x9f\x01\x04\x98\x01\x03\x44\x04\x0a\x73\x65\x74\x2f"
  "\x75\x6e\x69\x6f\x6e\x44\x04\x47\x06\x9d\x06\x18\x81\x8d\x02\x9c"
  "\x06\x16\x81\x8b\x02\x9b\x06\x14\x81\x89\x02\x9a\x06\x12\x81\x89"
  "\x02\x99\x06\x10\x81\x8f\x02\x98\x06\x0e\x81\x89\x02\x97\x06\x0c"
  "\x81\x89\x02\x96\x06\x0a\x81\x8d\x02\x95\x06\x08\x81\x8b\x02\x94"
  "\x06\x06\x81\x85\x02\x93\x06\x04\x84\x06\x17\x2b\x47\x02\x4b\x36"
  "\x37\x74\x02\x03\x9f\x01\x02\xa4\x06\x10\x81\x85\x02\xa3\x06\x0e"
  "\x81\x83\x02\xa2\x06\x0c\x81\x85\x02\xa1\x06\x0a\x81\x83\x02\xa0"
  "\x06\x08\x81\x85\x02\x9f\x06\x06\x81\x83\x02\x9e\x06\x04\x83\x04"
  "\x0f\x1a\xa0\x01\x02\x4c\xa5\x06\x04\x82\x02\x03\xa1\x01\x02\x4d"
  "\xa6\x06\x04\x82\x02\x03\xa2\x01\x02\x4e\x40\x96\x01\x03\x04\x98"
  "\x01\x02\xa9\x06\x08\x81\x83\x02\xa8\x06\x06\x81\x81\x02\xa7\x06"
  "\x04\x82\x02\x07\x10\xa3\x01\x02\x4f\x40\x96\x01\x03\x04\x98\x01"
  "\x02\xac\x06\x08\x81\x83\x02\xab\x06\x06\x81\x81\x02\xaa\x06\x04"
  "\x82\x02\x07\x10\xa4\x01\x02\x50\xad\x06\x04\x82\x02\x03\xa5\x01"
  "\x02\x51\x0c\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66\xa6\x01"
  "\xae\x06\x04\x83\x04\x03\xa7\x01\x02\x52\xa6\x01\xaf\x06\x04\x83"
  "\x04\x03\xa8\x01\x02\x53\xa6\x01\xb0\x06\x04\x83\x04\x03\xa9\x01"
  "\x02\x54\xa6\x01\xb1\x06\x04\x83\x04\x03\xaa\x01\x02\x55\xa6\x01"
  "\xb2\x06\x04\x83\x04\x03\xab\x01\x02\x56\x0d\x25\x72\x65\x63\x6f"
  "\x72\x64\x2d\x73\x65\x74\x21\xac\x01\x02\xb3\x06\x04\x84\x06\x03"
  "\xad\x01\x02\x57\xac\x01\x02\xb4\x06\x04\x84\x06\x03\xae\x01\x02"
  "\x58\xac\x01\x02\xb5\x06\x04\x84\x06\x03\xaf\x01\x02\x59\xac\x01"
  "\x02\xb6\x06\x04\x84\x06\x03\xb0\x01\x02\x5a\x05\x62\x61\x73\x65"
  "\xb1\x01\x40\x41\x03\x04\x98\x01\x04\x0b\x25\x6d\x61\x6b\x65\x2d"
  "\x6e\x6f\x64\x65\xb2\x01\x03\xba\x06\x0a\x81\x81\x02\xb9\x06\x08"
  "\x81\x85\x02\xb8\x06\x06\x81\x83\x02\xb7\x06\x04\x82\x02\x09\x15"
  "\xb3\x01\x02\x5b\x06\x73\x65\x74\x75\x70\xb4\x01\x40\x41\x03\x05"
  "\x9a\x01\x04\xb2\x01\x03\xbe\x06\x0a\x81\x85\x02\xbd\x06\x08\x81"
  "\x8b\x02\xbc\x06\x06\x81\x89\x02\xbb\x06\x04\x83\x04\x09\x15\xb5"
  "\x01\x02\x5c\x07\x6c\x65\x74\x72\x65\x63\xb6\x01\x04\xb2\x01\x02"
  "\xbf\x06\x04\x83\x04\x03\x0a\xb7\x01\x02\x5d\xac\x01\x02\xa6\x01"
  "\x04\x0b\x73\x65\x74\x2f\x61\x64\x6a\x6f\x69\x6e\xb8\x01\x02\xc2"
  "\x06\x08\x81\x87\x02\xc1\x06\x06\x81\x8b\x02\xc0\x06\x04\x84\x06"
  "\x07\x11\xb9\x01\x02\x5e\xac\x01\x02\xa6\x01\x04\x0b\x73\x65\x74"
  "\x2f\x72\x65\x6d\x6f\x76\x65\xba\x01\x02\xc5\x06\x08\x81\x87\x02"
  "\xc4\x06\x06\x81\x8b\x02\xc3\x06\x04\x84\x06\x07\x11\xbb\x01\x02"
  "\x5f\xac\x01\x02\xa6\x01\x04\xb8\x01\x02\xc8\x06\x08\x81\x87\x02"
  "\xc7\x06\x06\x81\x8b\x02\xc6\x06\x04\x84\x06\x07\x11\xbc\x01\x02"
  "\x60\xac\x01\x02\xa6\x01\x04\xba\x01\x02\xcb\x06\x08\x81\x87\x02"
  "\xca\x06\x06\x81\x8b\x02\xc9\x06\x04\x84\x06\x07\x11\xbd\x01\x02"
  "\x61\xb4\x01\x40\x41\x03\x02\x92\x01\x04\x32\x07\x0c\x6c\x69\x6e"
  "\x6b\x2d\x6e\x6f\x64\x65\x73\x21\xb4\x01\x05\x9a\x01\x05\x93\x01"
  "\x04\xb2\x01\x07\xd3\x06\x12\x81\x87\x02\xd2\x06\x10\x81\x85\x02"
  "\xd1\x06\x0e\x81\x8d\x02\xd0\x06\x0c\x81\x8b\x02\xcf\x06\x0a\x81"
  "\x85\x02\xce\x06\x08\x81\x8d\x02\xcd\x06\x06\x81\x89\x02\xcc\x06"
  "\x04\x86\x0a\x11\x25\x93\x01\x02\x62\x02\xac\x01\xa6\x01\x04\xb8"
  "\x01\x02\xd9\x06\x0e\x81\x87\x02\xd8\x06\x0c\x81\x8b\x02\xd7\x06"
  "\x0a\x81\x85\x02\xd6\x06\x08\x81\x85\x02\xd5\x06\x06\x81\x89\x02"
  "\xd4\x06\x04\x84\x06\x0d\x18\x92\x01\x02\x63\xac\x01\x02\x09\x75"
  "\x6e\x6c\x69\x6e\x6b\x65\x64\xbe\x01\xa6\x01\x04\x0d\x73\x65\x74"
  "\x2f\x66\x6f\x72\x2d\x65\x61\x63\x68\xbf\x01\x04\xba\x01\x03\xe4"
  "\x06\x18\x81\x87\x02\xe3\x06\x16\x81\x87\x02\xe2\x06\x14\x81\x8b"
  "\x02\xe1\x06\x12\x81\x85\x02\xe0\x06\x10\x81\x83\x02\xdf\x06\x0e"
  "\x81\x8b\x02\xde\x06\x0c\x81\x85\x02\xdd\x06\x0a\x81\x85\x02\xdc"
  "\x06\x08\x81\x83\x02\xdb\x06\x06\x81\x85\x02\xda\x06\x04\x83\x04"
  "\x17\x26\xba\x01\x02\x64\x0d\x75\x6e\x6c\x69\x6e\x6b\x2d\x6e\x6f"
  "\x64\x65\x21\xc0\x01\x02\x04\x32\x02\xe6\x06\x06\x81\x83\x02\xe5"
  "\x06\x04\x83\x04\x05\x0d\xc1\x01\x02\x65\x02\x20\x42\x72\x6f\x6b"
  "\x65\x6e\x20\x61\x6e\x61\x6c\x79\x73\x69\x73\x3a\x20\x63\x61\x6e"
  "\x27\x74\x20\x67\x65\x74\x20\x6e\x6f\x64\x65\xac\x01\xa6\x01\x1a"
  "\x42\x72\x6f\x6b\x65\x6e\x20\x61\x6e\x61\x6c\x79\x73\x69\x73\x3a"
  "\x20\x66\x72\x65\x65\x20\x76\x61\x72\x2e\x42\x72\x6f\x6b\x65\x6e"
  "\x20\x61\x6e\x61\x6c\x79\x73\x69\x73\x3a\x20\x63\x61\x6e\x27\x74"
  "\x20\x67\x65\x74\x20\x66\x72\x65\x65\x20\x76\x61\x72\x69\x61\x62"
  "\x6c\x65\x20\x69\x6e\x66\x6f\x26\x42\x72\x6f\x6b\x65\x6e\x20\x61"
  "\x6e\x61\x6c\x79\x73\x69\x73\x3a\x20\x6e\x6f\x20\x6e\x6f\x64\x65"
  "\x20\x66\x6f\x72\x20\x76\x61\x72\x69\x61\x62\x6c\x65\xb1\x01\x40"
  "\x41\x03\x04\x32\x04\x98\x01\x06\x0a\x74\x61\x62\x6c\x65\x2d\x67"
  "\x65\x74\xb1\x01\x04\xbf\x01\x04\xb2\x01\x03\x1a\x07\x10\x74\x61"
  "\x62\x6c\x65\x2d\x67\x65\x74\x2d\x63\x68\x61\x69\x6e\x04\xb8\x01"
  "\x09\x82\x07\x3a\x81\x87\x02\x81\x07\x38\x81\x8b\x02\x80\x07\x36"
  "\x81\x85\x02\xff\x06\x34\x81\x85\x02\xfe\x06\x32\x81\x87\x02\xfd"
  "\x06\x30\x81\x89\x02\xfc\x06\x2e\x81\x85\x02\xfb\x06\x2c\x82\x02"
  "\xfa\x06\x2a\x81\x8b\x02\xf9\x06\x28\x81\x85\x02\xf8\x06\x26\x81"
  "\x85\x02\xf7\x06\x24\x81\x85\x02\xf6\x06\x22\x81\x89\x02\xf5\x06"
  "\x20\x81\x85\x02\xf4\x06\x1e\x82\x02\xf3\x06\x1c\x81\x85\x02\xf2"
  "\x06\x1a\x82\x02\xf1\x06\x18\x81\x85\x02\xf0\x06\x16\x81\x8f\x02"
  "\xef\x06\x14\x81\x85\x02\xee\x06\x12\x82\x02\xed\x06\x10\x81\x8f"
  "\x02\xec\x06\x0e\x81\x8d\x02\xeb\x06\x0c\x81\x85\x02\xea\x06\x0a"
  "\x81\x93\x02\xe9\x06\x08\x81\x91\x02\xe8\x06\x06\x81\x8d\x02\xe7"
  "\x06\x04\x87\x0c\x39\x5a\xc2\x01\x02\x66\x05\x11\x66\x69\x6e\x64"
  "\x2d\x63\x69\x72\x63\x75\x6c\x61\x72\x69\x74\x79\xc3\x01\x03\x13"
  "\x63\x6f\x6c\x6c\x61\x70\x73\x65\x2d\x6e\x6f\x64\x65\x6c\x69\x73"
  "\x74\x21\xc4\x01\x03\x87\x07\x0c\x81\x85\x02\x86\x07\x0a\x81\x83"
  "\x02\x85\x07\x08\x81\x85\x02\x84\x07\x06\x81\x83\x02\x83\x07\x04"
  "\x83\x04\x0b\x13\xc5\x01\x02\x67\x36\x37\xa6\x01\x04\x22\x04\x03"
  "\x0a\x73\x65\x74\x2d\x3e\x6c\x69\x73\x74\x22\x04\x91\x07\x16\x81"
  "\x85\x02\x90\x07\x14\x81\x83\x02\x8f\x07\x12\x81\x87\x02\x8e\x07"
  "\x10\x81\x85\x02\x8d\x07\x0e\x81\x8b\x02\x8c\x07\x0c\x81\x8d\x02"
  "\x8b\x07\x0a\x81\x8b\x02\x8a\x07\x08\x81\x89\x02\x89\x07\x06\x81"
  "\x89\x02\x88\x07\x04\x85\x08\x15\x24\xc6\x01\x02\x68\xac\x01\xb6"
  "\x01\x4c\x02\x10\x6e\x6f\x64\x65\x20\x6e\x6f\x74\x20\x6c\x69\x6e"
  "\x6b\x65\x64\xbe\x01\xa6\x01\x40\x96\x01\x0c\x25\x6e\x6f\x64\x65"
  "\x2d\x6e\x65\x65\x64\x73\xbe\x01\x0b\x25\x6e\x6f\x64\x65\x2d\x76"
  "\x61\x72\x73\xc7\x01\x0b\x73\x65\x74\x2f\x75\x6e\x69\x6f\x6e\x2a"
  "\xc8\x01\x10\x25\x6e\x6f\x64\x65\x2d\x6e\x65\x65\x64\x65\x64\x2d"
  "\x62\x79\xc9\x01\xc0\x01\x08\x04\x32\x05\x46\x03\x1a\x04\x10\x04"
  "\x0f\x73\x65\x74\x2f\x64\x69\x66\x66\x65\x72\x65\x6e\x63\x65\x04"
  "\xb2\x01\x04\xbf\x01\x04\xb8\x01\x09\xb6\x07\x4c\x81\x87\x02\xb5"
  "\x07\x4a\x81\x87\x02\xb4\x07\x48\x81\x8b\x02\xb3\x07\x46\x81\x85"
  "\x02\xb2\x07\x44\x81\x85\x02\xb1\x07\x42\x81\x8b\x02\xb0\x07\x40"
  "\x81\x85\x02\xaf\x07\x3e\x81\x85\x02\xae\x07\x3c\x81\x89\x02\xad"
  "\x07\x3a\x81\x85\x02\xac\x07\x38\x81\x8b\x02\xab\x07\x36\x81\x8b"
  "\x02\xaa\x07\x34\x81\x89\x02\xa9\x07\x32\x81\x85\x02\xa8\x07\x30"
  "\x81\x8b\x02\xa7\x07\x2e\x81\x89\x02\xa6\x07\x2c\x81\x91\x02\xa5"
  "\x07\x2a\x81\x8f\x02\xa4\x07\x28\x81\x8d\x02\xa3\x07\x26\x81\x89"
  "\x02\xa2\x07\x24\x81\x8b\x02\xa1\x07\x22\x81\x89\x02\xa0\x07\x20"
  "\x81\x93\x02\x9f\x07\x1e\x81\x87\x02\x9e\x07\x1c\x81\x8d\x02\x9d"
  "\x07\x1a\x81\x8b\x02\x9c\x07\x18\x81\x89\x02\x9b\x07\x16\x81\x8d"
  "\x02\x9a\x07\x14\x81\x85\x02\x99\x07\x12\x81\x8f\x02\x98\x07\x10"
  "\x81\x83\x02\x97\x07\x0e\x81\x83\x02\x96\x07\x0c\x83\x04\x95\x07"
  "\x0a\x81\x89\x02\x94\x07\x08\x81\x87\x02\x93\x07\x06\x81\x83\x02"
  "\x92\x07\x04\x83\x04\x4b\x71\xb8\x01\x02\x69\x4c\xac\x01\x02\x40"
  "\x96\x01\xc8\x01\xbe\x01\x05\x05\x9a\x01\x03\x45\x04\xbf\x01\x03"
  "\x22\x04\x10\x06\xc4\x07\x1e\x81\x8b\x02\xc3\x07\x1c\x81\x89\x02"
  "\xc2\x07\x1a\x81\x89\x02\xc1\x07\x18\x81\x87\x02\xc0\x07\x16\x81"
  "\x85\x02\xbf\x07\x14\x81\x85\x02\xbe\x07\x12\x81\x85\x02\xbd\x07"
  "\x10\x81\x85\x02\xbc\x07\x0e\x81\x85\x02\xbb\x07\x0c\x81\x85\x02"
  "\xba\x07\x0a\x81\x83\x02\xb9\x07\x08\x81\x89\x02\xb8\x07\x06\x81"
  "\x87\x02\xb7\x07\x04\x83\x04\x1d\x36\xc8\x01\x02\x6a\x04\x6c\x65"
  "\x74\xbf\x01\xb6\x01\x36\xa6\x01\x37\x40\x96\x01\x41\x04\x03\x45"
  "\x04\x98\x01\x03\x22\x04\x1b\x63\x6f\x6c\x6c\x61\x70\x73\x65\x2d"
  "\x70\x61\x72\x61\x6c\x6c\x65\x6c\x2d\x6e\x6f\x64\x65\x6c\x69\x73"
  "\x74\xb6\x01\x04\x44\x05\x07\xe7\x07\x48\x81\x8f\x02\xe6\x07\x46"
  "\x81\x8f\x02\xe5\x07\x44\x81\x8f\x02\xe4\x07\x42\x81\x8f\x02\xe3"
  "\x07\x40\x81\x8f\x02\xe2\x07\x3e\x81\x8f\x02\xe1\x07\x3c\x81\x8d"
  "\x02\xe0\x07\x3a\x81\x93\x02\xdf\x07\x38\x81\x8f\x02\xde\x07\x36"
  "\x81\x93\x02\xdd\x07\x34\x81\x8f\x02\xdc\x07\x32\x81\x93\x02\xdb"
  "\x07\x30\x81\x8f\x02\xda\x07\x2e\x81\x93\x02\xd9\x07\x2c\x81\x8f"
  "\x02\xd8\x07\x2a\x81\x8f\x02\xd7\x07\x28\x81\x8f\x02\xd6\x07\x26"
  "\x81\x8f\x02\xd5\x07\x24\x81\x91\x02\xd4\x07\x22\x81\x8f\x02\xd3"
  "\x07\x20\x81\x8d\x02\xd2\x07\x1e\x81\x91\x02\xd1\x07\x1c\x81\x8d"
  "\x02\xd0\x07\x1a\x81\x8b\x02\xcf\x07\x18\x81\x89\x02\xce\x07\x16"
  "\x81\x8d\x02\xcd\x07\x14\x81\x8b\x02\xcc\x07\x12\x81\x87\x02\xcb"
  "\x07\x10\x81\x8b\x02\xca\x07\x0e\x81\x89\x02\xc9\x07\x0c\x81\x85"
  "\x02\xc8\x07\x0a\x81\x89\x02\xc7\x07\x08\x81\x87\x02\xc6\x07\x06"
  "\x81\x85\x02\xc5\x07\x04\x84\x06\x47\x65\xac\x01\x02\x6b\xa6\x01"
  "\x04\xb6\x01\x02\xe9\x07\x06\x81\x85\x02\xe8\x07\x04\x83\x04\x05"
  "\x0e\x9a\x01\x02\x6c\x07\x62\x72\x6f\x6b\x65\x6e\xbf\x01\x36\x37"
  "\x74\x0f\x6c\x61\x6d\x62\x64\x61\x2d\x74\x61\x67\x3a\x6c\x65\x74"
  "\x03\x03\x9f\x01\x04\x72\x04\x10\x05\x0b\x62\x6c\x6f\x63\x6b\x2f"
  "\x6d\x61\x6b\x65\x06\xb1\x01\x03\x77\x09\x42\x03\x1a\x08\x31\x04"
  "\x04\x0a\x6d\x61\x6b\x65\x2d\x6c\x69\x73\x74\x06\x1f\x0d\x82\x08"
  "\x34\x81\x9d\x02\x81\x08\x32\x81\x99\x02\x80\x08\x30\x81\xa5\x02"
  "\xff\x07\x2e\x81\xa1\x02\xfe\x07\x2c\x81\xa7\x02\xfd\x07\x2a\x81"
  "\x9d\x02\xfc\x07\x28\x81\xa5\x02\xfb\x07\x26\x81\x99\x02\xfa\x07"
  "\x24\x83\x04\xf9\x07\x22\x82\x02\xf8\x07\x20\x81\xa7\x02\xf7\x07"
  "\x1e\x81\x99\x02\xf6\x07\x1c\x81\x97\x02\xf5\x07\x1a\x81\xa3\x02"
  "\xf4\x07\x18\x81\x99\x02\xf3\x07\x16\x81\x97\x02\xf2\x07\x14\x81"
  "\x85\x02\xf1\x07\x12\x81\x95\x02\xf0\x07\x10\x81\x95\x02\xef\x07"
  "\x0e\x81\x93\x02\xee\x07\x0c\x81\x91\x02\xed\x07\x0a\x81\x91\x02"
  "\xec\x07\x08\x81\x8d\x02\xeb\x07\x06\x81\x8b\x02\xea\x07\x04\x87"
  "\x0c\x33\x5a\xbf\x01\x6c\xb1\x01\xb1\x01\xa6\x01\x96\x01\xbf\x01"
  "\x04\x9a\x01\x04\xac\x01\x04\xc8\x01\x04\xb8\x01\x04\xc6\x01\x04"
  "\xc5\x01\x04\xc2\x01\x04\xc1\x01\x04\xba\x01\x04\x92\x01\x04\x93"
  "\x01\x04\xbd\x01\x04\xbc\x01\x04\xbb\x01\x04\xb9\x01\x04\xb7\x01"
  "\x04\xb5\x01\x04\xb3\x01\x04\x14\x90\x01\x8f\x01\xb6\x01\x8e\x01"
  "\xc4\x01\xc3\x01\x0a\xb4\x01\x0e\x75\x6e\x6c\x69\x6e\x6b\x2d\x6e"
  "\x6f\x64\x65\x73\x21\xc0\x01\x0e\x6c\x69\x6e\x6b\x2d\x32\x2d\x6e"
  "\x6f\x64\x65\x73\x21\x2c\x17\x72\x65\x6d\x6f\x76\x65\x2d\x6e\x6f"
  "\x64\x65\x2d\x6e\x65\x65\x64\x65\x64\x2d\x62\x79\x21\x14\x61\x64"
  "\x64\x2d\x6e\x6f\x64\x65\x2d\x6e\x65\x65\x64\x65\x64\x2d\x62\x79"
  "\x21\x12\x72\x65\x6d\x6f\x76\x65\x2d\x6e\x6f\x64\x65\x2d\x6e\x65"
  "\x65\x64\x21\x0f\x61\x64\x64\x2d\x6e\x6f\x64\x65\x2d\x6e\x65\x65"
  "\x64\x21\x11\x6d\x61\x6b\x65\x2d\x6c\x65\x74\x72\x65\x63\x2d\x6e"
  "\x6f\x64\x65\x0f\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x3e\x6e\x6f"
  "\x64\x65\x0f\x6d\x61\x6b\x65\x2d\x62\x61\x73\x65\x2d\x6e\x6f\x64"
  "\x65\x14\xb2\x01\x11\x73\x65\x74\x2d\x25\x6e\x6f\x64\x65\x2d\x64"
  "\x65\x70\x74\x68\x21\x15\x73\x65\x74\x2d\x25\x6e\x6f\x64\x65\x2d"
  "\x6e\x65\x65\x64\x65\x64\x2d\x62\x79\x21\x11\x73\x65\x74\x2d\x25"
  "\x6e\x6f\x64\x65\x2d\x6e\x65\x65\x64\x73\x21\x10\x73\x65\x74\x2d"
  "\x25\x6e\x6f\x64\x65\x2d\x74\x79\x70\x65\x21\x0c\x25\x6e\x6f\x64"
  "\x65\x2d\x64\x65\x70\x74\x68\xc9\x01\xbe\x01\xc7\x01\x0b\x25\x6e"
  "\x6f\x64\x65\x2d\x74\x79\x70\x65\x0a\xb0\x01\x04\xaf\x01\x04\xae"
  "\x01\x04\xad\x01\x04\xab\x01\x04\xaa\x01\x04\xa9\x01\x04\xa8\x01"
  "\x04\xa7\x01\x04\x0a\x09\x72\x74\x64\x3a\x6e\x6f\x64\x65\xc9\x01"
  "\x05\x6e\x6f\x64\x65\x05\x74\x79\x70\x65\x05\x76\x61\x72\x73\x06"
  "\x6e\x65\x65\x64\x73\x0a\x6e\x65\x65\x64\x65\x64\x2d\x62\x79\x06"
  "\x64\x65\x70\x74\x68\xa1\x01\x04\xa2\x01\x04\xa3\x01\x04\xa4\x01"
  "\x04\xa5\x01\x04\x8b\x01\x9f\x01\x53\x3b\x11\x73\x69\x6e\x67\x6c"
  "\x65\x74\x6f\x6e\x2d\x76\x61\x72\x73\x65\x74\x0d\x65\x6d\x70\x74"
  "\x79\x2d\x76\x61\x72\x73\x65\x74\x12\x73\x69\x6e\x67\x6c\x65\x74"
  "\x6f\x6e\x2d\x6e\x6f\x64\x65\x73\x65\x74\x0e\x65\x6d\x70\x74\x79"
  "\x2d\x6e\x6f\x64\x65\x73\x65\x74\x12\x6e\x6f\x64\x65\x6c\x69\x73"
  "\x74\x2d\x3e\x6e\x6f\x64\x65\x73\x65\x74\x10\x76\x61\x72\x6c\x69"
  "\x73\x74\x2d\x3e\x76\x61\x72\x73\x65\x74\x5a\x30\x38\x7a\x1f\x8d"
  "\x01\x10\xa0\x01\x04\x47\x04\x9e\x01\x04\x9d\x01\x04\x9c\x01\x04"
  "\x9b\x01\x04\x99\x01\x04\x97\x01\x04\x95\x01\x04\x94\x01\x04\x91"
  "\x01\x08\x5d\x04\x62\x04\x54\x04\x10\x0c\x6f\x62\x6a\x65\x63\x74"
  "\x2d\x74\x79\x70\x65\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70"
  "\x65\x3f\x04\x6e\x6f\x74\x40\x06\x6e\x75\x6c\x6c\x3f\x06\x70\x61"
  "\x69\x72\x3f\x06\x7a\x65\x72\x6f\x3f\x0a\x70\x6f\x73\x69\x74\x69"
  "\x76\x65\x3f\x0a\x6e\x65\x67\x61\x74\x69\x76\x65\x3f\x03\x26\x3d"
  "\x03\x26\x3c\x03\x26\x3e\x03\x26\x2b\x03\x26\x2d\x03\x26\x2a\x03"
  "\x26\x2f\x03\x31\x2b\x04\x2d\x31\x2b\x12\x8c\x01\x88\x01\x87\x01"
  "\x29\x27\x23\x1a\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f"
  "\x62\x69\x6e\x64\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x11\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x62\x69\x6e\x64\x09\x58"
  "\x51\x3d\x19\x15\x76\x61\x72\x69\x61\x62\x6c\x65\x2f\x66\x69\x6e"
  "\x61\x6c\x2d\x76\x61\x6c\x75\x65\x1e\x15\x4f\x6f\x13\x8a\x01\x04"
  "\x89\x01\x04\x68\x04\x79\x0a\x86\x01\x04\x7f\x04\x80\x01\x04\x85"
  "\x01\x04\x84\x01\x04\x83\x01\x04\x43\x04\x82\x01\x04\x0e\x55\x6e"
  "\x6b\x6e\x6f\x77\x6e\x20\x56\x61\x6c\x75\x65\x25\x04\x26\x04\x81"
  "\x01\x04\x78\x06\x7e\x04\x13\x06\x64\x65\x6c\x61\x79\x7d\x04\x50"
  "\x7c\x04\x07\x61\x63\x63\x65\x73\x73\x7b\x04\x6c\x75\x72\x2f\x4d"
  "\x04\x76\x04\x6a\x04\x2d\x06\x09\x73\x65\x71\x75\x65\x6e\x63\x65"
  "\x73\x04\x0c\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x71\x04"
  "\x0c\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x5c\x04\x0a\x71"
  "\x75\x6f\x74\x61\x74\x69\x6f\x6e\x70\x04\x10\x74\x68\x65\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x6e\x04\x09\x63\x6f\x6e"
  "\x73\x74\x61\x6e\x74\x0b\x04\x0c\x64\x65\x63\x6c\x61\x72\x61\x74"
  "\x69\x6f\x6e\x64\x04\x14\x5e\x66\x5b\x5f\x60\x55\x52\x56\x1c\x0b"
  "\x6d\x04\x6b\x04\x69\x04\x67\x04\x65\x04\x63\x04\x61\x04\x17\x04"
  "\x59\x04\x57\x04\x0b\x0c\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f"
  "\x6e\x4b\x04\x16\x3e\x39\x49\x04\x48\x04\x0a\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x3f\x04\x33\x0d\x3c\x04\x3a\x04\x0b\x6f\x70\x65"
  "\x6e\x2d\x62\x6c\x6f\x63\x6b\x35\x04\x0c\x4e\x24\x28\x20\x34\x04"
  "\x18\x04\x2e\x04\x2b\x04\x2a\x04\x0a\x72\x65\x66\x65\x72\x65\x6e"
  "\x63\x65\x21\x04\x1d\x18\x64\x65\x66\x69\x6e\x65\x2d\x6d\x65\x74"
  "\x68\x6f\x64\x2f\x69\x6e\x74\x65\x67\x72\x61\x74\x65\xc8\x01\x0b"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x1b\x04\x11\x6c\x6f\x63"
  "\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x12\x0e\x4a"
  "\x14\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f\x74\x6f\x70\x2d\x6c"
  "\x65\x76\x65\x6c\x1e\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2f\x67"
  "\x65\x74\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x62\x6c\x6f"
  "\x63\x6b\x13\x04\x11\x04\x0f\x04\x04\x04\x05\x10\x64\x65\x66\x69"
  "\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x06\x11\x6d\x61\x6b"
  "\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x03\x19\x72"
  "\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61"
  "\x74\x63\x68\x2d\x74\x61\x67\x04\x23\x72\x65\x63\x6f\x72\x64\x2d"
  "\x74\x79\x70\x65\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d\x76\x61\x6c"
  "\x75\x65\x2d\x62\x79\x2d\x69\x6e\x64\x65\x78\x05\x12\x19\x6d\x61"
  "\x6b\x65\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\xc9\x01\x04\x02\x20\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x2f\x6d\x61\x6b\x65\x2d\x64\x69\x73\x70\x61"
  "\x74\x63\x68\x2d\x76\x65\x63\x74\x6f\x72\x03\x1f\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x2f\x6d\x61\x6b\x65\x2d\x6d\x65\x74\x68"
  "\x6f\x64\x2d\x64\x65\x66\x69\x6e\x65\x72\x04\xc8\x01\x04\x10\x05"
  "\x33\x68\x80\x80\x04\x32\x66\x81\x81\x02\x31\x64\x81\x81\x02\x30"
  "\x62\x81\x89\x02\x2f\x60\x81\x85\x02\x2e\x5e\x81\x85\x02\x2d\x5c"
  "\x81\x8d\x02\x2c\x5a\x81\x87\x02\x2b\x58\x81\x85\x02\x2a\x56\x81"
  "\x83\x02\x29\x54\x81\x8b\x02\x28\x52\x81\x87\x02\x27\x50\x81\x87"
  "\x02\x26\x4e\x81\x83\x02\x25\x4c\x81\x85\x02\x24\x4a\x81\x83\x02"
  "\x23\x48\x81\x85\x02\x22\x46\x81\x87\x02\x21\x44\x81\x83\x02\x20"
  "\x42\x81\x83\x02\x1f\x40\x81\x85\x02\x1e\x3e\x81\x83\x02\x1d\x3c"
  "\x81\x89\x02\x1c\x3a\x81\x83\x02\x1b\x38\x81\x83\x02\x1a\x36\x81"
  "\x83\x02\x19\x34\x81\x83\x02\x18\x32\x81\x83\x02\x17\x30\x81\x83"
  "\x02\x16\x2e\x81\x83\x02\x15\x2c\x81\x83\x02\x14\x2a\x81\x83\x02"
  "\x13\x28\x81\x83\x02\x12\x26\x81\x83\x02\x11\x24\x81\x83\x02\x10"
  "\x22\x81\x83\x02\x0f\x20\x81\x83\x02\x0e\x1e\x81\x83\x02\x0d\x1c"
  "\x81\x83\x02\x0c\x1a\x81\x83\x02\x0b\x18\x81\x83\x02\x0a\x16\x81"
  "\x83\x02\x09\x14\x81\x83\x02\x08\x12\x81\x83\x02\x07\x10\x81\x83"
  "\x02\x06\x0e\x81\x85\x02\x05\x0c\x81\x83\x02\x04\x0a\x81\x85\x02"
  "\x03\x08\x81\x87\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x67"
  "\xca\x01";

SCHEME_OBJECT *
subst_so_data_bc41d8446aafe0f2 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_subst_so_data_bc41d8446aafe0f2 [0]))), (sizeof (prog_subst_so_data_bc41d8446aafe0f2)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_64]));
}

DECLARE_COMPILED_DATA_NS ("subst.so", subst_so_data_bc41d8446aafe0f2)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("subst.so", "6ea82385e3295bea")
