/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:41-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define LABEL_1_7 7
#define LABEL_1_9 9
#define LABEL_1_10 11
#define LABEL_1_11 13
#define ENVIRONMENT_LABEL_1_3 26
#define DEBUGGING_LABEL_1_2 25
#define EXECUTE_CACHE_1_13 15
#define EXECUTE_CACHE_1_12 17
#define EXECUTE_CACHE_1_8 19
#define EXECUTE_CACHE_1_6 21
#define FREE_REFERENCE_1_0 24
#define FREE_REFERENCES_LABEL_1_0 14
#define NUMBER_OF_LINKER_SECTIONS_1_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto po_5;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_1_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_1_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_1_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (po_9)
DEFLABEL (po_5)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_1_7);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_1_11);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_1_10);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_13]));

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_9])), (Wrd6.pObj));

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_6 7
#define LABEL_2_8 9
#define LABEL_2_7 11
#define LABEL_2_11 13
#define LABEL_2_13 15
#define LABEL_2_10 17
#define LABEL_2_15 19
#define LABEL_2_14 21
#define LABEL_2_17 23
#define ENVIRONMENT_LABEL_2_3 36
#define DEBUGGING_LABEL_2_2 35
#define OBJECT_2_1 34
#define OBJECT_2_0 33
#define EXECUTE_CACHE_2_16 25
#define EXECUTE_CACHE_2_12 27
#define EXECUTE_CACHE_2_9 29
#define FREE_REFERENCE_2_0 32
#define FREE_REFERENCES_LABEL_2_0 24
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto debug_find_procedure_14;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto label_16;

    case 2:
      current_block = (Rpc - LABEL_2_6);
      goto loop_12;

    case 3:
      current_block = (Rpc - LABEL_2_8);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_2_11);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_2_13);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_2_10);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_2_15);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_2_14);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_2_17);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (debug_find_procedure_23)
DEFLABEL (debug_find_procedure_14)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_26;
  Wrd5 = Wrd9;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_12;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_5])), (Wrd6.pObj));

DEFLABEL (label_16)
  (Wrd5.Obj) = Rvl;
  goto label_25;

DEFLABEL (loop_24)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_2_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_27;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_42;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_41)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_29;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_29)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 1);

DEFLABEL (label_18)
  (Wrd7.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_10]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_40;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_12]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_2_10);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd6.Obj) == Rvl)
    goto label_37;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_36;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_35)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_2_14);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd6.Obj) == Rvl)
    goto label_33;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_32;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_31)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_32)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_17]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 1);

DEFLABEL (label_21)
  (Wrd7.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_33)
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_34;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

DEFLABEL (label_36)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_37)
  (Wrd19.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_38;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  Rvl = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_38)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

DEFLABEL (label_40)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define LABEL_3_9 7
#define LABEL_3_6 9
#define LABEL_3_7 11
#define LABEL_3_12 13
#define LABEL_3_14 15
#define LABEL_3_13 17
#define LABEL_3_16 19
#define LABEL_3_18 21
#define LABEL_3_17 23
#define LABEL_3_20 25
#define ENVIRONMENT_LABEL_3_3 43
#define DEBUGGING_LABEL_3_2 42
#define OBJECT_3_2 41
#define OBJECT_3_1 40
#define OBJECT_3_0 39
#define EXECUTE_CACHE_3_19 27
#define EXECUTE_CACHE_3_15 29
#define EXECUTE_CACHE_3_11 31
#define EXECUTE_CACHE_3_10 33
#define EXECUTE_CACHE_3_8 35
#define FREE_REFERENCE_3_0 38
#define FREE_REFERENCES_LABEL_3_0 26
#define NUMBER_OF_LINKER_SECTIONS_3_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto debug_find_continuation_15;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_3_9);
      goto label_17;

    case 3:
      current_block = (Rpc - LABEL_3_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_3_7);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_3_12);
      goto loop_12;

    case 6:
      current_block = (Rpc - LABEL_3_14);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_3_13);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_3_16);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_3_18);
      goto label_19;

    case 10:
      current_block = (Rpc - LABEL_3_17);
      goto continuation_9;

    case 11:
      current_block = (Rpc - LABEL_3_20);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (debug_find_continuation_23)
DEFLABEL (debug_find_continuation_15)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_3_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_3_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_3_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_3_5);
  (Rsp [0]) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_26;
  Wrd6 = Wrd10;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_12;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_9])), (Wrd7.pObj));

DEFLABEL (label_17)
  (Wrd6.Obj) = Rvl;
  goto label_25;

DEFLABEL (loop_24)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_3_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_27;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_13]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_38;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_37)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_15]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_3_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_33;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_32)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_19]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_3_17);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd6.Obj) == Rvl)
    goto label_30;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_29;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_12;

DEFLABEL (label_29)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_20]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_21)
  (Wrd7.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_31;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 1);

DEFLABEL (label_33)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_18]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (label_34)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_36;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_35)
  (Rsp [0]) = (Wrd19.Obj);
  goto loop_12;

DEFLABEL (label_36)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_20)
  (Wrd19.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_14]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_37;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_8 7
#define LABEL_4_10 9
#define LABEL_4_7 11
#define LABEL_4_11 13
#define LABEL_4_15 15
#define LABEL_4_13 17
#define TAG_4_14 7
#define LABEL_4_17 19
#define ENVIRONMENT_LABEL_4_3 36
#define DEBUGGING_LABEL_4_2 35
#define OBJECT_4_0 34
#define EXECUTE_CACHE_4_18 21
#define EXECUTE_CACHE_4_16 23
#define EXECUTE_CACHE_4_12 25
#define EXECUTE_CACHE_4_9 27
#define EXECUTE_CACHE_4_6 29
#define FREE_REFERENCE_4_1 32
#define FREE_REFERENCE_4_0 33
#define FREE_REFERENCES_LABEL_4_0 20
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto debug_find_entry_node_8;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_4_8);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_4_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_4_7);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_4_11);
      goto label_12;

    case 6:
      current_block = (Rpc - LABEL_4_15);
      goto label_11;

    case 7:
      current_block = (Rpc - LABEL_4_13);
      goto lambda_15;

    case 8:
      current_block = (Rpc - LABEL_4_17);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (debug_find_entry_node_14)
DEFLABEL (debug_find_entry_node_8)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_23;
  Wrd9 = Wrd13;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_4_7);
  (Wrd6.Obj) = (Rsp [0]);
  if (Rvl == (Wrd6.Obj))
    goto label_19;

DEFLABEL (label_18)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_13])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_17;
  Wrd12 = Wrd16;

DEFLABEL (label_16)
  (Rsp [1]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_16]));

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_15])), (Wrd13.pObj));

DEFLABEL (label_11)
  (Wrd12.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_21;
  Wrd21 = Wrd25;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_4_10);
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_11])), (Wrd22.pObj));

DEFLABEL (label_12)
  (Wrd21.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_8])), (Wrd10.pObj));

DEFLABEL (label_10)
  (Wrd9.Obj) = Rvl;
  goto label_22;

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_4_13);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_18]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_4_17);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  if (Rvl == (Wrd8.Obj))
    goto label_24;
  Rvl = (current_block [OBJECT_4_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_12]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define LABEL_5_9 7
#define LABEL_5_7 9
#define LABEL_5_13 11
#define LABEL_5_14 13
#define LABEL_5_15 15
#define LABEL_5_16 17
#define LABEL_5_18 19
#define LABEL_5_19 21
#define LABEL_5_20 23
#define ENVIRONMENT_LABEL_5_3 47
#define DEBUGGING_LABEL_5_2 46
#define OBJECT_5_4 45
#define OBJECT_5_3 44
#define OBJECT_5_2 43
#define OBJECT_5_1 42
#define OBJECT_5_0 41
#define EXECUTE_CACHE_5_22 25
#define EXECUTE_CACHE_5_21 27
#define EXECUTE_CACHE_5_17 29
#define EXECUTE_CACHE_5_12 31
#define EXECUTE_CACHE_5_11 33
#define EXECUTE_CACHE_5_10 35
#define EXECUTE_CACHE_5_8 37
#define EXECUTE_CACHE_5_6 39
#define FREE_REFERENCES_LABEL_5_0 24
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto debug_where_10;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_5_9);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_5_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_5_13);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_5_14);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_5_15);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_5_16);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_5_18);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_5_19);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_5_20);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (debug_where_13)
DEFLABEL (debug_where_10)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_10]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_5_9);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_11]));

DEFLABEL (label_14)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  (Wrd17.Obj) = (current_block [OBJECT_5_0]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_12]));

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_14]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_15]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_5_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_5_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_5_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_5_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_19]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_5_3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_20]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_4]), 1);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_5_20);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_22]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_5_19);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_17]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_5_18);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_21]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define TAG_6_6 1
#define LABEL_6_8 7
#define TAG_6_9 2
#define LABEL_6_11 9
#define ENVIRONMENT_LABEL_6_3 20
#define DEBUGGING_LABEL_6_2 19
#define EXECUTE_CACHE_6_12 11
#define EXECUTE_CACHE_6_10 13
#define EXECUTE_CACHE_6_7 15
#define FREE_REFERENCE_6_0 18
#define FREE_REFERENCES_LABEL_6_0 10
#define NUMBER_OF_LINKER_SECTIONS_6_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto write_rtl_instructions_2;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_6_8);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_6_11);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_rtl_instructions_6)
DEFLABEL (write_rtl_instructions_2)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_6_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_8])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  ((Wrd11.pObj) [2]) = (Wrd14.Obj);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_6_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_10;
  Wrd5 = Wrd9;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_12]));

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_6_11])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define TAG_7_6 1
#define LABEL_7_8 7
#define LABEL_7_9 9
#define LABEL_7_11 11
#define LABEL_7_15 13
#define LABEL_7_14 15
#define LABEL_7_17 17
#define ENVIRONMENT_LABEL_7_3 36
#define DEBUGGING_LABEL_7_2 35
#define OBJECT_7_0 34
#define EXECUTE_CACHE_7_18 19
#define EXECUTE_CACHE_7_16 21
#define EXECUTE_CACHE_7_13 23
#define EXECUTE_CACHE_7_12 25
#define EXECUTE_CACHE_7_10 27
#define EXECUTE_CACHE_7_7 29
#define FREE_REFERENCE_7_1 32
#define FREE_REFERENCE_7_0 33
#define FREE_REFERENCES_LABEL_7_0 18
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto dump_rtl_5;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto lambda_11;

    case 2:
      current_block = (Rpc - LABEL_7_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_7_9);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_7_11);
      goto lambda_3;

    case 5:
      current_block = (Rpc - LABEL_7_15);
      goto label_7;

    case 6:
      current_block = (Rpc - LABEL_7_14);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_7_17);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dump_rtl_10)
DEFLABEL (dump_rtl_5)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_7]));

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_7_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_7_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_11]))));
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_12]));

DEFLABEL (lambda_12)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_7_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_16;
  Wrd8 = Wrd12;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7_14);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_14;
  Wrd5 = Wrd9;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_18]));

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_17])), (Wrd6.pObj));

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_15])), (Wrd9.pObj));

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define LABEL_8_6 7
#define TAG_8_7 2
#define LABEL_8_10 9
#define ENVIRONMENT_LABEL_8_3 20
#define DEBUGGING_LABEL_8_2 19
#define EXECUTE_CACHE_8_11 11
#define EXECUTE_CACHE_8_9 13
#define EXECUTE_CACHE_8_8 15
#define FREE_REFERENCE_8_0 18
#define FREE_REFERENCES_LABEL_8_0 10
#define NUMBER_OF_LINKER_SECTIONS_8_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto show_rtl_2;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_8_6);
      goto lambda_7;

    case 3:
      current_block = (Rpc - LABEL_8_10);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (show_rtl_6)
DEFLABEL (show_rtl_2)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_6])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_8_5);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_9]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_8_6);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_11]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8_10])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_6 7
#define TAG_9_7 2
#define LABEL_9_10 9
#define LABEL_9_12 11
#define LABEL_9_14 13
#define ENVIRONMENT_LABEL_9_3 28
#define DEBUGGING_LABEL_9_2 27
#define EXECUTE_CACHE_9_16 15
#define EXECUTE_CACHE_9_15 17
#define EXECUTE_CACHE_9_13 19
#define EXECUTE_CACHE_9_11 21
#define EXECUTE_CACHE_9_9 23
#define EXECUTE_CACHE_9_8 25
#define FREE_REFERENCES_LABEL_9_0 14
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto show_bblock_rtl_5;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_9_6);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_9_10);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_9_12);
      goto lambda_2;

    case 5:
      current_block = (Rpc - LABEL_9_14);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (show_bblock_rtl_8)
DEFLABEL (show_bblock_rtl_5)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_6])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9_5);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_9]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_9_6);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_13]));

DEFLABEL (lambda_10)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_9_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_15]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_14);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_16]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_6 7
#define TAG_10_7 2
#define LABEL_10_13 9
#define LABEL_10_14 11
#define LABEL_10_15 13
#define LABEL_10_16 15
#define LABEL_10_17 17
#define LABEL_10_18 19
#define LABEL_10_8 21
#define TAG_10_9 9
#define LABEL_10_10 23
#define TAG_10_11 10
#define LABEL_10_19 25
#define LABEL_10_20 27
#define LABEL_10_21 29
#define LABEL_10_22 31
#define LABEL_10_23 33
#define LABEL_10_24 35
#define ENVIRONMENT_LABEL_10_3 52
#define DEBUGGING_LABEL_10_2 51
#define OBJECT_10_2 50
#define OBJECT_10_1 49
#define OBJECT_10_0 48
#define EXECUTE_CACHE_10_12 37
#define FREE_REFERENCE_10_3 40
#define FREE_REFERENCE_10_2 41
#define FREE_REFERENCE_10_1 42
#define FREE_REFERENCE_10_0 43
#define FREE_ASSIGNMENT_10_2 45
#define FREE_ASSIGNMENT_10_1 46
#define FREE_ASSIGNMENT_10_0 47
#define FREE_REFERENCES_LABEL_10_0 36
#define NUMBER_OF_LINKER_SECTIONS_10_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd73;
  machine_word Wrd61;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto write_instructions_40;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto label_42;

    case 2:
      current_block = (Rpc - LABEL_10_6);
      goto lambda_57;

    case 3:
      current_block = (Rpc - LABEL_10_13);
      goto label_43;

    case 4:
      current_block = (Rpc - LABEL_10_14);
      goto label_44;

    case 5:
      current_block = (Rpc - LABEL_10_15);
      goto label_45;

    case 6:
      current_block = (Rpc - LABEL_10_16);
      goto label_46;

    case 7:
      current_block = (Rpc - LABEL_10_17);
      goto label_47;

    case 8:
      current_block = (Rpc - LABEL_10_18);
      goto label_48;

    case 9:
      current_block = (Rpc - LABEL_10_8);
      goto lambda_58;

    case 10:
      current_block = (Rpc - LABEL_10_10);
      goto lambda_59;

    case 11:
      current_block = (Rpc - LABEL_10_19);
      goto label_49;

    case 12:
      current_block = (Rpc - LABEL_10_20);
      goto label_50;

    case 13:
      current_block = (Rpc - LABEL_10_21);
      goto label_51;

    case 14:
      current_block = (Rpc - LABEL_10_22);
      goto label_52;

    case 15:
      current_block = (Rpc - LABEL_10_23);
      goto label_53;

    case 16:
      current_block = (Rpc - LABEL_10_24);
      goto label_54;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_instructions_56)
DEFLABEL (write_instructions_40)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_10_0]);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_10_1]);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd28.pObj) = (& (Rhp [-1]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_0]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_61;
  Wrd31 = Wrd35;

DEFLABEL (label_60)
  (* (Rhp++)) = (Wrd31.Obj);
  (Wrd38.pObj) = (& (Rhp [-1]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_6])));
  Rhp += 6;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  Wrd53 = Wrd42;
  (Wrd54.Obj) = (Rsp [5]);
  ((Wrd53.pObj) [2]) = (Wrd54.Obj);
  (Wrd52.Obj) = (Rsp [4]);
  ((Wrd53.pObj) [3]) = (Wrd52.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  ((Wrd53.pObj) [4]) = (Wrd50.Obj);
  (Wrd48.Obj) = (Rsp [2]);
  ((Wrd53.pObj) [5]) = (Wrd48.Obj);
  (Wrd46.Obj) = (Rsp [1]);
  ((Wrd53.pObj) [6]) = (Wrd46.Obj);
  ((Wrd53.pObj) [7]) = (Wrd39.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd57.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_8])));
  Rhp += 1;
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd57.pObj)));
  Wrd58 = Wrd57;
  (Wrd59.Obj) = (Rsp [6]);
  ((Wrd58.pObj) [2]) = (Wrd59.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd62.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_10])));
  Rhp += 6;
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd62.pObj)));
  Wrd73 = Wrd62;
  ((Wrd73.pObj) [2]) = (Wrd54.Obj);
  ((Wrd73.pObj) [3]) = (Wrd52.Obj);
  ((Wrd73.pObj) [4]) = (Wrd50.Obj);
  ((Wrd73.pObj) [5]) = (Wrd48.Obj);
  ((Wrd73.pObj) [6]) = (Wrd46.Obj);
  ((Wrd73.pObj) [7]) = (Wrd39.Obj);
  (Rsp [6]) = (Wrd61.Obj);
  (Rsp [5]) = (Wrd56.Obj);
  (Rsp [4]) = (Wrd41.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_12]));

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10_5])), (Wrd32.pObj));

DEFLABEL (label_42)
  (Wrd31.Obj) = Rvl;
  goto label_60;

DEFLABEL (lambda_57)
  CLOSURE_HEADER (LABEL_10_6);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_79;

DEFLABEL (label_78)
  Wrd19 = Wrd23;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_76;

DEFLABEL (label_75)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_74)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [4]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [6]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_73;

DEFLABEL (label_72)
  Wrd63 = Wrd67;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_70;

DEFLABEL (label_69)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_68)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [3]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [5]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_3]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_67;

DEFLABEL (label_66)
  Wrd107 = Wrd111;

DEFLABEL (label_65)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_64;

DEFLABEL (label_63)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_62)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [2]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  Rvl = (current_block [OBJECT_10_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_64)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_63;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_18])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_48)
  goto label_62;

DEFLABEL (label_67)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_66;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_17])), (Wrd108.pObj));

DEFLABEL (label_47)
  (Wrd107.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_70)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_69;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_16])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_46)
  goto label_68;

DEFLABEL (label_73)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_72;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_15])), (Wrd64.pObj));

DEFLABEL (label_45)
  (Wrd63.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_76)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_75;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_14])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_44)
  goto label_74;

DEFLABEL (label_79)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_78;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_13])), (Wrd20.pObj));

DEFLABEL (label_43)
  (Wrd19.Obj) = Rvl;
  goto label_77;

DEFLABEL (lambda_58)
  CLOSURE_HEADER (LABEL_10_8);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_59)
  CLOSURE_HEADER (LABEL_10_10);

DEFLABEL (lambda_38)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_97;

DEFLABEL (label_96)
  Wrd19 = Wrd23;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_94;

DEFLABEL (label_93)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_92)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [7]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [3]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_91;

DEFLABEL (label_90)
  Wrd63 = Wrd67;

DEFLABEL (label_89)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_88;

DEFLABEL (label_87)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_86)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [6]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [2]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_3]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_85;

DEFLABEL (label_84)
  Wrd107 = Wrd111;

DEFLABEL (label_83)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_82;

DEFLABEL (label_81)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_80)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [5]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  Rvl = (current_block [OBJECT_10_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_82)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_81;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_24])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_54)
  goto label_80;

DEFLABEL (label_85)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_84;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_23])), (Wrd108.pObj));

DEFLABEL (label_53)
  (Wrd107.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_88)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_87;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_22])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_52)
  goto label_86;

DEFLABEL (label_91)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_90;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_21])), (Wrd64.pObj));

DEFLABEL (label_51)
  (Wrd63.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_94)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_93;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_20])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_50)
  goto label_92;

DEFLABEL (label_97)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_96;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_10_19])), (Wrd20.pObj));

DEFLABEL (label_49)
  (Wrd19.Obj) = Rvl;
  goto label_95;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_6 7
#define TAG_11_7 2
#define LABEL_11_13 9
#define LABEL_11_14 11
#define LABEL_11_15 13
#define LABEL_11_16 15
#define LABEL_11_17 17
#define LABEL_11_18 19
#define LABEL_11_19 21
#define LABEL_11_20 23
#define LABEL_11_8 25
#define TAG_11_9 11
#define LABEL_11_10 27
#define TAG_11_11 12
#define LABEL_11_21 29
#define LABEL_11_22 31
#define LABEL_11_23 33
#define LABEL_11_24 35
#define LABEL_11_25 37
#define LABEL_11_26 39
#define LABEL_11_27 41
#define LABEL_11_28 43
#define ENVIRONMENT_LABEL_11_3 62
#define DEBUGGING_LABEL_11_2 61
#define OBJECT_11_2 60
#define OBJECT_11_1 59
#define OBJECT_11_0 58
#define EXECUTE_CACHE_11_12 45
#define FREE_REFERENCE_11_4 48
#define FREE_REFERENCE_11_3 49
#define FREE_REFERENCE_11_2 50
#define FREE_REFERENCE_11_1 51
#define FREE_REFERENCE_11_0 52
#define FREE_ASSIGNMENT_11_3 54
#define FREE_ASSIGNMENT_11_2 55
#define FREE_ASSIGNMENT_11_1 56
#define FREE_ASSIGNMENT_11_0 57
#define FREE_REFERENCES_LABEL_11_0 44
#define NUMBER_OF_LINKER_SECTIONS_11_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd151;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd63;
  machine_word Wrd53;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd91;
  machine_word Wrd75;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd70;
  machine_word Wrd71;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd41;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto pp_instructions_52;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto label_54;

    case 2:
      current_block = (Rpc - LABEL_11_6);
      goto lambda_73;

    case 3:
      current_block = (Rpc - LABEL_11_13);
      goto label_55;

    case 4:
      current_block = (Rpc - LABEL_11_14);
      goto label_56;

    case 5:
      current_block = (Rpc - LABEL_11_15);
      goto label_57;

    case 6:
      current_block = (Rpc - LABEL_11_16);
      goto label_58;

    case 7:
      current_block = (Rpc - LABEL_11_17);
      goto label_59;

    case 8:
      current_block = (Rpc - LABEL_11_18);
      goto label_60;

    case 9:
      current_block = (Rpc - LABEL_11_19);
      goto label_61;

    case 10:
      current_block = (Rpc - LABEL_11_20);
      goto label_62;

    case 11:
      current_block = (Rpc - LABEL_11_8);
      goto lambda_74;

    case 12:
      current_block = (Rpc - LABEL_11_10);
      goto lambda_75;

    case 13:
      current_block = (Rpc - LABEL_11_21);
      goto label_63;

    case 14:
      current_block = (Rpc - LABEL_11_22);
      goto label_64;

    case 15:
      current_block = (Rpc - LABEL_11_23);
      goto label_65;

    case 16:
      current_block = (Rpc - LABEL_11_24);
      goto label_66;

    case 17:
      current_block = (Rpc - LABEL_11_25);
      goto label_67;

    case 18:
      current_block = (Rpc - LABEL_11_26);
      goto label_68;

    case 19:
      current_block = (Rpc - LABEL_11_27);
      goto label_69;

    case 20:
      current_block = (Rpc - LABEL_11_28);
      goto label_70;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (pp_instructions_72)
DEFLABEL (pp_instructions_52)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_11_0]);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd30.pObj) = (& (Rhp [-1]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_11_1]);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd34.pObj) = (& (Rhp [-1]));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd34.pObj)));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd38.pObj) = (& (Rhp [-1]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd45.Obj) = ((Wrd42.pObj) [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if ((Wrd46.uLng) == 50)
    goto label_77;
  Wrd41 = Wrd45;

DEFLABEL (label_76)
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd48.pObj) = (& (Rhp [-1]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd52.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_6])));
  Rhp += 8;
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd52.pObj)));
  Wrd67 = Wrd52;
  (Wrd68.Obj) = (Rsp [7]);
  ((Wrd67.pObj) [2]) = (Wrd68.Obj);
  (Wrd66.Obj) = (Rsp [6]);
  ((Wrd67.pObj) [3]) = (Wrd66.Obj);
  (Wrd64.Obj) = (Rsp [5]);
  ((Wrd67.pObj) [4]) = (Wrd64.Obj);
  (Wrd62.Obj) = (Rsp [4]);
  ((Wrd67.pObj) [5]) = (Wrd62.Obj);
  (Wrd60.Obj) = (Rsp [3]);
  ((Wrd67.pObj) [6]) = (Wrd60.Obj);
  (Wrd58.Obj) = (Rsp [2]);
  ((Wrd67.pObj) [7]) = (Wrd58.Obj);
  (Wrd56.Obj) = (Rsp [1]);
  ((Wrd67.pObj) [8]) = (Wrd56.Obj);
  ((Wrd67.pObj) [9]) = (Wrd49.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd71.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_8])));
  Rhp += 1;
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd71.pObj)));
  Wrd72 = Wrd71;
  (Wrd73.Obj) = (Rsp [8]);
  ((Wrd72.pObj) [2]) = (Wrd73.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd76.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_10])));
  Rhp += 8;
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd76.pObj)));
  Wrd91 = Wrd76;
  ((Wrd91.pObj) [2]) = (Wrd68.Obj);
  ((Wrd91.pObj) [3]) = (Wrd66.Obj);
  ((Wrd91.pObj) [4]) = (Wrd64.Obj);
  ((Wrd91.pObj) [5]) = (Wrd62.Obj);
  ((Wrd91.pObj) [6]) = (Wrd60.Obj);
  ((Wrd91.pObj) [7]) = (Wrd58.Obj);
  ((Wrd91.pObj) [8]) = (Wrd56.Obj);
  ((Wrd91.pObj) [9]) = (Wrd49.Obj);
  (Rsp [8]) = (Wrd75.Obj);
  (Rsp [7]) = (Wrd70.Obj);
  (Rsp [6]) = (Wrd51.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_12]));

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_5])), (Wrd42.pObj));

DEFLABEL (label_54)
  (Wrd41.Obj) = Rvl;
  goto label_76;

DEFLABEL (lambda_73)
  CLOSURE_HEADER (LABEL_11_6);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [9]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_101;

DEFLABEL (label_100)
  Wrd19 = Wrd23;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_98;

DEFLABEL (label_97)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_96)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [8]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_95;

DEFLABEL (label_94)
  Wrd63 = Wrd67;

DEFLABEL (label_93)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_92;

DEFLABEL (label_91)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_90)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [7]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_3]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_89;

DEFLABEL (label_88)
  Wrd107 = Wrd111;

DEFLABEL (label_87)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_86;

DEFLABEL (label_85)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_84)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [3]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [6]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_4]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_83;

DEFLABEL (label_82)
  Wrd151 = Wrd155;

DEFLABEL (label_81)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_80;

DEFLABEL (label_79)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_78)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [2]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_11_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_80)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_79;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_20])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_62)
  goto label_78;

DEFLABEL (label_83)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_82;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_19])), (Wrd152.pObj));

DEFLABEL (label_61)
  (Wrd151.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_86)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_85;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_18])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_60)
  goto label_84;

DEFLABEL (label_89)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_88;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_17])), (Wrd108.pObj));

DEFLABEL (label_59)
  (Wrd107.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_92)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_91;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_16])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_58)
  goto label_90;

DEFLABEL (label_95)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_94;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_15])), (Wrd64.pObj));

DEFLABEL (label_57)
  (Wrd63.Obj) = Rvl;
  goto label_93;

DEFLABEL (label_98)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_97;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_14])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_56)
  goto label_96;

DEFLABEL (label_101)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_100;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_13])), (Wrd20.pObj));

DEFLABEL (label_55)
  (Wrd19.Obj) = Rvl;
  goto label_99;

DEFLABEL (lambda_74)
  CLOSURE_HEADER (LABEL_11_8);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_75)
  CLOSURE_HEADER (LABEL_11_10);

DEFLABEL (lambda_50)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_125;

DEFLABEL (label_124)
  Wrd19 = Wrd23;

DEFLABEL (label_123)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_122;

DEFLABEL (label_121)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_120)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [9]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_2]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_119;

DEFLABEL (label_118)
  Wrd63 = Wrd67;

DEFLABEL (label_117)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_116;

DEFLABEL (label_115)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_114)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [8]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [3]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_3]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_113;

DEFLABEL (label_112)
  Wrd107 = Wrd111;

DEFLABEL (label_111)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_110;

DEFLABEL (label_109)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_108)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [7]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [2]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_4]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_107;

DEFLABEL (label_106)
  Wrd151 = Wrd155;

DEFLABEL (label_105)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_104;

DEFLABEL (label_103)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_102)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [6]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_11_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_104)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_103;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_28])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_70)
  goto label_102;

DEFLABEL (label_107)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_106;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_27])), (Wrd152.pObj));

DEFLABEL (label_69)
  (Wrd151.Obj) = Rvl;
  goto label_105;

DEFLABEL (label_110)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_109;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_26])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_68)
  goto label_108;

DEFLABEL (label_113)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_112;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_25])), (Wrd108.pObj));

DEFLABEL (label_67)
  (Wrd107.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_116)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_115;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_24])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_66)
  goto label_114;

DEFLABEL (label_119)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_118;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_23])), (Wrd64.pObj));

DEFLABEL (label_65)
  (Wrd63.Obj) = Rvl;
  goto label_117;

DEFLABEL (label_122)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_121;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_22])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_64)
  goto label_120;

DEFLABEL (label_125)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_124;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_11_21])), (Wrd20.pObj));

DEFLABEL (label_63)
  (Wrd19.Obj) = Rvl;
  goto label_123;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_6 5
#define LABEL_12_8 7
#define LABEL_12_5 9
#define LABEL_12_9 11
#define ENVIRONMENT_LABEL_12_3 22
#define DEBUGGING_LABEL_12_2 21
#define OBJECT_12_1 20
#define OBJECT_12_0 19
#define EXECUTE_CACHE_12_11 13
#define EXECUTE_CACHE_12_10 15
#define EXECUTE_CACHE_12_7 17
#define FREE_REFERENCES_LABEL_12_0 12
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto show_rtl_instruction_4;

    case 1:
      current_block = (Rpc - LABEL_12_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_12_8);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_12_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (show_rtl_instruction_8)
DEFLABEL (show_rtl_instruction_4)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_12_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_11;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_10)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_12_8);

DEFLABEL (label_9)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_12_9);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_11]));

DEFLABEL (label_11)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_7 7
#define TAG_13_8 2
#define LABEL_13_13 9
#define LABEL_13_14 11
#define LABEL_13_15 13
#define LABEL_13_16 15
#define LABEL_13_9 17
#define TAG_13_10 7
#define LABEL_13_17 19
#define LABEL_13_18 21
#define LABEL_13_19 23
#define LABEL_13_20 25
#define LABEL_13_11 27
#define LABEL_13_21 29
#define LABEL_13_23 31
#define LABEL_13_26 33
#define LABEL_13_25 35
#define LABEL_13_28 37
#define LABEL_13_29 39
#define LABEL_13_34 41
#define LABEL_13_31 43
#define LABEL_13_32 45
#define LABEL_13_38 47
#define LABEL_13_33 49
#define LABEL_13_36 51
#define LABEL_13_37 53
#define LABEL_13_41 55
#define LABEL_13_44 57
#define LABEL_13_42 59
#define LABEL_13_43 61
#define LABEL_13_46 63
#define LABEL_13_49 65
#define LABEL_13_50 67
#define LABEL_13_51 69
#define LABEL_13_52 71
#define ENVIRONMENT_LABEL_13_3 113
#define DEBUGGING_LABEL_13_2 112
#define OBJECT_13_5 111
#define OBJECT_13_4 110
#define OBJECT_13_3 109
#define OBJECT_13_2 108
#define OBJECT_13_1 107
#define OBJECT_13_0 106
#define EXECUTE_CACHE_13_53 73
#define EXECUTE_CACHE_13_48 75
#define EXECUTE_CACHE_13_47 77
#define EXECUTE_CACHE_13_45 79
#define EXECUTE_CACHE_13_40 81
#define EXECUTE_CACHE_13_39 83
#define EXECUTE_CACHE_13_35 85
#define EXECUTE_CACHE_13_30 87
#define EXECUTE_CACHE_13_27 89
#define EXECUTE_CACHE_13_24 91
#define EXECUTE_CACHE_13_22 93
#define EXECUTE_CACHE_13_12 95
#define EXECUTE_CACHE_13_6 97
#define FREE_REFERENCE_13_2 100
#define FREE_REFERENCE_13_1 101
#define FREE_REFERENCE_13_0 102
#define FREE_ASSIGNMENT_13_1 104
#define FREE_ASSIGNMENT_13_0 105
#define FREE_REFERENCES_LABEL_13_0 72
#define NUMBER_OF_LINKER_SECTIONS_13_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto show_fg_47;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_13_7);
      goto lambda_63;

    case 3:
      current_block = (Rpc - LABEL_13_13);
      goto label_49;

    case 4:
      current_block = (Rpc - LABEL_13_14);
      goto label_50;

    case 5:
      current_block = (Rpc - LABEL_13_15);
      goto label_51;

    case 6:
      current_block = (Rpc - LABEL_13_16);
      goto label_52;

    case 7:
      current_block = (Rpc - LABEL_13_9);
      goto lambda_64;

    case 8:
      current_block = (Rpc - LABEL_13_17);
      goto label_53;

    case 9:
      current_block = (Rpc - LABEL_13_18);
      goto label_54;

    case 10:
      current_block = (Rpc - LABEL_13_19);
      goto label_55;

    case 11:
      current_block = (Rpc - LABEL_13_20);
      goto label_56;

    case 12:
      current_block = (Rpc - LABEL_13_11);
      goto lambda_32;

    case 13:
      current_block = (Rpc - LABEL_13_21);
      goto continuation_14;

    case 14:
      current_block = (Rpc - LABEL_13_23);
      goto continuation_15;

    case 15:
      current_block = (Rpc - LABEL_13_26);
      goto label_57;

    case 16:
      current_block = (Rpc - LABEL_13_25);
      goto continuation_16;

    case 17:
      current_block = (Rpc - LABEL_13_28);
      goto continuation_27;

    case 18:
      current_block = (Rpc - LABEL_13_29);
      goto lambda_26;

    case 19:
      current_block = (Rpc - LABEL_13_34);
      goto label_58;

    case 20:
      current_block = (Rpc - LABEL_13_31);
      goto continuation_28;

    case 21:
      current_block = (Rpc - LABEL_13_32);
      goto continuation_18;

    case 22:
      current_block = (Rpc - LABEL_13_38);
      goto label_59;

    case 23:
      current_block = (Rpc - LABEL_13_33);
      goto continuation_17;

    case 24:
      current_block = (Rpc - LABEL_13_36);
      goto continuation_29;

    case 25:
      current_block = (Rpc - LABEL_13_37);
      goto lambda_25;

    case 26:
      current_block = (Rpc - LABEL_13_41);
      goto continuation_30;

    case 27:
      current_block = (Rpc - LABEL_13_44);
      goto label_60;

    case 28:
      current_block = (Rpc - LABEL_13_42);
      goto continuation_19;

    case 29:
      current_block = (Rpc - LABEL_13_43);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_13_46);
      goto continuation_20;

    case 31:
      current_block = (Rpc - LABEL_13_49);
      goto continuation_21;

    case 32:
      current_block = (Rpc - LABEL_13_50);
      goto continuation_22;

    case 33:
      current_block = (Rpc - LABEL_13_51);
      goto continuation_23;

    case 34:
      current_block = (Rpc - LABEL_13_52);
      goto continuation_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (show_fg_62)
DEFLABEL (show_fg_47)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_13_0]);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = Rvl;
  (Wrd31.pObj) = (& (Rhp [-1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd31.pObj)));
  (Rsp [0]) = (Wrd32.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_7])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = (Wrd32.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_9])));
  Rhp += 4;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd25 = Wrd18;
  ((Wrd25.pObj) [2]) = (Wrd15.Obj);
  ((Wrd25.pObj) [3]) = (Wrd13.Obj);
  ((Wrd25.pObj) [4]) = (Wrd11.Obj);
  ((Wrd25.pObj) [5]) = (Wrd32.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_11]))));
  (Rsp [2]) = (Wrd27.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_12]));

DEFLABEL (lambda_63)
  CLOSURE_HEADER (LABEL_13_7);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_79;

DEFLABEL (label_78)
  Wrd19 = Wrd23;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_76;

DEFLABEL (label_75)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_74)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_73;

DEFLABEL (label_72)
  Wrd63 = Wrd67;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_70;

DEFLABEL (label_69)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_68)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [2]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_13_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_70)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_69;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_16])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_52)
  goto label_68;

DEFLABEL (label_73)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_72;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_13_15])), (Wrd64.pObj));

DEFLABEL (label_51)
  (Wrd63.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_76)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_75;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_14])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_50)
  goto label_74;

DEFLABEL (label_79)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_78;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_13_13])), (Wrd20.pObj));

DEFLABEL (label_49)
  (Wrd19.Obj) = Rvl;
  goto label_77;

DEFLABEL (lambda_64)
  CLOSURE_HEADER (LABEL_13_9);

DEFLABEL (lambda_45)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_91;

DEFLABEL (label_90)
  Wrd19 = Wrd23;

DEFLABEL (label_89)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_88;

DEFLABEL (label_87)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_86)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_85;

DEFLABEL (label_84)
  Wrd63 = Wrd67;

DEFLABEL (label_83)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_82;

DEFLABEL (label_81)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_80)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  Rvl = (current_block [OBJECT_13_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_82)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_81;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_20])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_56)
  goto label_80;

DEFLABEL (label_85)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_84;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_13_19])), (Wrd64.pObj));

DEFLABEL (label_55)
  (Wrd63.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_88)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_87;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_54)
  goto label_86;

DEFLABEL (label_91)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_90;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_13_17])), (Wrd20.pObj));

DEFLABEL (label_53)
  (Wrd19.Obj) = Rvl;
  goto label_89;

DEFLABEL (lambda_65)
DEFLABEL (lambda_32)
  INTERRUPT_CHECK (26, LABEL_13_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_22]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_13_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_24]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_13_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_2]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_95;
  Wrd8 = Wrd12;

DEFLABEL (label_94)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_27]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_13_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_30]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_13_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_24]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_13_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_22]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_13_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_24]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_13_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_2]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_93;
  Wrd8 = Wrd12;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_45]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_13_43);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_48]));

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_44])), (Wrd9.pObj));

DEFLABEL (label_60)
  (Wrd8.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_26])), (Wrd9.pObj));

DEFLABEL (label_57)
  (Wrd8.Obj) = Rvl;
  goto label_94;

DEFLABEL (lambda_66)
DEFLABEL (lambda_26)
  INTERRUPT_CHECK (26, LABEL_13_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_33]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_99;
  Wrd11 = Wrd15;

DEFLABEL (label_98)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_35]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_13_33);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_40]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_13_32);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_37]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_97;
  Wrd7 = Wrd11;

DEFLABEL (label_96)
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_39]));

DEFLABEL (label_97)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_38])), (Wrd8.pObj));

DEFLABEL (label_59)
  (Wrd7.Obj) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_34])), (Wrd12.pObj));

DEFLABEL (label_58)
  (Wrd11.Obj) = Rvl;
  goto label_98;

DEFLABEL (lambda_67)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_13_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_24]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_13_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_47]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_13_46);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_100;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_49]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_13_5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_22]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_13_49);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_24]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_13_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_27]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_13_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_52]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_53]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_13_52);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_40]));

DEFLABEL (label_100)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_49]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_13_4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_22]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define TAG_14_6 1
#define LABEL_14_12 7
#define LABEL_14_13 9
#define LABEL_14_7 11
#define TAG_14_8 4
#define LABEL_14_9 13
#define TAG_14_10 5
#define LABEL_14_17 15
#define LABEL_14_18 17
#define LABEL_14_14 19
#define TAG_14_15 8
#define LABEL_14_22 21
#define LABEL_14_19 23
#define LABEL_14_20 25
#define ENVIRONMENT_LABEL_14_3 45
#define DEBUGGING_LABEL_14_2 44
#define OBJECT_14_0 43
#define EXECUTE_CACHE_14_25 27
#define EXECUTE_CACHE_14_24 29
#define EXECUTE_CACHE_14_23 31
#define EXECUTE_CACHE_14_21 33
#define EXECUTE_CACHE_14_16 35
#define EXECUTE_CACHE_14_11 37
#define FREE_REFERENCE_14_0 40
#define FREE_ASSIGNMENT_14_0 42
#define FREE_REFERENCES_LABEL_14_0 26
#define NUMBER_OF_LINKER_SECTIONS_14_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto show_fg_node_21;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto lambda_29;

    case 2:
      current_block = (Rpc - LABEL_14_12);
      goto label_23;

    case 3:
      current_block = (Rpc - LABEL_14_13);
      goto label_24;

    case 4:
      current_block = (Rpc - LABEL_14_7);
      goto lambda_30;

    case 5:
      current_block = (Rpc - LABEL_14_9);
      goto lambda_31;

    case 6:
      current_block = (Rpc - LABEL_14_17);
      goto label_25;

    case 7:
      current_block = (Rpc - LABEL_14_18);
      goto label_26;

    case 8:
      current_block = (Rpc - LABEL_14_14);
      goto lambda_32;

    case 9:
      current_block = (Rpc - LABEL_14_22);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_14_19);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_14_20);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (show_fg_node_28)
DEFLABEL (show_fg_node_21)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_5])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  ((Wrd20.pObj) [2]) = (Wrd7.Obj);
  ((Wrd20.pObj) [3]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_7])));
  Rhp += 1;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd25 = Wrd24;
  (Wrd26.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_9])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  ((Wrd32.pObj) [2]) = (Wrd7.Obj);
  ((Wrd32.pObj) [3]) = (Wrd13.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  (Rsp [1]) = (Wrd23.Obj);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_11]));

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_14_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_38;

DEFLABEL (label_37)
  Wrd19 = Wrd23;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_35;

DEFLABEL (label_34)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_33)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_35)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_34;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_13])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_24)
  goto label_33;

DEFLABEL (label_38)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_37;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_12])), (Wrd20.pObj));

DEFLABEL (label_23)
  (Wrd19.Obj) = Rvl;
  goto label_36;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_14_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_14])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  ((Wrd8.pObj) [2]) = (Wrd11.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_16]));

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_14_9);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_44;

DEFLABEL (label_43)
  Wrd19 = Wrd23;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_14_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_41;

DEFLABEL (label_40)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_39)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_14_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_41)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_40;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_14_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_26)
  goto label_39;

DEFLABEL (label_44)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_43;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_14_17])), (Wrd20.pObj));

DEFLABEL (label_25)
  (Wrd19.Obj) = Rvl;
  goto label_42;

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_14_14);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_20]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_14_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_25]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_14_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_23]));

DEFLABEL (label_45)
  (Wrd5.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_46)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_24]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_14_19);
  (Wrd5.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 9
#define DEBUGGING_LABEL_15_2 8
#define OBJECT_15_0 7
#define EXECUTE_CACHE_15_5 5
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto fg_print_entry_node_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_entry_node_3)
DEFLABEL (fg_print_entry_node_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_4;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_5]));

DEFLABEL (label_4)
  Rvl = (current_block [OBJECT_15_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define ENVIRONMENT_LABEL_16_3 12
#define DEBUGGING_LABEL_16_2 11
#define EXECUTE_CACHE_16_7 7
#define EXECUTE_CACHE_16_6 9
#define FREE_REFERENCES_LABEL_16_0 6
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto fg_print_object_1;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_object_4)
DEFLABEL (fg_print_object_1)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define LABEL_17_7 7
#define LABEL_17_8 9
#define LABEL_17_12 11
#define LABEL_17_14 13
#define LABEL_17_10 15
#define LABEL_17_17 17
#define LABEL_17_20 19
#define LABEL_17_18 21
#define LABEL_17_23 23
#define LABEL_17_15 25
#define LABEL_17_24 27
#define LABEL_17_21 29
#define ENVIRONMENT_LABEL_17_3 49
#define DEBUGGING_LABEL_17_2 48
#define EXECUTE_CACHE_17_22 31
#define EXECUTE_CACHE_17_19 33
#define EXECUTE_CACHE_17_16 35
#define EXECUTE_CACHE_17_13 37
#define EXECUTE_CACHE_17_11 39
#define EXECUTE_CACHE_17_9 41
#define EXECUTE_CACHE_17_6 43
#define FREE_REFERENCE_17_1 46
#define FREE_REFERENCE_17_0 47
#define FREE_REFERENCES_LABEL_17_0 30
#define NUMBER_OF_LINKER_SECTIONS_17_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto fg_print_blocks_9;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_17_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_17_12);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_17_14);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_17_10);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_17_17);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_17_20);
      goto label_12;

    case 9:
      current_block = (Rpc - LABEL_17_18);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_17_23);
      goto label_13;

    case 11:
      current_block = (Rpc - LABEL_17_15);
      goto continuation_4;

    case 12:
      current_block = (Rpc - LABEL_17_24);
      goto label_14;

    case 13:
      current_block = (Rpc - LABEL_17_21);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_blocks_16)
DEFLABEL (fg_print_blocks_9)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_17_8);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_26;
  Wrd5 = Wrd9;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_17_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_17_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_22;

DEFLABEL (label_21)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_18]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_19]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_17_18);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_20;
  Wrd5 = Wrd9;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_17_17);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_18;
  Wrd5 = Wrd9;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_22]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17_21);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_13]));

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_20])), (Wrd6.pObj));

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_23])), (Wrd6.pObj));

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_15]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_16]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_17_15);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_24;
  Wrd5 = Wrd9;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_17_14);
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_24])), (Wrd6.pObj));

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_12])), (Wrd6.pObj));

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_7 7
#define LABEL_18_9 9
#define LABEL_18_11 11
#define LABEL_18_13 13
#define LABEL_18_17 15
#define LABEL_18_21 17
#define LABEL_18_25 19
#define LABEL_18_29 21
#define LABEL_18_33 23
#define LABEL_18_37 25
#define LABEL_18_41 27
#define LABEL_18_43 29
#define LABEL_18_44 31
#define LABEL_18_42 33
#define LABEL_18_38 35
#define LABEL_18_39 37
#define LABEL_18_34 39
#define LABEL_18_35 41
#define LABEL_18_30 43
#define LABEL_18_31 45
#define LABEL_18_26 47
#define LABEL_18_27 49
#define LABEL_18_22 51
#define LABEL_18_23 53
#define LABEL_18_18 55
#define LABEL_18_56 57
#define LABEL_18_19 59
#define LABEL_18_14 61
#define LABEL_18_15 63
#define LABEL_18_60 65
#define LABEL_18_48 67
#define LABEL_18_49 69
#define LABEL_18_52 71
#define LABEL_18_53 73
#define LABEL_18_54 75
#define LABEL_18_55 77
#define LABEL_18_57 79
#define LABEL_18_59 81
#define LABEL_18_62 83
#define ENVIRONMENT_LABEL_18_3 138
#define DEBUGGING_LABEL_18_2 137
#define OBJECT_18_1 136
#define OBJECT_18_0 135
#define EXECUTE_CACHE_18_63 85
#define EXECUTE_CACHE_18_61 87
#define EXECUTE_CACHE_18_58 89
#define EXECUTE_CACHE_18_51 91
#define EXECUTE_CACHE_18_50 93
#define EXECUTE_CACHE_18_47 95
#define EXECUTE_CACHE_18_46 97
#define EXECUTE_CACHE_18_45 99
#define EXECUTE_CACHE_18_40 101
#define EXECUTE_CACHE_18_36 103
#define EXECUTE_CACHE_18_32 105
#define EXECUTE_CACHE_18_28 107
#define EXECUTE_CACHE_18_24 109
#define EXECUTE_CACHE_18_20 111
#define EXECUTE_CACHE_18_16 113
#define EXECUTE_CACHE_18_12 115
#define EXECUTE_CACHE_18_10 117
#define EXECUTE_CACHE_18_8 119
#define EXECUTE_CACHE_18_6 121
#define FREE_REFERENCE_18_10 124
#define FREE_REFERENCE_18_9 125
#define FREE_REFERENCE_18_8 126
#define FREE_REFERENCE_18_7 127
#define FREE_REFERENCE_18_6 128
#define FREE_REFERENCE_18_5 129
#define FREE_REFERENCE_18_4 130
#define FREE_REFERENCE_18_3 131
#define FREE_REFERENCE_18_2 132
#define FREE_REFERENCE_18_1 133
#define FREE_REFERENCE_18_0 134
#define FREE_REFERENCES_LABEL_18_0 84
#define NUMBER_OF_LINKER_SECTIONS_18_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd78;
  machine_word Wrd86;
  machine_word Wrd81;
  machine_word Wrd76;
  machine_word Wrd70;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd85;
  machine_word Wrd68;
  machine_word Wrd62;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd60;
  machine_word Wrd54;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd52;
  machine_word Wrd46;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd44;
  machine_word Wrd38;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd131;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto fg_print_node_39;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_18_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_18_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_18_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_18_13);
      goto label_41;

    case 6:
      current_block = (Rpc - LABEL_18_17);
      goto label_42;

    case 7:
      current_block = (Rpc - LABEL_18_21);
      goto label_43;

    case 8:
      current_block = (Rpc - LABEL_18_25);
      goto label_44;

    case 9:
      current_block = (Rpc - LABEL_18_29);
      goto label_45;

    case 10:
      current_block = (Rpc - LABEL_18_33);
      goto label_46;

    case 11:
      current_block = (Rpc - LABEL_18_37);
      goto label_47;

    case 12:
      current_block = (Rpc - LABEL_18_41);
      goto label_48;

    case 13:
      current_block = (Rpc - LABEL_18_43);
      goto label_49;

    case 14:
      current_block = (Rpc - LABEL_18_44);
      goto continuation_13;

    case 15:
      current_block = (Rpc - LABEL_18_42);
      goto continuation_14;

    case 16:
      current_block = (Rpc - LABEL_18_38);
      goto continuation_16;

    case 17:
      current_block = (Rpc - LABEL_18_39);
      goto continuation_15;

    case 18:
      current_block = (Rpc - LABEL_18_34);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_18_35);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_18_30);
      goto continuation_24;

    case 21:
      current_block = (Rpc - LABEL_18_31);
      goto continuation_23;

    case 22:
      current_block = (Rpc - LABEL_18_26);
      goto continuation_27;

    case 23:
      current_block = (Rpc - LABEL_18_27);
      goto continuation_26;

    case 24:
      current_block = (Rpc - LABEL_18_22);
      goto continuation_30;

    case 25:
      current_block = (Rpc - LABEL_18_23);
      goto continuation_29;

    case 26:
      current_block = (Rpc - LABEL_18_18);
      goto continuation_33;

    case 27:
      current_block = (Rpc - LABEL_18_56);
      goto label_50;

    case 28:
      current_block = (Rpc - LABEL_18_19);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_18_14);
      goto continuation_36;

    case 30:
      current_block = (Rpc - LABEL_18_15);
      goto continuation_35;

    case 31:
      current_block = (Rpc - LABEL_18_60);
      goto label_51;

    case 32:
      current_block = (Rpc - LABEL_18_48);
      goto continuation_18;

    case 33:
      current_block = (Rpc - LABEL_18_49);
      goto continuation_17;

    case 34:
      current_block = (Rpc - LABEL_18_52);
      goto continuation_22;

    case 35:
      current_block = (Rpc - LABEL_18_53);
      goto continuation_25;

    case 36:
      current_block = (Rpc - LABEL_18_54);
      goto continuation_28;

    case 37:
      current_block = (Rpc - LABEL_18_55);
      goto continuation_31;

    case 38:
      current_block = (Rpc - LABEL_18_57);
      goto continuation_34;

    case 39:
      current_block = (Rpc - LABEL_18_59);
      goto continuation_37;

    case 40:
      current_block = (Rpc - LABEL_18_62);
      goto continuation_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_node_53)
DEFLABEL (fg_print_node_39)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_54;
  Rvl = (current_block [OBJECT_18_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_54)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  Rvl = (current_block [OBJECT_18_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_55)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_18_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_18_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_87;
  Wrd6 = Wrd10;

DEFLABEL (label_86)
  (Wrd12.Obj) = (Rsp [0]);
  if (! ((Wrd12.Obj) == (Wrd6.Obj)))
    goto label_58;
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_14]))));
  (* (--Rsp)) = (Wrd131.Obj);
  (Wrd134.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_15]))));
  (* (--Rsp)) = (Wrd134.Obj);
  (Wrd135.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd135.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_16]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_18_15);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_10]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_57;
  Wrd5 = Wrd9;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_61]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_18_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_18_59);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_60])), (Wrd6.pObj));

DEFLABEL (label_51)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_58)
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_85;
  Wrd14 = Wrd18;

DEFLABEL (label_84)
  (Wrd20.Obj) = (Rsp [0]);
  if (! ((Wrd20.Obj) == (Wrd14.Obj)))
    goto label_61;
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_18]))));
  (* (--Rsp)) = (Wrd124.Obj);
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_19]))));
  (* (--Rsp)) = (Wrd127.Obj);
  (Wrd128.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd128.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_20]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_18_19);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_18_18);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_9]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_60;
  Wrd6 = Wrd10;

DEFLABEL (label_59)
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_57]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_58]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_18_57);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_61]));

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_56])), (Wrd7.pObj));

DEFLABEL (label_50)
  (Wrd6.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_61)
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_2]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_83;
  Wrd22 = Wrd26;

DEFLABEL (label_82)
  (Wrd28.Obj) = (Rsp [0]);
  if (! ((Wrd28.Obj) == (Wrd22.Obj)))
    goto label_62;
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_22]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (Wrd120.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_23]))));
  (* (--Rsp)) = (Wrd120.Obj);
  (Wrd121.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd121.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_24]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_18_23);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_18_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_18_55);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_62)
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_3]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_81;
  Wrd30 = Wrd34;

DEFLABEL (label_80)
  (Wrd36.Obj) = (Rsp [0]);
  if (! ((Wrd36.Obj) == (Wrd30.Obj)))
    goto label_63;
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_26]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_27]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (Wrd114.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd114.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_28]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_18_27);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_18_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_18_54);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_63)
  (Wrd39.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_4]));
  (Wrd42.Obj) = ((Wrd39.pObj) [0]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if ((Wrd43.uLng) == 50)
    goto label_79;
  Wrd38 = Wrd42;

DEFLABEL (label_78)
  (Wrd44.Obj) = (Rsp [0]);
  if (! ((Wrd44.Obj) == (Wrd38.Obj)))
    goto label_64;
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_30]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_31]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd107.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd107.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_32]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_18_31);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_18_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_53]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_18_53);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_64)
  (Wrd47.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_5]));
  (Wrd50.Obj) = ((Wrd47.pObj) [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 50)
    goto label_77;
  Wrd46 = Wrd50;

DEFLABEL (label_76)
  (Wrd52.Obj) = (Rsp [0]);
  if (! ((Wrd52.Obj) == (Wrd46.Obj)))
    goto label_65;
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_34]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_35]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd100.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd100.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_36]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_18_35);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_18_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_52]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_18_52);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_65)
  (Wrd55.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_6]));
  (Wrd58.Obj) = ((Wrd55.pObj) [0]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if ((Wrd59.uLng) == 50)
    goto label_75;
  Wrd54 = Wrd58;

DEFLABEL (label_74)
  (Wrd60.Obj) = (Rsp [0]);
  if (! ((Wrd60.Obj) == (Wrd54.Obj)))
    goto label_66;
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_38]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_39]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd93.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd93.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_40]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_18_39);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_51]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_18_38);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_49]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_50]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_18_49);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_18_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_62]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_63]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_18_62);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (label_66)
  (Wrd63.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_7]));
  (Wrd66.Obj) = ((Wrd63.pObj) [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd67.uLng) == 50)
    goto label_73;
  Wrd62 = Wrd66;

DEFLABEL (label_72)
  (Wrd68.Obj) = (Rsp [0]);
  if ((Wrd68.Obj) == (Wrd62.Obj))
    goto label_71;
  (Wrd71.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_8]));
  (Wrd74.Obj) = ((Wrd71.pObj) [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if ((Wrd75.uLng) == 50)
    goto label_70;
  Wrd70 = Wrd74;

DEFLABEL (label_69)
  (Wrd76.Obj) = (Rsp [0]);
  if ((Wrd76.Obj) == (Wrd70.Obj))
    goto label_67;
  (Rsp [1]) = (Wrd76.Obj);
  (Wrd78.Obj) = (current_block [OBJECT_18_1]);
  (Rsp [0]) = (Wrd78.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_46]));

DEFLABEL (label_67)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_44]))));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_68)
  (Wrd86.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd86.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_45]));

DEFLABEL (label_70)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_43])), (Wrd71.pObj));

DEFLABEL (label_49)
  (Wrd70.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_71)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_42]))));
  (* (--Rsp)) = (Wrd85.Obj);
  goto label_68;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_41])), (Wrd63.pObj));

DEFLABEL (label_48)
  (Wrd62.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_37])), (Wrd55.pObj));

DEFLABEL (label_47)
  (Wrd54.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_33])), (Wrd47.pObj));

DEFLABEL (label_46)
  (Wrd46.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_29])), (Wrd39.pObj));

DEFLABEL (label_45)
  (Wrd38.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_25])), (Wrd31.pObj));

DEFLABEL (label_44)
  (Wrd30.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_21])), (Wrd23.pObj));

DEFLABEL (label_43)
  (Wrd22.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_17])), (Wrd15.pObj));

DEFLABEL (label_42)
  (Wrd14.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_13])), (Wrd7.pObj));

DEFLABEL (label_41)
  (Wrd6.Obj) = Rvl;
  goto label_86;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_18_44);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_18_42);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_47]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_6 7
#define LABEL_19_8 9
#define LABEL_19_11 11
#define LABEL_19_10 13
#define LABEL_19_13 15
#define LABEL_19_14 17
#define LABEL_19_15 19
#define ENVIRONMENT_LABEL_19_3 36
#define DEBUGGING_LABEL_19_2 35
#define OBJECT_19_0 34
#define EXECUTE_CACHE_19_16 21
#define EXECUTE_CACHE_19_12 23
#define EXECUTE_CACHE_19_9 25
#define EXECUTE_CACHE_19_7 27
#define FREE_REFERENCE_19_1 30
#define FREE_REFERENCE_19_0 31
#define FREE_ASSIGNMENT_19_0 33
#define FREE_REFERENCES_LABEL_19_0 20
#define NUMBER_OF_LINKER_SECTIONS_19_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto fg_print_rvalue_5;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_19_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_19_11);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_19_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_19_13);
      goto label_9;

    case 7:
      current_block = (Rpc - LABEL_19_14);
      goto label_10;

    case 8:
      current_block = (Rpc - LABEL_19_15);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_rvalue_13)
DEFLABEL (fg_print_rvalue_5)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_28;
  Wrd5 = Wrd9;

DEFLABEL (label_27)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_14;
  Rvl = (current_block [OBJECT_19_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_6);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  Rvl = (current_block [OBJECT_19_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_19_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  Rvl = (current_block [OBJECT_19_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_26;
  Wrd10 = Wrd14;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  Rvl = (current_block [OBJECT_19_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_24;
  Wrd10 = Wrd14;

DEFLABEL (label_23)
  (Wrd19.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_19_0]));
  (Wrd28.Obj) = ((Wrd20.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_22;

DEFLABEL (label_21)
  ((Wrd20.pObj) [0]) = (Wrd16.Obj);

DEFLABEL (label_20)
  (Wrd33.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd36.Obj) = ((Wrd33.pObj) [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd37.uLng) == 50)
    goto label_19;
  Wrd32 = Wrd36;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_16]));

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_15])), (Wrd33.pObj));

DEFLABEL (label_11)
  (Wrd32.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_22)
  if ((Wrd28.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_21;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_19_14])), (Wrd20.pObj), (Wrd16.Obj));

DEFLABEL (label_10)
  goto label_20;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_13])), (Wrd11.pObj));

DEFLABEL (label_9)
  (Wrd10.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_11])), (Wrd11.pObj));

DEFLABEL (label_8)
  (Wrd10.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_5])), (Wrd6.pObj));

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define LABEL_20_9 7
#define LABEL_20_7 9
#define LABEL_20_12 11
#define LABEL_20_10 13
#define LABEL_20_15 15
#define LABEL_20_17 17
#define ENVIRONMENT_LABEL_20_3 37
#define DEBUGGING_LABEL_20_2 36
#define OBJECT_20_0 35
#define EXECUTE_CACHE_20_19 19
#define EXECUTE_CACHE_20_18 21
#define EXECUTE_CACHE_20_16 23
#define EXECUTE_CACHE_20_14 25
#define EXECUTE_CACHE_20_13 27
#define EXECUTE_CACHE_20_11 29
#define EXECUTE_CACHE_20_8 31
#define EXECUTE_CACHE_20_6 33
#define FREE_REFERENCES_LABEL_20_0 18
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
debug_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto fg_print_subproblem_8;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_20_9);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_20_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_20_12);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_20_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_20_15);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_20_17);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fg_print_subproblem_11)
DEFLABEL (fg_print_subproblem_8)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_12]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_20_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_20_9);

DEFLABEL (label_13)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_20_10);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_20_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  Rvl = (current_block [OBJECT_20_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_18]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_20_17);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_19]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5 3
#define LABEL_6 5
#define LABEL_7 7
#define ENVIRONMENT_LABEL_3 16
#define DEBUGGING_LABEL_2 15
#define PURIFICATION_ROOT 14
#define OBJECT_2 13
#define OBJECT_1 12
#define OBJECT_0 11
#define GLOBAL_EXECUTE_CACHE_4 9
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
debug_so_fd2027912a0eee68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_5)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_4)
  {
    static const short sections [] =
      {
	0,
	1,
	3,
	2,
	2,
	1,
	1,
	3,
	3,
	1,
	3,
	3,
	1,
	2,
	2,
	2,
	1,
	2,
	2,
	2,
	2
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 20)
      goto label_3;
    blocks = (current_block [OBJECT_2]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_3)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

static const struct liarc_code_S arr_decl_debug_so_fd2027912a0eee68 [20] =
  {
    { "debug_so_code_1", 6, debug_so_code_1 },
    { "debug_so_code_2", 11, debug_so_code_2 },
    { "debug_so_code_3", 12, debug_so_code_3 },
    { "debug_so_code_4", 9, debug_so_code_4 },
    { "debug_so_code_5", 11, debug_so_code_5 },
    { "debug_so_code_6", 4, debug_so_code_6 },
    { "debug_so_code_7", 8, debug_so_code_7 },
    { "debug_so_code_8", 4, debug_so_code_8 },
    { "debug_so_code_9", 6, debug_so_code_9 },
    { "debug_so_code_10", 17, debug_so_code_10 },
    { "debug_so_code_11", 21, debug_so_code_11 },
    { "debug_so_code_12", 5, debug_so_code_12 },
    { "debug_so_code_13", 35, debug_so_code_13 },
    { "debug_so_code_14", 12, debug_so_code_14 },
    { "debug_so_code_15", 1, debug_so_code_15 },
    { "debug_so_code_16", 2, debug_so_code_16 },
    { "debug_so_code_17", 14, debug_so_code_17 },
    { "debug_so_code_18", 41, debug_so_code_18 },
    { "debug_so_code_19", 9, debug_so_code_19 },
    { "debug_so_code_20", 8, debug_so_code_20 }
  };

int
decl_debug_so_fd2027912a0eee68 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_debug_so_fd2027912a0eee68);
  return (0);
}

DECLARE_COMPILED_CODE ("debug.so", 3, decl_debug_so_fd2027912a0eee68, debug_so_fd2027912a0eee68)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_debug_so_data_fd2027912a0eee68 [4895] =
  "\x9f\x01\x23\xc9\x08\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x24\x28"
  "\x0d\xb9\x28\x0d\xba\x28\x0d\x28\x0d\xbb\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x82\x88\xc1"
  "\xbd\xc1\xbe\x0d\xbf\x24\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\xb5\xb6\x0c"
  "\xb7\x24\x28\x0d\xbd\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88\x1d\x0d"
  "\x1c\xb7\x24\x28\xb1\x28\x0d\xbf\x28\xb2\x28\xb3\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\xc1\x02\x0c\xc1\x0c\x28"
  "\x0d\x28\x0d\x28\x0d\x28\xb2\x28\x0d\xba\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\xb5\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x86"
  "\x88\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x28\xb3\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0d\x1b\x24"
  "\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\xb3\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x0d\x1c\x28\x1b\x28\xb3\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x28\x1b\x28\xb1\x28\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x02\x07\x0d\x1c\x0d\x1c\x0d\x1c\x25\x0d\x1b\x1b\x1b\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x02\x07"
  "\x1b\x0d\x1c\x1b\x1b\x25\x0d\x1b\x1b\x1b\x1b\x24\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb6\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x08\x8e\x28\x0d\x1c\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0c\x0c\x0c\x0c\x1d\x08\x0d\xbe\x0d\x1c\x25"
  "\xb6\x1b\x1b\x24\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\xb7\x28\x0d\x28\x0d\xbf\x28\x0d\x28\x1b\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\xb6\x25\xb6\x24\x28\x1b\x28\x1b\x28\xb1\x28\x1b\x28\xb7"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\xb9\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x1b\x24\x28\x1b\x28\x0d\x28\x0d\x28\xb3\x28"
  "\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x1c\x0d\x1c\x24\x28\x0d\x28\x0d\x28\x1b"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\xb2\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\xb3\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x02\x88\x1d\x1b\x25\xb6\x1b"
  "\x24\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1d\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28"
  "\x0d\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba\x17\xb8\x88\xb0\xb2\x2a"
  "\x1b\x2a\xb3\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1e"
  "\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb5"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb4\x2a\x17\x1b\x1b\x1b\x1b\x1b\xb7"
  "\x0d\x0d\x1b\xb6\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\xb1\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4c\x2f"
  "\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65"
  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f\x6d\x69\x74\x2d"
  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30\x2e\x31\x2f\x73"
  "\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65"
  "\x2f\x64\x65\x62\x75\x67\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
  "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
  "\x03\x70\x70\x02\x03\x10\x2d\x3e\x74\x61\x67\x67\x65\x64\x2d\x76"
  "\x65\x63\x74\x6f\x72\x03\x0b\x77\x72\x69\x74\x65\x2d\x6c\x69\x6e"
  "\x65\x03\x1a\x74\x61\x67\x67\x65\x64\x2d\x76\x65\x63\x74\x6f\x72"
  "\x2f\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x04\x09\x66\x6f"
  "\x72\x2d\x65\x61\x63\x68\x05\x09\x0e\x81\x89\x02\x08\x0c\x81\x85"
  "\x02\x07\x0a\x81\x83\x02\x06\x08\x81\x83\x02\x05\x06\x81\x83\x02"
  "\x04\x04\x83\x04\x0d\x1b\x02\x04\x63\x64\x72\x04\x63\x61\x72\x0d"
  "\x2a\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x2a\x02\x03\x18\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x63\x6f\x6e\x74\x69\x6e\x75"
  "\x61\x74\x69\x6f\x6e\x3f\x09\x03\x0f\x70\x72\x6f\x63\x65\x64\x75"
  "\x72\x65\x2d\x6e\x61\x6d\x65\x03\x10\x70\x72\x6f\x63\x65\x64\x75"
  "\x72\x65\x2d\x6c\x61\x62\x65\x6c\x0a\x04\x14\x18\x81\x85\x02\x13"
  "\x16\x81\x85\x02\x12\x14\x81\x87\x02\x11\x12\x81\x85\x02\x10\x10"
  "\x81\x85\x02\x0f\x0e\x81\x87\x02\x0e\x0c\x81\x85\x02\x0d\x0a\x81"
  "\x87\x02\x0c\x08\x81\x85\x02\x0b\x06\x81\x83\x02\x0a\x04\x83\x04"
  "\x17\x25\x0b\x02\x0e\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f"
  "\x6e\x2d\x02\x03\x0f\x6e\x75\x6d\x62\x65\x72\x2d\x3e\x73\x74\x72"
  "\x69\x6e\x67\x03\x07\x69\x6e\x74\x65\x72\x6e\x04\x0e\x73\x74\x72"
  "\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x03\x09\x03\x0a\x06\x20"
  "\x1a\x81\x85\x02\x1f\x18\x81\x85\x02\x1e\x16\x81\x87\x02\x1d\x14"
  "\x81\x85\x02\x1c\x12\x81\x85\x02\x1b\x10\x81\x87\x02\x1a\x0e\x81"
  "\x85\x02\x19\x0c\x81\x87\x02\x18\x0a\x81\x85\x02\x17\x08\x81\x83"
  "\x02\x16\x06\x81\x83\x02\x15\x04\x83\x04\x19\x2c\x0a\x02\x02\x12"
  "\x2a\x72\x6f\x6f\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2a\x0c\x03\x03\x03\x16\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x65\x6e\x74\x72\x79\x2d\x6e\x6f\x64\x65\x03\x04\x03\x15\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x65\x6e\x74\x72\x79\x2d\x6e"
  "\x6f\x64\x65\x0d\x06\x29\x14\x81\x85\x02\x28\x12\x81\x85\x02\x27"
  "\x10\x81\x85\x02\x26\x0e\x81\x85\x02\x25\x0c\x81\x83\x02\x24\x0a"
  "\x81\x83\x02\x23\x08\x81\x85\x02\x22\x06\x81\x83\x02\x21\x04\x83"
  "\x04\x13\x25\x0e\x02\x1e\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63"
  "\x6f\x64\x65\x2d\x61\x64\x64\x72\x65\x73\x73\x2d\x3e\x6f\x66\x66"
  "\x73\x65\x74\x11\x09\x4f\x66\x66\x73\x65\x74\x3a\x20\x1d\x63\x6f"
  "\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x61\x64\x64\x72"
  "\x65\x73\x73\x2d\x3e\x62\x6c\x6f\x63\x6b\x15\x64\x65\x62\x75\x67"
  "\x2f\x77\x68\x65\x72\x65\x20\x2d\x2d\x20\x77\x68\x61\x74\x3f\x03"
  "\x15\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x62"
  "\x6c\x6f\x63\x6b\x3f\x03\x17\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d"
  "\x63\x6f\x64\x65\x2d\x61\x64\x64\x72\x65\x73\x73\x3f\x03\x23\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x62\x6c\x6f"
  "\x63\x6b\x2f\x64\x65\x62\x75\x67\x67\x69\x6e\x67\x2d\x69\x6e\x66"
  "\x6f\x03\x04\x06\x65\x72\x72\x6f\x72\x03\x0d\x77\x72\x69\x74\x65"
  "\x2d\x73\x74\x72\x69\x6e\x67\x0f\x02\x08\x6e\x65\x77\x6c\x69\x6e"
  "\x65\x10\x04\x09\x34\x18\x81\x89\x02\x33\x16\x81\x85\x02\x32\x14"
  "\x81\x83\x02\x31\x12\x81\x83\x02\x30\x10\x81\x87\x02\x2f\x0e\x81"
  "\x85\x02\x2e\x0c\x81\x83\x02\x2d\x0a\x81\x83\x02\x2c\x08\x81\x83"
  "\x02\x2b\x06\x81\x83\x02\x2a\x04\x83\x04\x17\x30\x02\x15\x73\x68"
  "\x6f\x77\x2d\x72\x74\x6c\x2d\x69\x6e\x73\x74\x72\x75\x63\x74\x69"
  "\x6f\x6e\x11\x02\x03\x13\x77\x72\x69\x74\x65\x2d\x69\x6e\x73\x74"
  "\x72\x75\x63\x74\x69\x6f\x6e\x73\x12\x04\x14\x77\x69\x74\x68\x2d"
  "\x6f\x75\x74\x70\x75\x74\x2d\x74\x6f\x2d\x70\x6f\x72\x74\x04\x04"
  "\x38\x0a\x81\x83\x02\x37\x08\x81\x83\x02\x36\x06\x81\x83\x02\x35"
  "\x04\x84\x06\x09\x15\x13\x02\x08\x04\x72\x74\x6c\x0d\x2a\x72\x74"
  "\x6c\x2d\x67\x72\x61\x70\x68\x73\x2a\x11\x03\x03\x12\x03\x0b\x2d"
  "\x3e\x70\x61\x74\x68\x6e\x61\x6d\x65\x04\x14\x77\x69\x74\x68\x2d"
  "\x6f\x75\x74\x70\x75\x74\x2d\x74\x6f\x2d\x66\x69\x6c\x65\x04\x12"
  "\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6e\x65\x77\x2d\x74\x79\x70"
  "\x65\x03\x0e\x6c\x69\x6e\x65\x61\x72\x69\x7a\x65\x2d\x72\x74\x6c"
  "\x04\x07\x40\x12\x81\x83\x02\x3f\x10\x81\x81\x02\x3e\x0e\x81\x83"
  "\x02\x3d\x0c\x82\x02\x3c\x0a\x81\x87\x02\x3b\x08\x81\x83\x02\x3a"
  "\x06\x81\x83\x02\x39\x04\x83\x04\x11\x25\x14\x02\x09\x11\x02\x03"
  "\x10\x70\x70\x2d\x69\x6e\x73\x74\x72\x75\x63\x74\x69\x6f\x6e\x73"
  "\x15\x02\x10\x04\x04\x44\x0a\x81\x83\x02\x43\x08\x81\x83\x02\x42"
  "\x06\x81\x83\x02\x41\x04\x83\x04\x09\x15\x16\x02\x0a\x03\x15\x02"
  "\x10\x03\x04\x14\x62\x62\x6c\x6f\x63\x6b\x2d\x77\x61\x6c\x6b\x2d"
  "\x66\x6f\x72\x77\x61\x72\x64\x03\x0a\x72\x69\x6e\x73\x74\x2d\x72"
  "\x74\x6c\x03\x11\x07\x4a\x0e\x81\x83\x02\x49\x0c\x83\x04\x48\x0a"
  "\x81\x83\x02\x47\x08\x81\x83\x02\x46\x06\x81\x83\x02\x45\x04\x83"
  "\x04\x0d\x1d\x17\x02\x0b\x02\x11\x13\x2a\x73\x68\x6f\x77\x2d\x69"
  "\x6e\x73\x74\x72\x75\x63\x74\x69\x6f\x6e\x2a\x18\x11\x2a\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x72\x61\x64\x69\x78\x2a\x19\x26\x2a"
  "\x75\x6e\x70\x61\x72\x73\x65\x2d\x75\x6e\x69\x6e\x74\x65\x72\x6e"
  "\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x73\x2d\x62\x79\x2d\x6e\x61"
  "\x6d\x65\x3f\x2a\x1a\x04\x06\x77\x72\x69\x74\x65\x18\x19\x1a\x05"
  "\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d"
  "\x62\x69\x6e\x64\x1b\x02\x5b\x24\x81\x87\x02\x5a\x22\x81\x85\x02"
  "\x59\x20\x81\x87\x02\x58\x1e\x81\x85\x02\x57\x1c\x81\x87\x02\x56"
  "\x1a\x81\x85\x02\x55\x18\x81\x83\x02\x54\x16\x81\x83\x02\x53\x14"
  "\x81\x87\x02\x52\x12\x81\x85\x02\x51\x10\x81\x87\x02\x50\x0e\x81"
  "\x85\x02\x4f\x0c\x81\x87\x02\x4e\x0a\x81\x85\x02\x4d\x08\x81\x83"
  "\x02\x4c\x06\x81\x8d\x02\x4b\x04\x83\x04\x23\x35\x1c\x02\x0c\x02"
  "\x11\x18\x18\x2a\x70\x70\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65"
  "\x73\x2d\x62\x79\x2d\x6e\x61\x6d\x65\x2a\x1d\x19\x1a\x05\x0d\x70"
  "\x72\x65\x74\x74\x79\x2d\x70\x72\x69\x6e\x74\x18\x1d\x19\x1a\x06"
  "\x05\x1b\x02\x70\x2c\x81\x87\x02\x6f\x2a\x81\x85\x02\x6e\x28\x81"
  "\x87\x02\x6d\x26\x81\x85\x02\x6c\x24\x81\x87\x02\x6b\x22\x81\x85"
  "\x02\x6a\x20\x81\x87\x02\x69\x1e\x81\x85\x02\x68\x1c\x81\x83\x02"
  "\x67\x1a\x81\x83\x02\x66\x18\x81\x87\x02\x65\x16\x81\x85\x02\x64"
  "\x14\x81\x87\x02\x63\x12\x81\x85\x02\x62\x10\x81\x87\x02\x61\x0e"
  "\x81\x85\x02\x60\x0c\x81\x87\x02\x5f\x0a\x81\x85\x02\x5e\x08\x81"
  "\x83\x02\x5d\x06\x81\x91\x02\x5c\x04\x83\x04\x2b\x3f\x1d\x02\x0d"
  "\x06\x6c\x61\x62\x65\x6c\x13\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74"
  "\x69\x6f\x6e\x2d\x65\x6e\x74\x72\x79\x14\x63\x6f\x6e\x74\x69\x6e"
  "\x75\x61\x74\x69\x6f\x6e\x2d\x68\x65\x61\x64\x65\x72\x14\x69\x63"
  "\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x68\x65\x61\x64\x65"
  "\x72\x16\x6f\x70\x65\x6e\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65"
  "\x2d\x68\x65\x61\x64\x65\x72\x11\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x68\x65\x61\x64\x65\x72\x0f\x63\x6c\x6f\x73\x75\x72\x65"
  "\x2d\x68\x65\x61\x64\x65\x72\x04\x05\x6d\x65\x6d\x71\x1a\x03\x18"
  "\x02\x10\x04\x75\x0c\x81\x83\x02\x74\x0a\x81\x83\x02\x73\x08\x81"
  "\x83\x02\x72\x06\x81\x87\x02\x71\x04\x83\x04\x0b\x17\x19\x02\x0e"
  "\x23\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x43\x6f\x6e\x74"
  "\x69\x6e\x75\x61\x74\x69\x6f\x6e\x20\x2d\x2d\x2d\x2d\x2d\x2d\x2d"
  "\x2d\x2d\x2d\x20\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x50"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x20\x2d\x2d\x2d\x2d\x2d\x2d\x2d"
  "\x2d\x2d\x2d\x1d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x42"
  "\x6c\x6f\x63\x6b\x73\x20\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d"
  "\x21\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x45\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x20\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d"
  "\x2d\x02\x10\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x71\x75\x65"
  "\x75\x65\x13\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x2d\x6c\x6f"
  "\x63\x61\x74\x65\x64\x1e\x03\x1e\x0c\x04\x02\x0b\x6d\x61\x6b\x65"
  "\x2d\x71\x75\x65\x75\x65\x05\x1b\x03\x0f\x02\x10\x03\x10\x66\x67"
  "\x2f\x70\x72\x69\x6e\x74\x2d\x6f\x62\x6a\x65\x63\x74\x0f\x03\x14"
  "\x77\x69\x74\x68\x2d\x6e\x65\x77\x2d\x6e\x6f\x64\x65\x2d\x6d\x61"
  "\x72\x6b\x73\x0c\x03\x04\x12\x71\x75\x65\x75\x65\x2d\x6d\x61\x70"
  "\x21\x2f\x75\x6e\x73\x61\x66\x65\x03\x14\x66\x67\x2f\x70\x72\x69"
  "\x6e\x74\x2d\x65\x6e\x74\x72\x79\x2d\x6e\x6f\x64\x65\x03\x11\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x62\x6c\x6f\x63\x6b\x03"
  "\x09\x03\x10\x66\x67\x2f\x70\x72\x69\x6e\x74\x2d\x62\x6c\x6f\x63"
  "\x6b\x73\x09\x03\x0d\x0e\x98\x01\x48\x81\x83\x02\x97\x01\x46\x81"
  "\x83\x02\x96\x01\x44\x81\x83\x02\x95\x01\x42\x81\x83\x02\x94\x01"
  "\x40\x81\x83\x02\x93\x01\x3e\x81\x81\x02\x92\x01\x3c\x81\x83\x02"
  "\x91\x01\x3a\x81\x83\x02\x90\x01\x38\x81\x81\x02\x8f\x01\x36\x83"
  "\x04\x8e\x01\x34\x81\x81\x02\x8d\x01\x32\x81\x83\x02\x8c\x01\x30"
  "\x81\x83\x02\x8b\x01\x2e\x81\x81\x02\x8a\x01\x2c\x81\x81\x02\x89"
  "\x01\x2a\x81\x85\x02\x88\x01\x28\x82\x02\x87\x01\x26\x81\x81\x02"
  "\x86\x01\x24\x81\x81\x02\x85\x01\x22\x81\x83\x02\x84\x01\x20\x81"
  "\x81\x02\x83\x01\x1e\x81\x81\x02\x82\x01\x1c\x82\x02\x81\x01\x1a"
  "\x81\x87\x02\x80\x01\x18\x81\x85\x02\x7f\x16\x81\x87\x02\x7e\x14"
  "\x81\x85\x02\x7d\x12\x81\x83\x02\x7c\x10\x81\x87\x02\x7b\x0e\x81"
  "\x85\x02\x7a\x0c\x81\x87\x02\x79\x0a\x81\x85\x02\x78\x08\x81\x83"
  "\x02\x77\x06\x81\x87\x02\x76\x04\x82\x02\x47\x72\x1f\x02\x0f\x02"
  "\x02\x02\x05\x1b\x03\x0c\x03\x03\x0d\x03\x03\x0b\x70\x72\x6f\x63"
  "\x65\x64\x75\x72\x65\x3f\x07\xa4\x01\x1a\x81\x85\x02\xa3\x01\x18"
  "\x81\x83\x02\xa2\x01\x16\x81\x83\x02\xa1\x01\x14\x81\x83\x02\xa0"
  "\x01\x12\x81\x87\x02\x9f\x01\x10\x81\x85\x02\x9e\x01\x0e\x81\x83"
  "\x02\x9d\x01\x0c\x81\x83\x02\x9c\x01\x0a\x81\x87\x02\x9b\x01\x08"
  "\x81\x85\x02\x9a\x01\x06\x81\x83\x02\x99\x01\x04\x83\x04\x19\x2e"
  "\x1b\x02\x10\x02\x03\x0e\x66\x67\x2f\x70\x72\x69\x6e\x74\x2d\x6e"
  "\x6f\x64\x65\x0d\x02\xa5\x01\x04\x83\x04\x03\x0a\x0c\x02\x11\x03"
  "\x03\x70\x6f\x02\x10\x03\xa7\x01\x06\x81\x83\x02\xa6\x01\x04\x83"
  "\x04\x05\x0d\x10\x02\x12\x0f\x09\x03\x03\x0f\x03\x16\x62\x6c\x6f"
  "\x63\x6b\x2d\x62\x6f\x75\x6e\x64\x2d\x76\x61\x72\x69\x61\x62\x6c"
  "\x65\x73\x03\x0d\x62\x6c\x6f\x63\x6b\x2d\x70\x61\x72\x65\x6e\x74"
  "\x04\x03\x15\x62\x6c\x6f\x63\x6b\x2d\x66\x72\x65\x65\x2d\x76\x61"
  "\x72\x69\x61\x62\x6c\x65\x73\x03\x0f\x62\x6c\x6f\x63\x6b\x2d\x63"
  "\x68\x69\x6c\x64\x72\x65\x6e\x03\x18\x62\x6c\x6f\x63\x6b\x2d\x64"
  "\x69\x73\x6f\x77\x6e\x65\x64\x2d\x63\x68\x69\x6c\x64\x72\x65\x6e"
  "\x08\xb5\x01\x1e\x81\x85\x02\xb4\x01\x1c\x81\x87\x02\xb3\x01\x1a"
  "\x81\x85\x02\xb2\x01\x18\x81\x87\x02\xb1\x01\x16\x81\x85\x02\xb0"
  "\x01\x14\x81\x83\x02\xaf\x01\x12\x81\x83\x02\xae\x01\x10\x81\x83"
  "\x02\xad\x01\x0e\x81\x83\x02\xac\x01\x0c\x81\x87\x02\xab\x01\x0a"
  "\x81\x85\x02\xaa\x01\x08\x81\x83\x02\xa9\x01\x06\x81\x83\x02\xa8"
  "\x01\x04\x83\x04\x1d\x32\x20\x02\x13\x13\x55\x6e\x6b\x6e\x6f\x77"
  "\x6e\x20\x6e\x6f\x64\x65\x20\x74\x79\x70\x65\x3a\x02\x0d\x70\x61"
  "\x72\x61\x6c\x6c\x65\x6c\x2d\x74\x61\x67\x10\x61\x70\x70\x6c\x69"
  "\x63\x61\x74\x69\x6f\x6e\x2d\x74\x61\x67\x13\x76\x69\x72\x74\x75"
  "\x61\x6c\x2d\x72\x65\x74\x75\x72\x6e\x2d\x74\x61\x67\x08\x70\x6f"
  "\x70\x2d\x74\x61\x67\x0f\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74"
  "\x2d\x74\x61\x67\x0f\x64\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x2d"
  "\x74\x61\x67\x0e\x74\x72\x75\x65\x2d\x74\x65\x73\x74\x2d\x74\x61"
  "\x67\x14\x73\x74\x61\x63\x6b\x2d\x6f\x76\x65\x72\x77\x72\x69\x74"
  "\x65\x2d\x74\x61\x67\x0c\x66\x67\x2d\x6e\x6f\x6f\x70\x2d\x74\x61"
  "\x67\x10\x66\x67\x2f\x70\x72\x69\x6e\x74\x2d\x72\x76\x61\x6c\x75"
  "\x65\x21\x14\x66\x67\x2f\x70\x72\x69\x6e\x74\x2d\x73\x75\x62\x70"
  "\x72\x6f\x62\x6c\x65\x6d\x22\x0c\x03\x0d\x6e\x6f\x64\x65\x2d\x6d"
  "\x61\x72\x6b\x65\x64\x3f\x03\x0b\x6e\x6f\x64\x65\x2d\x6d\x61\x72"
  "\x6b\x21\x03\x0f\x03\x12\x74\x61\x67\x67\x65\x64\x2d\x76\x65\x63"
  "\x74\x6f\x72\x2f\x74\x61\x67\x03\x15\x70\x61\x72\x61\x6c\x6c\x65"
  "\x6c\x2d\x73\x75\x62\x70\x72\x6f\x62\x6c\x65\x6d\x73\x03\x15\x61"
  "\x70\x70\x6c\x69\x63\x61\x74\x69\x6f\x6e\x2d\x6f\x70\x65\x72\x61"
  "\x74\x6f\x72\x03\x17\x76\x69\x72\x74\x75\x61\x6c\x2d\x72\x65\x74"
  "\x75\x72\x6e\x2d\x6f\x70\x65\x72\x61\x6e\x64\x03\x11\x70\x6f\x70"
  "\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x03\x12\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x72\x76\x61\x6c\x75\x65"
  "\x03\x12\x64\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x2d\x72\x76\x61"
  "\x6c\x75\x65\x03\x11\x74\x72\x75\x65\x2d\x74\x65\x73\x74\x2d\x72"
  "\x76\x61\x6c\x75\x65\x03\x0b\x73\x6e\x6f\x64\x65\x2d\x6e\x65\x78"
  "\x74\x04\x03\x0d\x03\x11\x70\x6e\x6f\x64\x65\x2d\x63\x6f\x6e\x73"
  "\x65\x71\x75\x65\x6e\x74\x03\x21\x03\x15\x61\x70\x70\x6c\x69\x63"
  "\x61\x74\x69\x6f\x6e\x2d\x6f\x70\x65\x72\x61\x6e\x64\x73\x04\x03"
  "\x12\x70\x6e\x6f\x64\x65\x2d\x61\x6c\x74\x65\x72\x6e\x61\x74\x69"
  "\x76\x65\x14\xde\x01\x54\x81\x85\x02\xdd\x01\x52\x81\x85\x02\xdc"
  "\x01\x50\x81\x85\x02\xdb\x01\x4e\x81\x85\x02\xda\x01\x4c\x81\x85"
  "\x02\xd9\x01\x4a\x81\x85\x02\xd8\x01\x48\x81\x85\x02\xd7\x01\x46"
  "\x81\x87\x02\xd6\x01\x44\x81\x85\x02\xd5\x01\x42\x81\x89\x02\xd4"
  "\x01\x40\x81\x87\x02\xd3\x01\x3e\x81\x85\x02\xd2\x01\x3c\x81\x87"
  "\x02\xd1\x01\x3a\x81\x85\x02\xd0\x01\x38\x81\x85\x02\xcf\x01\x36"
  "\x81\x87\x02\xce\x01\x34\x81\x85\x02\xcd\x01\x32\x81\x87\x02\xcc"
  "\x01\x30\x81\x85\x02\xcb\x01\x2e\x81\x87\x02\xca\x01\x2c\x81\x85"
  "\x02\xc9\x01\x2a\x81\x87\x02\xc8\x01\x28\x81\x85\x02\xc7\x01\x26"
  "\x81\x87\x02\xc6\x01\x24\x81\x85\x02\xc5\x01\x22\x81\x85\x02\xc4"
  "\x01\x20\x81\x85\x02\xc3\x01\x1e\x81\x85\x02\xc2\x01\x1c\x81\x85"
  "\x02\xc1\x01\x1a\x81\x85\x02\xc0\x01\x18\x81\x85\x02\xbf\x01\x16"
  "\x81\x85\x02\xbe\x01\x14\x81\x85\x02\xbd\x01\x12\x81\x85\x02\xbc"
  "\x01\x10\x81\x85\x02\xbb\x01\x0e\x81\x85\x02\xba\x01\x0c\x81\x83"
  "\x02\xb9\x01\x0a\x81\x83\x02\xb8\x01\x08\x81\x83\x02\xb7\x01\x06"
  "\x81\x83\x02\xb6\x01\x04\x83\x04\x53\x8b\x01\x02\x14\x02\x1e\x02"
  "\x1e\x03\x03\x13\x72\x76\x61\x6c\x75\x65\x2d\x6b\x6e\x6f\x77\x6e"
  "\x2d\x76\x61\x6c\x75\x65\x03\x12\x72\x76\x61\x6c\x75\x65\x2f\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x3f\x04\x1a\x04\x10\x65\x6e\x71"
  "\x75\x65\x75\x65\x21\x2f\x75\x6e\x73\x61\x66\x65\x05\xe7\x01\x14"
  "\x81\x83\x02\xe6\x01\x12\x81\x83\x02\xe5\x01\x10\x81\x83\x02\xe4"
  "\x01\x0e\x81\x83\x02\xe3\x01\x0c\x81\x85\x02\xe2\x01\x0a\x81\x83"
  "\x02\xe1\x01\x08\x81\x83\x02\xe0\x01\x06\x81\x83\x02\xdf\x01\x04"
  "\x83\x04\x13\x25\x1a\x02\x15\x02\x03\x0f\x03\x16\x73\x75\x62\x70"
  "\x72\x6f\x62\x6c\x65\x6d\x2d\x63\x61\x6e\x6f\x6e\x69\x63\x61\x6c"
  "\x3f\x03\x12\x73\x75\x62\x70\x72\x6f\x62\x6c\x65\x6d\x2d\x70\x72"
  "\x65\x66\x69\x78\x03\x18\x73\x75\x62\x70\x72\x6f\x62\x6c\x65\x6d"
  "\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x03\x21\x03"
  "\x0a\x63\x66\x67\x2d\x6e\x75\x6c\x6c\x3f\x03\x0f\x63\x66\x67\x2d"
  "\x65\x6e\x74\x72\x79\x2d\x6e\x6f\x64\x65\x03\x0d\x09\xef\x01\x12"
  "\x81\x83\x02\xee\x01\x10\x81\x83\x02\xed\x01\x0e\x81\x83\x02\xec"
  "\x01\x0c\x81\x85\x02\xeb\x01\x0a\x81\x83\x02\xea\x01\x08\x81\x83"
  "\x02\xe9\x01\x06\x81\x83\x02\xe8\x01\x04\x83\x04\x11\x26\x15\x04"
  "\x1a\x04\x04\x20\x04\x10\x04\x0c\x04\x1b\x04\x1f\x04\x19\x04\x1d"
  "\x04\x1c\x04\x17\x04\x16\x04\x14\x04\x13\x04\x04\x0e\x04\x0a\x04"
  "\x0b\x04\x04\x18\x22\x21\x0d\x09\x0f\x0d\x73\x68\x6f\x77\x2d\x66"
  "\x67\x2d\x6e\x6f\x64\x65\x08\x73\x68\x6f\x77\x2d\x66\x67\x1e\x11"
  "\x18\x15\x12\x10\x73\x68\x6f\x77\x2d\x62\x62\x6c\x6f\x63\x6b\x2d"
  "\x72\x74\x6c\x09\x73\x68\x6f\x77\x2d\x72\x74\x6c\x09\x64\x75\x6d"
  "\x70\x2d\x72\x74\x6c\x17\x77\x72\x69\x74\x65\x2d\x72\x74\x6c\x2d"
  "\x69\x6e\x73\x74\x72\x75\x63\x74\x69\x6f\x6e\x73\x0c\x64\x65\x62"
  "\x75\x67\x2f\x77\x68\x65\x72\x65\x16\x64\x65\x62\x75\x67\x2f\x66"
  "\x69\x6e\x64\x2d\x65\x6e\x74\x72\x79\x2d\x6e\x6f\x64\x65\x18\x64"
  "\x65\x62\x75\x67\x2f\x66\x69\x6e\x64\x2d\x63\x6f\x6e\x74\x69\x6e"
  "\x75\x61\x74\x69\x6f\x6e\x15\x64\x65\x62\x75\x67\x2f\x66\x69\x6e"
  "\x64\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x18\x05\x10\x64\x65"
  "\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x03\x08"
  "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";

SCHEME_OBJECT *
debug_so_data_fd2027912a0eee68 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_debug_so_data_fd2027912a0eee68 [0]))), (sizeof (prog_debug_so_data_fd2027912a0eee68)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_7]));
}

DECLARE_COMPILED_DATA_NS ("debug.so", debug_so_data_fd2027912a0eee68)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("debug.so", "a008e1b67e1d1c02")
