/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:15-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 6
#define DEBUGGING_LABEL_1_2 5
#define OBJECT_1_0 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto x_close_all_displays_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_close_all_displays_3)
DEFLABEL (x_close_all_displays_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 0);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 6
#define DEBUGGING_LABEL_2_2 5
#define OBJECT_2_0 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto x_display_descriptor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_descriptor_3)
DEFLABEL (x_display_descriptor_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 6
#define DEBUGGING_LABEL_3_2 5
#define OBJECT_3_0 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto x_display_get_default_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_get_default_3)
DEFLABEL (x_display_get_default_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 6
#define DEBUGGING_LABEL_4_2 5
#define OBJECT_4_0 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto x_display_process_events_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_process_events_3)
DEFLABEL (x_display_process_events_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 6
#define DEBUGGING_LABEL_5_2 5
#define OBJECT_5_0 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto x_font_structure_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_3)
DEFLABEL (x_font_structure_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 6
#define DEBUGGING_LABEL_6_2 5
#define OBJECT_6_0 4
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto x_window_beep_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_beep_3)
DEFLABEL (x_window_beep_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define ENVIRONMENT_LABEL_7_3 6
#define DEBUGGING_LABEL_7_2 5
#define OBJECT_7_0 4
#define FREE_REFERENCES_LABEL_7_0 4
#define NUMBER_OF_LINKER_SECTIONS_7_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto x_window_clear_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_clear_3)
DEFLABEL (x_window_clear_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 6
#define DEBUGGING_LABEL_8_2 5
#define OBJECT_8_0 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto x_window_colormap_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_colormap_3)
DEFLABEL (x_window_colormap_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 6
#define DEBUGGING_LABEL_9_2 5
#define OBJECT_9_0 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto x_window_depth_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_depth_3)
DEFLABEL (x_window_depth_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define ENVIRONMENT_LABEL_10_3 6
#define DEBUGGING_LABEL_10_2 5
#define OBJECT_10_0 4
#define FREE_REFERENCES_LABEL_10_0 4
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto x_window_event_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_event_mask_3)
DEFLABEL (x_window_event_mask_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 6
#define DEBUGGING_LABEL_11_2 5
#define OBJECT_11_0 4
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto x_window_flush_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_flush_3)
DEFLABEL (x_window_flush_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 6
#define DEBUGGING_LABEL_12_2 5
#define OBJECT_12_0 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto x_window_iconify_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_iconify_3)
DEFLABEL (x_window_iconify_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define ENVIRONMENT_LABEL_13_3 6
#define DEBUGGING_LABEL_13_2 5
#define OBJECT_13_0 4
#define FREE_REFERENCES_LABEL_13_0 4
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto x_window_id_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_id_3)
DEFLABEL (x_window_id_0)
  INTERRUPT_CHECK (26, LABEL_13_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 6
#define DEBUGGING_LABEL_14_2 5
#define OBJECT_14_0 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto x_window_lower_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_lower_3)
DEFLABEL (x_window_lower_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 6
#define DEBUGGING_LABEL_15_2 5
#define OBJECT_15_0 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto x_window_map_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_map_3)
DEFLABEL (x_window_map_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 6
#define DEBUGGING_LABEL_16_2 5
#define OBJECT_16_0 4
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto x_window_query_pointer_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_query_pointer_3)
DEFLABEL (x_window_query_pointer_0)
  INTERRUPT_CHECK (26, LABEL_16_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define ENVIRONMENT_LABEL_17_3 6
#define DEBUGGING_LABEL_17_2 5
#define OBJECT_17_0 4
#define FREE_REFERENCES_LABEL_17_0 4
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto x_window_raise_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_raise_3)
DEFLABEL (x_window_raise_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define ENVIRONMENT_LABEL_18_3 6
#define DEBUGGING_LABEL_18_2 5
#define OBJECT_18_0 4
#define FREE_REFERENCES_LABEL_18_0 4
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto x_window_set_background_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_background_color_3)
DEFLABEL (x_window_set_background_color_0)
  INTERRUPT_CHECK (26, LABEL_18_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define ENVIRONMENT_LABEL_19_3 6
#define DEBUGGING_LABEL_19_2 5
#define OBJECT_19_0 4
#define FREE_REFERENCES_LABEL_19_0 4
#define NUMBER_OF_LINKER_SECTIONS_19_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto x_window_set_border_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_border_color_3)
DEFLABEL (x_window_set_border_color_0)
  INTERRUPT_CHECK (26, LABEL_19_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define ENVIRONMENT_LABEL_20_3 6
#define DEBUGGING_LABEL_20_2 5
#define OBJECT_20_0 4
#define FREE_REFERENCES_LABEL_20_0 4
#define NUMBER_OF_LINKER_SECTIONS_20_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto x_window_set_border_width_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_border_width_3)
DEFLABEL (x_window_set_border_width_0)
  INTERRUPT_CHECK (26, LABEL_20_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 6
#define DEBUGGING_LABEL_21_2 5
#define OBJECT_21_0 4
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto x_window_set_cursor_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_cursor_color_3)
DEFLABEL (x_window_set_cursor_color_0)
  INTERRUPT_CHECK (26, LABEL_21_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 6
#define DEBUGGING_LABEL_22_2 5
#define OBJECT_22_0 4
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto x_window_set_event_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_event_mask_3)
DEFLABEL (x_window_set_event_mask_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define ENVIRONMENT_LABEL_23_3 6
#define DEBUGGING_LABEL_23_2 5
#define OBJECT_23_0 4
#define FREE_REFERENCES_LABEL_23_0 4
#define NUMBER_OF_LINKER_SECTIONS_23_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto x_window_set_font_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_font_3)
DEFLABEL (x_window_set_font_0)
  INTERRUPT_CHECK (26, LABEL_23_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define ENVIRONMENT_LABEL_24_3 6
#define DEBUGGING_LABEL_24_2 5
#define OBJECT_24_0 4
#define FREE_REFERENCES_LABEL_24_0 4
#define NUMBER_OF_LINKER_SECTIONS_24_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto x_window_set_foreground_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_foreground_color_3)
DEFLABEL (x_window_set_foreground_color_0)
  INTERRUPT_CHECK (26, LABEL_24_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define ENVIRONMENT_LABEL_25_3 6
#define DEBUGGING_LABEL_25_2 5
#define OBJECT_25_0 4
#define FREE_REFERENCES_LABEL_25_0 4
#define NUMBER_OF_LINKER_SECTIONS_25_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto x_window_set_icon_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_icon_name_3)
DEFLABEL (x_window_set_icon_name_0)
  INTERRUPT_CHECK (26, LABEL_25_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 6
#define DEBUGGING_LABEL_26_2 5
#define OBJECT_26_0 4
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto x_window_set_input_hint_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_input_hint_3)
DEFLABEL (x_window_set_input_hint_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 6
#define DEBUGGING_LABEL_27_2 5
#define OBJECT_27_0 4
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto x_window_set_internal_border_width_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_internal_border_width_3)
DEFLABEL (x_window_set_internal_border_width_0)
  INTERRUPT_CHECK (26, LABEL_27_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 6
#define DEBUGGING_LABEL_28_2 5
#define OBJECT_28_0 4
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto x_window_set_mouse_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_mouse_color_3)
DEFLABEL (x_window_set_mouse_color_0)
  INTERRUPT_CHECK (26, LABEL_28_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define ENVIRONMENT_LABEL_29_3 6
#define DEBUGGING_LABEL_29_2 5
#define OBJECT_29_0 4
#define FREE_REFERENCES_LABEL_29_0 4
#define NUMBER_OF_LINKER_SECTIONS_29_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto x_window_set_mouse_shape_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_mouse_shape_3)
DEFLABEL (x_window_set_mouse_shape_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define ENVIRONMENT_LABEL_30_3 6
#define DEBUGGING_LABEL_30_2 5
#define OBJECT_30_0 4
#define FREE_REFERENCES_LABEL_30_0 4
#define NUMBER_OF_LINKER_SECTIONS_30_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto x_window_set_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_name_3)
DEFLABEL (x_window_set_name_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define ENVIRONMENT_LABEL_31_3 6
#define DEBUGGING_LABEL_31_2 5
#define OBJECT_31_0 4
#define FREE_REFERENCES_LABEL_31_0 4
#define NUMBER_OF_LINKER_SECTIONS_31_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto x_window_set_position_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_position_3)
DEFLABEL (x_window_set_position_0)
  INTERRUPT_CHECK (26, LABEL_31_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define ENVIRONMENT_LABEL_32_3 6
#define DEBUGGING_LABEL_32_2 5
#define OBJECT_32_0 4
#define FREE_REFERENCES_LABEL_32_0 4
#define NUMBER_OF_LINKER_SECTIONS_32_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto x_window_set_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_set_size_3)
DEFLABEL (x_window_set_size_0)
  INTERRUPT_CHECK (26, LABEL_32_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 6
#define DEBUGGING_LABEL_33_2 5
#define OBJECT_33_0 4
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto x_window_starbase_filename_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_starbase_filename_3)
DEFLABEL (x_window_starbase_filename_0)
  INTERRUPT_CHECK (26, LABEL_33_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 6
#define DEBUGGING_LABEL_34_2 5
#define OBJECT_34_0 4
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto x_window_visual_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_visual_3)
DEFLABEL (x_window_visual_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define ENVIRONMENT_LABEL_35_3 6
#define DEBUGGING_LABEL_35_2 5
#define OBJECT_35_0 4
#define FREE_REFERENCES_LABEL_35_0 4
#define NUMBER_OF_LINKER_SECTIONS_35_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto x_window_withdraw_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_withdraw_3)
DEFLABEL (x_window_withdraw_0)
  INTERRUPT_CHECK (26, LABEL_35_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 6
#define DEBUGGING_LABEL_36_2 5
#define OBJECT_36_0 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto x_window_x_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_x_size_3)
DEFLABEL (x_window_x_size_0)
  INTERRUPT_CHECK (26, LABEL_36_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define ENVIRONMENT_LABEL_37_3 6
#define DEBUGGING_LABEL_37_2 5
#define OBJECT_37_0 4
#define FREE_REFERENCES_LABEL_37_0 4
#define NUMBER_OF_LINKER_SECTIONS_37_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto x_window_y_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_y_size_3)
DEFLABEL (x_window_y_size_0)
  INTERRUPT_CHECK (26, LABEL_37_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define ENVIRONMENT_LABEL_38_3 6
#define DEBUGGING_LABEL_38_2 5
#define OBJECT_38_0 4
#define FREE_REFERENCES_LABEL_38_0 4
#define NUMBER_OF_LINKER_SECTIONS_38_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto x_graphics_copy_area_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_copy_area_3)
DEFLABEL (x_graphics_copy_area_0)
  INTERRUPT_CHECK (26, LABEL_38_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 8);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define ENVIRONMENT_LABEL_39_3 6
#define DEBUGGING_LABEL_39_2 5
#define OBJECT_39_0 4
#define FREE_REFERENCES_LABEL_39_0 4
#define NUMBER_OF_LINKER_SECTIONS_39_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto x_graphics_drag_cursor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_drag_cursor_3)
DEFLABEL (x_graphics_drag_cursor_0)
  INTERRUPT_CHECK (26, LABEL_39_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 6
#define DEBUGGING_LABEL_40_2 5
#define OBJECT_40_0 4
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto x_graphics_draw_arc_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_arc_3)
DEFLABEL (x_graphics_draw_arc_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_0]), 8);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define ENVIRONMENT_LABEL_41_3 6
#define DEBUGGING_LABEL_41_2 5
#define OBJECT_41_0 4
#define FREE_REFERENCES_LABEL_41_0 4
#define NUMBER_OF_LINKER_SECTIONS_41_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto x_graphics_draw_line_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_line_3)
DEFLABEL (x_graphics_draw_line_0)
  INTERRUPT_CHECK (26, LABEL_41_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 5);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define ENVIRONMENT_LABEL_42_3 6
#define DEBUGGING_LABEL_42_2 5
#define OBJECT_42_0 4
#define FREE_REFERENCES_LABEL_42_0 4
#define NUMBER_OF_LINKER_SECTIONS_42_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto x_graphics_draw_lines_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_lines_3)
DEFLABEL (x_graphics_draw_lines_0)
  INTERRUPT_CHECK (26, LABEL_42_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define ENVIRONMENT_LABEL_43_3 6
#define DEBUGGING_LABEL_43_2 5
#define OBJECT_43_0 4
#define FREE_REFERENCES_LABEL_43_0 4
#define NUMBER_OF_LINKER_SECTIONS_43_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto x_graphics_draw_point_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_point_3)
DEFLABEL (x_graphics_draw_point_0)
  INTERRUPT_CHECK (26, LABEL_43_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define ENVIRONMENT_LABEL_44_3 6
#define DEBUGGING_LABEL_44_2 5
#define OBJECT_44_0 4
#define FREE_REFERENCES_LABEL_44_0 4
#define NUMBER_OF_LINKER_SECTIONS_44_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto x_graphics_draw_points_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_points_3)
DEFLABEL (x_graphics_draw_points_0)
  INTERRUPT_CHECK (26, LABEL_44_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define ENVIRONMENT_LABEL_45_3 6
#define DEBUGGING_LABEL_45_2 5
#define OBJECT_45_0 4
#define FREE_REFERENCES_LABEL_45_0 4
#define NUMBER_OF_LINKER_SECTIONS_45_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto x_graphics_draw_string_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_string_3)
DEFLABEL (x_graphics_draw_string_0)
  INTERRUPT_CHECK (26, LABEL_45_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_0]), 4);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define ENVIRONMENT_LABEL_46_3 6
#define DEBUGGING_LABEL_46_2 5
#define OBJECT_46_0 4
#define FREE_REFERENCES_LABEL_46_0 4
#define NUMBER_OF_LINKER_SECTIONS_46_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto x_graphics_draw_image_string_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_image_string_3)
DEFLABEL (x_graphics_draw_image_string_0)
  INTERRUPT_CHECK (26, LABEL_46_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_0]), 4);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define ENVIRONMENT_LABEL_47_3 6
#define DEBUGGING_LABEL_47_2 5
#define OBJECT_47_0 4
#define FREE_REFERENCES_LABEL_47_0 4
#define NUMBER_OF_LINKER_SECTIONS_47_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto x_graphics_fill_polygon_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_fill_polygon_3)
DEFLABEL (x_graphics_fill_polygon_0)
  INTERRUPT_CHECK (26, LABEL_47_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define ENVIRONMENT_LABEL_48_3 6
#define DEBUGGING_LABEL_48_2 5
#define OBJECT_48_0 4
#define FREE_REFERENCES_LABEL_48_0 4
#define NUMBER_OF_LINKER_SECTIONS_48_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto x_graphics_map_x_coordinate_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_map_x_coordinate_3)
DEFLABEL (x_graphics_map_x_coordinate_0)
  INTERRUPT_CHECK (26, LABEL_48_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define ENVIRONMENT_LABEL_49_3 6
#define DEBUGGING_LABEL_49_2 5
#define OBJECT_49_0 4
#define FREE_REFERENCES_LABEL_49_0 4
#define NUMBER_OF_LINKER_SECTIONS_49_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto x_graphics_map_y_coordinate_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_map_y_coordinate_3)
DEFLABEL (x_graphics_map_y_coordinate_0)
  INTERRUPT_CHECK (26, LABEL_49_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define ENVIRONMENT_LABEL_50_3 6
#define DEBUGGING_LABEL_50_2 5
#define OBJECT_50_0 4
#define FREE_REFERENCES_LABEL_50_0 4
#define NUMBER_OF_LINKER_SECTIONS_50_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto x_graphics_move_cursor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_move_cursor_3)
DEFLABEL (x_graphics_move_cursor_0)
  INTERRUPT_CHECK (26, LABEL_50_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define ENVIRONMENT_LABEL_51_3 6
#define DEBUGGING_LABEL_51_2 5
#define OBJECT_51_0 4
#define FREE_REFERENCES_LABEL_51_0 4
#define NUMBER_OF_LINKER_SECTIONS_51_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto x_graphics_open_window_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_open_window_3)
DEFLABEL (x_graphics_open_window_0)
  INTERRUPT_CHECK (26, LABEL_51_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define ENVIRONMENT_LABEL_52_3 6
#define DEBUGGING_LABEL_52_2 5
#define OBJECT_52_0 4
#define FREE_REFERENCES_LABEL_52_0 4
#define NUMBER_OF_LINKER_SECTIONS_52_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto x_graphics_reconfigure_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_reconfigure_3)
DEFLABEL (x_graphics_reconfigure_0)
  INTERRUPT_CHECK (26, LABEL_52_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define ENVIRONMENT_LABEL_53_3 6
#define DEBUGGING_LABEL_53_2 5
#define OBJECT_53_0 4
#define FREE_REFERENCES_LABEL_53_0 4
#define NUMBER_OF_LINKER_SECTIONS_53_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto x_graphics_reset_clip_rectangle_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_reset_clip_rectangle_3)
DEFLABEL (x_graphics_reset_clip_rectangle_0)
  INTERRUPT_CHECK (26, LABEL_53_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define ENVIRONMENT_LABEL_54_3 6
#define DEBUGGING_LABEL_54_2 5
#define OBJECT_54_0 4
#define FREE_REFERENCES_LABEL_54_0 4
#define NUMBER_OF_LINKER_SECTIONS_54_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto x_graphics_set_clip_rectangle_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_clip_rectangle_3)
DEFLABEL (x_graphics_set_clip_rectangle_0)
  INTERRUPT_CHECK (26, LABEL_54_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_0]), 5);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define ENVIRONMENT_LABEL_55_3 6
#define DEBUGGING_LABEL_55_2 5
#define OBJECT_55_0 4
#define FREE_REFERENCES_LABEL_55_0 4
#define NUMBER_OF_LINKER_SECTIONS_55_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto x_graphics_set_dashes_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_dashes_3)
DEFLABEL (x_graphics_set_dashes_0)
  INTERRUPT_CHECK (26, LABEL_55_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define ENVIRONMENT_LABEL_56_3 6
#define DEBUGGING_LABEL_56_2 5
#define OBJECT_56_0 4
#define FREE_REFERENCES_LABEL_56_0 4
#define NUMBER_OF_LINKER_SECTIONS_56_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto x_graphics_set_fill_style_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_fill_style_3)
DEFLABEL (x_graphics_set_fill_style_0)
  INTERRUPT_CHECK (26, LABEL_56_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define ENVIRONMENT_LABEL_57_3 6
#define DEBUGGING_LABEL_57_2 5
#define OBJECT_57_0 4
#define FREE_REFERENCES_LABEL_57_0 4
#define NUMBER_OF_LINKER_SECTIONS_57_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto x_graphics_set_function_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_function_3)
DEFLABEL (x_graphics_set_function_0)
  INTERRUPT_CHECK (26, LABEL_57_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define ENVIRONMENT_LABEL_58_3 6
#define DEBUGGING_LABEL_58_2 5
#define OBJECT_58_0 4
#define FREE_REFERENCES_LABEL_58_0 4
#define NUMBER_OF_LINKER_SECTIONS_58_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto x_graphics_set_line_style_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_line_style_3)
DEFLABEL (x_graphics_set_line_style_0)
  INTERRUPT_CHECK (26, LABEL_58_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define ENVIRONMENT_LABEL_59_3 6
#define DEBUGGING_LABEL_59_2 5
#define OBJECT_59_0 4
#define FREE_REFERENCES_LABEL_59_0 4
#define NUMBER_OF_LINKER_SECTIONS_59_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto x_graphics_set_vdc_extent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_vdc_extent_3)
DEFLABEL (x_graphics_set_vdc_extent_0)
  INTERRUPT_CHECK (26, LABEL_59_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_0]), 5);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define ENVIRONMENT_LABEL_60_3 6
#define DEBUGGING_LABEL_60_2 5
#define OBJECT_60_0 4
#define FREE_REFERENCES_LABEL_60_0 4
#define NUMBER_OF_LINKER_SECTIONS_60_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto x_graphics_vdc_extent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_vdc_extent_3)
DEFLABEL (x_graphics_vdc_extent_0)
  INTERRUPT_CHECK (26, LABEL_60_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define ENVIRONMENT_LABEL_61_3 6
#define DEBUGGING_LABEL_61_2 5
#define OBJECT_61_0 4
#define FREE_REFERENCES_LABEL_61_0 4
#define NUMBER_OF_LINKER_SECTIONS_61_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto x_bytes_into_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_bytes_into_image_3)
DEFLABEL (x_bytes_into_image_0)
  INTERRUPT_CHECK (26, LABEL_61_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_61_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define ENVIRONMENT_LABEL_62_3 6
#define DEBUGGING_LABEL_62_2 5
#define OBJECT_62_0 4
#define FREE_REFERENCES_LABEL_62_0 4
#define NUMBER_OF_LINKER_SECTIONS_62_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto x_create_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_create_image_3)
DEFLABEL (x_create_image_0)
  INTERRUPT_CHECK (26, LABEL_62_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define ENVIRONMENT_LABEL_63_3 6
#define DEBUGGING_LABEL_63_2 5
#define OBJECT_63_0 4
#define FREE_REFERENCES_LABEL_63_0 4
#define NUMBER_OF_LINKER_SECTIONS_63_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto x_destroy_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_destroy_image_3)
DEFLABEL (x_destroy_image_0)
  INTERRUPT_CHECK (26, LABEL_63_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define ENVIRONMENT_LABEL_64_3 6
#define DEBUGGING_LABEL_64_2 5
#define OBJECT_64_0 4
#define FREE_REFERENCES_LABEL_64_0 4
#define NUMBER_OF_LINKER_SECTIONS_64_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto x_display_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_image_3)
DEFLABEL (x_display_image_0)
  INTERRUPT_CHECK (26, LABEL_64_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_0]), 8);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define ENVIRONMENT_LABEL_65_3 6
#define DEBUGGING_LABEL_65_2 5
#define OBJECT_65_0 4
#define FREE_REFERENCES_LABEL_65_0 4
#define NUMBER_OF_LINKER_SECTIONS_65_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto x_get_pixel_from_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_get_pixel_from_image_3)
DEFLABEL (x_get_pixel_from_image_0)
  INTERRUPT_CHECK (26, LABEL_65_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define ENVIRONMENT_LABEL_66_3 6
#define DEBUGGING_LABEL_66_2 5
#define OBJECT_66_0 4
#define FREE_REFERENCES_LABEL_66_0 4
#define NUMBER_OF_LINKER_SECTIONS_66_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto x_set_pixel_in_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_set_pixel_in_image_3)
DEFLABEL (x_set_pixel_in_image_0)
  INTERRUPT_CHECK (26, LABEL_66_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_0]), 4);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define ENVIRONMENT_LABEL_67_3 6
#define DEBUGGING_LABEL_67_2 5
#define OBJECT_67_0 4
#define FREE_REFERENCES_LABEL_67_0 4
#define NUMBER_OF_LINKER_SECTIONS_67_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto x_allocate_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_allocate_color_3)
DEFLABEL (x_allocate_color_0)
  INTERRUPT_CHECK (26, LABEL_67_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_0]), 4);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define ENVIRONMENT_LABEL_68_3 6
#define DEBUGGING_LABEL_68_2 5
#define OBJECT_68_0 4
#define FREE_REFERENCES_LABEL_68_0 4
#define NUMBER_OF_LINKER_SECTIONS_68_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto x_create_colormap_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_create_colormap_3)
DEFLABEL (x_create_colormap_0)
  INTERRUPT_CHECK (26, LABEL_68_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_0]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_4 3
#define ENVIRONMENT_LABEL_69_3 6
#define DEBUGGING_LABEL_69_2 5
#define OBJECT_69_0 4
#define FREE_REFERENCES_LABEL_69_0 4
#define NUMBER_OF_LINKER_SECTIONS_69_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_4);
      goto x_free_colormap_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_free_colormap_3)
DEFLABEL (x_free_colormap_0)
  INTERRUPT_CHECK (26, LABEL_69_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define ENVIRONMENT_LABEL_70_3 6
#define DEBUGGING_LABEL_70_2 5
#define OBJECT_70_0 4
#define FREE_REFERENCES_LABEL_70_0 4
#define NUMBER_OF_LINKER_SECTIONS_70_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto x_query_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_query_color_3)
DEFLABEL (x_query_color_0)
  INTERRUPT_CHECK (26, LABEL_70_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define ENVIRONMENT_LABEL_71_3 6
#define DEBUGGING_LABEL_71_2 5
#define OBJECT_71_0 4
#define FREE_REFERENCES_LABEL_71_0 4
#define NUMBER_OF_LINKER_SECTIONS_71_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto x_set_window_colormap_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_set_window_colormap_3)
DEFLABEL (x_set_window_colormap_0)
  INTERRUPT_CHECK (26, LABEL_71_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define ENVIRONMENT_LABEL_72_3 6
#define DEBUGGING_LABEL_72_2 5
#define OBJECT_72_0 4
#define FREE_REFERENCES_LABEL_72_0 4
#define NUMBER_OF_LINKER_SECTIONS_72_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto x_store_color_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_store_color_3)
DEFLABEL (x_store_color_0)
  INTERRUPT_CHECK (26, LABEL_72_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_0]), 5);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define ENVIRONMENT_LABEL_73_3 6
#define DEBUGGING_LABEL_73_2 5
#define OBJECT_73_0 4
#define FREE_REFERENCES_LABEL_73_0 4
#define NUMBER_OF_LINKER_SECTIONS_73_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto x_store_colors_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_store_colors_3)
DEFLABEL (x_store_colors_0)
  INTERRUPT_CHECK (26, LABEL_73_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define ENVIRONMENT_LABEL_74_3 6
#define DEBUGGING_LABEL_74_2 5
#define OBJECT_74_0 4
#define FREE_REFERENCES_LABEL_74_0 4
#define NUMBER_OF_LINKER_SECTIONS_74_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto x_visual_deallocate_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_deallocate_3)
DEFLABEL (x_visual_deallocate_0)
  INTERRUPT_CHECK (26, LABEL_74_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define LABEL_75_7 5
#define LABEL_75_8 7
#define LABEL_75_9 9
#define LABEL_75_10 11
#define LABEL_75_11 13
#define LABEL_75_12 15
#define LABEL_75_13 17
#define LABEL_75_14 19
#define LABEL_75_15 21
#define LABEL_75_16 23
#define LABEL_75_17 25
#define LABEL_75_18 27
#define LABEL_75_19 29
#define LABEL_75_20 31
#define LABEL_75_21 33
#define LABEL_75_22 35
#define LABEL_75_23 37
#define LABEL_75_24 39
#define LABEL_75_25 41
#define LABEL_75_26 43
#define LABEL_75_27 45
#define LABEL_75_28 47
#define LABEL_75_29 49
#define LABEL_75_30 51
#define LABEL_75_31 53
#define LABEL_75_32 55
#define LABEL_75_33 57
#define LABEL_75_34 59
#define LABEL_75_35 61
#define LABEL_75_36 63
#define LABEL_75_37 65
#define LABEL_75_38 67
#define LABEL_75_39 69
#define LABEL_75_40 71
#define LABEL_75_41 73
#define LABEL_75_42 75
#define LABEL_75_43 77
#define LABEL_75_44 79
#define LABEL_75_45 81
#define LABEL_75_46 83
#define LABEL_75_47 85
#define LABEL_75_48 87
#define LABEL_75_49 89
#define LABEL_75_50 91
#define LABEL_75_51 93
#define LABEL_75_52 95
#define LABEL_75_53 97
#define LABEL_75_54 99
#define LABEL_75_55 101
#define LABEL_75_56 103
#define LABEL_75_57 105
#define LABEL_75_58 107
#define LABEL_75_59 109
#define LABEL_75_60 111
#define LABEL_75_61 113
#define LABEL_75_62 115
#define LABEL_75_63 117
#define LABEL_75_5 119
#define LABEL_75_65 121
#define LABEL_75_67 123
#define LABEL_75_68 125
#define LABEL_75_69 127
#define LABEL_75_6 129
#define LABEL_75_66 131
#define LABEL_75_72 133
#define LABEL_75_73 135
#define ENVIRONMENT_LABEL_75_3 272
#define DEBUGGING_LABEL_75_2 271
#define OBJECT_75_59 270
#define OBJECT_75_58 269
#define OBJECT_75_57 268
#define OBJECT_75_56 267
#define OBJECT_75_55 266
#define OBJECT_75_54 265
#define OBJECT_75_53 264
#define OBJECT_75_52 263
#define OBJECT_75_51 262
#define OBJECT_75_50 261
#define OBJECT_75_49 260
#define OBJECT_75_48 259
#define OBJECT_75_47 258
#define OBJECT_75_46 257
#define OBJECT_75_45 256
#define OBJECT_75_44 255
#define OBJECT_75_43 254
#define OBJECT_75_42 253
#define OBJECT_75_41 252
#define OBJECT_75_40 251
#define OBJECT_75_39 250
#define OBJECT_75_38 249
#define OBJECT_75_37 248
#define OBJECT_75_36 247
#define OBJECT_75_35 246
#define OBJECT_75_34 245
#define OBJECT_75_33 244
#define OBJECT_75_32 243
#define OBJECT_75_31 242
#define OBJECT_75_30 241
#define OBJECT_75_29 240
#define OBJECT_75_28 239
#define OBJECT_75_27 238
#define OBJECT_75_26 237
#define OBJECT_75_25 236
#define OBJECT_75_24 235
#define OBJECT_75_23 234
#define OBJECT_75_22 233
#define OBJECT_75_21 232
#define OBJECT_75_20 231
#define OBJECT_75_19 230
#define OBJECT_75_18 229
#define OBJECT_75_17 228
#define OBJECT_75_16 227
#define OBJECT_75_15 226
#define OBJECT_75_14 225
#define OBJECT_75_13 224
#define OBJECT_75_12 223
#define OBJECT_75_11 222
#define OBJECT_75_10 221
#define OBJECT_75_9 220
#define OBJECT_75_8 219
#define OBJECT_75_7 218
#define OBJECT_75_6 217
#define OBJECT_75_5 216
#define OBJECT_75_4 215
#define OBJECT_75_3 214
#define OBJECT_75_2 213
#define OBJECT_75_1 212
#define OBJECT_75_0 211
#define EXECUTE_CACHE_75_75 137
#define EXECUTE_CACHE_75_74 139
#define EXECUTE_CACHE_75_71 141
#define EXECUTE_CACHE_75_70 143
#define EXECUTE_CACHE_75_64 145
#define FREE_REFERENCE_75_59 148
#define FREE_REFERENCE_75_58 149
#define FREE_REFERENCE_75_57 150
#define FREE_REFERENCE_75_56 151
#define FREE_REFERENCE_75_55 152
#define FREE_REFERENCE_75_54 153
#define FREE_REFERENCE_75_53 154
#define FREE_REFERENCE_75_52 155
#define FREE_REFERENCE_75_51 156
#define FREE_REFERENCE_75_50 157
#define FREE_REFERENCE_75_49 158
#define FREE_REFERENCE_75_48 159
#define FREE_REFERENCE_75_47 160
#define FREE_REFERENCE_75_46 161
#define FREE_REFERENCE_75_45 162
#define FREE_REFERENCE_75_44 163
#define FREE_REFERENCE_75_43 164
#define FREE_REFERENCE_75_42 165
#define FREE_REFERENCE_75_41 166
#define FREE_REFERENCE_75_40 167
#define FREE_REFERENCE_75_39 168
#define FREE_REFERENCE_75_38 169
#define FREE_REFERENCE_75_37 170
#define FREE_REFERENCE_75_36 171
#define FREE_REFERENCE_75_35 172
#define FREE_REFERENCE_75_34 173
#define FREE_REFERENCE_75_33 174
#define FREE_REFERENCE_75_32 175
#define FREE_REFERENCE_75_31 176
#define FREE_REFERENCE_75_30 177
#define FREE_REFERENCE_75_29 178
#define FREE_REFERENCE_75_28 179
#define FREE_REFERENCE_75_27 180
#define FREE_REFERENCE_75_26 181
#define FREE_REFERENCE_75_25 182
#define FREE_REFERENCE_75_24 183
#define FREE_REFERENCE_75_23 184
#define FREE_REFERENCE_75_22 185
#define FREE_REFERENCE_75_21 186
#define FREE_REFERENCE_75_20 187
#define FREE_REFERENCE_75_19 188
#define FREE_REFERENCE_75_18 189
#define FREE_REFERENCE_75_17 190
#define FREE_REFERENCE_75_16 191
#define FREE_REFERENCE_75_15 192
#define FREE_REFERENCE_75_14 193
#define FREE_REFERENCE_75_13 194
#define FREE_REFERENCE_75_12 195
#define FREE_REFERENCE_75_11 196
#define FREE_REFERENCE_75_10 197
#define FREE_REFERENCE_75_9 198
#define FREE_REFERENCE_75_8 199
#define FREE_REFERENCE_75_7 200
#define FREE_REFERENCE_75_6 201
#define FREE_REFERENCE_75_5 202
#define FREE_REFERENCE_75_4 203
#define FREE_REFERENCE_75_3 204
#define FREE_REFERENCE_75_2 205
#define FREE_REFERENCE_75_1 206
#define FREE_REFERENCE_75_0 207
#define FREE_ASSIGNMENT_75_1 209
#define FREE_ASSIGNMENT_75_0 210
#define FREE_REFERENCES_LABEL_75_0 136
#define NUMBER_OF_LINKER_SECTIONS_75_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd864;
  machine_word Wrd863;
  machine_word Wrd865;
  machine_word Wrd858;
  machine_word Wrd860;
  machine_word Wrd861;
  machine_word Wrd852;
  machine_word Wrd857;
  machine_word Wrd856;
  machine_word Wrd853;
  machine_word Wrd849;
  machine_word Wrd848;
  machine_word Wrd850;
  machine_word Wrd843;
  machine_word Wrd845;
  machine_word Wrd846;
  machine_word Wrd837;
  machine_word Wrd842;
  machine_word Wrd841;
  machine_word Wrd838;
  machine_word Wrd834;
  machine_word Wrd833;
  machine_word Wrd835;
  machine_word Wrd828;
  machine_word Wrd830;
  machine_word Wrd831;
  machine_word Wrd822;
  machine_word Wrd827;
  machine_word Wrd826;
  machine_word Wrd823;
  machine_word Wrd819;
  machine_word Wrd818;
  machine_word Wrd820;
  machine_word Wrd813;
  machine_word Wrd815;
  machine_word Wrd816;
  machine_word Wrd807;
  machine_word Wrd812;
  machine_word Wrd811;
  machine_word Wrd808;
  machine_word Wrd804;
  machine_word Wrd803;
  machine_word Wrd805;
  machine_word Wrd798;
  machine_word Wrd800;
  machine_word Wrd801;
  machine_word Wrd792;
  machine_word Wrd797;
  machine_word Wrd796;
  machine_word Wrd793;
  machine_word Wrd789;
  machine_word Wrd788;
  machine_word Wrd790;
  machine_word Wrd783;
  machine_word Wrd785;
  machine_word Wrd786;
  machine_word Wrd777;
  machine_word Wrd782;
  machine_word Wrd781;
  machine_word Wrd778;
  machine_word Wrd774;
  machine_word Wrd773;
  machine_word Wrd775;
  machine_word Wrd768;
  machine_word Wrd770;
  machine_word Wrd771;
  machine_word Wrd762;
  machine_word Wrd767;
  machine_word Wrd766;
  machine_word Wrd763;
  machine_word Wrd759;
  machine_word Wrd758;
  machine_word Wrd760;
  machine_word Wrd753;
  machine_word Wrd755;
  machine_word Wrd756;
  machine_word Wrd747;
  machine_word Wrd752;
  machine_word Wrd751;
  machine_word Wrd748;
  machine_word Wrd744;
  machine_word Wrd743;
  machine_word Wrd745;
  machine_word Wrd738;
  machine_word Wrd740;
  machine_word Wrd741;
  machine_word Wrd732;
  machine_word Wrd737;
  machine_word Wrd736;
  machine_word Wrd733;
  machine_word Wrd729;
  machine_word Wrd728;
  machine_word Wrd730;
  machine_word Wrd723;
  machine_word Wrd725;
  machine_word Wrd726;
  machine_word Wrd717;
  machine_word Wrd722;
  machine_word Wrd721;
  machine_word Wrd718;
  machine_word Wrd714;
  machine_word Wrd713;
  machine_word Wrd715;
  machine_word Wrd708;
  machine_word Wrd710;
  machine_word Wrd711;
  machine_word Wrd702;
  machine_word Wrd707;
  machine_word Wrd706;
  machine_word Wrd703;
  machine_word Wrd699;
  machine_word Wrd698;
  machine_word Wrd700;
  machine_word Wrd693;
  machine_word Wrd695;
  machine_word Wrd696;
  machine_word Wrd687;
  machine_word Wrd692;
  machine_word Wrd691;
  machine_word Wrd688;
  machine_word Wrd684;
  machine_word Wrd683;
  machine_word Wrd685;
  machine_word Wrd678;
  machine_word Wrd680;
  machine_word Wrd681;
  machine_word Wrd672;
  machine_word Wrd677;
  machine_word Wrd676;
  machine_word Wrd673;
  machine_word Wrd669;
  machine_word Wrd668;
  machine_word Wrd670;
  machine_word Wrd663;
  machine_word Wrd665;
  machine_word Wrd666;
  machine_word Wrd657;
  machine_word Wrd662;
  machine_word Wrd661;
  machine_word Wrd658;
  machine_word Wrd654;
  machine_word Wrd653;
  machine_word Wrd655;
  machine_word Wrd648;
  machine_word Wrd650;
  machine_word Wrd651;
  machine_word Wrd642;
  machine_word Wrd647;
  machine_word Wrd646;
  machine_word Wrd643;
  machine_word Wrd639;
  machine_word Wrd638;
  machine_word Wrd640;
  machine_word Wrd633;
  machine_word Wrd635;
  machine_word Wrd636;
  machine_word Wrd627;
  machine_word Wrd632;
  machine_word Wrd631;
  machine_word Wrd628;
  machine_word Wrd624;
  machine_word Wrd623;
  machine_word Wrd625;
  machine_word Wrd618;
  machine_word Wrd620;
  machine_word Wrd621;
  machine_word Wrd612;
  machine_word Wrd617;
  machine_word Wrd616;
  machine_word Wrd613;
  machine_word Wrd609;
  machine_word Wrd608;
  machine_word Wrd610;
  machine_word Wrd603;
  machine_word Wrd605;
  machine_word Wrd606;
  machine_word Wrd597;
  machine_word Wrd602;
  machine_word Wrd601;
  machine_word Wrd598;
  machine_word Wrd594;
  machine_word Wrd593;
  machine_word Wrd595;
  machine_word Wrd588;
  machine_word Wrd590;
  machine_word Wrd591;
  machine_word Wrd582;
  machine_word Wrd587;
  machine_word Wrd586;
  machine_word Wrd583;
  machine_word Wrd579;
  machine_word Wrd578;
  machine_word Wrd580;
  machine_word Wrd573;
  machine_word Wrd575;
  machine_word Wrd576;
  machine_word Wrd567;
  machine_word Wrd572;
  machine_word Wrd571;
  machine_word Wrd568;
  machine_word Wrd564;
  machine_word Wrd563;
  machine_word Wrd565;
  machine_word Wrd558;
  machine_word Wrd560;
  machine_word Wrd561;
  machine_word Wrd552;
  machine_word Wrd557;
  machine_word Wrd556;
  machine_word Wrd553;
  machine_word Wrd549;
  machine_word Wrd548;
  machine_word Wrd550;
  machine_word Wrd543;
  machine_word Wrd545;
  machine_word Wrd546;
  machine_word Wrd537;
  machine_word Wrd542;
  machine_word Wrd541;
  machine_word Wrd538;
  machine_word Wrd534;
  machine_word Wrd533;
  machine_word Wrd535;
  machine_word Wrd528;
  machine_word Wrd530;
  machine_word Wrd531;
  machine_word Wrd522;
  machine_word Wrd527;
  machine_word Wrd526;
  machine_word Wrd523;
  machine_word Wrd519;
  machine_word Wrd518;
  machine_word Wrd520;
  machine_word Wrd513;
  machine_word Wrd515;
  machine_word Wrd516;
  machine_word Wrd507;
  machine_word Wrd512;
  machine_word Wrd511;
  machine_word Wrd508;
  machine_word Wrd504;
  machine_word Wrd503;
  machine_word Wrd505;
  machine_word Wrd498;
  machine_word Wrd500;
  machine_word Wrd501;
  machine_word Wrd492;
  machine_word Wrd497;
  machine_word Wrd496;
  machine_word Wrd493;
  machine_word Wrd489;
  machine_word Wrd488;
  machine_word Wrd490;
  machine_word Wrd483;
  machine_word Wrd485;
  machine_word Wrd486;
  machine_word Wrd477;
  machine_word Wrd482;
  machine_word Wrd481;
  machine_word Wrd478;
  machine_word Wrd474;
  machine_word Wrd473;
  machine_word Wrd475;
  machine_word Wrd468;
  machine_word Wrd470;
  machine_word Wrd471;
  machine_word Wrd462;
  machine_word Wrd467;
  machine_word Wrd466;
  machine_word Wrd463;
  machine_word Wrd459;
  machine_word Wrd458;
  machine_word Wrd460;
  machine_word Wrd453;
  machine_word Wrd455;
  machine_word Wrd456;
  machine_word Wrd447;
  machine_word Wrd452;
  machine_word Wrd451;
  machine_word Wrd448;
  machine_word Wrd444;
  machine_word Wrd443;
  machine_word Wrd445;
  machine_word Wrd438;
  machine_word Wrd440;
  machine_word Wrd441;
  machine_word Wrd432;
  machine_word Wrd437;
  machine_word Wrd436;
  machine_word Wrd433;
  machine_word Wrd429;
  machine_word Wrd428;
  machine_word Wrd430;
  machine_word Wrd423;
  machine_word Wrd425;
  machine_word Wrd426;
  machine_word Wrd417;
  machine_word Wrd422;
  machine_word Wrd421;
  machine_word Wrd418;
  machine_word Wrd414;
  machine_word Wrd413;
  machine_word Wrd415;
  machine_word Wrd408;
  machine_word Wrd410;
  machine_word Wrd411;
  machine_word Wrd402;
  machine_word Wrd407;
  machine_word Wrd406;
  machine_word Wrd403;
  machine_word Wrd399;
  machine_word Wrd398;
  machine_word Wrd400;
  machine_word Wrd393;
  machine_word Wrd395;
  machine_word Wrd396;
  machine_word Wrd387;
  machine_word Wrd392;
  machine_word Wrd391;
  machine_word Wrd388;
  machine_word Wrd384;
  machine_word Wrd383;
  machine_word Wrd385;
  machine_word Wrd378;
  machine_word Wrd380;
  machine_word Wrd381;
  machine_word Wrd372;
  machine_word Wrd377;
  machine_word Wrd376;
  machine_word Wrd373;
  machine_word Wrd369;
  machine_word Wrd368;
  machine_word Wrd370;
  machine_word Wrd363;
  machine_word Wrd365;
  machine_word Wrd366;
  machine_word Wrd357;
  machine_word Wrd362;
  machine_word Wrd361;
  machine_word Wrd358;
  machine_word Wrd354;
  machine_word Wrd353;
  machine_word Wrd355;
  machine_word Wrd348;
  machine_word Wrd350;
  machine_word Wrd351;
  machine_word Wrd342;
  machine_word Wrd347;
  machine_word Wrd346;
  machine_word Wrd343;
  machine_word Wrd339;
  machine_word Wrd338;
  machine_word Wrd340;
  machine_word Wrd333;
  machine_word Wrd335;
  machine_word Wrd336;
  machine_word Wrd327;
  machine_word Wrd332;
  machine_word Wrd331;
  machine_word Wrd328;
  machine_word Wrd324;
  machine_word Wrd323;
  machine_word Wrd325;
  machine_word Wrd318;
  machine_word Wrd320;
  machine_word Wrd321;
  machine_word Wrd312;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd313;
  machine_word Wrd309;
  machine_word Wrd308;
  machine_word Wrd310;
  machine_word Wrd303;
  machine_word Wrd305;
  machine_word Wrd306;
  machine_word Wrd297;
  machine_word Wrd302;
  machine_word Wrd301;
  machine_word Wrd298;
  machine_word Wrd294;
  machine_word Wrd293;
  machine_word Wrd295;
  machine_word Wrd288;
  machine_word Wrd290;
  machine_word Wrd291;
  machine_word Wrd282;
  machine_word Wrd287;
  machine_word Wrd286;
  machine_word Wrd283;
  machine_word Wrd279;
  machine_word Wrd278;
  machine_word Wrd280;
  machine_word Wrd273;
  machine_word Wrd275;
  machine_word Wrd276;
  machine_word Wrd267;
  machine_word Wrd272;
  machine_word Wrd271;
  machine_word Wrd268;
  machine_word Wrd264;
  machine_word Wrd263;
  machine_word Wrd265;
  machine_word Wrd258;
  machine_word Wrd260;
  machine_word Wrd261;
  machine_word Wrd252;
  machine_word Wrd257;
  machine_word Wrd256;
  machine_word Wrd253;
  machine_word Wrd249;
  machine_word Wrd248;
  machine_word Wrd250;
  machine_word Wrd243;
  machine_word Wrd245;
  machine_word Wrd246;
  machine_word Wrd237;
  machine_word Wrd242;
  machine_word Wrd241;
  machine_word Wrd238;
  machine_word Wrd234;
  machine_word Wrd233;
  machine_word Wrd235;
  machine_word Wrd228;
  machine_word Wrd230;
  machine_word Wrd231;
  machine_word Wrd222;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd223;
  machine_word Wrd219;
  machine_word Wrd218;
  machine_word Wrd220;
  machine_word Wrd213;
  machine_word Wrd215;
  machine_word Wrd216;
  machine_word Wrd207;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd208;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd205;
  machine_word Wrd198;
  machine_word Wrd200;
  machine_word Wrd201;
  machine_word Wrd192;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd193;
  machine_word Wrd189;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd183;
  machine_word Wrd185;
  machine_word Wrd186;
  machine_word Wrd177;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd178;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd175;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd162;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd163;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd160;
  machine_word Wrd153;
  machine_word Wrd155;
  machine_word Wrd156;
  machine_word Wrd147;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd145;
  machine_word Wrd138;
  machine_word Wrd140;
  machine_word Wrd141;
  machine_word Wrd132;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd130;
  machine_word Wrd123;
  machine_word Wrd125;
  machine_word Wrd126;
  machine_word Wrd117;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd118;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd111;
  machine_word Wrd102;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd93;
  machine_word Wrd95;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd72;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd70;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto initialize_packageB_118;

    case 1:
      current_block = (Rpc - LABEL_75_7);
      goto label_120;

    case 2:
      current_block = (Rpc - LABEL_75_8);
      goto label_121;

    case 3:
      current_block = (Rpc - LABEL_75_9);
      goto label_122;

    case 4:
      current_block = (Rpc - LABEL_75_10);
      goto label_123;

    case 5:
      current_block = (Rpc - LABEL_75_11);
      goto label_124;

    case 6:
      current_block = (Rpc - LABEL_75_12);
      goto label_125;

    case 7:
      current_block = (Rpc - LABEL_75_13);
      goto label_126;

    case 8:
      current_block = (Rpc - LABEL_75_14);
      goto label_127;

    case 9:
      current_block = (Rpc - LABEL_75_15);
      goto label_128;

    case 10:
      current_block = (Rpc - LABEL_75_16);
      goto label_129;

    case 11:
      current_block = (Rpc - LABEL_75_17);
      goto label_130;

    case 12:
      current_block = (Rpc - LABEL_75_18);
      goto label_131;

    case 13:
      current_block = (Rpc - LABEL_75_19);
      goto label_132;

    case 14:
      current_block = (Rpc - LABEL_75_20);
      goto label_133;

    case 15:
      current_block = (Rpc - LABEL_75_21);
      goto label_134;

    case 16:
      current_block = (Rpc - LABEL_75_22);
      goto label_135;

    case 17:
      current_block = (Rpc - LABEL_75_23);
      goto label_136;

    case 18:
      current_block = (Rpc - LABEL_75_24);
      goto label_137;

    case 19:
      current_block = (Rpc - LABEL_75_25);
      goto label_138;

    case 20:
      current_block = (Rpc - LABEL_75_26);
      goto label_139;

    case 21:
      current_block = (Rpc - LABEL_75_27);
      goto label_140;

    case 22:
      current_block = (Rpc - LABEL_75_28);
      goto label_141;

    case 23:
      current_block = (Rpc - LABEL_75_29);
      goto label_142;

    case 24:
      current_block = (Rpc - LABEL_75_30);
      goto label_143;

    case 25:
      current_block = (Rpc - LABEL_75_31);
      goto label_144;

    case 26:
      current_block = (Rpc - LABEL_75_32);
      goto label_145;

    case 27:
      current_block = (Rpc - LABEL_75_33);
      goto label_146;

    case 28:
      current_block = (Rpc - LABEL_75_34);
      goto label_147;

    case 29:
      current_block = (Rpc - LABEL_75_35);
      goto label_148;

    case 30:
      current_block = (Rpc - LABEL_75_36);
      goto label_149;

    case 31:
      current_block = (Rpc - LABEL_75_37);
      goto label_150;

    case 32:
      current_block = (Rpc - LABEL_75_38);
      goto label_151;

    case 33:
      current_block = (Rpc - LABEL_75_39);
      goto label_152;

    case 34:
      current_block = (Rpc - LABEL_75_40);
      goto label_153;

    case 35:
      current_block = (Rpc - LABEL_75_41);
      goto label_154;

    case 36:
      current_block = (Rpc - LABEL_75_42);
      goto label_155;

    case 37:
      current_block = (Rpc - LABEL_75_43);
      goto label_156;

    case 38:
      current_block = (Rpc - LABEL_75_44);
      goto label_157;

    case 39:
      current_block = (Rpc - LABEL_75_45);
      goto label_158;

    case 40:
      current_block = (Rpc - LABEL_75_46);
      goto label_159;

    case 41:
      current_block = (Rpc - LABEL_75_47);
      goto label_160;

    case 42:
      current_block = (Rpc - LABEL_75_48);
      goto label_161;

    case 43:
      current_block = (Rpc - LABEL_75_49);
      goto label_162;

    case 44:
      current_block = (Rpc - LABEL_75_50);
      goto label_163;

    case 45:
      current_block = (Rpc - LABEL_75_51);
      goto label_164;

    case 46:
      current_block = (Rpc - LABEL_75_52);
      goto label_165;

    case 47:
      current_block = (Rpc - LABEL_75_53);
      goto label_166;

    case 48:
      current_block = (Rpc - LABEL_75_54);
      goto label_167;

    case 49:
      current_block = (Rpc - LABEL_75_55);
      goto label_168;

    case 50:
      current_block = (Rpc - LABEL_75_56);
      goto label_169;

    case 51:
      current_block = (Rpc - LABEL_75_57);
      goto label_170;

    case 52:
      current_block = (Rpc - LABEL_75_58);
      goto label_171;

    case 53:
      current_block = (Rpc - LABEL_75_59);
      goto label_172;

    case 54:
      current_block = (Rpc - LABEL_75_60);
      goto label_173;

    case 55:
      current_block = (Rpc - LABEL_75_61);
      goto label_174;

    case 56:
      current_block = (Rpc - LABEL_75_62);
      goto label_175;

    case 57:
      current_block = (Rpc - LABEL_75_63);
      goto label_176;

    case 58:
      current_block = (Rpc - LABEL_75_5);
      goto continuation_115;

    case 59:
      current_block = (Rpc - LABEL_75_65);
      goto label_177;

    case 60:
      current_block = (Rpc - LABEL_75_67);
      goto label_178;

    case 61:
      current_block = (Rpc - LABEL_75_68);
      goto label_179;

    case 62:
      current_block = (Rpc - LABEL_75_69);
      goto label_180;

    case 63:
      current_block = (Rpc - LABEL_75_6);
      goto continuation_114;

    case 64:
      current_block = (Rpc - LABEL_75_66);
      goto continuation_116;

    case 65:
      current_block = (Rpc - LABEL_75_72);
      goto label_181;

    case 66:
      current_block = (Rpc - LABEL_75_73);
      goto continuation_117;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_183)
DEFLABEL (initialize_packageB_118)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_309;
  Wrd12 = Wrd16;

DEFLABEL (label_308)
  (Wrd21.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_75_1]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_1]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_307;
  Wrd27 = Wrd31;

DEFLABEL (label_306)
  (Wrd36.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd40.Obj) = (current_block [OBJECT_75_2]);
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_2]));
  (Wrd46.Obj) = ((Wrd43.pObj) [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 50)
    goto label_305;
  Wrd42 = Wrd46;

DEFLABEL (label_304)
  (Wrd51.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd51.Obj);
  (Wrd50.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd50.pObj)));
  (Wrd55.Obj) = (current_block [OBJECT_75_3]);
  (* (Rhp++)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_3]));
  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 50)
    goto label_303;
  Wrd57 = Wrd61;

DEFLABEL (label_302)
  (Wrd66.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd65.pObj) = (& (Rhp [-2]));
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd65.pObj)));
  (Wrd70.Obj) = (current_block [OBJECT_75_4]);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd63.Obj);
  (Wrd68.pObj) = (& (Rhp [-2]));
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd68.pObj)));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_4]));
  (Wrd76.Obj) = ((Wrd73.pObj) [0]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if ((Wrd77.uLng) == 50)
    goto label_301;
  Wrd72 = Wrd76;

DEFLABEL (label_300)
  (Wrd81.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd72.Obj);
  (* (Rhp++)) = (Wrd81.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (Wrd85.Obj) = (current_block [OBJECT_75_5]);
  (* (Rhp++)) = (Wrd85.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd83.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd83.pObj)));
  (* (--Rsp)) = (Wrd84.Obj);
  (Wrd88.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_5]));
  (Wrd91.Obj) = ((Wrd88.pObj) [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd92.uLng) == 50)
    goto label_299;
  Wrd87 = Wrd91;

DEFLABEL (label_298)
  (Wrd96.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd87.Obj);
  (* (Rhp++)) = (Wrd96.Obj);
  (Wrd95.pObj) = (& (Rhp [-2]));
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd95.pObj)));
  (Wrd100.Obj) = (current_block [OBJECT_75_6]);
  (* (Rhp++)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd93.Obj);
  (Wrd98.pObj) = (& (Rhp [-2]));
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd98.pObj)));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd103.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_6]));
  (Wrd106.Obj) = ((Wrd103.pObj) [0]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if ((Wrd107.uLng) == 50)
    goto label_297;
  Wrd102 = Wrd106;

DEFLABEL (label_296)
  (Wrd111.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd102.Obj);
  (* (Rhp++)) = (Wrd111.Obj);
  (Wrd110.pObj) = (& (Rhp [-2]));
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd110.pObj)));
  (Wrd115.Obj) = (current_block [OBJECT_75_7]);
  (* (Rhp++)) = (Wrd115.Obj);
  (* (Rhp++)) = (Wrd108.Obj);
  (Wrd113.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd113.pObj)));
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd118.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_7]));
  (Wrd121.Obj) = ((Wrd118.pObj) [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if ((Wrd122.uLng) == 50)
    goto label_295;
  Wrd117 = Wrd121;

DEFLABEL (label_294)
  (Wrd126.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd117.Obj);
  (* (Rhp++)) = (Wrd126.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (Wrd130.Obj) = (current_block [OBJECT_75_8]);
  (* (Rhp++)) = (Wrd130.Obj);
  (* (Rhp++)) = (Wrd123.Obj);
  (Wrd128.pObj) = (& (Rhp [-2]));
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd128.pObj)));
  (* (--Rsp)) = (Wrd129.Obj);
  (Wrd133.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_8]));
  (Wrd136.Obj) = ((Wrd133.pObj) [0]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if ((Wrd137.uLng) == 50)
    goto label_293;
  Wrd132 = Wrd136;

DEFLABEL (label_292)
  (Wrd141.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd132.Obj);
  (* (Rhp++)) = (Wrd141.Obj);
  (Wrd140.pObj) = (& (Rhp [-2]));
  (Wrd138.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd140.pObj)));
  (Wrd145.Obj) = (current_block [OBJECT_75_9]);
  (* (Rhp++)) = (Wrd145.Obj);
  (* (Rhp++)) = (Wrd138.Obj);
  (Wrd143.pObj) = (& (Rhp [-2]));
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd143.pObj)));
  (* (--Rsp)) = (Wrd144.Obj);
  (Wrd148.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_9]));
  (Wrd151.Obj) = ((Wrd148.pObj) [0]);
  (Wrd152.uLng) = (OBJECT_TYPE (Wrd151.Obj));
  if ((Wrd152.uLng) == 50)
    goto label_291;
  Wrd147 = Wrd151;

DEFLABEL (label_290)
  (Wrd156.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd147.Obj);
  (* (Rhp++)) = (Wrd156.Obj);
  (Wrd155.pObj) = (& (Rhp [-2]));
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd155.pObj)));
  (Wrd160.Obj) = (current_block [OBJECT_75_10]);
  (* (Rhp++)) = (Wrd160.Obj);
  (* (Rhp++)) = (Wrd153.Obj);
  (Wrd158.pObj) = (& (Rhp [-2]));
  (Wrd159.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd158.pObj)));
  (* (--Rsp)) = (Wrd159.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_10]));
  (Wrd166.Obj) = ((Wrd163.pObj) [0]);
  (Wrd167.uLng) = (OBJECT_TYPE (Wrd166.Obj));
  if ((Wrd167.uLng) == 50)
    goto label_289;
  Wrd162 = Wrd166;

DEFLABEL (label_288)
  (Wrd171.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd162.Obj);
  (* (Rhp++)) = (Wrd171.Obj);
  (Wrd170.pObj) = (& (Rhp [-2]));
  (Wrd168.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd170.pObj)));
  (Wrd175.Obj) = (current_block [OBJECT_75_11]);
  (* (Rhp++)) = (Wrd175.Obj);
  (* (Rhp++)) = (Wrd168.Obj);
  (Wrd173.pObj) = (& (Rhp [-2]));
  (Wrd174.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd173.pObj)));
  (* (--Rsp)) = (Wrd174.Obj);
  (Wrd178.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_11]));
  (Wrd181.Obj) = ((Wrd178.pObj) [0]);
  (Wrd182.uLng) = (OBJECT_TYPE (Wrd181.Obj));
  if ((Wrd182.uLng) == 50)
    goto label_287;
  Wrd177 = Wrd181;

DEFLABEL (label_286)
  (Wrd186.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd177.Obj);
  (* (Rhp++)) = (Wrd186.Obj);
  (Wrd185.pObj) = (& (Rhp [-2]));
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd185.pObj)));
  (Wrd190.Obj) = (current_block [OBJECT_75_12]);
  (* (Rhp++)) = (Wrd190.Obj);
  (* (Rhp++)) = (Wrd183.Obj);
  (Wrd188.pObj) = (& (Rhp [-2]));
  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd188.pObj)));
  (* (--Rsp)) = (Wrd189.Obj);
  (Wrd193.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_12]));
  (Wrd196.Obj) = ((Wrd193.pObj) [0]);
  (Wrd197.uLng) = (OBJECT_TYPE (Wrd196.Obj));
  if ((Wrd197.uLng) == 50)
    goto label_285;
  Wrd192 = Wrd196;

DEFLABEL (label_284)
  (Wrd201.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd192.Obj);
  (* (Rhp++)) = (Wrd201.Obj);
  (Wrd200.pObj) = (& (Rhp [-2]));
  (Wrd198.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd200.pObj)));
  (Wrd205.Obj) = (current_block [OBJECT_75_13]);
  (* (Rhp++)) = (Wrd205.Obj);
  (* (Rhp++)) = (Wrd198.Obj);
  (Wrd203.pObj) = (& (Rhp [-2]));
  (Wrd204.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd203.pObj)));
  (* (--Rsp)) = (Wrd204.Obj);
  (Wrd208.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_13]));
  (Wrd211.Obj) = ((Wrd208.pObj) [0]);
  (Wrd212.uLng) = (OBJECT_TYPE (Wrd211.Obj));
  if ((Wrd212.uLng) == 50)
    goto label_283;
  Wrd207 = Wrd211;

DEFLABEL (label_282)
  (Wrd216.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd207.Obj);
  (* (Rhp++)) = (Wrd216.Obj);
  (Wrd215.pObj) = (& (Rhp [-2]));
  (Wrd213.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd215.pObj)));
  (Wrd220.Obj) = (current_block [OBJECT_75_14]);
  (* (Rhp++)) = (Wrd220.Obj);
  (* (Rhp++)) = (Wrd213.Obj);
  (Wrd218.pObj) = (& (Rhp [-2]));
  (Wrd219.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd218.pObj)));
  (* (--Rsp)) = (Wrd219.Obj);
  (Wrd223.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_14]));
  (Wrd226.Obj) = ((Wrd223.pObj) [0]);
  (Wrd227.uLng) = (OBJECT_TYPE (Wrd226.Obj));
  if ((Wrd227.uLng) == 50)
    goto label_281;
  Wrd222 = Wrd226;

DEFLABEL (label_280)
  (Wrd231.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd222.Obj);
  (* (Rhp++)) = (Wrd231.Obj);
  (Wrd230.pObj) = (& (Rhp [-2]));
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd230.pObj)));
  (Wrd235.Obj) = (current_block [OBJECT_75_15]);
  (* (Rhp++)) = (Wrd235.Obj);
  (* (Rhp++)) = (Wrd228.Obj);
  (Wrd233.pObj) = (& (Rhp [-2]));
  (Wrd234.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd233.pObj)));
  (* (--Rsp)) = (Wrd234.Obj);
  (Wrd238.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_15]));
  (Wrd241.Obj) = ((Wrd238.pObj) [0]);
  (Wrd242.uLng) = (OBJECT_TYPE (Wrd241.Obj));
  if ((Wrd242.uLng) == 50)
    goto label_279;
  Wrd237 = Wrd241;

DEFLABEL (label_278)
  (Wrd246.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd237.Obj);
  (* (Rhp++)) = (Wrd246.Obj);
  (Wrd245.pObj) = (& (Rhp [-2]));
  (Wrd243.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd245.pObj)));
  (Wrd250.Obj) = (current_block [OBJECT_75_16]);
  (* (Rhp++)) = (Wrd250.Obj);
  (* (Rhp++)) = (Wrd243.Obj);
  (Wrd248.pObj) = (& (Rhp [-2]));
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd248.pObj)));
  (* (--Rsp)) = (Wrd249.Obj);
  (Wrd253.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_16]));
  (Wrd256.Obj) = ((Wrd253.pObj) [0]);
  (Wrd257.uLng) = (OBJECT_TYPE (Wrd256.Obj));
  if ((Wrd257.uLng) == 50)
    goto label_277;
  Wrd252 = Wrd256;

DEFLABEL (label_276)
  (Wrd261.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd252.Obj);
  (* (Rhp++)) = (Wrd261.Obj);
  (Wrd260.pObj) = (& (Rhp [-2]));
  (Wrd258.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd260.pObj)));
  (Wrd265.Obj) = (current_block [OBJECT_75_17]);
  (* (Rhp++)) = (Wrd265.Obj);
  (* (Rhp++)) = (Wrd258.Obj);
  (Wrd263.pObj) = (& (Rhp [-2]));
  (Wrd264.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd263.pObj)));
  (* (--Rsp)) = (Wrd264.Obj);
  (Wrd268.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_17]));
  (Wrd271.Obj) = ((Wrd268.pObj) [0]);
  (Wrd272.uLng) = (OBJECT_TYPE (Wrd271.Obj));
  if ((Wrd272.uLng) == 50)
    goto label_275;
  Wrd267 = Wrd271;

DEFLABEL (label_274)
  (Wrd276.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd267.Obj);
  (* (Rhp++)) = (Wrd276.Obj);
  (Wrd275.pObj) = (& (Rhp [-2]));
  (Wrd273.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd275.pObj)));
  (Wrd280.Obj) = (current_block [OBJECT_75_18]);
  (* (Rhp++)) = (Wrd280.Obj);
  (* (Rhp++)) = (Wrd273.Obj);
  (Wrd278.pObj) = (& (Rhp [-2]));
  (Wrd279.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd278.pObj)));
  (* (--Rsp)) = (Wrd279.Obj);
  (Wrd283.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_18]));
  (Wrd286.Obj) = ((Wrd283.pObj) [0]);
  (Wrd287.uLng) = (OBJECT_TYPE (Wrd286.Obj));
  if ((Wrd287.uLng) == 50)
    goto label_273;
  Wrd282 = Wrd286;

DEFLABEL (label_272)
  (Wrd291.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd282.Obj);
  (* (Rhp++)) = (Wrd291.Obj);
  (Wrd290.pObj) = (& (Rhp [-2]));
  (Wrd288.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd290.pObj)));
  (Wrd295.Obj) = (current_block [OBJECT_75_19]);
  (* (Rhp++)) = (Wrd295.Obj);
  (* (Rhp++)) = (Wrd288.Obj);
  (Wrd293.pObj) = (& (Rhp [-2]));
  (Wrd294.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd293.pObj)));
  (* (--Rsp)) = (Wrd294.Obj);
  (Wrd298.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_19]));
  (Wrd301.Obj) = ((Wrd298.pObj) [0]);
  (Wrd302.uLng) = (OBJECT_TYPE (Wrd301.Obj));
  if ((Wrd302.uLng) == 50)
    goto label_271;
  Wrd297 = Wrd301;

DEFLABEL (label_270)
  (Wrd306.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd297.Obj);
  (* (Rhp++)) = (Wrd306.Obj);
  (Wrd305.pObj) = (& (Rhp [-2]));
  (Wrd303.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd305.pObj)));
  (Wrd310.Obj) = (current_block [OBJECT_75_20]);
  (* (Rhp++)) = (Wrd310.Obj);
  (* (Rhp++)) = (Wrd303.Obj);
  (Wrd308.pObj) = (& (Rhp [-2]));
  (Wrd309.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd308.pObj)));
  (* (--Rsp)) = (Wrd309.Obj);
  (Wrd313.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_20]));
  (Wrd316.Obj) = ((Wrd313.pObj) [0]);
  (Wrd317.uLng) = (OBJECT_TYPE (Wrd316.Obj));
  if ((Wrd317.uLng) == 50)
    goto label_269;
  Wrd312 = Wrd316;

DEFLABEL (label_268)
  (Wrd321.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd312.Obj);
  (* (Rhp++)) = (Wrd321.Obj);
  (Wrd320.pObj) = (& (Rhp [-2]));
  (Wrd318.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd320.pObj)));
  (Wrd325.Obj) = (current_block [OBJECT_75_21]);
  (* (Rhp++)) = (Wrd325.Obj);
  (* (Rhp++)) = (Wrd318.Obj);
  (Wrd323.pObj) = (& (Rhp [-2]));
  (Wrd324.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd323.pObj)));
  (* (--Rsp)) = (Wrd324.Obj);
  (Wrd328.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_21]));
  (Wrd331.Obj) = ((Wrd328.pObj) [0]);
  (Wrd332.uLng) = (OBJECT_TYPE (Wrd331.Obj));
  if ((Wrd332.uLng) == 50)
    goto label_267;
  Wrd327 = Wrd331;

DEFLABEL (label_266)
  (Wrd336.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd327.Obj);
  (* (Rhp++)) = (Wrd336.Obj);
  (Wrd335.pObj) = (& (Rhp [-2]));
  (Wrd333.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd335.pObj)));
  (Wrd340.Obj) = (current_block [OBJECT_75_22]);
  (* (Rhp++)) = (Wrd340.Obj);
  (* (Rhp++)) = (Wrd333.Obj);
  (Wrd338.pObj) = (& (Rhp [-2]));
  (Wrd339.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd338.pObj)));
  (* (--Rsp)) = (Wrd339.Obj);
  (Wrd343.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_22]));
  (Wrd346.Obj) = ((Wrd343.pObj) [0]);
  (Wrd347.uLng) = (OBJECT_TYPE (Wrd346.Obj));
  if ((Wrd347.uLng) == 50)
    goto label_265;
  Wrd342 = Wrd346;

DEFLABEL (label_264)
  (Wrd351.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd342.Obj);
  (* (Rhp++)) = (Wrd351.Obj);
  (Wrd350.pObj) = (& (Rhp [-2]));
  (Wrd348.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd350.pObj)));
  (Wrd355.Obj) = (current_block [OBJECT_75_23]);
  (* (Rhp++)) = (Wrd355.Obj);
  (* (Rhp++)) = (Wrd348.Obj);
  (Wrd353.pObj) = (& (Rhp [-2]));
  (Wrd354.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd353.pObj)));
  (* (--Rsp)) = (Wrd354.Obj);
  (Wrd358.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_23]));
  (Wrd361.Obj) = ((Wrd358.pObj) [0]);
  (Wrd362.uLng) = (OBJECT_TYPE (Wrd361.Obj));
  if ((Wrd362.uLng) == 50)
    goto label_263;
  Wrd357 = Wrd361;

DEFLABEL (label_262)
  (Wrd366.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd357.Obj);
  (* (Rhp++)) = (Wrd366.Obj);
  (Wrd365.pObj) = (& (Rhp [-2]));
  (Wrd363.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd365.pObj)));
  (Wrd370.Obj) = (current_block [OBJECT_75_24]);
  (* (Rhp++)) = (Wrd370.Obj);
  (* (Rhp++)) = (Wrd363.Obj);
  (Wrd368.pObj) = (& (Rhp [-2]));
  (Wrd369.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd368.pObj)));
  (* (--Rsp)) = (Wrd369.Obj);
  (Wrd373.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_24]));
  (Wrd376.Obj) = ((Wrd373.pObj) [0]);
  (Wrd377.uLng) = (OBJECT_TYPE (Wrd376.Obj));
  if ((Wrd377.uLng) == 50)
    goto label_261;
  Wrd372 = Wrd376;

DEFLABEL (label_260)
  (Wrd381.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd372.Obj);
  (* (Rhp++)) = (Wrd381.Obj);
  (Wrd380.pObj) = (& (Rhp [-2]));
  (Wrd378.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd380.pObj)));
  (Wrd385.Obj) = (current_block [OBJECT_75_25]);
  (* (Rhp++)) = (Wrd385.Obj);
  (* (Rhp++)) = (Wrd378.Obj);
  (Wrd383.pObj) = (& (Rhp [-2]));
  (Wrd384.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd383.pObj)));
  (* (--Rsp)) = (Wrd384.Obj);
  (Wrd388.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_25]));
  (Wrd391.Obj) = ((Wrd388.pObj) [0]);
  (Wrd392.uLng) = (OBJECT_TYPE (Wrd391.Obj));
  if ((Wrd392.uLng) == 50)
    goto label_259;
  Wrd387 = Wrd391;

DEFLABEL (label_258)
  (Wrd396.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd387.Obj);
  (* (Rhp++)) = (Wrd396.Obj);
  (Wrd395.pObj) = (& (Rhp [-2]));
  (Wrd393.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd395.pObj)));
  (Wrd400.Obj) = (current_block [OBJECT_75_26]);
  (* (Rhp++)) = (Wrd400.Obj);
  (* (Rhp++)) = (Wrd393.Obj);
  (Wrd398.pObj) = (& (Rhp [-2]));
  (Wrd399.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd398.pObj)));
  (* (--Rsp)) = (Wrd399.Obj);
  (Wrd403.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_26]));
  (Wrd406.Obj) = ((Wrd403.pObj) [0]);
  (Wrd407.uLng) = (OBJECT_TYPE (Wrd406.Obj));
  if ((Wrd407.uLng) == 50)
    goto label_257;
  Wrd402 = Wrd406;

DEFLABEL (label_256)
  (Wrd411.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd402.Obj);
  (* (Rhp++)) = (Wrd411.Obj);
  (Wrd410.pObj) = (& (Rhp [-2]));
  (Wrd408.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd410.pObj)));
  (Wrd415.Obj) = (current_block [OBJECT_75_27]);
  (* (Rhp++)) = (Wrd415.Obj);
  (* (Rhp++)) = (Wrd408.Obj);
  (Wrd413.pObj) = (& (Rhp [-2]));
  (Wrd414.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd413.pObj)));
  (* (--Rsp)) = (Wrd414.Obj);
  (Wrd418.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_27]));
  (Wrd421.Obj) = ((Wrd418.pObj) [0]);
  (Wrd422.uLng) = (OBJECT_TYPE (Wrd421.Obj));
  if ((Wrd422.uLng) == 50)
    goto label_255;
  Wrd417 = Wrd421;

DEFLABEL (label_254)
  (Wrd426.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd417.Obj);
  (* (Rhp++)) = (Wrd426.Obj);
  (Wrd425.pObj) = (& (Rhp [-2]));
  (Wrd423.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd425.pObj)));
  (Wrd430.Obj) = (current_block [OBJECT_75_28]);
  (* (Rhp++)) = (Wrd430.Obj);
  (* (Rhp++)) = (Wrd423.Obj);
  (Wrd428.pObj) = (& (Rhp [-2]));
  (Wrd429.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd428.pObj)));
  (* (--Rsp)) = (Wrd429.Obj);
  (Wrd433.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_28]));
  (Wrd436.Obj) = ((Wrd433.pObj) [0]);
  (Wrd437.uLng) = (OBJECT_TYPE (Wrd436.Obj));
  if ((Wrd437.uLng) == 50)
    goto label_253;
  Wrd432 = Wrd436;

DEFLABEL (label_252)
  (Wrd441.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd432.Obj);
  (* (Rhp++)) = (Wrd441.Obj);
  (Wrd440.pObj) = (& (Rhp [-2]));
  (Wrd438.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd440.pObj)));
  (Wrd445.Obj) = (current_block [OBJECT_75_29]);
  (* (Rhp++)) = (Wrd445.Obj);
  (* (Rhp++)) = (Wrd438.Obj);
  (Wrd443.pObj) = (& (Rhp [-2]));
  (Wrd444.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd443.pObj)));
  (* (--Rsp)) = (Wrd444.Obj);
  (Wrd448.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_29]));
  (Wrd451.Obj) = ((Wrd448.pObj) [0]);
  (Wrd452.uLng) = (OBJECT_TYPE (Wrd451.Obj));
  if ((Wrd452.uLng) == 50)
    goto label_251;
  Wrd447 = Wrd451;

DEFLABEL (label_250)
  (Wrd456.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd447.Obj);
  (* (Rhp++)) = (Wrd456.Obj);
  (Wrd455.pObj) = (& (Rhp [-2]));
  (Wrd453.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd455.pObj)));
  (Wrd460.Obj) = (current_block [OBJECT_75_30]);
  (* (Rhp++)) = (Wrd460.Obj);
  (* (Rhp++)) = (Wrd453.Obj);
  (Wrd458.pObj) = (& (Rhp [-2]));
  (Wrd459.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd458.pObj)));
  (* (--Rsp)) = (Wrd459.Obj);
  (Wrd463.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_30]));
  (Wrd466.Obj) = ((Wrd463.pObj) [0]);
  (Wrd467.uLng) = (OBJECT_TYPE (Wrd466.Obj));
  if ((Wrd467.uLng) == 50)
    goto label_249;
  Wrd462 = Wrd466;

DEFLABEL (label_248)
  (Wrd471.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd462.Obj);
  (* (Rhp++)) = (Wrd471.Obj);
  (Wrd470.pObj) = (& (Rhp [-2]));
  (Wrd468.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd470.pObj)));
  (Wrd475.Obj) = (current_block [OBJECT_75_31]);
  (* (Rhp++)) = (Wrd475.Obj);
  (* (Rhp++)) = (Wrd468.Obj);
  (Wrd473.pObj) = (& (Rhp [-2]));
  (Wrd474.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd473.pObj)));
  (* (--Rsp)) = (Wrd474.Obj);
  (Wrd478.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_31]));
  (Wrd481.Obj) = ((Wrd478.pObj) [0]);
  (Wrd482.uLng) = (OBJECT_TYPE (Wrd481.Obj));
  if ((Wrd482.uLng) == 50)
    goto label_247;
  Wrd477 = Wrd481;

DEFLABEL (label_246)
  (Wrd486.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd477.Obj);
  (* (Rhp++)) = (Wrd486.Obj);
  (Wrd485.pObj) = (& (Rhp [-2]));
  (Wrd483.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd485.pObj)));
  (Wrd490.Obj) = (current_block [OBJECT_75_32]);
  (* (Rhp++)) = (Wrd490.Obj);
  (* (Rhp++)) = (Wrd483.Obj);
  (Wrd488.pObj) = (& (Rhp [-2]));
  (Wrd489.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd488.pObj)));
  (* (--Rsp)) = (Wrd489.Obj);
  (Wrd493.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_32]));
  (Wrd496.Obj) = ((Wrd493.pObj) [0]);
  (Wrd497.uLng) = (OBJECT_TYPE (Wrd496.Obj));
  if ((Wrd497.uLng) == 50)
    goto label_245;
  Wrd492 = Wrd496;

DEFLABEL (label_244)
  (Wrd501.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd492.Obj);
  (* (Rhp++)) = (Wrd501.Obj);
  (Wrd500.pObj) = (& (Rhp [-2]));
  (Wrd498.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd500.pObj)));
  (Wrd505.Obj) = (current_block [OBJECT_75_33]);
  (* (Rhp++)) = (Wrd505.Obj);
  (* (Rhp++)) = (Wrd498.Obj);
  (Wrd503.pObj) = (& (Rhp [-2]));
  (Wrd504.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd503.pObj)));
  (* (--Rsp)) = (Wrd504.Obj);
  (Wrd508.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_33]));
  (Wrd511.Obj) = ((Wrd508.pObj) [0]);
  (Wrd512.uLng) = (OBJECT_TYPE (Wrd511.Obj));
  if ((Wrd512.uLng) == 50)
    goto label_243;
  Wrd507 = Wrd511;

DEFLABEL (label_242)
  (Wrd516.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd507.Obj);
  (* (Rhp++)) = (Wrd516.Obj);
  (Wrd515.pObj) = (& (Rhp [-2]));
  (Wrd513.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd515.pObj)));
  (Wrd520.Obj) = (current_block [OBJECT_75_34]);
  (* (Rhp++)) = (Wrd520.Obj);
  (* (Rhp++)) = (Wrd513.Obj);
  (Wrd518.pObj) = (& (Rhp [-2]));
  (Wrd519.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd518.pObj)));
  (* (--Rsp)) = (Wrd519.Obj);
  (Wrd523.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_34]));
  (Wrd526.Obj) = ((Wrd523.pObj) [0]);
  (Wrd527.uLng) = (OBJECT_TYPE (Wrd526.Obj));
  if ((Wrd527.uLng) == 50)
    goto label_241;
  Wrd522 = Wrd526;

DEFLABEL (label_240)
  (Wrd531.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd522.Obj);
  (* (Rhp++)) = (Wrd531.Obj);
  (Wrd530.pObj) = (& (Rhp [-2]));
  (Wrd528.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd530.pObj)));
  (Wrd535.Obj) = (current_block [OBJECT_75_35]);
  (* (Rhp++)) = (Wrd535.Obj);
  (* (Rhp++)) = (Wrd528.Obj);
  (Wrd533.pObj) = (& (Rhp [-2]));
  (Wrd534.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd533.pObj)));
  (* (--Rsp)) = (Wrd534.Obj);
  (Wrd538.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_35]));
  (Wrd541.Obj) = ((Wrd538.pObj) [0]);
  (Wrd542.uLng) = (OBJECT_TYPE (Wrd541.Obj));
  if ((Wrd542.uLng) == 50)
    goto label_239;
  Wrd537 = Wrd541;

DEFLABEL (label_238)
  (Wrd546.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd537.Obj);
  (* (Rhp++)) = (Wrd546.Obj);
  (Wrd545.pObj) = (& (Rhp [-2]));
  (Wrd543.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd545.pObj)));
  (Wrd550.Obj) = (current_block [OBJECT_75_36]);
  (* (Rhp++)) = (Wrd550.Obj);
  (* (Rhp++)) = (Wrd543.Obj);
  (Wrd548.pObj) = (& (Rhp [-2]));
  (Wrd549.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd548.pObj)));
  (* (--Rsp)) = (Wrd549.Obj);
  (Wrd553.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_36]));
  (Wrd556.Obj) = ((Wrd553.pObj) [0]);
  (Wrd557.uLng) = (OBJECT_TYPE (Wrd556.Obj));
  if ((Wrd557.uLng) == 50)
    goto label_237;
  Wrd552 = Wrd556;

DEFLABEL (label_236)
  (Wrd561.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd552.Obj);
  (* (Rhp++)) = (Wrd561.Obj);
  (Wrd560.pObj) = (& (Rhp [-2]));
  (Wrd558.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd560.pObj)));
  (Wrd565.Obj) = (current_block [OBJECT_75_37]);
  (* (Rhp++)) = (Wrd565.Obj);
  (* (Rhp++)) = (Wrd558.Obj);
  (Wrd563.pObj) = (& (Rhp [-2]));
  (Wrd564.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd563.pObj)));
  (* (--Rsp)) = (Wrd564.Obj);
  (Wrd568.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_37]));
  (Wrd571.Obj) = ((Wrd568.pObj) [0]);
  (Wrd572.uLng) = (OBJECT_TYPE (Wrd571.Obj));
  if ((Wrd572.uLng) == 50)
    goto label_235;
  Wrd567 = Wrd571;

DEFLABEL (label_234)
  (Wrd576.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd567.Obj);
  (* (Rhp++)) = (Wrd576.Obj);
  (Wrd575.pObj) = (& (Rhp [-2]));
  (Wrd573.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd575.pObj)));
  (Wrd580.Obj) = (current_block [OBJECT_75_38]);
  (* (Rhp++)) = (Wrd580.Obj);
  (* (Rhp++)) = (Wrd573.Obj);
  (Wrd578.pObj) = (& (Rhp [-2]));
  (Wrd579.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd578.pObj)));
  (* (--Rsp)) = (Wrd579.Obj);
  (Wrd583.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_38]));
  (Wrd586.Obj) = ((Wrd583.pObj) [0]);
  (Wrd587.uLng) = (OBJECT_TYPE (Wrd586.Obj));
  if ((Wrd587.uLng) == 50)
    goto label_233;
  Wrd582 = Wrd586;

DEFLABEL (label_232)
  (Wrd591.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd582.Obj);
  (* (Rhp++)) = (Wrd591.Obj);
  (Wrd590.pObj) = (& (Rhp [-2]));
  (Wrd588.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd590.pObj)));
  (Wrd595.Obj) = (current_block [OBJECT_75_39]);
  (* (Rhp++)) = (Wrd595.Obj);
  (* (Rhp++)) = (Wrd588.Obj);
  (Wrd593.pObj) = (& (Rhp [-2]));
  (Wrd594.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd593.pObj)));
  (* (--Rsp)) = (Wrd594.Obj);
  (Wrd598.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_39]));
  (Wrd601.Obj) = ((Wrd598.pObj) [0]);
  (Wrd602.uLng) = (OBJECT_TYPE (Wrd601.Obj));
  if ((Wrd602.uLng) == 50)
    goto label_231;
  Wrd597 = Wrd601;

DEFLABEL (label_230)
  (Wrd606.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd597.Obj);
  (* (Rhp++)) = (Wrd606.Obj);
  (Wrd605.pObj) = (& (Rhp [-2]));
  (Wrd603.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd605.pObj)));
  (Wrd610.Obj) = (current_block [OBJECT_75_40]);
  (* (Rhp++)) = (Wrd610.Obj);
  (* (Rhp++)) = (Wrd603.Obj);
  (Wrd608.pObj) = (& (Rhp [-2]));
  (Wrd609.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd608.pObj)));
  (* (--Rsp)) = (Wrd609.Obj);
  (Wrd613.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_40]));
  (Wrd616.Obj) = ((Wrd613.pObj) [0]);
  (Wrd617.uLng) = (OBJECT_TYPE (Wrd616.Obj));
  if ((Wrd617.uLng) == 50)
    goto label_229;
  Wrd612 = Wrd616;

DEFLABEL (label_228)
  (Wrd621.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd612.Obj);
  (* (Rhp++)) = (Wrd621.Obj);
  (Wrd620.pObj) = (& (Rhp [-2]));
  (Wrd618.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd620.pObj)));
  (Wrd625.Obj) = (current_block [OBJECT_75_41]);
  (* (Rhp++)) = (Wrd625.Obj);
  (* (Rhp++)) = (Wrd618.Obj);
  (Wrd623.pObj) = (& (Rhp [-2]));
  (Wrd624.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd623.pObj)));
  (* (--Rsp)) = (Wrd624.Obj);
  (Wrd628.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_41]));
  (Wrd631.Obj) = ((Wrd628.pObj) [0]);
  (Wrd632.uLng) = (OBJECT_TYPE (Wrd631.Obj));
  if ((Wrd632.uLng) == 50)
    goto label_227;
  Wrd627 = Wrd631;

DEFLABEL (label_226)
  (Wrd636.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd627.Obj);
  (* (Rhp++)) = (Wrd636.Obj);
  (Wrd635.pObj) = (& (Rhp [-2]));
  (Wrd633.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd635.pObj)));
  (Wrd640.Obj) = (current_block [OBJECT_75_42]);
  (* (Rhp++)) = (Wrd640.Obj);
  (* (Rhp++)) = (Wrd633.Obj);
  (Wrd638.pObj) = (& (Rhp [-2]));
  (Wrd639.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd638.pObj)));
  (* (--Rsp)) = (Wrd639.Obj);
  (Wrd643.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_42]));
  (Wrd646.Obj) = ((Wrd643.pObj) [0]);
  (Wrd647.uLng) = (OBJECT_TYPE (Wrd646.Obj));
  if ((Wrd647.uLng) == 50)
    goto label_225;
  Wrd642 = Wrd646;

DEFLABEL (label_224)
  (Wrd651.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd642.Obj);
  (* (Rhp++)) = (Wrd651.Obj);
  (Wrd650.pObj) = (& (Rhp [-2]));
  (Wrd648.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd650.pObj)));
  (Wrd655.Obj) = (current_block [OBJECT_75_43]);
  (* (Rhp++)) = (Wrd655.Obj);
  (* (Rhp++)) = (Wrd648.Obj);
  (Wrd653.pObj) = (& (Rhp [-2]));
  (Wrd654.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd653.pObj)));
  (* (--Rsp)) = (Wrd654.Obj);
  (Wrd658.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_43]));
  (Wrd661.Obj) = ((Wrd658.pObj) [0]);
  (Wrd662.uLng) = (OBJECT_TYPE (Wrd661.Obj));
  if ((Wrd662.uLng) == 50)
    goto label_223;
  Wrd657 = Wrd661;

DEFLABEL (label_222)
  (Wrd666.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd657.Obj);
  (* (Rhp++)) = (Wrd666.Obj);
  (Wrd665.pObj) = (& (Rhp [-2]));
  (Wrd663.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd665.pObj)));
  (Wrd670.Obj) = (current_block [OBJECT_75_44]);
  (* (Rhp++)) = (Wrd670.Obj);
  (* (Rhp++)) = (Wrd663.Obj);
  (Wrd668.pObj) = (& (Rhp [-2]));
  (Wrd669.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd668.pObj)));
  (* (--Rsp)) = (Wrd669.Obj);
  (Wrd673.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_44]));
  (Wrd676.Obj) = ((Wrd673.pObj) [0]);
  (Wrd677.uLng) = (OBJECT_TYPE (Wrd676.Obj));
  if ((Wrd677.uLng) == 50)
    goto label_221;
  Wrd672 = Wrd676;

DEFLABEL (label_220)
  (Wrd681.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd672.Obj);
  (* (Rhp++)) = (Wrd681.Obj);
  (Wrd680.pObj) = (& (Rhp [-2]));
  (Wrd678.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd680.pObj)));
  (Wrd685.Obj) = (current_block [OBJECT_75_45]);
  (* (Rhp++)) = (Wrd685.Obj);
  (* (Rhp++)) = (Wrd678.Obj);
  (Wrd683.pObj) = (& (Rhp [-2]));
  (Wrd684.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd683.pObj)));
  (* (--Rsp)) = (Wrd684.Obj);
  (Wrd688.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_45]));
  (Wrd691.Obj) = ((Wrd688.pObj) [0]);
  (Wrd692.uLng) = (OBJECT_TYPE (Wrd691.Obj));
  if ((Wrd692.uLng) == 50)
    goto label_219;
  Wrd687 = Wrd691;

DEFLABEL (label_218)
  (Wrd696.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd687.Obj);
  (* (Rhp++)) = (Wrd696.Obj);
  (Wrd695.pObj) = (& (Rhp [-2]));
  (Wrd693.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd695.pObj)));
  (Wrd700.Obj) = (current_block [OBJECT_75_46]);
  (* (Rhp++)) = (Wrd700.Obj);
  (* (Rhp++)) = (Wrd693.Obj);
  (Wrd698.pObj) = (& (Rhp [-2]));
  (Wrd699.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd698.pObj)));
  (* (--Rsp)) = (Wrd699.Obj);
  (Wrd703.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_46]));
  (Wrd706.Obj) = ((Wrd703.pObj) [0]);
  (Wrd707.uLng) = (OBJECT_TYPE (Wrd706.Obj));
  if ((Wrd707.uLng) == 50)
    goto label_217;
  Wrd702 = Wrd706;

DEFLABEL (label_216)
  (Wrd711.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd702.Obj);
  (* (Rhp++)) = (Wrd711.Obj);
  (Wrd710.pObj) = (& (Rhp [-2]));
  (Wrd708.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd710.pObj)));
  (Wrd715.Obj) = (current_block [OBJECT_75_47]);
  (* (Rhp++)) = (Wrd715.Obj);
  (* (Rhp++)) = (Wrd708.Obj);
  (Wrd713.pObj) = (& (Rhp [-2]));
  (Wrd714.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd713.pObj)));
  (* (--Rsp)) = (Wrd714.Obj);
  (Wrd718.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_47]));
  (Wrd721.Obj) = ((Wrd718.pObj) [0]);
  (Wrd722.uLng) = (OBJECT_TYPE (Wrd721.Obj));
  if ((Wrd722.uLng) == 50)
    goto label_215;
  Wrd717 = Wrd721;

DEFLABEL (label_214)
  (Wrd726.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd717.Obj);
  (* (Rhp++)) = (Wrd726.Obj);
  (Wrd725.pObj) = (& (Rhp [-2]));
  (Wrd723.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd725.pObj)));
  (Wrd730.Obj) = (current_block [OBJECT_75_48]);
  (* (Rhp++)) = (Wrd730.Obj);
  (* (Rhp++)) = (Wrd723.Obj);
  (Wrd728.pObj) = (& (Rhp [-2]));
  (Wrd729.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd728.pObj)));
  (* (--Rsp)) = (Wrd729.Obj);
  (Wrd733.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_48]));
  (Wrd736.Obj) = ((Wrd733.pObj) [0]);
  (Wrd737.uLng) = (OBJECT_TYPE (Wrd736.Obj));
  if ((Wrd737.uLng) == 50)
    goto label_213;
  Wrd732 = Wrd736;

DEFLABEL (label_212)
  (Wrd741.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd732.Obj);
  (* (Rhp++)) = (Wrd741.Obj);
  (Wrd740.pObj) = (& (Rhp [-2]));
  (Wrd738.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd740.pObj)));
  (Wrd745.Obj) = (current_block [OBJECT_75_49]);
  (* (Rhp++)) = (Wrd745.Obj);
  (* (Rhp++)) = (Wrd738.Obj);
  (Wrd743.pObj) = (& (Rhp [-2]));
  (Wrd744.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd743.pObj)));
  (* (--Rsp)) = (Wrd744.Obj);
  (Wrd748.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_49]));
  (Wrd751.Obj) = ((Wrd748.pObj) [0]);
  (Wrd752.uLng) = (OBJECT_TYPE (Wrd751.Obj));
  if ((Wrd752.uLng) == 50)
    goto label_211;
  Wrd747 = Wrd751;

DEFLABEL (label_210)
  (Wrd756.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd747.Obj);
  (* (Rhp++)) = (Wrd756.Obj);
  (Wrd755.pObj) = (& (Rhp [-2]));
  (Wrd753.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd755.pObj)));
  (Wrd760.Obj) = (current_block [OBJECT_75_50]);
  (* (Rhp++)) = (Wrd760.Obj);
  (* (Rhp++)) = (Wrd753.Obj);
  (Wrd758.pObj) = (& (Rhp [-2]));
  (Wrd759.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd758.pObj)));
  (* (--Rsp)) = (Wrd759.Obj);
  (Wrd763.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_50]));
  (Wrd766.Obj) = ((Wrd763.pObj) [0]);
  (Wrd767.uLng) = (OBJECT_TYPE (Wrd766.Obj));
  if ((Wrd767.uLng) == 50)
    goto label_209;
  Wrd762 = Wrd766;

DEFLABEL (label_208)
  (Wrd771.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd762.Obj);
  (* (Rhp++)) = (Wrd771.Obj);
  (Wrd770.pObj) = (& (Rhp [-2]));
  (Wrd768.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd770.pObj)));
  (Wrd775.Obj) = (current_block [OBJECT_75_51]);
  (* (Rhp++)) = (Wrd775.Obj);
  (* (Rhp++)) = (Wrd768.Obj);
  (Wrd773.pObj) = (& (Rhp [-2]));
  (Wrd774.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd773.pObj)));
  (* (--Rsp)) = (Wrd774.Obj);
  (Wrd778.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_51]));
  (Wrd781.Obj) = ((Wrd778.pObj) [0]);
  (Wrd782.uLng) = (OBJECT_TYPE (Wrd781.Obj));
  if ((Wrd782.uLng) == 50)
    goto label_207;
  Wrd777 = Wrd781;

DEFLABEL (label_206)
  (Wrd786.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd777.Obj);
  (* (Rhp++)) = (Wrd786.Obj);
  (Wrd785.pObj) = (& (Rhp [-2]));
  (Wrd783.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd785.pObj)));
  (Wrd790.Obj) = (current_block [OBJECT_75_52]);
  (* (Rhp++)) = (Wrd790.Obj);
  (* (Rhp++)) = (Wrd783.Obj);
  (Wrd788.pObj) = (& (Rhp [-2]));
  (Wrd789.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd788.pObj)));
  (* (--Rsp)) = (Wrd789.Obj);
  (Wrd793.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_52]));
  (Wrd796.Obj) = ((Wrd793.pObj) [0]);
  (Wrd797.uLng) = (OBJECT_TYPE (Wrd796.Obj));
  if ((Wrd797.uLng) == 50)
    goto label_205;
  Wrd792 = Wrd796;

DEFLABEL (label_204)
  (Wrd801.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd792.Obj);
  (* (Rhp++)) = (Wrd801.Obj);
  (Wrd800.pObj) = (& (Rhp [-2]));
  (Wrd798.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd800.pObj)));
  (Wrd805.Obj) = (current_block [OBJECT_75_53]);
  (* (Rhp++)) = (Wrd805.Obj);
  (* (Rhp++)) = (Wrd798.Obj);
  (Wrd803.pObj) = (& (Rhp [-2]));
  (Wrd804.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd803.pObj)));
  (* (--Rsp)) = (Wrd804.Obj);
  (Wrd808.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_53]));
  (Wrd811.Obj) = ((Wrd808.pObj) [0]);
  (Wrd812.uLng) = (OBJECT_TYPE (Wrd811.Obj));
  if ((Wrd812.uLng) == 50)
    goto label_203;
  Wrd807 = Wrd811;

DEFLABEL (label_202)
  (Wrd816.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd807.Obj);
  (* (Rhp++)) = (Wrd816.Obj);
  (Wrd815.pObj) = (& (Rhp [-2]));
  (Wrd813.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd815.pObj)));
  (Wrd820.Obj) = (current_block [OBJECT_75_54]);
  (* (Rhp++)) = (Wrd820.Obj);
  (* (Rhp++)) = (Wrd813.Obj);
  (Wrd818.pObj) = (& (Rhp [-2]));
  (Wrd819.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd818.pObj)));
  (* (--Rsp)) = (Wrd819.Obj);
  (Wrd823.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_54]));
  (Wrd826.Obj) = ((Wrd823.pObj) [0]);
  (Wrd827.uLng) = (OBJECT_TYPE (Wrd826.Obj));
  if ((Wrd827.uLng) == 50)
    goto label_201;
  Wrd822 = Wrd826;

DEFLABEL (label_200)
  (Wrd831.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd822.Obj);
  (* (Rhp++)) = (Wrd831.Obj);
  (Wrd830.pObj) = (& (Rhp [-2]));
  (Wrd828.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd830.pObj)));
  (Wrd835.Obj) = (current_block [OBJECT_75_55]);
  (* (Rhp++)) = (Wrd835.Obj);
  (* (Rhp++)) = (Wrd828.Obj);
  (Wrd833.pObj) = (& (Rhp [-2]));
  (Wrd834.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd833.pObj)));
  (* (--Rsp)) = (Wrd834.Obj);
  (Wrd838.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_55]));
  (Wrd841.Obj) = ((Wrd838.pObj) [0]);
  (Wrd842.uLng) = (OBJECT_TYPE (Wrd841.Obj));
  if ((Wrd842.uLng) == 50)
    goto label_199;
  Wrd837 = Wrd841;

DEFLABEL (label_198)
  (Wrd846.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd837.Obj);
  (* (Rhp++)) = (Wrd846.Obj);
  (Wrd845.pObj) = (& (Rhp [-2]));
  (Wrd843.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd845.pObj)));
  (Wrd850.Obj) = (current_block [OBJECT_75_56]);
  (* (Rhp++)) = (Wrd850.Obj);
  (* (Rhp++)) = (Wrd843.Obj);
  (Wrd848.pObj) = (& (Rhp [-2]));
  (Wrd849.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd848.pObj)));
  (* (--Rsp)) = (Wrd849.Obj);
  (Wrd853.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_56]));
  (Wrd856.Obj) = ((Wrd853.pObj) [0]);
  (Wrd857.uLng) = (OBJECT_TYPE (Wrd856.Obj));
  if ((Wrd857.uLng) == 50)
    goto label_197;
  Wrd852 = Wrd856;

DEFLABEL (label_196)
  (Wrd861.Obj) = (current_block [OBJECT_75_0]);
  (* (Rhp++)) = (Wrd852.Obj);
  (* (Rhp++)) = (Wrd861.Obj);
  (Wrd860.pObj) = (& (Rhp [-2]));
  (Wrd858.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd860.pObj)));
  (Wrd865.Obj) = (current_block [OBJECT_75_57]);
  (* (Rhp++)) = (Wrd865.Obj);
  (* (Rhp++)) = (Wrd858.Obj);
  (Wrd863.pObj) = (& (Rhp [-2]));
  (Wrd864.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd863.pObj)));
  (* (--Rsp)) = (Wrd864.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_64]));

DEFLABEL (continuation_114)
  INTERRUPT_CHECK (27, LABEL_75_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_75_59]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_71]));

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_75_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_75_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_195;

DEFLABEL (label_194)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_193)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_66]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_57]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_192;
  Wrd21 = Wrd25;

DEFLABEL (label_191)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_58]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_190;
  Wrd27 = Wrd31;

DEFLABEL (label_189)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_75_59]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_188;
  Wrd33 = Wrd37;

DEFLABEL (label_187)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_75_58]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_70]));

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_75_66);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_75_1]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_186;

DEFLABEL (label_185)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_184)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_73]))));
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_74]));

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_75_73);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_75]));

DEFLABEL (label_186)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_185;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_75_72])), (Wrd6.pObj), Rvl);

DEFLABEL (label_181)
  goto label_184;

DEFLABEL (label_188)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_69])), (Wrd34.pObj));

DEFLABEL (label_180)
  (Wrd33.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_68])), (Wrd28.pObj));

DEFLABEL (label_179)
  (Wrd27.Obj) = Rvl;
  goto label_189;

DEFLABEL (label_192)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_67])), (Wrd22.pObj));

DEFLABEL (label_178)
  (Wrd21.Obj) = Rvl;
  goto label_191;

DEFLABEL (label_195)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_194;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_75_65])), (Wrd6.pObj), Rvl);

DEFLABEL (label_177)
  goto label_193;

DEFLABEL (label_197)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_63])), (Wrd853.pObj));

DEFLABEL (label_176)
  (Wrd852.Obj) = Rvl;
  goto label_196;

DEFLABEL (label_199)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_62])), (Wrd838.pObj));

DEFLABEL (label_175)
  (Wrd837.Obj) = Rvl;
  goto label_198;

DEFLABEL (label_201)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_61])), (Wrd823.pObj));

DEFLABEL (label_174)
  (Wrd822.Obj) = Rvl;
  goto label_200;

DEFLABEL (label_203)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_60])), (Wrd808.pObj));

DEFLABEL (label_173)
  (Wrd807.Obj) = Rvl;
  goto label_202;

DEFLABEL (label_205)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_59])), (Wrd793.pObj));

DEFLABEL (label_172)
  (Wrd792.Obj) = Rvl;
  goto label_204;

DEFLABEL (label_207)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_58])), (Wrd778.pObj));

DEFLABEL (label_171)
  (Wrd777.Obj) = Rvl;
  goto label_206;

DEFLABEL (label_209)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_57])), (Wrd763.pObj));

DEFLABEL (label_170)
  (Wrd762.Obj) = Rvl;
  goto label_208;

DEFLABEL (label_211)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_56])), (Wrd748.pObj));

DEFLABEL (label_169)
  (Wrd747.Obj) = Rvl;
  goto label_210;

DEFLABEL (label_213)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_55])), (Wrd733.pObj));

DEFLABEL (label_168)
  (Wrd732.Obj) = Rvl;
  goto label_212;

DEFLABEL (label_215)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_54])), (Wrd718.pObj));

DEFLABEL (label_167)
  (Wrd717.Obj) = Rvl;
  goto label_214;

DEFLABEL (label_217)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_53])), (Wrd703.pObj));

DEFLABEL (label_166)
  (Wrd702.Obj) = Rvl;
  goto label_216;

DEFLABEL (label_219)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_52])), (Wrd688.pObj));

DEFLABEL (label_165)
  (Wrd687.Obj) = Rvl;
  goto label_218;

DEFLABEL (label_221)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_51])), (Wrd673.pObj));

DEFLABEL (label_164)
  (Wrd672.Obj) = Rvl;
  goto label_220;

DEFLABEL (label_223)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_50])), (Wrd658.pObj));

DEFLABEL (label_163)
  (Wrd657.Obj) = Rvl;
  goto label_222;

DEFLABEL (label_225)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_49])), (Wrd643.pObj));

DEFLABEL (label_162)
  (Wrd642.Obj) = Rvl;
  goto label_224;

DEFLABEL (label_227)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_48])), (Wrd628.pObj));

DEFLABEL (label_161)
  (Wrd627.Obj) = Rvl;
  goto label_226;

DEFLABEL (label_229)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_47])), (Wrd613.pObj));

DEFLABEL (label_160)
  (Wrd612.Obj) = Rvl;
  goto label_228;

DEFLABEL (label_231)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_46])), (Wrd598.pObj));

DEFLABEL (label_159)
  (Wrd597.Obj) = Rvl;
  goto label_230;

DEFLABEL (label_233)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_45])), (Wrd583.pObj));

DEFLABEL (label_158)
  (Wrd582.Obj) = Rvl;
  goto label_232;

DEFLABEL (label_235)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_44])), (Wrd568.pObj));

DEFLABEL (label_157)
  (Wrd567.Obj) = Rvl;
  goto label_234;

DEFLABEL (label_237)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_43])), (Wrd553.pObj));

DEFLABEL (label_156)
  (Wrd552.Obj) = Rvl;
  goto label_236;

DEFLABEL (label_239)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_42])), (Wrd538.pObj));

DEFLABEL (label_155)
  (Wrd537.Obj) = Rvl;
  goto label_238;

DEFLABEL (label_241)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_41])), (Wrd523.pObj));

DEFLABEL (label_154)
  (Wrd522.Obj) = Rvl;
  goto label_240;

DEFLABEL (label_243)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_40])), (Wrd508.pObj));

DEFLABEL (label_153)
  (Wrd507.Obj) = Rvl;
  goto label_242;

DEFLABEL (label_245)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_39])), (Wrd493.pObj));

DEFLABEL (label_152)
  (Wrd492.Obj) = Rvl;
  goto label_244;

DEFLABEL (label_247)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_38])), (Wrd478.pObj));

DEFLABEL (label_151)
  (Wrd477.Obj) = Rvl;
  goto label_246;

DEFLABEL (label_249)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_37])), (Wrd463.pObj));

DEFLABEL (label_150)
  (Wrd462.Obj) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_36])), (Wrd448.pObj));

DEFLABEL (label_149)
  (Wrd447.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_35])), (Wrd433.pObj));

DEFLABEL (label_148)
  (Wrd432.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_34])), (Wrd418.pObj));

DEFLABEL (label_147)
  (Wrd417.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_33])), (Wrd403.pObj));

DEFLABEL (label_146)
  (Wrd402.Obj) = Rvl;
  goto label_256;

DEFLABEL (label_259)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_32])), (Wrd388.pObj));

DEFLABEL (label_145)
  (Wrd387.Obj) = Rvl;
  goto label_258;

DEFLABEL (label_261)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_31])), (Wrd373.pObj));

DEFLABEL (label_144)
  (Wrd372.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_30])), (Wrd358.pObj));

DEFLABEL (label_143)
  (Wrd357.Obj) = Rvl;
  goto label_262;

DEFLABEL (label_265)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_29])), (Wrd343.pObj));

DEFLABEL (label_142)
  (Wrd342.Obj) = Rvl;
  goto label_264;

DEFLABEL (label_267)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_28])), (Wrd328.pObj));

DEFLABEL (label_141)
  (Wrd327.Obj) = Rvl;
  goto label_266;

DEFLABEL (label_269)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_27])), (Wrd313.pObj));

DEFLABEL (label_140)
  (Wrd312.Obj) = Rvl;
  goto label_268;

DEFLABEL (label_271)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_26])), (Wrd298.pObj));

DEFLABEL (label_139)
  (Wrd297.Obj) = Rvl;
  goto label_270;

DEFLABEL (label_273)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_25])), (Wrd283.pObj));

DEFLABEL (label_138)
  (Wrd282.Obj) = Rvl;
  goto label_272;

DEFLABEL (label_275)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_24])), (Wrd268.pObj));

DEFLABEL (label_137)
  (Wrd267.Obj) = Rvl;
  goto label_274;

DEFLABEL (label_277)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_23])), (Wrd253.pObj));

DEFLABEL (label_136)
  (Wrd252.Obj) = Rvl;
  goto label_276;

DEFLABEL (label_279)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_22])), (Wrd238.pObj));

DEFLABEL (label_135)
  (Wrd237.Obj) = Rvl;
  goto label_278;

DEFLABEL (label_281)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_21])), (Wrd223.pObj));

DEFLABEL (label_134)
  (Wrd222.Obj) = Rvl;
  goto label_280;

DEFLABEL (label_283)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_20])), (Wrd208.pObj));

DEFLABEL (label_133)
  (Wrd207.Obj) = Rvl;
  goto label_282;

DEFLABEL (label_285)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_19])), (Wrd193.pObj));

DEFLABEL (label_132)
  (Wrd192.Obj) = Rvl;
  goto label_284;

DEFLABEL (label_287)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_18])), (Wrd178.pObj));

DEFLABEL (label_131)
  (Wrd177.Obj) = Rvl;
  goto label_286;

DEFLABEL (label_289)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_17])), (Wrd163.pObj));

DEFLABEL (label_130)
  (Wrd162.Obj) = Rvl;
  goto label_288;

DEFLABEL (label_291)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_16])), (Wrd148.pObj));

DEFLABEL (label_129)
  (Wrd147.Obj) = Rvl;
  goto label_290;

DEFLABEL (label_293)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_15])), (Wrd133.pObj));

DEFLABEL (label_128)
  (Wrd132.Obj) = Rvl;
  goto label_292;

DEFLABEL (label_295)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_14])), (Wrd118.pObj));

DEFLABEL (label_127)
  (Wrd117.Obj) = Rvl;
  goto label_294;

DEFLABEL (label_297)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_13])), (Wrd103.pObj));

DEFLABEL (label_126)
  (Wrd102.Obj) = Rvl;
  goto label_296;

DEFLABEL (label_299)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_12])), (Wrd88.pObj));

DEFLABEL (label_125)
  (Wrd87.Obj) = Rvl;
  goto label_298;

DEFLABEL (label_301)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_11])), (Wrd73.pObj));

DEFLABEL (label_124)
  (Wrd72.Obj) = Rvl;
  goto label_300;

DEFLABEL (label_303)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_10])), (Wrd58.pObj));

DEFLABEL (label_123)
  (Wrd57.Obj) = Rvl;
  goto label_302;

DEFLABEL (label_305)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_9])), (Wrd43.pObj));

DEFLABEL (label_122)
  (Wrd42.Obj) = Rvl;
  goto label_304;

DEFLABEL (label_307)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_8])), (Wrd28.pObj));

DEFLABEL (label_121)
  (Wrd27.Obj) = Rvl;
  goto label_306;

DEFLABEL (label_309)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75_7])), (Wrd13.pObj));

DEFLABEL (label_120)
  (Wrd12.Obj) = Rvl;
  goto label_308;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define ENVIRONMENT_LABEL_76_3 9
#define DEBUGGING_LABEL_76_2 8
#define OBJECT_76_0 7
#define EXECUTE_CACHE_76_5 5
#define FREE_REFERENCES_LABEL_76_0 4
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto x_graphics_availableP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_availableP_3)
DEFLABEL (x_graphics_availableP_0)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (Wrd5.Obj) = (current_block [OBJECT_76_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define ENVIRONMENT_LABEL_77_3 5
#define DEBUGGING_LABEL_77_2 4
#define FREE_REFERENCES_LABEL_77_0 4
#define NUMBER_OF_LINKER_SECTIONS_77_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_77_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define ENVIRONMENT_LABEL_78_3 5
#define DEBUGGING_LABEL_78_2 4
#define FREE_REFERENCES_LABEL_78_0 4
#define NUMBER_OF_LINKER_SECTIONS_78_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_78_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define LABEL_79_5 5
#define LABEL_79_6 7
#define LABEL_79_7 9
#define ENVIRONMENT_LABEL_79_3 19
#define DEBUGGING_LABEL_79_2 18
#define OBJECT_79_0 17
#define EXECUTE_CACHE_79_8 11
#define FREE_REFERENCE_79_2 14
#define FREE_REFERENCE_79_1 15
#define FREE_REFERENCE_79_0 16
#define FREE_REFERENCES_LABEL_79_0 10
#define NUMBER_OF_LINKER_SECTIONS_79_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto lambda_0;

    case 1:
      current_block = (Rpc - LABEL_79_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_79_6);
      goto label_3;

    case 3:
      current_block = (Rpc - LABEL_79_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_79_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_12;
  Wrd5 = Wrd9;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_79_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_10;
  Wrd11 = Wrd15;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_79_2]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_8;
  Wrd17 = Wrd21;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_79_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_8]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79_7])), (Wrd18.pObj));

DEFLABEL (label_4)
  (Wrd17.Obj) = Rvl;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79_6])), (Wrd12.pObj));

DEFLABEL (label_3)
  (Wrd11.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define ENVIRONMENT_LABEL_80_3 8
#define DEBUGGING_LABEL_80_2 7
#define EXECUTE_CACHE_80_5 5
#define FREE_REFERENCES_LABEL_80_0 4
#define NUMBER_OF_LINKER_SECTIONS_80_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_80_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define ENVIRONMENT_LABEL_81_3 8
#define DEBUGGING_LABEL_81_2 7
#define EXECUTE_CACHE_81_5 5
#define FREE_REFERENCES_LABEL_81_0 4
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_81_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_5 5
#define LABEL_82_7 7
#define ENVIRONMENT_LABEL_82_3 17
#define DEBUGGING_LABEL_82_2 16
#define OBJECT_82_2 15
#define OBJECT_82_1 14
#define OBJECT_82_0 13
#define EXECUTE_CACHE_82_8 9
#define EXECUTE_CACHE_82_6 11
#define FREE_REFERENCES_LABEL_82_0 8
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_82_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_82_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_8;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_8;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_7)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_8]));

DEFLABEL (label_8)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_82_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_2]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define ENVIRONMENT_LABEL_83_3 7
#define DEBUGGING_LABEL_83_2 6
#define OBJECT_83_1 5
#define OBJECT_83_0 4
#define FREE_REFERENCES_LABEL_83_0 4
#define NUMBER_OF_LINKER_SECTIONS_83_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto x_display_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_name_3)
DEFLABEL (x_display_name_0)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_83_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define ENVIRONMENT_LABEL_84_3 7
#define DEBUGGING_LABEL_84_2 6
#define OBJECT_84_1 5
#define OBJECT_84_0 4
#define FREE_REFERENCES_LABEL_84_0 4
#define NUMBER_OF_LINKER_SECTIONS_84_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto x_display_xd_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_xd_3)
DEFLABEL (x_display_xd_0)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_84_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define ENVIRONMENT_LABEL_85_3 7
#define DEBUGGING_LABEL_85_2 6
#define OBJECT_85_1 5
#define OBJECT_85_0 4
#define FREE_REFERENCES_LABEL_85_0 4
#define NUMBER_OF_LINKER_SECTIONS_85_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto x_display_window_finalizer_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_window_finalizer_3)
DEFLABEL (x_display_window_finalizer_0)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_85_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_4 3
#define ENVIRONMENT_LABEL_86_3 7
#define DEBUGGING_LABEL_86_2 6
#define OBJECT_86_1 5
#define OBJECT_86_0 4
#define FREE_REFERENCES_LABEL_86_0 4
#define NUMBER_OF_LINKER_SECTIONS_86_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_4);
      goto x_display_event_queue_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_event_queue_3)
DEFLABEL (x_display_event_queue_0)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_86_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define ENVIRONMENT_LABEL_87_3 7
#define DEBUGGING_LABEL_87_2 6
#define OBJECT_87_1 5
#define OBJECT_87_0 4
#define FREE_REFERENCES_LABEL_87_0 4
#define NUMBER_OF_LINKER_SECTIONS_87_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto x_display_properties_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_display_properties_3)
DEFLABEL (x_display_properties_0)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_87_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define ENVIRONMENT_LABEL_88_3 8
#define DEBUGGING_LABEL_88_2 7
#define OBJECT_88_2 6
#define OBJECT_88_1 5
#define OBJECT_88_0 4
#define FREE_REFERENCES_LABEL_88_0 4
#define NUMBER_OF_LINKER_SECTIONS_88_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto set_x_display_xdB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_display_xdB_3)
DEFLABEL (set_x_display_xdB_0)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_88_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_88_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define ENVIRONMENT_LABEL_89_3 8
#define DEBUGGING_LABEL_89_2 7
#define OBJECT_89_2 6
#define OBJECT_89_1 5
#define OBJECT_89_0 4
#define FREE_REFERENCES_LABEL_89_0 4
#define NUMBER_OF_LINKER_SECTIONS_89_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto set_x_display_event_queueB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_display_event_queueB_3)
DEFLABEL (set_x_display_event_queueB_0)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_89_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_89_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_5 3
#define LABEL_90_6 5
#define LABEL_90_8 7
#define LABEL_90_4 9
#define LABEL_90_9 11
#define LABEL_90_14 13
#define LABEL_90_16 15
#define LABEL_90_11 17
#define LABEL_90_12 19
#define TAG_90_13 8
#define LABEL_90_19 21
#define LABEL_90_21 23
#define LABEL_90_18 25
#define LABEL_90_23 27
#define LABEL_90_26 29
#define LABEL_90_25 31
#define LABEL_90_28 33
#define ENVIRONMENT_LABEL_90_3 65
#define DEBUGGING_LABEL_90_2 64
#define OBJECT_90_6 63
#define OBJECT_90_5 62
#define OBJECT_90_4 61
#define OBJECT_90_3 60
#define OBJECT_90_2 59
#define OBJECT_90_1 58
#define OBJECT_90_0 57
#define EXECUTE_CACHE_90_29 35
#define EXECUTE_CACHE_90_27 37
#define EXECUTE_CACHE_90_24 39
#define EXECUTE_CACHE_90_20 41
#define EXECUTE_CACHE_90_17 43
#define EXECUTE_CACHE_90_15 45
#define EXECUTE_CACHE_90_10 47
#define EXECUTE_CACHE_90_22 49
#define EXECUTE_CACHE_90_7 51
#define FREE_REFERENCE_90_2 54
#define FREE_REFERENCE_90_1 55
#define FREE_REFERENCE_90_0 56
#define FREE_REFERENCES_LABEL_90_0 34
#define NUMBER_OF_LINKER_SECTIONS_90_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd11;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd35;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd21;
  machine_word Wrd55;
  machine_word Wrd54;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_90_6);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_90_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_90_4);
      goto x_graphics_open_display_18;

    case 4:
      current_block = (Rpc - LABEL_90_9);
      goto label_22;

    case 5:
      current_block = (Rpc - LABEL_90_14);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_90_16);
      goto label_20;

    case 7:
      current_block = (Rpc - LABEL_90_11);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_90_12);
      goto lambda_27;

    case 9:
      current_block = (Rpc - LABEL_90_19);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_90_21);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_90_18);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_90_23);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_90_26);
      goto label_24;

    case 14:
      current_block = (Rpc - LABEL_90_25);
      goto continuation_12;

    case 15:
      current_block = (Rpc - LABEL_90_28);
      goto continuation_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_open_display_26)
DEFLABEL (x_graphics_open_display_18)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd11.uLng) == 30)
    goto label_38;
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_37;
  Wrd12 = Wrd16;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_90_2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_17]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_8);
  (Wrd21.Obj) = Rvl;

DEFLABEL (label_35)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_11]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_90_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_90_12])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  ((Wrd26.pObj) [2]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_1]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_34;
  Wrd29 = Wrd33;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_90_11);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_18]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_3]), 1);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_90_18);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;

DEFLABEL (label_31)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_24]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_90_23);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_25]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_30;
  Wrd10 = Wrd14;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_27]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_90_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_29]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_90_28);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_26])), (Wrd11.pObj));

DEFLABEL (label_24)
  (Wrd10.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_21]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_90_6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_22]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_90_21);
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_14])), (Wrd30.pObj));

DEFLABEL (label_21)
  (Wrd29.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_16])), (Wrd13.pObj));

DEFLABEL (label_20)
  (Wrd12.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  Wrd21 = Wrd8;
  Rsp = (& (Rsp [1]));
  goto label_35;

DEFLABEL (label_39)
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_90_0]));
  (Wrd39.Obj) = ((Wrd36.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_44;
  Wrd35 = Wrd39;

DEFLABEL (label_43)
  (* (--Rsp)) = (Wrd35.Obj);
  if (! ((Wrd35.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_42;
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_6]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_90_1]);
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_90_6);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_41;
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (current_block [OBJECT_90_0]);
  (* (--Rsp)) = (Wrd55.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_90_5);

DEFLABEL (label_41)
  (Wrd21.Obj) = (Rsp [0]);

DEFLABEL (label_40)
  Rsp = (& (Rsp [2]));
  goto label_35;

DEFLABEL (label_42)
  Wrd21 = Wrd35;
  goto label_40;

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90_9])), (Wrd36.pObj));

DEFLABEL (label_22)
  (Wrd35.Obj) = Rvl;
  goto label_43;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_90_12);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_46;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_46;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_45)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd24.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_20]));

DEFLABEL (label_46)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_90_4]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_19]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_5]), 2);

DEFLABEL (label_23)
  (Wrd8.Obj) = Rvl;
  goto label_45;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define LABEL_91_5 5
#define TAG_91_6 1
#define LABEL_91_8 7
#define LABEL_91_10 9
#define LABEL_91_9 11
#define LABEL_91_12 13
#define ENVIRONMENT_LABEL_91_3 28
#define DEBUGGING_LABEL_91_2 27
#define OBJECT_91_3 26
#define OBJECT_91_2 25
#define OBJECT_91_1 24
#define OBJECT_91_0 23
#define EXECUTE_CACHE_91_13 15
#define EXECUTE_CACHE_91_11 17
#define EXECUTE_CACHE_91_7 19
#define FREE_REFERENCE_91_0 22
#define FREE_REFERENCES_LABEL_91_0 14
#define NUMBER_OF_LINKER_SECTIONS_91_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd20;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd15;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto x_graphics_close_display_4;

    case 1:
      current_block = (Rpc - LABEL_91_5);
      goto lambda_11;

    case 2:
      current_block = (Rpc - LABEL_91_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_91_10);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_91_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_91_12);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_close_display_10)
DEFLABEL (x_graphics_close_display_4)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_91_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_91_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_7]));

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_91_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [2]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 62))
    goto label_18;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd47.Lng))))
    goto label_18;
  (Wrd9.Obj) = ((Wrd45.pObj) [3]);
  if (! ((Wrd9.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_13;

DEFLABEL (label_12)
  Rvl = (current_block [OBJECT_91_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [2]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 62))
    goto label_17;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd28.Lng))))
    goto label_17;
  (Wrd20.Obj) = ((Wrd26.pObj) [4]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_16)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_91_9);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_91_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_15;
  Wrd5 = Wrd9;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_13]));

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_91_12])), (Wrd6.pObj));

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [2]);
  (Wrd36.Obj) = (current_block [OBJECT_91_3]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_10]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (label_18)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [2]);
  (Wrd55.Obj) = (current_block [OBJECT_91_0]);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_8]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_1]), 2);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  goto label_13;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_5 5
#define ENVIRONMENT_LABEL_92_3 10
#define DEBUGGING_LABEL_92_2 9
#define OBJECT_92_2 8
#define OBJECT_92_1 7
#define OBJECT_92_0 6
#define FREE_REFERENCES_LABEL_92_0 6
#define NUMBER_OF_LINKER_SECTIONS_92_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd7;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto x_graphics_open_displayP_1;

    case 1:
      current_block = (Rpc - LABEL_92_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_open_displayP_5)
DEFLABEL (x_graphics_open_displayP_1)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_10;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_10;
  (Wrd7.Obj) = ((Wrd16.pObj) [3]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_7;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_92_2]);
  goto label_6;

DEFLABEL (label_7)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_6)
DEFLABEL (label_9)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.Obj) = (current_block [OBJECT_92_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_1]), 2);

DEFLABEL (label_3)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_5 5
#define LABEL_93_6 7
#define TAG_93_7 2
#define LABEL_93_8 9
#define LABEL_93_14 11
#define LABEL_93_10 13
#define TAG_93_11 5
#define LABEL_93_15 15
#define LABEL_93_16 17
#define LABEL_93_13 19
#define LABEL_93_17 21
#define TAG_93_18 9
#define LABEL_93_24 23
#define LABEL_93_19 25
#define TAG_93_20 11
#define LABEL_93_23 27
#define LABEL_93_25 29
#define ENVIRONMENT_LABEL_93_3 54
#define DEBUGGING_LABEL_93_2 53
#define OBJECT_93_6 52
#define OBJECT_93_5 51
#define OBJECT_93_4 50
#define OBJECT_93_3 49
#define OBJECT_93_2 48
#define OBJECT_93_1 47
#define OBJECT_93_0 46
#define EXECUTE_CACHE_93_27 31
#define EXECUTE_CACHE_93_26 33
#define EXECUTE_CACHE_93_22 35
#define EXECUTE_CACHE_93_21 37
#define EXECUTE_CACHE_93_12 39
#define EXECUTE_CACHE_93_9 41
#define FREE_REFERENCE_93_1 44
#define FREE_REFERENCE_93_0 45
#define FREE_REFERENCES_LABEL_93_0 30
#define NUMBER_OF_LINKER_SECTIONS_93_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd27;
  machine_word Wrd38;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto make_event_previewer_15;

    case 1:
      current_block = (Rpc - LABEL_93_5);
      goto continuation_13;

    case 2:
      current_block = (Rpc - LABEL_93_6);
      goto lambda_23;

    case 3:
      current_block = (Rpc - LABEL_93_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_93_14);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_93_10);
      goto lambda_24;

    case 6:
      current_block = (Rpc - LABEL_93_15);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_93_16);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_93_13);
      goto continuation_1;

    case 9:
      current_block = (Rpc - LABEL_93_17);
      goto lambda_25;

    case 10:
      current_block = (Rpc - LABEL_93_24);
      goto label_20;

    case 11:
      current_block = (Rpc - LABEL_93_19);
      goto lambda_26;

    case 12:
      current_block = (Rpc - LABEL_93_23);
      goto continuation_8;

    case 13:
      current_block = (Rpc - LABEL_93_25);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_event_previewer_22)
DEFLABEL (make_event_previewer_15)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_93_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_93_6])));
  Rhp += 2;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  Wrd18 = Wrd15;
  (Wrd19.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [2]) = (Wrd19.Obj);
  ((Wrd18.pObj) [3]) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_8]))));
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_93_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_93_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [6]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_28;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_28;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_27)
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_3]), 1);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_93_13);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_22]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_93_5);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd20.Obj) = (Rsp [6]);
  (Wrd21.Obj) = (current_block [OBJECT_93_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_14]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_2]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_93_6);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_93_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_93_10])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_12]));

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_93_10);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_93_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_32;
  Wrd6 = Wrd10;

DEFLABEL (label_31)
  (Wrd15.Obj) = (current_block [OBJECT_93_4]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_93_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_30;
  Wrd17 = Wrd21;

DEFLABEL (label_29)
  (Wrd23.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_93_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_93_17])));
  Rhp += 1;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd30 = Wrd29;
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [2]);
  ((Wrd30.pObj) [2]) = (Wrd33.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd36.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_93_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_93_19])));
  Rhp += 2;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd36.pObj)));
  Wrd39 = Wrd36;
  (Wrd42.Obj) = ((Wrd32.pObj) [3]);
  ((Wrd39.pObj) [2]) = (Wrd42.Obj);
  (Wrd38.Obj) = (Rsp [2]);
  ((Wrd39.pObj) [3]) = (Wrd38.Obj);
  (Rsp [1]) = (Wrd35.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_21]));

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93_16])), (Wrd18.pObj));

DEFLABEL (label_19)
  (Wrd17.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93_15])), (Wrd7.pObj));

DEFLABEL (label_18)
  (Wrd6.Obj) = Rvl;
  goto label_31;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_93_17);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_35;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd21.Lng))))
    goto label_35;
  (Wrd13.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_34)
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_5]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_93_23);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [2]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_27]));

DEFLABEL (label_33)
  Rvl = (current_block [OBJECT_93_6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Wrd29.Obj) = (current_block [OBJECT_93_1]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_24]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_2]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_93_19);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_26]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_93_25);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93_6]);
  (Rsp [1]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_5 5
#define LABEL_94_6 7
#define TAG_94_7 2
#define LABEL_94_9 9
#define LABEL_94_12 11
#define ENVIRONMENT_LABEL_94_3 24
#define DEBUGGING_LABEL_94_2 23
#define OBJECT_94_1 22
#define OBJECT_94_0 21
#define EXECUTE_CACHE_94_13 13
#define EXECUTE_CACHE_94_11 15
#define EXECUTE_CACHE_94_10 17
#define EXECUTE_CACHE_94_8 19
#define FREE_REFERENCES_LABEL_94_0 12
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto read_event_8;

    case 1:
      current_block = (Rpc - LABEL_94_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_94_6);
      goto lambda_13;

    case 3:
      current_block = (Rpc - LABEL_94_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_94_12);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (read_event_12)
DEFLABEL (read_event_8)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_15;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd19.Lng))))
    goto label_15;
  (Wrd13.Obj) = ((Wrd17.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_14)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_94_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_94_6])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [0]);
  ((Wrd34.pObj) [4]) = (Wrd31.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  ((Wrd38.pObj) [0]) = (Wrd28.Obj);
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Rsp [1]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_8]));

DEFLABEL (label_15)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_94_0]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_5]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_1]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_94_6);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_94_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [4]);
  (Rsp [0]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_11]));

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_94_12);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_8 5
#define LABEL_95_6 7
#define LABEL_95_9 9
#define LABEL_95_5 11
#define LABEL_95_7 13
#define ENVIRONMENT_LABEL_95_3 28
#define DEBUGGING_LABEL_95_2 27
#define OBJECT_95_7 26
#define OBJECT_95_6 25
#define OBJECT_95_5 24
#define OBJECT_95_4 23
#define OBJECT_95_3 22
#define OBJECT_95_2 21
#define OBJECT_95_1 20
#define OBJECT_95_0 19
#define EXECUTE_CACHE_95_11 15
#define EXECUTE_CACHE_95_10 17
#define FREE_REFERENCES_LABEL_95_0 14
#define NUMBER_OF_LINKER_SECTIONS_95_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto Z__read_and_process_event_7;

    case 1:
      current_block = (Rpc - LABEL_95_8);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_95_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_95_9);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_95_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__read_and_process_event_12)
DEFLABEL (Z__read_and_process_event_7)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_95_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_95_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 62))
    goto label_19;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_19;
  (Wrd18.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_18)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_4]), 1);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_95_7);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_95_6);
  if (Rvl == (current_block [OBJECT_95_0]))
    goto label_15;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_14)
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_10]));

DEFLABEL (label_13)
  Rvl = (current_block [OBJECT_95_7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd15.Obj) = (current_block [OBJECT_95_5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 62))
    goto label_17;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_17;
  (Wrd18.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_16)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_6]), 2);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_95_5);
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (current_block [OBJECT_95_2]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_9]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_3]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd27.Obj) = (Rsp [5]);
  (Wrd28.Obj) = (current_block [OBJECT_95_2]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_3]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_5 5
#define LABEL_96_6 7
#define TAG_96_7 2
#define LABEL_96_9 9
#define LABEL_96_14 11
#define LABEL_96_13 13
#define LABEL_96_11 15
#define LABEL_96_15 17
#define ENVIRONMENT_LABEL_96_3 33
#define DEBUGGING_LABEL_96_2 32
#define OBJECT_96_4 31
#define OBJECT_96_3 30
#define OBJECT_96_2 29
#define OBJECT_96_1 28
#define OBJECT_96_0 27
#define EXECUTE_CACHE_96_16 19
#define EXECUTE_CACHE_96_12 21
#define EXECUTE_CACHE_96_10 23
#define EXECUTE_CACHE_96_8 25
#define FREE_REFERENCES_LABEL_96_0 18
#define NUMBER_OF_LINKER_SECTIONS_96_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd30;
  machine_word Wrd15;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd40;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto discard_events_13;

    case 1:
      current_block = (Rpc - LABEL_96_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_96_6);
      goto lambda_19;

    case 3:
      current_block = (Rpc - LABEL_96_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_96_14);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_96_13);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_96_11);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_96_15);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (discard_events_18)
DEFLABEL (discard_events_13)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_21;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd19.Lng))))
    goto label_21;
  (Wrd13.Obj) = ((Wrd17.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_20)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_6])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [0]);
  ((Wrd34.pObj) [4]) = (Wrd31.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  ((Wrd38.pObj) [0]) = (Wrd28.Obj);
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Rsp [1]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_8]));

DEFLABEL (label_21)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_96_0]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_1]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_96_6);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_96_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_11]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [4]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_96_11);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_22)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_96_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 62))
    goto label_25;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd23.Lng))))
    goto label_25;
  (Wrd15.Obj) = ((Wrd21.pObj) [3]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_24)
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_3]), 2);

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_96_13);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_23;
  Rvl = (current_block [OBJECT_96_4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_96_15);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_25)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [2]);
  (Wrd31.Obj) = (current_block [OBJECT_96_2]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_14]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_1]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_24;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define LABEL_97_5 5
#define TAG_97_6 1
#define LABEL_97_9 7
#define LABEL_97_12 9
#define LABEL_97_14 11
#define LABEL_97_8 13
#define LABEL_97_15 15
#define LABEL_97_16 17
#define LABEL_97_17 19
#define LABEL_97_18 21
#define LABEL_97_19 23
#define LABEL_97_20 25
#define LABEL_97_21 27
#define LABEL_97_22 29
#define LABEL_97_10 31
#define TAG_97_11 14
#define LABEL_97_24 33
#define ENVIRONMENT_LABEL_97_3 55
#define DEBUGGING_LABEL_97_2 54
#define OBJECT_97_10 53
#define OBJECT_97_9 52
#define OBJECT_97_8 51
#define OBJECT_97_7 50
#define OBJECT_97_6 49
#define OBJECT_97_5 48
#define OBJECT_97_4 47
#define OBJECT_97_3 46
#define OBJECT_97_2 45
#define OBJECT_97_1 44
#define OBJECT_97_0 43
#define EXECUTE_CACHE_97_23 35
#define EXECUTE_CACHE_97_13 37
#define EXECUTE_CACHE_97_7 39
#define FREE_REFERENCE_97_0 42
#define FREE_REFERENCES_LABEL_97_0 34
#define NUMBER_OF_LINKER_SECTIONS_97_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd175;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd119;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd96;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd148;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd128;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd91;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd69;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd174;
  machine_word Wrd171;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd169;
  machine_word Wrd151;
  machine_word Wrd163;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd165;
  machine_word Wrd164;
  machine_word Wrd203;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd196;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd183;
  machine_word Wrd191;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd192;
  machine_word Wrd68;
  machine_word Wrd59;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto process_event_23;

    case 1:
      current_block = (Rpc - LABEL_97_5);
      goto lambda_38;

    case 2:
      current_block = (Rpc - LABEL_97_9);
      goto label_25;

    case 3:
      current_block = (Rpc - LABEL_97_12);
      goto label_26;

    case 4:
      current_block = (Rpc - LABEL_97_14);
      goto continuation_9;

    case 5:
      current_block = (Rpc - LABEL_97_8);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_97_15);
      goto label_27;

    case 7:
      current_block = (Rpc - LABEL_97_16);
      goto label_28;

    case 8:
      current_block = (Rpc - LABEL_97_17);
      goto label_29;

    case 9:
      current_block = (Rpc - LABEL_97_18);
      goto label_34;

    case 10:
      current_block = (Rpc - LABEL_97_19);
      goto label_33;

    case 11:
      current_block = (Rpc - LABEL_97_20);
      goto label_30;

    case 12:
      current_block = (Rpc - LABEL_97_21);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_97_22);
      goto label_31;

    case 14:
      current_block = (Rpc - LABEL_97_10);
      goto lambda_39;

    case 15:
      current_block = (Rpc - LABEL_97_24);
      goto label_35;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (process_event_37)
DEFLABEL (process_event_23)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_97_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_97_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_7]));

DEFLABEL (lambda_38)
  CLOSURE_HEADER (LABEL_97_5);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_65;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd20.Lng))))
    goto label_65;
  (Wrd12.Obj) = ((Wrd18.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_64)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_97_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_97_10])));
  Rhp += 1;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd36 = Wrd35;
  (Wrd37.Obj) = (Rsp [0]);
  ((Wrd36.pObj) [2]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [3]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_63;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd50.Lng))))
    goto label_63;
  (Wrd42.Obj) = ((Wrd48.pObj) [4]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_62)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_97_8);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_40;
  Rvl = (current_block [OBJECT_97_4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_61;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_61;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_60)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_14]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_97_0]));
  (Wrd39.Obj) = ((Wrd36.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_59;
  Wrd35 = Wrd39;

DEFLABEL (label_58)
  Wrd34 = Wrd35;
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd53.uLng) == 10))
    goto label_57;
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 26))
    goto label_57;
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) (Wrd49.Lng)) < ((unsigned long) (Wrd52.Lng))))
    goto label_57;
  (Wrd42.uLng) = (OBJECT_DATUM (Wrd46.Obj));
  (Wrd44.pObj) = (& ((Wrd50.pObj) [(Wrd42.Lng)]));
  (Wrd45.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_56)
  (Wrd59.Obj) = (Rsp [0]);
  if ((Wrd59.Obj) == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Wrd61.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd64.Obj) = (Rsp [6]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd63.Obj) = ((Wrd65.pObj) [2]);
  (Rsp [2]) = (Wrd63.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_41)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_55)
  (Wrd68.Obj) = (Rsp [0]);
  if ((Wrd68.Obj) == (current_block [OBJECT_97_6]))
    goto label_50;
  (Wrd78.Obj) = (Rsp [1]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 62))
    goto label_49;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd77.Lng))))
    goto label_49;
  (Wrd69.Obj) = ((Wrd75.pObj) [6]);

DEFLABEL (label_48)
  (Wrd87.Lng) = 1L;
  (Wrd88.Obj) = (Rsp [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  (Wrd92.Lng) = (FIXNUM_LSH ((Wrd87.Lng), (Wrd89.Lng)));
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  (Wrd94.Lng) = ((Wrd92.Lng) & (Wrd93.Lng));
  (Wrd91.Obj) = (LONG_TO_FIXNUM (Wrd94.Lng));
  if (! ((Wrd91.Obj) == (current_block [OBJECT_97_5])))
    goto label_42;
  Rvl = (current_block [OBJECT_97_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd137.Obj) = (Rsp [2]);
  (Wrd138.pObj) = (OBJECT_ADDRESS (Wrd137.Obj));
  (Wrd139.Obj) = ((Wrd138.pObj) [2]);
  (Wrd140.uLng) = (OBJECT_TYPE (Wrd139.Obj));
  if (! ((Wrd140.uLng) == 10))
    goto label_47;
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [0]);
  (Wrd136.Lng) = (FIXNUM_TO_LONG (Wrd135.Obj));
  if (! (((unsigned long) (Wrd87.Lng)) < ((unsigned long) (Wrd136.Lng))))
    goto label_47;
  (Wrd128.Obj) = (Rsp [1]);
  ((Wrd134.pObj) [2]) = (Wrd128.Obj);

DEFLABEL (label_46)
  (Wrd109.Obj) = (Rsp [2]);
  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd111.Obj) = ((Wrd110.pObj) [3]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 62))
    goto label_45;
  (Wrd106.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd107.Obj) = ((Wrd106.pObj) [0]);
  (Wrd108.Lng) = (FIXNUM_TO_LONG (Wrd107.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd108.Lng))))
    goto label_45;
  (Wrd96.Obj) = ((Wrd106.pObj) [5]);

DEFLABEL (label_44)
  (Rsp [1]) = (Wrd96.Obj);

DEFLABEL (label_43)
  (Wrd176.Obj) = (Rsp [2]);
  (Wrd177.pObj) = (OBJECT_ADDRESS (Wrd176.Obj));
  (Wrd175.Obj) = ((Wrd177.pObj) [2]);
  (Rsp [2]) = (Wrd175.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_23]));

DEFLABEL (label_45)
  (Wrd114.Obj) = (Rsp [2]);
  (Wrd115.pObj) = (OBJECT_ADDRESS (Wrd114.Obj));
  (Wrd113.Obj) = ((Wrd115.pObj) [3]);
  (Wrd116.Obj) = (current_block [OBJECT_97_8]);
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_22]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_3]), 2);

DEFLABEL (label_31)
  (Wrd96.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd142.Obj) = (Rsp [2]);
  (Wrd143.pObj) = (OBJECT_ADDRESS (Wrd142.Obj));
  (Wrd141.Obj) = ((Wrd143.pObj) [2]);
  (Wrd144.Obj) = (current_block [OBJECT_97_0]);
  (Wrd145.Obj) = (Rsp [1]);
  (Wrd148.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_21]))));
  (* (--Rsp)) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd145.Obj);
  (* (--Rsp)) = (Wrd144.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_7]), 3);

DEFLABEL (label_32)
  goto label_46;

DEFLABEL (label_49)
  (Wrd80.Obj) = (Rsp [1]);
  (Wrd81.Obj) = (current_block [OBJECT_97_9]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_20]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_3]), 2);

DEFLABEL (label_30)
  (Wrd69.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd192.Obj) = (Rsp [2]);
  (Wrd193.pObj) = (OBJECT_ADDRESS (Wrd192.Obj));
  (Wrd194.Obj) = ((Wrd193.pObj) [2]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if (! ((Wrd195.uLng) == 10))
    goto label_54;
  (Wrd189.pObj) = (OBJECT_ADDRESS (Wrd194.Obj));
  (Wrd190.Obj) = ((Wrd189.pObj) [0]);
  (Wrd191.Lng) = (FIXNUM_TO_LONG (Wrd190.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd191.Lng))))
    goto label_54;
  (Wrd183.Obj) = (Rsp [1]);
  ((Wrd189.pObj) [2]) = (Wrd183.Obj);

DEFLABEL (label_53)
  (Wrd164.Obj) = (Rsp [2]);
  (Wrd165.pObj) = (OBJECT_ADDRESS (Wrd164.Obj));
  (Wrd166.Obj) = ((Wrd165.pObj) [3]);
  (Wrd167.uLng) = (OBJECT_TYPE (Wrd166.Obj));
  if (! ((Wrd167.uLng) == 62))
    goto label_52;
  (Wrd161.pObj) = (OBJECT_ADDRESS (Wrd166.Obj));
  (Wrd162.Obj) = ((Wrd161.pObj) [0]);
  (Wrd163.Lng) = (FIXNUM_TO_LONG (Wrd162.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd163.Lng))))
    goto label_52;
  (Wrd151.Obj) = ((Wrd161.pObj) [5]);

DEFLABEL (label_51)
  (Rsp [1]) = (Wrd151.Obj);
  goto label_43;

DEFLABEL (label_52)
  (Wrd169.Obj) = (Rsp [2]);
  (Wrd170.pObj) = (OBJECT_ADDRESS (Wrd169.Obj));
  (Wrd168.Obj) = ((Wrd170.pObj) [3]);
  (Wrd171.Obj) = (current_block [OBJECT_97_8]);
  (Wrd174.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_19]))));
  (* (--Rsp)) = (Wrd174.Obj);
  (* (--Rsp)) = (Wrd171.Obj);
  (* (--Rsp)) = (Wrd168.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_3]), 2);

DEFLABEL (label_33)
  (Wrd151.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd197.Obj) = (Rsp [2]);
  (Wrd198.pObj) = (OBJECT_ADDRESS (Wrd197.Obj));
  (Wrd196.Obj) = ((Wrd198.pObj) [2]);
  (Wrd199.Obj) = (current_block [OBJECT_97_0]);
  (Wrd200.Obj) = (Rsp [1]);
  (Wrd203.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_18]))));
  (* (--Rsp)) = (Wrd203.Obj);
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd199.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_7]), 3);

DEFLABEL (label_34)
  goto label_53;

DEFLABEL (label_57)
  (Wrd55.Obj) = (Rsp [1]);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_17]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_1]), 2);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_97_16])), (Wrd36.pObj));

DEFLABEL (label_28)
  (Wrd35.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [2]);
  (Wrd27.Obj) = (current_block [OBJECT_97_5]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_15]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_1]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd56.Obj) = (Rsp [2]);
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [3]);
  (Wrd58.Obj) = (current_block [OBJECT_97_2]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_12]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_3]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [2]);
  (Wrd28.Obj) = (current_block [OBJECT_97_0]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_9]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_97_14);
  goto label_55;

DEFLABEL (lambda_39)
  CLOSURE_HEADER (LABEL_97_10);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_70;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_70;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_69)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  if ((Wrd5.Obj) == (Wrd24.Obj))
    goto label_67;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_66;

DEFLABEL (label_67)
  Rvl = (current_block [OBJECT_97_10]);

DEFLABEL (label_66)
DEFLABEL (label_68)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_70)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_97_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_24]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_3]), 2);

DEFLABEL (label_35)
  (Wrd5.Obj) = Rvl;
  goto label_69;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_4 3
#define LABEL_98_5 5
#define ENVIRONMENT_LABEL_98_3 11
#define DEBUGGING_LABEL_98_2 10
#define OBJECT_98_1 9
#define OBJECT_98_0 8
#define FREE_REFERENCE_98_0 7
#define FREE_REFERENCES_LABEL_98_0 6
#define NUMBER_OF_LINKER_SECTIONS_98_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd28;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_4);
      goto define_event_handler_0;

    case 1:
      current_block = (Rpc - LABEL_98_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_event_handler_4)
DEFLABEL (define_event_handler_0)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_98_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_8;
  Wrd5 = Wrd9;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd28.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_1]), 3);

DEFLABEL (label_6)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_5;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd26.Lng))))
    goto label_5;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd16.pObj) = (& ((Wrd24.pObj) [(Wrd13.Lng)]));
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [1]) = (Wrd17.Obj);
  Rvl = (current_block [OBJECT_98_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_98_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_4 3
#define LABEL_99_6 5
#define LABEL_99_7 7
#define LABEL_99_8 9
#define LABEL_99_5 11
#define LABEL_99_9 13
#define ENVIRONMENT_LABEL_99_3 25
#define DEBUGGING_LABEL_99_2 24
#define OBJECT_99_9 23
#define OBJECT_99_8 22
#define OBJECT_99_7 21
#define OBJECT_99_6 20
#define OBJECT_99_5 19
#define OBJECT_99_4 18
#define OBJECT_99_3 17
#define OBJECT_99_2 16
#define OBJECT_99_1 15
#define OBJECT_99_0 14
#define FREE_REFERENCES_LABEL_99_0 14
#define NUMBER_OF_LINKER_SECTIONS_99_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_4);
      goto lambda_6;

    case 1:
      current_block = (Rpc - LABEL_99_6);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_99_7);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_99_8);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_99_5);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_99_9);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_13)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_24;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_24;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_23)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_22;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_22;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_21)
  (Wrd49.Obj) = (Rsp [4]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_20;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd48.Lng))))
    goto label_20;
  (Wrd42.Obj) = ((Wrd46.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_19)
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_4]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_99_5);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_18;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_18;
  (Wrd5.Obj) = ((Wrd11.pObj) [4]);

DEFLABEL (label_17)
  if ((Wrd5.Obj) == (current_block [OBJECT_99_6]))
    goto label_14;
  Rvl = (current_block [OBJECT_99_8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd24.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_99_0]);
  (Rsp [1]) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_99_7]);
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd39.uLng) == 62)
    goto label_16;

DEFLABEL (label_15)
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_9]), 3);

DEFLABEL (label_16)
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd37.Lng))))
    goto label_15;
  ((Wrd35.pObj) [4]) = (Wrd26.Obj);
  Rvl = (current_block [OBJECT_99_8]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_99_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_5]), 2);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd51.Obj) = (Rsp [4]);
  (Wrd52.Obj) = (current_block [OBJECT_99_3]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_8]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_99_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_99_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_4 3
#define ENVIRONMENT_LABEL_100_3 8
#define DEBUGGING_LABEL_100_2 7
#define EXECUTE_CACHE_100_5 5
#define FREE_REFERENCES_LABEL_100_0 4
#define NUMBER_OF_LINKER_SECTIONS_100_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_100_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_4 3
#define ENVIRONMENT_LABEL_101_3 9
#define DEBUGGING_LABEL_101_2 8
#define OBJECT_101_3 7
#define OBJECT_101_2 6
#define OBJECT_101_1 5
#define OBJECT_101_0 4
#define FREE_REFERENCES_LABEL_101_0 4
#define NUMBER_OF_LINKER_SECTIONS_101_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_101_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_101_1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd20.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_3]), 3);

DEFLABEL (label_5)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_4;
  ((Wrd16.pObj) [4]) = (Wrd7.Obj);
  Rvl = (current_block [OBJECT_101_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_4 3
#define ENVIRONMENT_LABEL_102_3 8
#define DEBUGGING_LABEL_102_2 7
#define OBJECT_102_2 6
#define OBJECT_102_1 5
#define OBJECT_102_0 4
#define FREE_REFERENCES_LABEL_102_0 4
#define NUMBER_OF_LINKER_SECTIONS_102_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_102_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd20.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_2]), 3);

DEFLABEL (label_5)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_4;
  ((Wrd16.pObj) [4]) = ((SCHEME_OBJECT) 0);
  Rvl = (current_block [OBJECT_102_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define LABEL_103_5 5
#define ENVIRONMENT_LABEL_103_3 17
#define DEBUGGING_LABEL_103_2 16
#define OBJECT_103_9 15
#define OBJECT_103_8 14
#define OBJECT_103_7 13
#define OBJECT_103_6 12
#define OBJECT_103_5 11
#define OBJECT_103_4 10
#define OBJECT_103_3 9
#define OBJECT_103_2 8
#define OBJECT_103_1 7
#define OBJECT_103_0 6
#define FREE_REFERENCES_LABEL_103_0 6
#define NUMBER_OF_LINKER_SECTIONS_103_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd60;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd76;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto lambda_5;

    case 1:
      current_block = (Rpc - LABEL_103_5);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_9)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_103_4);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_17;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_17;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_16)
  (Wrd21.Obj) = (Rsp [0]);
  if ((Wrd21.Obj) == (current_block [OBJECT_103_2]))
    goto label_15;
  if ((Wrd21.Obj) == (current_block [OBJECT_103_5]))
    goto label_14;
  if ((Wrd21.Obj) == (current_block [OBJECT_103_0]))
    goto label_11;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_103_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd29.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_103_7]);
  (Rsp [2]) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_103_4]);
  (Rsp [1]) = (Wrd31.Obj);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd44.uLng) == 62)
    goto label_13;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_8]), 3);

DEFLABEL (label_13)
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd42.Lng))))
    goto label_12;
  ((Wrd40.pObj) [5]) = (Wrd30.Obj);
  goto label_10;

DEFLABEL (label_14)
  (Wrd45.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd45.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_103_6]);
  (Rsp [2]) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_103_4]);
  (Rsp [1]) = (Wrd47.Obj);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd60.uLng) == 62))
    goto label_12;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [0]);
  (Wrd58.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd58.Lng))))
    goto label_12;
  ((Wrd56.pObj) [5]) = (Wrd46.Obj);
  goto label_10;

DEFLABEL (label_15)
  (Wrd61.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd61.Obj);
  (Wrd62.Obj) = (current_block [OBJECT_103_3]);
  (Rsp [2]) = (Wrd62.Obj);
  (Wrd63.Obj) = (current_block [OBJECT_103_4]);
  (Rsp [1]) = (Wrd63.Obj);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd76.uLng) == 62))
    goto label_12;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd73.Obj) = ((Wrd72.pObj) [0]);
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd73.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd74.Lng))))
    goto label_12;
  ((Wrd72.pObj) [5]) = (Wrd62.Obj);
  goto label_10;

DEFLABEL (label_17)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_103_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define ENVIRONMENT_LABEL_104_3 5
#define DEBUGGING_LABEL_104_2 4
#define FREE_REFERENCES_LABEL_104_0 4
#define NUMBER_OF_LINKER_SECTIONS_104_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_104_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_4 3
#define ENVIRONMENT_LABEL_105_3 5
#define DEBUGGING_LABEL_105_2 4
#define FREE_REFERENCES_LABEL_105_0 4
#define NUMBER_OF_LINKER_SECTIONS_105_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_105_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define ENVIRONMENT_LABEL_106_3 6
#define DEBUGGING_LABEL_106_2 5
#define OBJECT_106_0 4
#define FREE_REFERENCES_LABEL_106_0 4
#define NUMBER_OF_LINKER_SECTIONS_106_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_106_4);
  Rvl = (current_block [OBJECT_106_0]);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define ENVIRONMENT_LABEL_107_3 5
#define DEBUGGING_LABEL_107_2 4
#define FREE_REFERENCES_LABEL_107_0 4
#define NUMBER_OF_LINKER_SECTIONS_107_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_107_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_108_4 3
#define ENVIRONMENT_LABEL_108_3 6
#define DEBUGGING_LABEL_108_2 5
#define OBJECT_108_0 4
#define FREE_REFERENCES_LABEL_108_0 4
#define NUMBER_OF_LINKER_SECTIONS_108_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_108 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_108_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_108_4);
  Rvl = (current_block [OBJECT_108_0]);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_109_4 3
#define ENVIRONMENT_LABEL_109_3 7
#define DEBUGGING_LABEL_109_2 6
#define OBJECT_109_1 5
#define OBJECT_109_0 4
#define FREE_REFERENCES_LABEL_109_0 4
#define NUMBER_OF_LINKER_SECTIONS_109_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_109 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_109_4);
      goto x_window_xw_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_xw_3)
DEFLABEL (x_window_xw_0)
  INTERRUPT_CHECK (26, LABEL_109_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_109_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_109_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_110_4 3
#define ENVIRONMENT_LABEL_110_3 7
#define DEBUGGING_LABEL_110_2 6
#define OBJECT_110_1 5
#define OBJECT_110_0 4
#define FREE_REFERENCES_LABEL_110_0 4
#define NUMBER_OF_LINKER_SECTIONS_110_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_110 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_110_4);
      goto x_window_display_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_display_3)
DEFLABEL (x_window_display_0)
  INTERRUPT_CHECK (26, LABEL_110_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_110_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_110_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_111_4 3
#define ENVIRONMENT_LABEL_111_3 7
#define DEBUGGING_LABEL_111_2 6
#define OBJECT_111_1 5
#define OBJECT_111_0 4
#define FREE_REFERENCES_LABEL_111_0 4
#define NUMBER_OF_LINKER_SECTIONS_111_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_111 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_111_4);
      goto x_window_mappedP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_mappedP_3)
DEFLABEL (x_window_mappedP_0)
  INTERRUPT_CHECK (26, LABEL_111_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_111_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_112_4 3
#define ENVIRONMENT_LABEL_112_3 7
#define DEBUGGING_LABEL_112_2 6
#define OBJECT_112_1 5
#define OBJECT_112_0 4
#define FREE_REFERENCES_LABEL_112_0 4
#define NUMBER_OF_LINKER_SECTIONS_112_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_112 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_112_4);
      goto x_window_visibility_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_visibility_3)
DEFLABEL (x_window_visibility_0)
  INTERRUPT_CHECK (26, LABEL_112_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_112_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_112_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_113_4 3
#define ENVIRONMENT_LABEL_113_3 7
#define DEBUGGING_LABEL_113_2 6
#define OBJECT_113_1 5
#define OBJECT_113_0 4
#define FREE_REFERENCES_LABEL_113_0 4
#define NUMBER_OF_LINKER_SECTIONS_113_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_113 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_113_4);
      goto x_window_user_event_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_window_user_event_mask_3)
DEFLABEL (x_window_user_event_mask_0)
  INTERRUPT_CHECK (26, LABEL_113_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_113_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_114_4 3
#define ENVIRONMENT_LABEL_114_3 8
#define DEBUGGING_LABEL_114_2 7
#define OBJECT_114_2 6
#define OBJECT_114_1 5
#define OBJECT_114_0 4
#define FREE_REFERENCES_LABEL_114_0 4
#define NUMBER_OF_LINKER_SECTIONS_114_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_114 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_114_4);
      goto set_x_window_xwB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_window_xwB_3)
DEFLABEL (set_x_window_xwB_0)
  INTERRUPT_CHECK (26, LABEL_114_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_114_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [2]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_114_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_115_4 3
#define ENVIRONMENT_LABEL_115_3 8
#define DEBUGGING_LABEL_115_2 7
#define OBJECT_115_2 6
#define OBJECT_115_1 5
#define OBJECT_115_0 4
#define FREE_REFERENCES_LABEL_115_0 4
#define NUMBER_OF_LINKER_SECTIONS_115_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_115 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_115_4);
      goto set_x_window_mappedPB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_window_mappedPB_3)
DEFLABEL (set_x_window_mappedPB_0)
  INTERRUPT_CHECK (26, LABEL_115_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_115_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [4]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_115_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_116_4 3
#define ENVIRONMENT_LABEL_116_3 8
#define DEBUGGING_LABEL_116_2 7
#define OBJECT_116_2 6
#define OBJECT_116_1 5
#define OBJECT_116_0 4
#define FREE_REFERENCES_LABEL_116_0 4
#define NUMBER_OF_LINKER_SECTIONS_116_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_116 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_116_4);
      goto set_x_window_visibilityB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_window_visibilityB_3)
DEFLABEL (set_x_window_visibilityB_0)
  INTERRUPT_CHECK (26, LABEL_116_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_116_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_116_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_117_4 3
#define ENVIRONMENT_LABEL_117_3 8
#define DEBUGGING_LABEL_117_2 7
#define OBJECT_117_2 6
#define OBJECT_117_1 5
#define OBJECT_117_0 4
#define FREE_REFERENCES_LABEL_117_0 4
#define NUMBER_OF_LINKER_SECTIONS_117_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_117 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_117_4);
      goto set_x_window_user_event_maskB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_window_user_event_maskB_3)
DEFLABEL (set_x_window_user_event_maskB_0)
  INTERRUPT_CHECK (26, LABEL_117_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_117_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [6]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_117_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_118_4 3
#define LABEL_118_5 5
#define ENVIRONMENT_LABEL_118_3 10
#define DEBUGGING_LABEL_118_2 9
#define OBJECT_118_2 8
#define OBJECT_118_1 7
#define OBJECT_118_0 6
#define FREE_REFERENCES_LABEL_118_0 6
#define NUMBER_OF_LINKER_SECTIONS_118_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_118 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_118_4);
      goto x_graphics_device_xw_1;

    case 1:
      current_block = (Rpc - LABEL_118_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_device_xw_5)
DEFLABEL (x_graphics_device_xw_1)
  INTERRUPT_CHECK (26, LABEL_118_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_118_2]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 2);

DEFLABEL (label_7)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_6;
  Rvl = ((Wrd29.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_118_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_119_4 3
#define LABEL_119_5 5
#define ENVIRONMENT_LABEL_119_3 9
#define DEBUGGING_LABEL_119_2 8
#define OBJECT_119_1 7
#define OBJECT_119_0 6
#define FREE_REFERENCES_LABEL_119_0 6
#define NUMBER_OF_LINKER_SECTIONS_119_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_119 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_119_4);
      goto x_graphics_display_1;

    case 1:
      current_block = (Rpc - LABEL_119_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_display_5)
DEFLABEL (x_graphics_display_1)
  INTERRUPT_CHECK (26, LABEL_119_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_119_0]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_119_1]), 2);

DEFLABEL (label_7)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd31.Lng))))
    goto label_6;
  Rvl = ((Wrd29.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_119_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_119_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_120_4 3
#define LABEL_120_5 5
#define LABEL_120_6 7
#define ENVIRONMENT_LABEL_120_3 11
#define DEBUGGING_LABEL_120_2 10
#define OBJECT_120_1 9
#define OBJECT_120_0 8
#define FREE_REFERENCES_LABEL_120_0 8
#define NUMBER_OF_LINKER_SECTIONS_120_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_120 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_120_4);
      goto x_graphics_device_xd_2;

    case 1:
      current_block = (Rpc - LABEL_120_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_120_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_device_xd_7)
DEFLABEL (x_graphics_device_xd_2)
  INTERRUPT_CHECK (26, LABEL_120_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd22.Obj) = ((Wrd25.pObj) [3]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_10)
  (Wrd34.Obj) = (current_block [OBJECT_120_0]);
  (Rsp [1]) = (Wrd34.Obj);
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if ((Wrd46.uLng) == 62)
    goto label_9;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_120_1]), 2);

DEFLABEL (label_9)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd44.Lng))))
    goto label_8;
  Rvl = ((Wrd42.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_120_0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_120_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_120_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_120_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_121_4 3
#define LABEL_121_5 5
#define LABEL_121_6 7
#define ENVIRONMENT_LABEL_121_3 13
#define DEBUGGING_LABEL_121_2 12
#define OBJECT_121_3 11
#define OBJECT_121_2 10
#define OBJECT_121_1 9
#define OBJECT_121_0 8
#define FREE_REFERENCES_LABEL_121_0 8
#define NUMBER_OF_LINKER_SECTIONS_121_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_121 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_121_4);
      goto x_graphics_device_mappedP_2;

    case 1:
      current_block = (Rpc - LABEL_121_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_121_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_device_mappedP_7)
DEFLABEL (x_graphics_device_mappedP_2)
  INTERRUPT_CHECK (26, LABEL_121_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_14;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_14;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_13)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_12;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd27.Lng))))
    goto label_12;
  (Wrd21.Obj) = ((Wrd25.pObj) [4]);

DEFLABEL (label_11)
  (Wrd35.Obj) = (current_block [OBJECT_121_3]);
  if ((Wrd35.Obj) == (Wrd21.Obj))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_8;

DEFLABEL (label_9)
  Rvl = (Wrd35.Obj);

DEFLABEL (label_8)
DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd30.Obj) = (current_block [OBJECT_121_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_121_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_122_4 3
#define LABEL_122_5 5
#define ENVIRONMENT_LABEL_122_3 10
#define DEBUGGING_LABEL_122_2 9
#define OBJECT_122_2 8
#define OBJECT_122_1 7
#define OBJECT_122_0 6
#define FREE_REFERENCES_LABEL_122_0 6
#define NUMBER_OF_LINKER_SECTIONS_122_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_122 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_122_4);
      goto x_graphics_device_visibility_1;

    case 1:
      current_block = (Rpc - LABEL_122_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_device_visibility_5)
DEFLABEL (x_graphics_device_visibility_1)
  INTERRUPT_CHECK (26, LABEL_122_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_122_2]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_1]), 2);

DEFLABEL (label_7)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd31.Lng))))
    goto label_6;
  Rvl = ((Wrd29.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_122_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_123_4 3
#define LABEL_123_5 5
#define LABEL_123_6 7
#define ENVIRONMENT_LABEL_123_3 13
#define DEBUGGING_LABEL_123_2 12
#define OBJECT_123_3 11
#define OBJECT_123_2 10
#define OBJECT_123_1 9
#define OBJECT_123_0 8
#define FREE_REFERENCES_LABEL_123_0 8
#define NUMBER_OF_LINKER_SECTIONS_123_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_123 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd22;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd33;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_123_4);
      goto x_graphics_open_windowP_2;

    case 1:
      current_block = (Rpc - LABEL_123_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_123_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_open_windowP_7)
DEFLABEL (x_graphics_open_windowP_2)
  INTERRUPT_CHECK (26, LABEL_123_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_14;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_14;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_13)
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_12;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd32.Lng))))
    goto label_12;
  (Wrd22.Obj) = ((Wrd30.pObj) [2]);
  if ((Wrd22.Obj) == ((SCHEME_OBJECT) 0))
    goto label_9;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_123_3]);
  goto label_8;

DEFLABEL (label_9)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_8)
DEFLABEL (label_11)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd35.Obj) = (current_block [OBJECT_123_2]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_6]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_123_1]), 2);

DEFLABEL (label_5)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  goto label_10;

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_123_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_123_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_124_4 3
#define LABEL_124_5 5
#define TAG_124_6 1
#define LABEL_124_8 7
#define ENVIRONMENT_LABEL_124_3 16
#define DEBUGGING_LABEL_124_2 15
#define OBJECT_124_1 14
#define OBJECT_124_0 13
#define EXECUTE_CACHE_124_9 9
#define EXECUTE_CACHE_124_7 11
#define FREE_REFERENCES_LABEL_124_0 8
#define NUMBER_OF_LINKER_SECTIONS_124_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_124 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_124_4);
      goto x_graphics_close_window_2;

    case 1:
      current_block = (Rpc - LABEL_124_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_124_8);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_close_window_6)
DEFLABEL (x_graphics_close_window_2)
  INTERRUPT_CHECK (26, LABEL_124_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_124_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_124_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_124_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_9;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_9;
  (Wrd5.Obj) = ((Wrd15.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_9]));

DEFLABEL (label_9)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [2]);
  (Wrd25.Obj) = (current_block [OBJECT_124_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_124_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_125_4 3
#define LABEL_125_5 5
#define LABEL_125_6 7
#define ENVIRONMENT_LABEL_125_3 15
#define DEBUGGING_LABEL_125_2 14
#define OBJECT_125_2 13
#define OBJECT_125_1 12
#define OBJECT_125_0 11
#define EXECUTE_CACHE_125_7 9
#define FREE_REFERENCES_LABEL_125_0 8
#define NUMBER_OF_LINKER_SECTIONS_125_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_125 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_125_4);
      goto close_x_window_2;

    case 1:
      current_block = (Rpc - LABEL_125_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_125_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (close_x_window_7)
DEFLABEL (close_x_window_2)
  INTERRUPT_CHECK (26, LABEL_125_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd22.Obj) = ((Wrd25.pObj) [4]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_8)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_7]));

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_125_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_125_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_126_5 3
#define LABEL_126_6 5
#define LABEL_126_4 7
#define LABEL_126_10 9
#define LABEL_126_8 11
#define LABEL_126_12 13
#define LABEL_126_11 15
#define LABEL_126_13 17
#define LABEL_126_15 19
#define ENVIRONMENT_LABEL_126_3 33
#define DEBUGGING_LABEL_126_2 32
#define OBJECT_126_2 31
#define OBJECT_126_1 30
#define OBJECT_126_0 29
#define EXECUTE_CACHE_126_9 21
#define EXECUTE_CACHE_126_16 23
#define EXECUTE_CACHE_126_14 25
#define EXECUTE_CACHE_126_7 27
#define FREE_REFERENCES_LABEL_126_0 20
#define NUMBER_OF_LINKER_SECTIONS_126_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_126 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd17;
  machine_word Wrd30;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_126_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_126_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_126_4);
      goto x_geometry_string_10;

    case 3:
      current_block = (Rpc - LABEL_126_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_126_8);
      goto continuation_9;

    case 5:
      current_block = (Rpc - LABEL_126_12);
      goto label_12;

    case 6:
      current_block = (Rpc - LABEL_126_11);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_126_13);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_126_15);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_geometry_string_15)
DEFLABEL (x_geometry_string_10)
  INTERRUPT_CHECK (26, LABEL_126_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd10.Obj) = (Rsp [4]);
  if ((Wrd10.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_10]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_126_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_126_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_126_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_14]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_126_6);
  (Wrd17.Obj) = Rvl;

DEFLABEL (label_28)
  (Rsp [2]) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd23.Obj) = (Rsp [2]);
  if ((Wrd23.Obj) == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_9]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_126_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_26;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd19.Lng) < 0)
    goto label_17;

DEFLABEL (label_18)
  (Wrd12.Obj) = (current_block [OBJECT_126_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_16;

DEFLABEL (label_17)
  (Wrd17.Obj) = (current_block [OBJECT_126_0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_16)
DEFLABEL (label_25)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_126_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_24;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd15.Lng) < 0)
    goto label_20;

DEFLABEL (label_21)
  (Wrd12.Obj) = (current_block [OBJECT_126_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_19;

DEFLABEL (label_20)
  (Wrd13.Obj) = (current_block [OBJECT_126_0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_19)
DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_126_5);
  (Wrd30.Obj) = Rvl;

DEFLABEL (label_22)
  (Rsp [3]) = (Wrd30.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_7]));

DEFLABEL (label_24)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_20;

DEFLABEL (label_26)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  goto label_17;

DEFLABEL (label_27)
  (Wrd30.Obj) = (current_block [OBJECT_126_0]);
  Rsp = (& (Rsp [1]));
  goto label_22;

DEFLABEL (label_29)
  (Wrd17.Obj) = (current_block [OBJECT_126_0]);
  Rsp = (& (Rsp [1]));
  goto label_28;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_127_4 3
#define LABEL_127_6 5
#define LABEL_127_5 7
#define LABEL_127_9 9
#define TAG_127_10 3
#define LABEL_127_14 11
#define LABEL_127_15 13
#define LABEL_127_11 15
#define LABEL_127_13 17
#define LABEL_127_16 19
#define LABEL_127_17 21
#define LABEL_127_20 23
#define LABEL_127_22 25
#define LABEL_127_19 27
#define ENVIRONMENT_LABEL_127_3 52
#define DEBUGGING_LABEL_127_2 51
#define OBJECT_127_7 50
#define OBJECT_127_6 49
#define OBJECT_127_5 48
#define OBJECT_127_4 47
#define OBJECT_127_3 46
#define OBJECT_127_2 45
#define OBJECT_127_1 44
#define OBJECT_127_0 43
#define EXECUTE_CACHE_127_23 29
#define EXECUTE_CACHE_127_21 31
#define EXECUTE_CACHE_127_18 33
#define EXECUTE_CACHE_127_12 35
#define EXECUTE_CACHE_127_8 37
#define EXECUTE_CACHE_127_7 39
#define FREE_REFERENCE_127_0 42
#define FREE_REFERENCES_LABEL_127_0 28
#define NUMBER_OF_LINKER_SECTIONS_127_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_127 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd28;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd48;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd24;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_127_4);
      goto x_graphics_open_22;

    case 1:
      current_block = (Rpc - LABEL_127_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_127_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_127_9);
      goto lambda_29;

    case 4:
      current_block = (Rpc - LABEL_127_14);
      goto label_25;

    case 5:
      current_block = (Rpc - LABEL_127_15);
      goto label_24;

    case 6:
      current_block = (Rpc - LABEL_127_11);
      goto continuation_20;

    case 7:
      current_block = (Rpc - LABEL_127_13);
      goto continuation_9;

    case 8:
      current_block = (Rpc - LABEL_127_16);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_127_17);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_127_20);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_127_22);
      goto continuation_14;

    case 12:
      current_block = (Rpc - LABEL_127_19);
      goto continuation_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_open_28)
DEFLABEL (x_graphics_open_22)
  INTERRUPT_CHECK (26, LABEL_127_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  if ((Wrd8.Obj) == (current_block [OBJECT_127_0]))
    goto label_31;
  (* (--Rsp)) = (Wrd8.Obj);
  goto label_30;

DEFLABEL (label_31)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_30)
DEFLABEL (label_37)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_127_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_32;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_8]));

DEFLABEL (label_32)
  (Wrd24.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_36)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_127_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_127_9])));
  Rhp += 3;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [3]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [4]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_127_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [7]);
  if ((Wrd17.Obj) == (current_block [OBJECT_127_0]))
    goto label_34;
  (* (--Rsp)) = (Wrd17.Obj);
  goto label_33;

DEFLABEL (label_34)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_33)
DEFLABEL (label_35)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_12]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_127_11);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_127_5);
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_127_9);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd9.pObj) = (& (Rhp [-4]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  if ((Wrd19.Obj) == (current_block [OBJECT_127_0]))
    goto label_45;
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_44)
  (Wrd37.Obj) = (Rsp [3]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [4]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_43;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd36.Lng))))
    goto label_43;
  (Wrd28.Obj) = ((Wrd34.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_42)
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_4]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_127_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_127_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_6]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_127_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_18]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_127_17);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_19]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd23.Obj) = (Rsp [3]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 62))
    goto label_41;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_41;
  (Wrd14.Obj) = ((Wrd20.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_40)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_21]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_127_19);
  (Wrd5.Obj) = (Rsp [2]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_39;

DEFLABEL (label_38)
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [3]) = (Wrd11.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd14.Obj);
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_39)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_23]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_127_22);
  goto label_38;

DEFLABEL (label_41)
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [4]);
  (Wrd30.Obj) = (current_block [OBJECT_127_7]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_20]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_3]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [4]);
  (Wrd44.Obj) = (current_block [OBJECT_127_2]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_15]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_3]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd49.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_127_0]));
  (Wrd52.Obj) = ((Wrd49.pObj) [0]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if ((Wrd53.uLng) == 50)
    goto label_47;
  Wrd48 = Wrd52;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd48.Obj);
  goto label_44;

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_127_14])), (Wrd49.pObj));

DEFLABEL (label_25)
  (Wrd48.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_128_4 3
#define LABEL_128_5 5
#define LABEL_128_6 7
#define LABEL_128_8 9
#define LABEL_128_7 11
#define LABEL_128_10 13
#define LABEL_128_11 15
#define LABEL_128_12 17
#define TAG_128_13 7
#define LABEL_128_15 19
#define LABEL_128_16 21
#define ENVIRONMENT_LABEL_128_3 38
#define DEBUGGING_LABEL_128_2 37
#define OBJECT_128_7 36
#define OBJECT_128_6 35
#define OBJECT_128_5 34
#define OBJECT_128_4 33
#define OBJECT_128_3 32
#define OBJECT_128_2 31
#define OBJECT_128_1 30
#define OBJECT_128_0 29
#define EXECUTE_CACHE_128_17 23
#define EXECUTE_CACHE_128_14 25
#define EXECUTE_CACHE_128_9 27
#define FREE_REFERENCES_LABEL_128_0 22
#define NUMBER_OF_LINKER_SECTIONS_128_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_128 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd5;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_128_4);
      goto map_window_15;

    case 1:
      current_block = (Rpc - LABEL_128_5);
      goto label_17;

    case 2:
      current_block = (Rpc - LABEL_128_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_128_8);
      goto label_18;

    case 4:
      current_block = (Rpc - LABEL_128_7);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_128_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_128_11);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_128_12);
      goto lambda_23;

    case 8:
      current_block = (Rpc - LABEL_128_15);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_128_16);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (map_window_22)
DEFLABEL (map_window_15)
  INTERRUPT_CHECK (26, LABEL_128_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_30;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_30;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_29)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_2]), 1);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_128_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_28;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_28;
  (Wrd10.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_128_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  Rvl = (current_block [OBJECT_128_5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_4]), 1);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_128_10);
  Rsp = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_26;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_26;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_25)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_128_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_128_12])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  (Wrd31.Obj) = (Rsp [0]);
  ((Wrd34.pObj) [4]) = (Wrd31.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  ((Wrd38.pObj) [0]) = (Wrd28.Obj);
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Rsp [1]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_14]));

DEFLABEL (label_26)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_128_6]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_128_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_1]), 2);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_128_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_1]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_128_12);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_33;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_33;
  (Wrd5.Obj) = ((Wrd15.pObj) [4]);

DEFLABEL (label_32)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_128_7])))
    goto label_31;
  Rvl = (current_block [OBJECT_128_5]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_16]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [4]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_17]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_128_16);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_33)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [2]);
  (Wrd25.Obj) = (current_block [OBJECT_128_3]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_15]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_1]), 2);

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_32;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_129_4 3
#define LABEL_129_5 5
#define LABEL_129_7 7
#define LABEL_129_8 9
#define LABEL_129_9 11
#define LABEL_129_10 13
#define LABEL_129_13 15
#define LABEL_129_15 17
#define LABEL_129_17 19
#define TAG_129_18 8
#define LABEL_129_14 21
#define LABEL_129_19 23
#define LABEL_129_20 25
#define LABEL_129_21 27
#define LABEL_129_22 29
#define LABEL_129_23 31
#define LABEL_129_11 33
#define TAG_129_12 15
#define LABEL_129_24 35
#define TAG_129_25 16
#define ENVIRONMENT_LABEL_129_3 54
#define DEBUGGING_LABEL_129_2 53
#define OBJECT_129_11 52
#define OBJECT_129_10 51
#define OBJECT_129_9 50
#define OBJECT_129_8 49
#define OBJECT_129_7 48
#define OBJECT_129_6 47
#define OBJECT_129_5 46
#define OBJECT_129_4 45
#define OBJECT_129_3 44
#define OBJECT_129_2 43
#define OBJECT_129_1 42
#define OBJECT_129_0 41
#define EXECUTE_CACHE_129_16 37
#define EXECUTE_CACHE_129_6 39
#define FREE_REFERENCES_LABEL_129_0 36
#define NUMBER_OF_LINKER_SECTIONS_129_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_129 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd97;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd89;
  machine_word Wrd85;
  machine_word Wrd76;
  machine_word Wrd72;
  machine_word Wrd61;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd60;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd36;
  machine_word Wrd23;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd41;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd94;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd83;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_129_4);
      goto decode_suppress_map_arg_27;

    case 1:
      current_block = (Rpc - LABEL_129_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_129_7);
      goto label_31;

    case 3:
      current_block = (Rpc - LABEL_129_8);
      goto label_32;

    case 4:
      current_block = (Rpc - LABEL_129_9);
      goto label_33;

    case 5:
      current_block = (Rpc - LABEL_129_10);
      goto label_34;

    case 6:
      current_block = (Rpc - LABEL_129_13);
      goto label_29;

    case 7:
      current_block = (Rpc - LABEL_129_15);
      goto label_30;

    case 8:
      current_block = (Rpc - LABEL_129_17);
      goto lambda_43;

    case 9:
      current_block = (Rpc - LABEL_129_14);
      goto continuation_10;

    case 10:
      current_block = (Rpc - LABEL_129_19);
      goto label_35;

    case 11:
      current_block = (Rpc - LABEL_129_20);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_129_21);
      goto label_37;

    case 13:
      current_block = (Rpc - LABEL_129_22);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_129_23);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_129_11);
      goto lambda_42;

    case 16:
      current_block = (Rpc - LABEL_129_24);
      goto lambda_44;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decode_suppress_map_arg_41)
DEFLABEL (decode_suppress_map_arg_27)
  INTERRUPT_CHECK (26, LABEL_129_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_129_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_46;
  (Wrd9.Obj) = ((SCHEME_OBJECT) 0);
  goto label_45;

DEFLABEL (label_46)
  (Wrd9.Obj) = (current_block [OBJECT_129_7]);

DEFLABEL (label_45)
DEFLABEL (label_47)
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_129_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_129_17])));
  Rhp += 1;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd13 = Wrd12;
  (Wrd14.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  Rvl = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_48)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 1)
    goto label_69;

DEFLABEL (label_68)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_50;
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_49)
  (Wrd35.Obj) = (current_block [OBJECT_129_6]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_16]));

DEFLABEL (label_50)
  if (! ((Wrd19.uLng) == 10))
    goto label_67;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd22.Obj) = (MAKE_OBJECT (26, (Wrd26.uLng)));

DEFLABEL (label_66)
  if ((Wrd22.Obj) == (current_block [OBJECT_129_3]))
    goto label_51;
  (Wrd34.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_49;

DEFLABEL (label_51)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_14]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd48.Obj) = (Rsp [1]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_65;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd47.Lng))))
    goto label_65;
  (Wrd41.Obj) = ((Wrd45.pObj) [1]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_64)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_6]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_129_14);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_53;

DEFLABEL (label_52)
  (Wrd102.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd102.Obj);
  (Wrd103.Obj) = (current_block [OBJECT_129_6]);
  (Rsp [1]) = (Wrd103.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_16]));

DEFLABEL (label_53)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_63;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_63;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_62)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd23.uLng) == 30))
    goto label_52;
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_61;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_61;
  (Wrd26.Obj) = ((Wrd32.pObj) [3]);

DEFLABEL (label_60)
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd42.uLng) == 30))
    goto label_52;
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_59;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd53.Lng))))
    goto label_59;
  (Wrd47.Obj) = ((Wrd51.pObj) [1]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_58)
  (Wrd70.Obj) = (Rsp [1]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 10))
    goto label_57;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd69.Lng))))
    goto label_57;
  (Wrd61.Obj) = ((Wrd67.pObj) [3]);

DEFLABEL (label_56)
  (Rsp [2]) = (Wrd61.Obj);
  (Wrd86.Obj) = (Rsp [1]);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if (! ((Wrd87.uLng) == 10))
    goto label_55;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd84.Obj) = ((Wrd83.pObj) [0]);
  (Wrd85.Lng) = (FIXNUM_TO_LONG (Wrd84.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd85.Lng))))
    goto label_55;
  (Wrd77.Obj) = ((Wrd83.pObj) [2]);

DEFLABEL (label_54)
  (Rsp [1]) = (Wrd77.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd95.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_129_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_129_24])));
  Rhp += 3;
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd95.pObj)));
  Wrd100 = Wrd95;
  (Wrd101.Obj) = (Rsp [2]);
  ((Wrd100.pObj) [2]) = (Wrd101.Obj);
  ((Wrd100.pObj) [3]) = (Wrd77.Obj);
  (Wrd97.Obj) = (Rsp [0]);
  ((Wrd100.pObj) [4]) = (Wrd97.Obj);
  Rvl = (Wrd94.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_55)
  (Wrd88.Obj) = (Rsp [1]);
  (Wrd89.Obj) = (current_block [OBJECT_129_10]);
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_23]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_39)
  (Wrd77.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd72.Obj) = (Rsp [1]);
  (Wrd73.Obj) = (current_block [OBJECT_129_11]);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_22]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_38)
  (Wrd61.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Obj) = (current_block [OBJECT_129_4]);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_21]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (current_block [OBJECT_129_11]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_20]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_36)
  (Wrd26.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_129_10]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_19]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_35)
  (Wrd7.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd50.Obj) = (Rsp [1]);
  (Wrd51.Obj) = (current_block [OBJECT_129_4]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_15]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_5]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_13]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_2]), 1);

DEFLABEL (label_29)
  (Wrd22.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  if (! ((Wrd17.uLng) == 1))
    goto label_77;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [0]);

DEFLABEL (label_76)
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd64.uLng) == 30))
    goto label_68;
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_75;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd65.Obj) = ((Wrd67.pObj) [1]);

DEFLABEL (label_74)
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd74.uLng) == 30))
    goto label_68;
  (Wrd78.Obj) = (Rsp [0]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 1))
    goto label_73;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = ((Wrd77.pObj) [1]);

DEFLABEL (label_72)
  (Rsp [1]) = (Wrd75.Obj);
  (Wrd87.Obj) = (Rsp [0]);
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd87.Obj));
  if (! ((Wrd88.uLng) == 1))
    goto label_71;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
  (Wrd84.Obj) = ((Wrd86.pObj) [0]);

DEFLABEL (label_70)
  (Rsp [0]) = (Wrd84.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd95.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_129_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_129_11])));
  Rhp += 2;
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd95.pObj)));
  Wrd98 = Wrd95;
  (Wrd99.Obj) = (Rsp [1]);
  ((Wrd98.pObj) [2]) = (Wrd99.Obj);
  ((Wrd98.pObj) [3]) = (Wrd84.Obj);
  Rvl = (Wrd94.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_71)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_10]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_0]), 1);

DEFLABEL (label_34)
  (Wrd84.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_9]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_1]), 1);

DEFLABEL (label_33)
  (Wrd75.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_8]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_1]), 1);

DEFLABEL (label_32)
  (Wrd65.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_7]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_0]), 1);

DEFLABEL (label_31)
  (Wrd55.Obj) = Rvl;
  goto label_76;

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_129_17);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_129_8]);
  (Rsp [2]) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_129_9]);
  (Rsp [3]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_42)
  CLOSURE_HEADER (LABEL_129_11);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Rsp [2]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_129_24);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_130_4 3
#define LABEL_130_5 5
#define LABEL_130_6 7
#define ENVIRONMENT_LABEL_130_3 13
#define DEBUGGING_LABEL_130_2 12
#define OBJECT_130_3 11
#define OBJECT_130_2 10
#define OBJECT_130_1 9
#define OBJECT_130_0 8
#define FREE_REFERENCES_LABEL_130_0 8
#define NUMBER_OF_LINKER_SECTIONS_130_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_130 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_130_4);
      goto x_graphics_clear_2;

    case 1:
      current_block = (Rpc - LABEL_130_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_130_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_clear_7)
DEFLABEL (x_graphics_clear_2)
  INTERRUPT_CHECK (26, LABEL_130_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_130_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_130_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_130_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_130_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_130_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_131_4 3
#define LABEL_131_6 5
#define LABEL_131_7 7
#define LABEL_131_5 9
#define LABEL_131_8 11
#define LABEL_131_9 13
#define LABEL_131_10 15
#define LABEL_131_11 17
#define LABEL_131_12 19
#define TAG_131_13 8
#define ENVIRONMENT_LABEL_131_3 28
#define DEBUGGING_LABEL_131_2 27
#define OBJECT_131_6 26
#define OBJECT_131_5 25
#define OBJECT_131_4 24
#define OBJECT_131_3 23
#define OBJECT_131_2 22
#define OBJECT_131_1 21
#define OBJECT_131_0 20
#define FREE_REFERENCES_LABEL_131_0 20
#define NUMBER_OF_LINKER_SECTIONS_131_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_131 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd78;
  machine_word Wrd79;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_131_4);
      goto x_graphics_coordinate_limits_10;

    case 1:
      current_block = (Rpc - LABEL_131_6);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_131_7);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_131_5);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_131_8);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_131_9);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_131_10);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_131_11);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_131_12);
      goto lambda_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_coordinate_limits_19)
DEFLABEL (x_graphics_coordinate_limits_10)
  INTERRUPT_CHECK (26, LABEL_131_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_32;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_32;
  (Wrd8.Obj) = ((Wrd14.pObj) [3]);

DEFLABEL (label_31)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_30;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_30;
  (Wrd25.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_29)
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_3]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_131_5);
  (Rsp [0]) = Rvl;
  (Wrd16.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd16.uLng) == 10))
    goto label_28;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd14.Lng))))
    goto label_28;
  (Wrd8.Obj) = ((Wrd12.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_27)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_26;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_26;
  (Wrd24.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_25)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_24;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd46.Lng))))
    goto label_24;
  (Wrd40.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_23)
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_22;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd62.Lng))))
    goto label_22;
  (Wrd54.Obj) = ((Wrd60.pObj) [4]);

DEFLABEL (label_21)
  (Rsp [3]) = (Wrd54.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd72.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_131_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_131_12])));
  Rhp += 4;
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd72.pObj)));
  Wrd79 = Wrd72;
  ((Wrd79.pObj) [2]) = (Wrd54.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  ((Wrd79.pObj) [3]) = (Wrd78.Obj);
  (Wrd76.Obj) = (Rsp [1]);
  ((Wrd79.pObj) [4]) = (Wrd76.Obj);
  (Wrd74.Obj) = (Rsp [0]);
  ((Wrd79.pObj) [5]) = (Wrd74.Obj);
  Rvl = (Wrd71.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd65.Obj) = (Rsp [3]);
  (Wrd66.Obj) = (current_block [OBJECT_131_6]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_11]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_4]), 2);

DEFLABEL (label_17)
  (Wrd54.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (current_block [OBJECT_131_5]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_10]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_4]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (current_block [OBJECT_131_2]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_9]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_4]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_131_0]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_8]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_4]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd33.Obj) = (current_block [OBJECT_131_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_1]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_131_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_1]), 2);

DEFLABEL (label_12)
  (Wrd8.Obj) = Rvl;
  goto label_31;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_131_12);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [4]) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [3]) = (Wrd15.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_132_4 3
#define LABEL_132_5 5
#define LABEL_132_6 7
#define LABEL_132_7 9
#define LABEL_132_8 11
#define LABEL_132_9 13
#define LABEL_132_10 15
#define LABEL_132_11 17
#define TAG_132_12 7
#define ENVIRONMENT_LABEL_132_3 25
#define DEBUGGING_LABEL_132_2 24
#define OBJECT_132_5 23
#define OBJECT_132_4 22
#define OBJECT_132_3 21
#define OBJECT_132_2 20
#define OBJECT_132_1 19
#define OBJECT_132_0 18
#define FREE_REFERENCES_LABEL_132_0 18
#define NUMBER_OF_LINKER_SECTIONS_132_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_132 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_132_4);
      goto x_graphics_device_coordinate_limits_9;

    case 1:
      current_block = (Rpc - LABEL_132_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_132_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_132_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_132_8);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_132_9);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_132_10);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_132_11);
      goto lambda_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_device_coordinate_limits_16)
DEFLABEL (x_graphics_device_coordinate_limits_9)
  INTERRUPT_CHECK (26, LABEL_132_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_25;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_25;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_24)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_23;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_23;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_3]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_132_7);
  (Wrd5.Obj) = Rvl;
  (Wrd10.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd10.uLng) == 26))
    goto label_21;
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd11.Lng) = ((Wrd12.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd11.Lng)))
    goto label_21;
  (Wrd13.Obj) = (LONG_TO_FIXNUM (Wrd11.Lng));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_20)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_4]), 1);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_132_9);
  (Wrd5.Obj) = Rvl;
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 26))
    goto label_19;
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd12.Lng) = ((Wrd13.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_19;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_18)
  (Rsp [1]) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_132_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_132_11])));
  Rhp += 2;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd19 = Wrd16;
  ((Wrd19.pObj) [2]) = (Wrd10.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  ((Wrd19.pObj) [3]) = (Wrd18.Obj);
  Rvl = (Wrd15.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_14)
  (Wrd10.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd30.Obj) = (current_block [OBJECT_132_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_1]), 2);

DEFLABEL (label_12)
  (Wrd21.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_132_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_1]), 2);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_24;

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_132_11);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_132_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd10.Obj);
  (Rsp [4]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_133_4 3
#define LABEL_133_5 5
#define LABEL_133_6 7
#define LABEL_133_7 9
#define LABEL_133_9 11
#define ENVIRONMENT_LABEL_133_3 20
#define DEBUGGING_LABEL_133_2 19
#define OBJECT_133_3 18
#define OBJECT_133_2 17
#define OBJECT_133_1 16
#define OBJECT_133_0 15
#define EXECUTE_CACHE_133_8 13
#define FREE_REFERENCES_LABEL_133_0 12
#define NUMBER_OF_LINKER_SECTIONS_133_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_133 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_133_4);
      goto x_graphics_drag_cursor_4;

    case 1:
      current_block = (Rpc - LABEL_133_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_133_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_133_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_133_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_drag_cursor_9)
DEFLABEL (x_graphics_drag_cursor_4)
  INTERRUPT_CHECK (26, LABEL_133_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_133_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_133_9);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_3]), 3);

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_133_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_133_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_134_4 3
#define LABEL_134_5 5
#define LABEL_134_6 7
#define LABEL_134_7 9
#define LABEL_134_9 11
#define LABEL_134_10 13
#define LABEL_134_11 15
#define ENVIRONMENT_LABEL_134_3 24
#define DEBUGGING_LABEL_134_2 23
#define OBJECT_134_3 22
#define OBJECT_134_2 21
#define OBJECT_134_1 20
#define OBJECT_134_0 19
#define EXECUTE_CACHE_134_8 17
#define FREE_REFERENCES_LABEL_134_0 16
#define NUMBER_OF_LINKER_SECTIONS_134_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_134 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_134_4);
      goto x_graphics_draw_line_6;

    case 1:
      current_block = (Rpc - LABEL_134_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_134_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_134_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_134_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_134_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_134_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_line_11)
DEFLABEL (x_graphics_draw_line_6)
  INTERRUPT_CHECK (26, LABEL_134_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_134_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_134_9);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_134_10);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_134_11);
  (Rsp [4]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_3]), 5);

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_134_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_1]), 2);

DEFLABEL (label_9)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_134_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_1]), 2);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_135_4 3
#define LABEL_135_5 5
#define LABEL_135_6 7
#define ENVIRONMENT_LABEL_135_3 13
#define DEBUGGING_LABEL_135_2 12
#define OBJECT_135_3 11
#define OBJECT_135_2 10
#define OBJECT_135_1 9
#define OBJECT_135_0 8
#define FREE_REFERENCES_LABEL_135_0 8
#define NUMBER_OF_LINKER_SECTIONS_135_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_135 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_135_4);
      goto x_graphics_draw_lines_2;

    case 1:
      current_block = (Rpc - LABEL_135_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_135_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_lines_7)
DEFLABEL (x_graphics_draw_lines_2)
  INTERRUPT_CHECK (26, LABEL_135_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_3]), 3);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_135_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_135_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_136_4 3
#define LABEL_136_5 5
#define LABEL_136_6 7
#define LABEL_136_7 9
#define LABEL_136_9 11
#define ENVIRONMENT_LABEL_136_3 20
#define DEBUGGING_LABEL_136_2 19
#define OBJECT_136_3 18
#define OBJECT_136_2 17
#define OBJECT_136_1 16
#define OBJECT_136_0 15
#define EXECUTE_CACHE_136_8 13
#define FREE_REFERENCES_LABEL_136_0 12
#define NUMBER_OF_LINKER_SECTIONS_136_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_136 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_136_4);
      goto x_graphics_draw_point_4;

    case 1:
      current_block = (Rpc - LABEL_136_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_136_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_136_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_136_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_point_9)
DEFLABEL (x_graphics_draw_point_4)
  INTERRUPT_CHECK (26, LABEL_136_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_136_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_136_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_136_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_136_9);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_136_3]), 3);

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_136_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_136_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_136_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_136_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_137_4 3
#define LABEL_137_5 5
#define LABEL_137_6 7
#define ENVIRONMENT_LABEL_137_3 13
#define DEBUGGING_LABEL_137_2 12
#define OBJECT_137_3 11
#define OBJECT_137_2 10
#define OBJECT_137_1 9
#define OBJECT_137_0 8
#define FREE_REFERENCES_LABEL_137_0 8
#define NUMBER_OF_LINKER_SECTIONS_137_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_137 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_137_4);
      goto x_graphics_draw_points_2;

    case 1:
      current_block = (Rpc - LABEL_137_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_137_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_points_7)
DEFLABEL (x_graphics_draw_points_2)
  INTERRUPT_CHECK (26, LABEL_137_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_137_3]), 3);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_137_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_137_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_137_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_137_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_138_4 3
#define LABEL_138_5 5
#define LABEL_138_6 7
#define LABEL_138_7 9
#define LABEL_138_9 11
#define ENVIRONMENT_LABEL_138_3 20
#define DEBUGGING_LABEL_138_2 19
#define OBJECT_138_3 18
#define OBJECT_138_2 17
#define OBJECT_138_1 16
#define OBJECT_138_0 15
#define EXECUTE_CACHE_138_8 13
#define FREE_REFERENCES_LABEL_138_0 12
#define NUMBER_OF_LINKER_SECTIONS_138_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_138 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_138_4);
      goto x_graphics_draw_text_4;

    case 1:
      current_block = (Rpc - LABEL_138_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_138_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_138_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_138_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_text_9)
DEFLABEL (x_graphics_draw_text_4)
  INTERRUPT_CHECK (26, LABEL_138_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_138_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_138_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_138_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_138_9);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_3]), 4);

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_138_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_138_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_139_4 3
#define LABEL_139_5 5
#define LABEL_139_6 7
#define LABEL_139_7 9
#define LABEL_139_9 11
#define ENVIRONMENT_LABEL_139_3 20
#define DEBUGGING_LABEL_139_2 19
#define OBJECT_139_3 18
#define OBJECT_139_2 17
#define OBJECT_139_1 16
#define OBJECT_139_0 15
#define EXECUTE_CACHE_139_8 13
#define FREE_REFERENCES_LABEL_139_0 12
#define NUMBER_OF_LINKER_SECTIONS_139_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_139 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_139_4);
      goto x_graphics_draw_text_opaque_4;

    case 1:
      current_block = (Rpc - LABEL_139_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_139_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_139_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_139_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_text_opaque_9)
DEFLABEL (x_graphics_draw_text_opaque_4)
  INTERRUPT_CHECK (26, LABEL_139_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_139_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_139_9);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_139_3]), 4);

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_139_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_139_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_139_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_139_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_140_5 3
#define LABEL_140_4 5
#define LABEL_140_6 7
#define LABEL_140_7 9
#define LABEL_140_8 11
#define LABEL_140_9 13
#define LABEL_140_10 15
#define LABEL_140_12 17
#define LABEL_140_13 19
#define LABEL_140_14 21
#define ENVIRONMENT_LABEL_140_3 35
#define DEBUGGING_LABEL_140_2 34
#define OBJECT_140_6 33
#define OBJECT_140_5 32
#define OBJECT_140_4 31
#define OBJECT_140_3 30
#define OBJECT_140_2 29
#define OBJECT_140_1 28
#define OBJECT_140_0 27
#define EXECUTE_CACHE_140_11 23
#define FREE_REFERENCE_140_0 26
#define FREE_REFERENCES_LABEL_140_0 22
#define NUMBER_OF_LINKER_SECTIONS_140_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_140 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd71;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd78;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd58;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd65;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd112;
  machine_word Wrd109;
  machine_word Wrd100;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd107;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd84;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd28;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_140_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_140_4);
      goto x_graphics_flush_10;

    case 2:
      current_block = (Rpc - LABEL_140_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_140_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_140_8);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_140_9);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_140_10);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_140_12);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_140_13);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_140_14);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_flush_21)
DEFLABEL (x_graphics_flush_10)
  INTERRUPT_CHECK (26, LABEL_140_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_140_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_39;
  Wrd5 = Wrd9;

DEFLABEL (label_38)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_28;
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 62))
    goto label_37;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_37;
  (Wrd12.Obj) = ((Wrd18.pObj) [3]);

DEFLABEL (label_36)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd35.uLng) == 62))
    goto label_35;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd34.Lng))))
    goto label_35;
  (Wrd28.Obj) = ((Wrd32.pObj) [4]);

DEFLABEL (label_34)
  if ((Wrd28.Obj) == (current_block [OBJECT_140_3]))
    goto label_29;

DEFLABEL (label_28)
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 62))
    goto label_27;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd50.Lng))))
    goto label_27;
  (Wrd42.Obj) = ((Wrd48.pObj) [3]);

DEFLABEL (label_26)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd65.uLng) == 62))
    goto label_25;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd64.Lng))))
    goto label_25;
  (Wrd58.Obj) = ((Wrd62.pObj) [3]);

DEFLABEL (label_24)
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd78.uLng) == 62))
    goto label_23;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd77.Lng))))
    goto label_23;
  (Wrd71.Obj) = ((Wrd75.pObj) [3]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd71.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_6]), 1);

DEFLABEL (label_23)
  (Wrd80.Obj) = (current_block [OBJECT_140_0]);
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_14]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_17)
  (Wrd71.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd67.Obj) = (current_block [OBJECT_140_0]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_13]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_16)
  (Wrd58.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.Obj) = (current_block [OBJECT_140_0]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_12]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_15)
  (Wrd42.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 62))
    goto label_33;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [0]);
  (Wrd92.Lng) = (FIXNUM_TO_LONG (Wrd91.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd92.Lng))))
    goto label_33;
  (Wrd84.Obj) = ((Wrd90.pObj) [3]);

DEFLABEL (label_32)
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd84.Obj));
  if (! ((Wrd107.uLng) == 62))
    goto label_31;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [0]);
  (Wrd106.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd106.Lng))))
    goto label_31;
  (Wrd100.Obj) = ((Wrd104.pObj) [5]);

DEFLABEL (label_30)
  if ((Wrd100.Obj) == (current_block [OBJECT_140_5]))
    goto label_28;
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_5]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (Wrd117.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd117.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_140_5);
  goto label_28;

DEFLABEL (label_31)
  (Wrd109.Obj) = (current_block [OBJECT_140_4]);
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_10]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_19)
  (Wrd100.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd95.Obj) = (Rsp [0]);
  (Wrd96.Obj) = (current_block [OBJECT_140_0]);
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_9]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_18)
  (Wrd84.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd37.Obj) = (current_block [OBJECT_140_2]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_8]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_14)
  (Wrd28.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.Obj) = (current_block [OBJECT_140_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_7]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 2);

DEFLABEL (label_13)
  (Wrd12.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_140_6])), (Wrd6.pObj));

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_38;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_141_4 3
#define LABEL_141_5 5
#define LABEL_141_6 7
#define LABEL_141_7 9
#define LABEL_141_9 11
#define ENVIRONMENT_LABEL_141_3 20
#define DEBUGGING_LABEL_141_2 19
#define OBJECT_141_3 18
#define OBJECT_141_2 17
#define OBJECT_141_1 16
#define OBJECT_141_0 15
#define EXECUTE_CACHE_141_8 13
#define FREE_REFERENCES_LABEL_141_0 12
#define NUMBER_OF_LINKER_SECTIONS_141_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_141 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_141_4);
      goto x_graphics_move_cursor_4;

    case 1:
      current_block = (Rpc - LABEL_141_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_141_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_141_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_141_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_move_cursor_9)
DEFLABEL (x_graphics_move_cursor_4)
  INTERRUPT_CHECK (26, LABEL_141_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_12)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_11;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_141_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_141_9);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_141_3]), 3);

DEFLABEL (label_11)
  (Wrd30.Obj) = (current_block [OBJECT_141_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_141_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_141_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_141_1]), 2);

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_142_4 3
#define LABEL_142_5 5
#define LABEL_142_6 7
#define ENVIRONMENT_LABEL_142_3 13
#define DEBUGGING_LABEL_142_2 12
#define OBJECT_142_3 11
#define OBJECT_142_2 10
#define OBJECT_142_1 9
#define OBJECT_142_0 8
#define FREE_REFERENCES_LABEL_142_0 8
#define NUMBER_OF_LINKER_SECTIONS_142_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_142 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_142_4);
      goto x_graphics_reset_clip_rectangle_2;

    case 1:
      current_block = (Rpc - LABEL_142_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_142_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_reset_clip_rectangle_7)
DEFLABEL (x_graphics_reset_clip_rectangle_2)
  INTERRUPT_CHECK (26, LABEL_142_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_142_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_142_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_143_4 3
#define LABEL_143_5 5
#define LABEL_143_6 7
#define LABEL_143_7 9
#define LABEL_143_9 11
#define LABEL_143_10 13
#define LABEL_143_11 15
#define ENVIRONMENT_LABEL_143_3 24
#define DEBUGGING_LABEL_143_2 23
#define OBJECT_143_3 22
#define OBJECT_143_2 21
#define OBJECT_143_1 20
#define OBJECT_143_0 19
#define EXECUTE_CACHE_143_8 17
#define FREE_REFERENCES_LABEL_143_0 16
#define NUMBER_OF_LINKER_SECTIONS_143_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_143 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_143_4);
      goto x_graphics_set_clip_rectangle_6;

    case 1:
      current_block = (Rpc - LABEL_143_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_143_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_143_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_143_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_143_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_143_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_clip_rectangle_11)
DEFLABEL (x_graphics_set_clip_rectangle_6)
  INTERRUPT_CHECK (26, LABEL_143_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_143_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_143_9);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_143_10);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_143_11);
  (Rsp [4]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_3]), 5);

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_143_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_1]), 2);

DEFLABEL (label_9)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_143_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_1]), 2);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_144_4 3
#define LABEL_144_5 5
#define LABEL_144_6 7
#define LABEL_144_7 9
#define LABEL_144_9 11
#define LABEL_144_10 13
#define LABEL_144_11 15
#define ENVIRONMENT_LABEL_144_3 24
#define DEBUGGING_LABEL_144_2 23
#define OBJECT_144_3 22
#define OBJECT_144_2 21
#define OBJECT_144_1 20
#define OBJECT_144_0 19
#define EXECUTE_CACHE_144_8 17
#define FREE_REFERENCES_LABEL_144_0 16
#define NUMBER_OF_LINKER_SECTIONS_144_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_144 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_144_4);
      goto x_graphics_set_coordinate_limits_6;

    case 1:
      current_block = (Rpc - LABEL_144_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_144_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_144_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_144_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_144_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_144_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_coordinate_limits_11)
DEFLABEL (x_graphics_set_coordinate_limits_6)
  INTERRUPT_CHECK (26, LABEL_144_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_144_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_144_9);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_144_10);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_144_11);
  (Rsp [4]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_144_3]), 5);

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_144_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_144_1]), 2);

DEFLABEL (label_9)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_144_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_144_1]), 2);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_145_4 3
#define LABEL_145_5 5
#define LABEL_145_6 7
#define ENVIRONMENT_LABEL_145_3 13
#define DEBUGGING_LABEL_145_2 12
#define OBJECT_145_3 11
#define OBJECT_145_2 10
#define OBJECT_145_1 9
#define OBJECT_145_0 8
#define FREE_REFERENCES_LABEL_145_0 8
#define NUMBER_OF_LINKER_SECTIONS_145_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_145 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_145_4);
      goto x_graphics_set_drawing_mode_2;

    case 1:
      current_block = (Rpc - LABEL_145_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_145_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_drawing_mode_7)
DEFLABEL (x_graphics_set_drawing_mode_2)
  INTERRUPT_CHECK (26, LABEL_145_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_145_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_145_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_146_4 3
#define LABEL_146_7 5
#define LABEL_146_5 7
#define LABEL_146_8 9
#define LABEL_146_10 11
#define LABEL_146_11 13
#define LABEL_146_12 15
#define LABEL_146_13 17
#define LABEL_146_14 19
#define LABEL_146_15 21
#define ENVIRONMENT_LABEL_146_3 39
#define DEBUGGING_LABEL_146_2 38
#define OBJECT_146_10 37
#define OBJECT_146_9 36
#define OBJECT_146_8 35
#define OBJECT_146_7 34
#define OBJECT_146_6 33
#define OBJECT_146_5 32
#define OBJECT_146_4 31
#define OBJECT_146_3 30
#define OBJECT_146_2 29
#define OBJECT_146_1 28
#define OBJECT_146_0 27
#define EXECUTE_CACHE_146_9 23
#define EXECUTE_CACHE_146_6 25
#define FREE_REFERENCES_LABEL_146_0 22
#define NUMBER_OF_LINKER_SECTIONS_146_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_146 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd64;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd19;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_146_4);
      goto x_graphics_set_line_style_10;

    case 1:
      current_block = (Rpc - LABEL_146_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_146_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_146_8);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_146_10);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_146_11);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_146_12);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_146_13);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_146_14);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_146_15);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_line_style_19)
DEFLABEL (x_graphics_set_line_style_10)
  INTERRUPT_CHECK (26, LABEL_146_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_146_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_146_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_33;

DEFLABEL (label_32)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_7]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (current_block [OBJECT_146_1]);
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd75.Obj) = (current_block [OBJECT_146_2]);
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_146_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_146_7);

DEFLABEL (label_31)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 62))
    goto label_30;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_30;
  (Wrd19.Obj) = ((Wrd25.pObj) [3]);

DEFLABEL (label_29)
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd42.uLng) == 62))
    goto label_28;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd41.Lng))))
    goto label_28;
  (Wrd36.Obj) = ((Wrd39.pObj) [2]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_27)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 26))
    goto label_26;
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! ((Wrd64.Lng) == 0))
    goto label_21;

DEFLABEL (label_20)
  (Wrd60.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd60.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_146_7]);
  (Rsp [2]) = (Wrd61.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_6]), 2);

DEFLABEL (label_21)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_13]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (current_block [OBJECT_146_3]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_6]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_146_13);
  (Wrd5.Obj) = (current_block [OBJECT_146_7]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_25;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_25;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_24)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_23;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd23.Obj) = (current_block [OBJECT_146_8]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd26.Lng))))
    goto label_23;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd10.Obj));
  (Wrd20.pObj) = (& ((Wrd24.pObj) [(Wrd17.Lng)]));
  (Wrd16.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [2]) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_10]), 3);

DEFLABEL (label_23)
  (Wrd27.Obj) = (current_block [OBJECT_146_8]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_9]), 2);

DEFLABEL (label_17)
  (Wrd16.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd6.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_16)
  (Wrd10.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_26)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_12]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_20;

DEFLABEL (label_28)
  (Wrd44.Obj) = (current_block [OBJECT_146_5]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_11]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_4]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.Obj) = (current_block [OBJECT_146_3]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_10]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_4]), 2);

DEFLABEL (label_12)
  (Wrd19.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_33)
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_34;
  (Wrd10.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd10.Lng) < 8L)
    goto label_31;
  goto label_32;

DEFLABEL (label_34)
  (Wrd66.Obj) = (current_block [OBJECT_146_0]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_8]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_147_4 3
#define LABEL_147_5 5
#define LABEL_147_6 7
#define ENVIRONMENT_LABEL_147_3 13
#define DEBUGGING_LABEL_147_2 12
#define OBJECT_147_3 11
#define OBJECT_147_2 10
#define OBJECT_147_1 9
#define OBJECT_147_0 8
#define FREE_REFERENCES_LABEL_147_0 8
#define NUMBER_OF_LINKER_SECTIONS_147_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_147 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_147_4);
      goto x_graphics_set_background_color_2;

    case 1:
      current_block = (Rpc - LABEL_147_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_147_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_background_color_7)
DEFLABEL (x_graphics_set_background_color_2)
  INTERRUPT_CHECK (26, LABEL_147_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_147_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_147_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_148_4 3
#define LABEL_148_5 5
#define LABEL_148_6 7
#define ENVIRONMENT_LABEL_148_3 13
#define DEBUGGING_LABEL_148_2 12
#define OBJECT_148_3 11
#define OBJECT_148_2 10
#define OBJECT_148_1 9
#define OBJECT_148_0 8
#define FREE_REFERENCES_LABEL_148_0 8
#define NUMBER_OF_LINKER_SECTIONS_148_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_148 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_148_4);
      goto x_graphics_set_border_color_2;

    case 1:
      current_block = (Rpc - LABEL_148_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_148_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_border_color_7)
DEFLABEL (x_graphics_set_border_color_2)
  INTERRUPT_CHECK (26, LABEL_148_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_148_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_148_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_149_4 3
#define LABEL_149_5 5
#define LABEL_149_6 7
#define ENVIRONMENT_LABEL_149_3 13
#define DEBUGGING_LABEL_149_2 12
#define OBJECT_149_3 11
#define OBJECT_149_2 10
#define OBJECT_149_1 9
#define OBJECT_149_0 8
#define FREE_REFERENCES_LABEL_149_0 8
#define NUMBER_OF_LINKER_SECTIONS_149_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_149 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_149_4);
      goto x_graphics_set_border_width_2;

    case 1:
      current_block = (Rpc - LABEL_149_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_149_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_border_width_7)
DEFLABEL (x_graphics_set_border_width_2)
  INTERRUPT_CHECK (26, LABEL_149_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_149_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_149_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_150_4 3
#define LABEL_150_5 5
#define LABEL_150_6 7
#define ENVIRONMENT_LABEL_150_3 13
#define DEBUGGING_LABEL_150_2 12
#define OBJECT_150_3 11
#define OBJECT_150_2 10
#define OBJECT_150_1 9
#define OBJECT_150_0 8
#define FREE_REFERENCES_LABEL_150_0 8
#define NUMBER_OF_LINKER_SECTIONS_150_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_150 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_150_4);
      goto x_graphics_set_font_2;

    case 1:
      current_block = (Rpc - LABEL_150_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_150_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_font_7)
DEFLABEL (x_graphics_set_font_2)
  INTERRUPT_CHECK (26, LABEL_150_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_150_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_150_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_151_4 3
#define LABEL_151_5 5
#define LABEL_151_6 7
#define ENVIRONMENT_LABEL_151_3 13
#define DEBUGGING_LABEL_151_2 12
#define OBJECT_151_3 11
#define OBJECT_151_2 10
#define OBJECT_151_1 9
#define OBJECT_151_0 8
#define FREE_REFERENCES_LABEL_151_0 8
#define NUMBER_OF_LINKER_SECTIONS_151_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_151 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_151_4);
      goto x_graphics_set_foreground_color_2;

    case 1:
      current_block = (Rpc - LABEL_151_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_151_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_foreground_color_7)
DEFLABEL (x_graphics_set_foreground_color_2)
  INTERRUPT_CHECK (26, LABEL_151_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_151_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_151_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_152_4 3
#define LABEL_152_5 5
#define LABEL_152_6 7
#define ENVIRONMENT_LABEL_152_3 13
#define DEBUGGING_LABEL_152_2 12
#define OBJECT_152_3 11
#define OBJECT_152_2 10
#define OBJECT_152_1 9
#define OBJECT_152_0 8
#define FREE_REFERENCES_LABEL_152_0 8
#define NUMBER_OF_LINKER_SECTIONS_152_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_152 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_152_4);
      goto x_graphics_set_internal_border_width_2;

    case 1:
      current_block = (Rpc - LABEL_152_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_152_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_internal_border_width_7)
DEFLABEL (x_graphics_set_internal_border_width_2)
  INTERRUPT_CHECK (26, LABEL_152_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_152_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_152_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_153_4 3
#define LABEL_153_5 5
#define LABEL_153_6 7
#define ENVIRONMENT_LABEL_153_3 13
#define DEBUGGING_LABEL_153_2 12
#define OBJECT_153_3 11
#define OBJECT_153_2 10
#define OBJECT_153_1 9
#define OBJECT_153_0 8
#define FREE_REFERENCES_LABEL_153_0 8
#define NUMBER_OF_LINKER_SECTIONS_153_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_153 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_153_4);
      goto x_graphics_set_mouse_color_2;

    case 1:
      current_block = (Rpc - LABEL_153_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_153_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_mouse_color_7)
DEFLABEL (x_graphics_set_mouse_color_2)
  INTERRUPT_CHECK (26, LABEL_153_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_153_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_153_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_153_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_153_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_153_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_154_4 3
#define LABEL_154_5 5
#define LABEL_154_6 7
#define ENVIRONMENT_LABEL_154_3 13
#define DEBUGGING_LABEL_154_2 12
#define OBJECT_154_3 11
#define OBJECT_154_2 10
#define OBJECT_154_1 9
#define OBJECT_154_0 8
#define FREE_REFERENCES_LABEL_154_0 8
#define NUMBER_OF_LINKER_SECTIONS_154_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_154 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_154_4);
      goto x_graphics_set_mouse_shape_2;

    case 1:
      current_block = (Rpc - LABEL_154_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_154_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_mouse_shape_7)
DEFLABEL (x_graphics_set_mouse_shape_2)
  INTERRUPT_CHECK (26, LABEL_154_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_154_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_154_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_154_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_154_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_154_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_155_4 3
#define LABEL_155_5 5
#define LABEL_155_6 7
#define LABEL_155_7 9
#define LABEL_155_9 11
#define LABEL_155_10 13
#define LABEL_155_11 15
#define LABEL_155_12 17
#define LABEL_155_13 19
#define ENVIRONMENT_LABEL_155_3 28
#define DEBUGGING_LABEL_155_2 27
#define OBJECT_155_3 26
#define OBJECT_155_2 25
#define OBJECT_155_1 24
#define OBJECT_155_0 23
#define EXECUTE_CACHE_155_8 21
#define FREE_REFERENCES_LABEL_155_0 20
#define NUMBER_OF_LINKER_SECTIONS_155_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_155 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_155_4);
      goto x_graphics_draw_arc_8;

    case 1:
      current_block = (Rpc - LABEL_155_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_155_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_155_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_155_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_155_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_155_11);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_155_12);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_155_13);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_arc_13)
DEFLABEL (x_graphics_draw_arc_8)
  INTERRUPT_CHECK (26, LABEL_155_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_17;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_17;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_16)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_15;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_15;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_14)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_155_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_155_9);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_155_10);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_155_11);
  (Rsp [4]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_155_12);
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_8]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_155_13);
  (Rsp [6]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_155_3]), 8);

DEFLABEL (label_15)
  (Wrd30.Obj) = (current_block [OBJECT_155_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_155_1]), 2);

DEFLABEL (label_11)
  (Wrd21.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_155_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_155_1]), 2);

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_156_4 3
#define LABEL_156_5 5
#define LABEL_156_7 7
#define LABEL_156_8 9
#define LABEL_156_9 11
#define LABEL_156_10 13
#define LABEL_156_11 15
#define ENVIRONMENT_LABEL_156_3 26
#define DEBUGGING_LABEL_156_2 25
#define OBJECT_156_5 24
#define OBJECT_156_4 23
#define OBJECT_156_3 22
#define OBJECT_156_2 21
#define OBJECT_156_1 20
#define OBJECT_156_0 19
#define EXECUTE_CACHE_156_6 17
#define FREE_REFERENCES_LABEL_156_0 16
#define NUMBER_OF_LINKER_SECTIONS_156_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_156 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_156_4);
      goto x_graphics_draw_circle_6;

    case 1:
      current_block = (Rpc - LABEL_156_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_156_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_156_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_156_9);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_156_10);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_156_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_draw_circle_11)
DEFLABEL (x_graphics_draw_circle_6)
  INTERRUPT_CHECK (26, LABEL_156_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_156_6]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_156_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_156_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_156_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_156_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_156_8);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_12)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_11]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_156_6]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_156_11);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_156_3]);
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_156_4]);
  (Rsp [6]) = (Wrd7.Obj);
  (Rsp [7]) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_156_5]), 8);

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_156_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_156_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_156_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_156_1]), 2);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_157_4 3
#define LABEL_157_5 5
#define LABEL_157_7 7
#define LABEL_157_8 9
#define LABEL_157_9 11
#define LABEL_157_10 13
#define LABEL_157_11 15
#define ENVIRONMENT_LABEL_157_3 27
#define DEBUGGING_LABEL_157_2 26
#define OBJECT_157_6 25
#define OBJECT_157_5 24
#define OBJECT_157_4 23
#define OBJECT_157_3 22
#define OBJECT_157_2 21
#define OBJECT_157_1 20
#define OBJECT_157_0 19
#define EXECUTE_CACHE_157_6 17
#define FREE_REFERENCES_LABEL_157_0 16
#define NUMBER_OF_LINKER_SECTIONS_157_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_157 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_157_4);
      goto x_graphics_fill_circle_6;

    case 1:
      current_block = (Rpc - LABEL_157_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_157_7);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_157_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_157_9);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_157_10);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_157_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_fill_circle_11)
DEFLABEL (x_graphics_fill_circle_6)
  INTERRUPT_CHECK (26, LABEL_157_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_157_6]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_157_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_157_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_157_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_157_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_157_8);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_12)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_11]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_157_6]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_157_11);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_157_3]);
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_157_4]);
  (Rsp [6]) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_157_5]);
  (Rsp [7]) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_6]), 8);

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_157_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_157_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_1]), 2);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_158_4 3
#define LABEL_158_5 5
#define LABEL_158_6 7
#define LABEL_158_8 9
#define LABEL_158_7 11
#define ENVIRONMENT_LABEL_158_3 22
#define DEBUGGING_LABEL_158_2 21
#define OBJECT_158_3 20
#define OBJECT_158_2 19
#define OBJECT_158_1 18
#define OBJECT_158_0 17
#define EXECUTE_CACHE_158_9 13
#define FREE_REFERENCE_158_0 16
#define FREE_REFERENCES_LABEL_158_0 12
#define NUMBER_OF_LINKER_SECTIONS_158_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_158 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_158_4);
      goto x_graphics_fill_polygon_3;

    case 1:
      current_block = (Rpc - LABEL_158_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_158_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_158_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_158_7);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_fill_polygon_9)
DEFLABEL (x_graphics_fill_polygon_3)
  INTERRUPT_CHECK (26, LABEL_158_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd39.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_158_0]));
  (Wrd42.Obj) = ((Wrd39.pObj) [0]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if ((Wrd43.uLng) == 50)
    goto label_11;
  Wrd38 = Wrd42;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_158_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_158_7);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_3]), 2);

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_158_8])), (Wrd39.pObj));

DEFLABEL (label_7)
  (Wrd38.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_158_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_1]), 2);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_158_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_1]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_159_4 3
#define LABEL_159_5 5
#define LABEL_159_6 7
#define LABEL_159_7 9
#define LABEL_159_9 11
#define LABEL_159_10 13
#define LABEL_159_11 15
#define LABEL_159_12 17
#define LABEL_159_13 19
#define ENVIRONMENT_LABEL_159_3 28
#define DEBUGGING_LABEL_159_2 27
#define OBJECT_159_3 26
#define OBJECT_159_2 25
#define OBJECT_159_1 24
#define OBJECT_159_0 23
#define EXECUTE_CACHE_159_8 21
#define FREE_REFERENCES_LABEL_159_0 20
#define NUMBER_OF_LINKER_SECTIONS_159_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_159 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_159_4);
      goto x_graphics_copy_area_9;

    case 1:
      current_block = (Rpc - LABEL_159_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_159_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_159_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_159_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_159_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_159_11);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_159_12);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_159_13);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_copy_area_14)
DEFLABEL (x_graphics_copy_area_9)
  INTERRUPT_CHECK (26, LABEL_159_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_18;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_18;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_17)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_16;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_16;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_15)
  (Wrd34.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_7]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_159_7);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_159_9);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_159_10);
  (Rsp [4]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_159_11);
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_159_12);
  (Rsp [6]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_159_8]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_159_13);
  (Rsp [7]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_159_3]), 8);

DEFLABEL (label_16)
  (Wrd30.Obj) = (current_block [OBJECT_159_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_159_1]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_159_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_159_1]), 2);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_160_4 3
#define LABEL_160_5 5
#define LABEL_160_6 7
#define LABEL_160_7 9
#define ENVIRONMENT_LABEL_160_3 14
#define DEBUGGING_LABEL_160_2 13
#define OBJECT_160_2 12
#define OBJECT_160_1 11
#define OBJECT_160_0 10
#define FREE_REFERENCES_LABEL_160_0 10
#define NUMBER_OF_LINKER_SECTIONS_160_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_160 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd34;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_160_4);
      goto x_graphics_get_default_3;

    case 1:
      current_block = (Rpc - LABEL_160_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_160_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_160_7);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_get_default_9)
DEFLABEL (x_graphics_get_default_3)
  INTERRUPT_CHECK (26, LABEL_160_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [3]);

DEFLABEL (label_12)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd41.uLng) == 62))
    goto label_11;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd40.Lng))))
    goto label_11;
  (Wrd34.Obj) = ((Wrd38.pObj) [3]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_160_2]), 3);

DEFLABEL (label_11)
  (Wrd43.Obj) = (current_block [OBJECT_160_0]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160_7]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_160_1]), 2);

DEFLABEL (label_7)
  (Wrd34.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_160_0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_160_1]), 2);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_160_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_160_1]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_161_4 3
#define LABEL_161_5 5
#define LABEL_161_6 7
#define ENVIRONMENT_LABEL_161_3 13
#define DEBUGGING_LABEL_161_2 12
#define OBJECT_161_3 11
#define OBJECT_161_2 10
#define OBJECT_161_1 9
#define OBJECT_161_0 8
#define FREE_REFERENCES_LABEL_161_0 8
#define NUMBER_OF_LINKER_SECTIONS_161_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_161 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_161_4);
      goto x_graphics_starbase_filename_2;

    case 1:
      current_block = (Rpc - LABEL_161_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_161_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_starbase_filename_7)
DEFLABEL (x_graphics_starbase_filename_2)
  INTERRUPT_CHECK (26, LABEL_161_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_161_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_161_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_161_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_161_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_161_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_162_4 3
#define LABEL_162_5 5
#define LABEL_162_6 7
#define ENVIRONMENT_LABEL_162_3 13
#define DEBUGGING_LABEL_162_2 12
#define OBJECT_162_3 11
#define OBJECT_162_2 10
#define OBJECT_162_1 9
#define OBJECT_162_0 8
#define FREE_REFERENCES_LABEL_162_0 8
#define NUMBER_OF_LINKER_SECTIONS_162_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_162 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_162_4);
      goto x_graphics_window_id_2;

    case 1:
      current_block = (Rpc - LABEL_162_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_162_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_window_id_7)
DEFLABEL (x_graphics_window_id_2)
  INTERRUPT_CHECK (26, LABEL_162_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_162_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_162_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_162_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_162_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_162_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_163_4 3
#define LABEL_163_5 5
#define LABEL_163_6 7
#define ENVIRONMENT_LABEL_163_3 13
#define DEBUGGING_LABEL_163_2 12
#define OBJECT_163_3 11
#define OBJECT_163_2 10
#define OBJECT_163_1 9
#define OBJECT_163_0 8
#define FREE_REFERENCES_LABEL_163_0 8
#define NUMBER_OF_LINKER_SECTIONS_163_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_163 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_163_4);
      goto x_graphics_set_input_hint_2;

    case 1:
      current_block = (Rpc - LABEL_163_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_163_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_input_hint_7)
DEFLABEL (x_graphics_set_input_hint_2)
  INTERRUPT_CHECK (26, LABEL_163_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_163_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_163_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_163_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_163_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_163_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_164_4 3
#define LABEL_164_5 5
#define LABEL_164_6 7
#define ENVIRONMENT_LABEL_164_3 14
#define DEBUGGING_LABEL_164_2 13
#define OBJECT_164_4 12
#define OBJECT_164_3 11
#define OBJECT_164_2 10
#define OBJECT_164_1 9
#define OBJECT_164_0 8
#define FREE_REFERENCES_LABEL_164_0 8
#define NUMBER_OF_LINKER_SECTIONS_164_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_164 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_164_4);
      goto x_graphics_disable_keyboard_focus_2;

    case 1:
      current_block = (Rpc - LABEL_164_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_164_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_disable_keyboard_focus_7)
DEFLABEL (x_graphics_disable_keyboard_focus_2)
  INTERRUPT_CHECK (26, LABEL_164_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_8)
  (Wrd34.Obj) = (current_block [OBJECT_164_3]);
  (Rsp [1]) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_4]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_164_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_164_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_165_4 3
#define LABEL_165_5 5
#define LABEL_165_6 7
#define ENVIRONMENT_LABEL_165_3 14
#define DEBUGGING_LABEL_165_2 13
#define OBJECT_165_4 12
#define OBJECT_165_3 11
#define OBJECT_165_2 10
#define OBJECT_165_1 9
#define OBJECT_165_0 8
#define FREE_REFERENCES_LABEL_165_0 8
#define NUMBER_OF_LINKER_SECTIONS_165_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_165 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_165_4);
      goto x_graphics_enable_keyboard_focus_2;

    case 1:
      current_block = (Rpc - LABEL_165_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_165_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_enable_keyboard_focus_7)
DEFLABEL (x_graphics_enable_keyboard_focus_2)
  INTERRUPT_CHECK (26, LABEL_165_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_8)
  (Wrd34.Obj) = (current_block [OBJECT_165_3]);
  (Rsp [1]) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_4]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_165_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_165_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_166_4 3
#define LABEL_166_5 5
#define ENVIRONMENT_LABEL_166_3 12
#define DEBUGGING_LABEL_166_2 11
#define OBJECT_166_4 10
#define OBJECT_166_3 9
#define OBJECT_166_2 8
#define OBJECT_166_1 7
#define OBJECT_166_0 6
#define FREE_REFERENCES_LABEL_166_0 6
#define NUMBER_OF_LINKER_SECTIONS_166_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_166 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_166_4);
      goto x_graphics_select_user_events_1;

    case 1:
      current_block = (Rpc - LABEL_166_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_select_user_events_5)
DEFLABEL (x_graphics_select_user_events_1)
  INTERRUPT_CHECK (26, LABEL_166_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_166_2]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_4]), 3);

DEFLABEL (label_7)
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd32.Lng))))
    goto label_6;
  (Wrd25.Obj) = (Rsp [2]);
  ((Wrd30.pObj) [6]) = (Wrd25.Obj);
  Rvl = (current_block [OBJECT_166_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_166_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_167_4 3
#define LABEL_167_5 5
#define LABEL_167_6 7
#define LABEL_167_7 9
#define LABEL_167_9 11
#define LABEL_167_8 13
#define LABEL_167_10 15
#define LABEL_167_12 17
#define LABEL_167_11 19
#define LABEL_167_13 21
#define TAG_167_14 9
#define ENVIRONMENT_LABEL_167_3 32
#define DEBUGGING_LABEL_167_2 31
#define OBJECT_167_8 30
#define OBJECT_167_7 29
#define OBJECT_167_6 28
#define OBJECT_167_5 27
#define OBJECT_167_4 26
#define OBJECT_167_3 25
#define OBJECT_167_2 24
#define OBJECT_167_1 23
#define OBJECT_167_0 22
#define FREE_REFERENCES_LABEL_167_0 22
#define NUMBER_OF_LINKER_SECTIONS_167_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_167 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_167_4);
      goto x_graphics_query_pointer_12;

    case 1:
      current_block = (Rpc - LABEL_167_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_167_6);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_167_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_167_9);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_167_8);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_167_10);
      goto label_17;

    case 7:
      current_block = (Rpc - LABEL_167_12);
      goto label_18;

    case 8:
      current_block = (Rpc - LABEL_167_11);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_167_13);
      goto lambda_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_query_pointer_20)
DEFLABEL (x_graphics_query_pointer_12)
  INTERRUPT_CHECK (26, LABEL_167_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_31;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_31;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_30)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_29;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_29;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_3]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_167_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 10))
    goto label_27;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_27;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_26)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_5]), 2);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_167_8);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_25;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_25;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_24)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_23;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd32.Lng))))
    goto label_23;
  (Wrd26.Obj) = ((Wrd30.pObj) [4]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_22)
  (Wrd40.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_8]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_167_11);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_167_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_167_13])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  ((Wrd14.pObj) [2]) = (Wrd6.Obj);
  ((Wrd14.pObj) [3]) = Rvl;
  (Wrd11.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  Rvl = (Wrd8.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_167_7]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_4]), 2);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_167_6]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_4]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_167_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_4]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd30.Obj) = (current_block [OBJECT_167_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 2);

DEFLABEL (label_15)
  (Wrd21.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_167_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 2);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_30;

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_167_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_168_4 3
#define LABEL_168_5 5
#define LABEL_168_7 7
#define LABEL_168_8 9
#define LABEL_168_9 11
#define LABEL_168_10 13
#define TAG_168_11 5
#define ENVIRONMENT_LABEL_168_3 23
#define DEBUGGING_LABEL_168_2 22
#define OBJECT_168_4 21
#define OBJECT_168_3 20
#define OBJECT_168_2 19
#define OBJECT_168_1 18
#define OBJECT_168_0 17
#define EXECUTE_CACHE_168_6 15
#define FREE_REFERENCES_LABEL_168_0 14
#define NUMBER_OF_LINKER_SECTIONS_168_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_168 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_168_4);
      goto x_graphics_read_button_7;

    case 1:
      current_block = (Rpc - LABEL_168_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_168_7);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_168_8);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_168_9);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_168_10);
      goto lambda_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_read_button_13)
DEFLABEL (x_graphics_read_button_7)
  INTERRUPT_CHECK (26, LABEL_168_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_168_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_168_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_168_5);
  (Rsp [0]) = Rvl;
  (Wrd16.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd16.uLng) == 10))
    goto label_20;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd14.Lng))))
    goto label_20;
  (Wrd8.Obj) = ((Wrd12.pObj) [4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_19)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_18;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd30.Lng))))
    goto label_18;
  (Wrd24.Obj) = ((Wrd28.pObj) [3]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_17)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_16;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd46.Lng))))
    goto label_16;
  (Wrd38.Obj) = ((Wrd44.pObj) [5]);

DEFLABEL (label_15)
  (Rsp [2]) = (Wrd38.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd56.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_168_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_168_10])));
  Rhp += 3;
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd56.pObj)));
  Wrd61 = Wrd56;
  ((Wrd61.pObj) [2]) = (Wrd38.Obj);
  (Wrd60.Obj) = (Rsp [1]);
  ((Wrd61.pObj) [3]) = (Wrd60.Obj);
  (Wrd58.Obj) = (Rsp [0]);
  ((Wrd61.pObj) [4]) = (Wrd58.Obj);
  Rvl = (Wrd55.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (current_block [OBJECT_168_4]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_9]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 2);

DEFLABEL (label_11)
  (Wrd38.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (current_block [OBJECT_168_3]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_8]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_168_1]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_168_10);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_169_4 3
#define LABEL_169_5 5
#define LABEL_169_7 7
#define LABEL_169_8 9
#define LABEL_169_11 11
#define LABEL_169_9 13
#define LABEL_169_12 15
#define LABEL_169_13 17
#define LABEL_169_15 19
#define ENVIRONMENT_LABEL_169_3 35
#define DEBUGGING_LABEL_169_2 34
#define OBJECT_169_6 33
#define OBJECT_169_5 32
#define OBJECT_169_4 31
#define OBJECT_169_3 30
#define OBJECT_169_2 29
#define OBJECT_169_1 28
#define OBJECT_169_0 27
#define EXECUTE_CACHE_169_14 21
#define EXECUTE_CACHE_169_10 23
#define EXECUTE_CACHE_169_6 25
#define FREE_REFERENCES_LABEL_169_0 20
#define NUMBER_OF_LINKER_SECTIONS_169_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_169 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd40;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_169_4);
      goto read_event_of_type_15;

    case 1:
      current_block = (Rpc - LABEL_169_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_169_7);
      goto label_17;

    case 3:
      current_block = (Rpc - LABEL_169_8);
      goto loop_12;

    case 4:
      current_block = (Rpc - LABEL_169_11);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_169_9);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_169_12);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_169_13);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_169_15);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (read_event_of_type_22)
DEFLABEL (read_event_of_type_15)
  INTERRUPT_CHECK (26, LABEL_169_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_169_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_169_5);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_25;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_25;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_24)
  goto loop_12;

DEFLABEL (label_25)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_169_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_1]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (loop_23)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_169_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_169_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_169_9);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_34;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_34;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_33)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == (Wrd5.Obj))
    goto label_27;

DEFLABEL (label_26)
  Rsp = (& (Rsp [1]));
  goto loop_12;

DEFLABEL (label_27)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_32;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd31.Lng))))
    goto label_32;
  (Wrd23.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_31)
  if (! ((Wrd23.Obj) == (current_block [OBJECT_169_5])))
    goto label_30;
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_11]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (current_block [OBJECT_169_6]);
  (* (--Rsp)) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_169_14]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_169_11);

DEFLABEL (label_30)
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_29;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd48.Lng))))
    goto label_29;
  (Wrd40.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_28)
  (Wrd56.Obj) = (Rsp [4]);
  if (! ((Wrd40.Obj) == (Wrd56.Obj)))
    goto label_26;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.Obj) = (current_block [OBJECT_169_4]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_15]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_3]), 2);

DEFLABEL (label_20)
  (Wrd40.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_32)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (current_block [OBJECT_169_4]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_13]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_3]), 2);

DEFLABEL (label_19)
  (Wrd23.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_169_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_12]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_3]), 2);

DEFLABEL (label_18)
  (Wrd5.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_170_4 3
#define LABEL_170_5 5
#define ENVIRONMENT_LABEL_170_3 12
#define DEBUGGING_LABEL_170_2 11
#define EXECUTE_CACHE_170_7 7
#define EXECUTE_CACHE_170_6 9
#define FREE_REFERENCES_LABEL_170_0 6
#define NUMBER_OF_LINKER_SECTIONS_170_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_170 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_170_4);
      goto x_graphics_read_user_event_1;

    case 1:
      current_block = (Rpc - LABEL_170_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_read_user_event_4)
DEFLABEL (x_graphics_read_user_event_1)
  INTERRUPT_CHECK (26, LABEL_170_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_170_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_171_4 3
#define LABEL_171_5 5
#define ENVIRONMENT_LABEL_171_3 12
#define DEBUGGING_LABEL_171_2 11
#define EXECUTE_CACHE_171_7 7
#define EXECUTE_CACHE_171_6 9
#define FREE_REFERENCES_LABEL_171_0 6
#define NUMBER_OF_LINKER_SECTIONS_171_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_171 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_171_4);
      goto x_graphics_discard_events_1;

    case 1:
      current_block = (Rpc - LABEL_171_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_discard_events_4)
DEFLABEL (x_graphics_discard_events_1)
  INTERRUPT_CHECK (26, LABEL_171_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_171_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_171_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_171_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_172_4 3
#define LABEL_172_5 5
#define LABEL_172_6 7
#define LABEL_172_7 9
#define ENVIRONMENT_LABEL_172_3 14
#define DEBUGGING_LABEL_172_2 13
#define OBJECT_172_2 12
#define OBJECT_172_1 11
#define OBJECT_172_0 10
#define FREE_REFERENCES_LABEL_172_0 10
#define NUMBER_OF_LINKER_SECTIONS_172_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_172 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd34;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_172_4);
      goto x_graphics_font_structure_3;

    case 1:
      current_block = (Rpc - LABEL_172_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_172_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_172_7);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_font_structure_9)
DEFLABEL (x_graphics_font_structure_3)
  INTERRUPT_CHECK (26, LABEL_172_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_15;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_15;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_14)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_13;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_13;
  (Wrd21.Obj) = ((Wrd25.pObj) [3]);

DEFLABEL (label_12)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd41.uLng) == 62))
    goto label_11;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd40.Lng))))
    goto label_11;
  (Wrd34.Obj) = ((Wrd38.pObj) [3]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_2]), 2);

DEFLABEL (label_11)
  (Wrd43.Obj) = (current_block [OBJECT_172_0]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_7]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 2);

DEFLABEL (label_7)
  (Wrd34.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd30.Obj) = (current_block [OBJECT_172_0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 2);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_172_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_173_4 3
#define ENVIRONMENT_LABEL_173_3 5
#define DEBUGGING_LABEL_173_2 4
#define FREE_REFERENCES_LABEL_173_0 4
#define NUMBER_OF_LINKER_SECTIONS_173_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_173 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_173_4);
      goto make_x_font_structure_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_x_font_structure_3)
DEFLABEL (make_x_font_structure_0)
  INTERRUPT_CHECK (26, LABEL_173_4);
  (Wrd18.Obj) = (MAKE_OBJECT (0, 10));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.Obj) = (Rsp [4]);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (Wrd10.Obj) = (Rsp [8]);
  (Wrd11.Obj) = (Rsp [9]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-11]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [10]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_174_4 3
#define ENVIRONMENT_LABEL_174_3 7
#define DEBUGGING_LABEL_174_2 6
#define OBJECT_174_1 5
#define OBJECT_174_0 4
#define FREE_REFERENCES_LABEL_174_0 4
#define NUMBER_OF_LINKER_SECTIONS_174_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_174 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_174_4);
      goto x_font_structure_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_name_3)
DEFLABEL (x_font_structure_name_0)
  INTERRUPT_CHECK (26, LABEL_174_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_174_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_175_4 3
#define ENVIRONMENT_LABEL_175_3 7
#define DEBUGGING_LABEL_175_2 6
#define OBJECT_175_1 5
#define OBJECT_175_0 4
#define FREE_REFERENCES_LABEL_175_0 4
#define NUMBER_OF_LINKER_SECTIONS_175_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_175 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_175_4);
      goto x_font_structure_direction_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_direction_3)
DEFLABEL (x_font_structure_direction_0)
  INTERRUPT_CHECK (26, LABEL_175_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_175_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_175_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_176_4 3
#define ENVIRONMENT_LABEL_176_3 7
#define DEBUGGING_LABEL_176_2 6
#define OBJECT_176_1 5
#define OBJECT_176_0 4
#define FREE_REFERENCES_LABEL_176_0 4
#define NUMBER_OF_LINKER_SECTIONS_176_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_176 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_176_4);
      goto x_font_structure_all_chars_existP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_all_chars_existP_3)
DEFLABEL (x_font_structure_all_chars_existP_0)
  INTERRUPT_CHECK (26, LABEL_176_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_176_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_176_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_177_4 3
#define ENVIRONMENT_LABEL_177_3 7
#define DEBUGGING_LABEL_177_2 6
#define OBJECT_177_1 5
#define OBJECT_177_0 4
#define FREE_REFERENCES_LABEL_177_0 4
#define NUMBER_OF_LINKER_SECTIONS_177_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_177 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_177_4);
      goto x_font_structure_default_char_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_default_char_3)
DEFLABEL (x_font_structure_default_char_0)
  INTERRUPT_CHECK (26, LABEL_177_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_177_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_178_4 3
#define ENVIRONMENT_LABEL_178_3 7
#define DEBUGGING_LABEL_178_2 6
#define OBJECT_178_1 5
#define OBJECT_178_0 4
#define FREE_REFERENCES_LABEL_178_0 4
#define NUMBER_OF_LINKER_SECTIONS_178_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_178 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_178_4);
      goto x_font_structure_min_bounds_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_min_bounds_3)
DEFLABEL (x_font_structure_min_bounds_0)
  INTERRUPT_CHECK (26, LABEL_178_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_178_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_178_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_179_4 3
#define ENVIRONMENT_LABEL_179_3 7
#define DEBUGGING_LABEL_179_2 6
#define OBJECT_179_1 5
#define OBJECT_179_0 4
#define FREE_REFERENCES_LABEL_179_0 4
#define NUMBER_OF_LINKER_SECTIONS_179_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_179 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_179_4);
      goto x_font_structure_max_bounds_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_max_bounds_3)
DEFLABEL (x_font_structure_max_bounds_0)
  INTERRUPT_CHECK (26, LABEL_179_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_179_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_179_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_180_4 3
#define ENVIRONMENT_LABEL_180_3 7
#define DEBUGGING_LABEL_180_2 6
#define OBJECT_180_1 5
#define OBJECT_180_0 4
#define FREE_REFERENCES_LABEL_180_0 4
#define NUMBER_OF_LINKER_SECTIONS_180_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_180 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_180_4);
      goto x_font_structure_start_index_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_start_index_3)
DEFLABEL (x_font_structure_start_index_0)
  INTERRUPT_CHECK (26, LABEL_180_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_180_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_181_4 3
#define ENVIRONMENT_LABEL_181_3 7
#define DEBUGGING_LABEL_181_2 6
#define OBJECT_181_1 5
#define OBJECT_181_0 4
#define FREE_REFERENCES_LABEL_181_0 4
#define NUMBER_OF_LINKER_SECTIONS_181_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_181 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_181_4);
      goto x_font_structure_character_bounds_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_character_bounds_3)
DEFLABEL (x_font_structure_character_bounds_0)
  INTERRUPT_CHECK (26, LABEL_181_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_181_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_181_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_182_4 3
#define ENVIRONMENT_LABEL_182_3 7
#define DEBUGGING_LABEL_182_2 6
#define OBJECT_182_1 5
#define OBJECT_182_0 4
#define FREE_REFERENCES_LABEL_182_0 4
#define NUMBER_OF_LINKER_SECTIONS_182_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_182 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_182_4);
      goto x_font_structure_max_ascent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_max_ascent_3)
DEFLABEL (x_font_structure_max_ascent_0)
  INTERRUPT_CHECK (26, LABEL_182_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_182_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_182_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [9]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_183_4 3
#define ENVIRONMENT_LABEL_183_3 7
#define DEBUGGING_LABEL_183_2 6
#define OBJECT_183_1 5
#define OBJECT_183_0 4
#define FREE_REFERENCES_LABEL_183_0 4
#define NUMBER_OF_LINKER_SECTIONS_183_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_183 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_183_4);
      goto x_font_structure_max_descent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_font_structure_max_descent_3)
DEFLABEL (x_font_structure_max_descent_0)
  INTERRUPT_CHECK (26, LABEL_183_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_183_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [10]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_184_4 3
#define ENVIRONMENT_LABEL_184_3 5
#define DEBUGGING_LABEL_184_2 4
#define FREE_REFERENCES_LABEL_184_0 4
#define NUMBER_OF_LINKER_SECTIONS_184_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_184 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_184_4);
      goto make_x_character_bounds_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_x_character_bounds_3)
DEFLABEL (make_x_character_bounds_0)
  INTERRUPT_CHECK (26, LABEL_184_4);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_185_4 3
#define ENVIRONMENT_LABEL_185_3 7
#define DEBUGGING_LABEL_185_2 6
#define OBJECT_185_1 5
#define OBJECT_185_0 4
#define FREE_REFERENCES_LABEL_185_0 4
#define NUMBER_OF_LINKER_SECTIONS_185_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_185 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_185_4);
      goto x_character_bounds_lbearing_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_character_bounds_lbearing_3)
DEFLABEL (x_character_bounds_lbearing_0)
  INTERRUPT_CHECK (26, LABEL_185_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_185_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_186_4 3
#define ENVIRONMENT_LABEL_186_3 7
#define DEBUGGING_LABEL_186_2 6
#define OBJECT_186_1 5
#define OBJECT_186_0 4
#define FREE_REFERENCES_LABEL_186_0 4
#define NUMBER_OF_LINKER_SECTIONS_186_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_186 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_186_4);
      goto x_character_bounds_rbearing_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_character_bounds_rbearing_3)
DEFLABEL (x_character_bounds_rbearing_0)
  INTERRUPT_CHECK (26, LABEL_186_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_186_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_186_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_187_4 3
#define ENVIRONMENT_LABEL_187_3 7
#define DEBUGGING_LABEL_187_2 6
#define OBJECT_187_1 5
#define OBJECT_187_0 4
#define FREE_REFERENCES_LABEL_187_0 4
#define NUMBER_OF_LINKER_SECTIONS_187_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_187 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_187_4);
      goto x_character_bounds_width_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_character_bounds_width_3)
DEFLABEL (x_character_bounds_width_0)
  INTERRUPT_CHECK (26, LABEL_187_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_187_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_187_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_188_4 3
#define ENVIRONMENT_LABEL_188_3 7
#define DEBUGGING_LABEL_188_2 6
#define OBJECT_188_1 5
#define OBJECT_188_0 4
#define FREE_REFERENCES_LABEL_188_0 4
#define NUMBER_OF_LINKER_SECTIONS_188_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_188 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_188_4);
      goto x_character_bounds_ascent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_character_bounds_ascent_3)
DEFLABEL (x_character_bounds_ascent_0)
  INTERRUPT_CHECK (26, LABEL_188_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_188_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_189_4 3
#define ENVIRONMENT_LABEL_189_3 7
#define DEBUGGING_LABEL_189_2 6
#define OBJECT_189_1 5
#define OBJECT_189_0 4
#define FREE_REFERENCES_LABEL_189_0 4
#define NUMBER_OF_LINKER_SECTIONS_189_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_189 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_189_4);
      goto x_character_bounds_descent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_character_bounds_descent_3)
DEFLABEL (x_character_bounds_descent_0)
  INTERRUPT_CHECK (26, LABEL_189_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_189_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_190_4 3
#define LABEL_190_5 5
#define ENVIRONMENT_LABEL_190_3 12
#define DEBUGGING_LABEL_190_2 11
#define OBJECT_190_1 10
#define OBJECT_190_0 9
#define EXECUTE_CACHE_190_6 7
#define FREE_REFERENCES_LABEL_190_0 6
#define NUMBER_OF_LINKER_SECTIONS_190_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_190 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_190_4);
      goto x_graphics_map_window_1;

    case 1:
      current_block = (Rpc - LABEL_190_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_map_window_5)
DEFLABEL (x_graphics_map_window_1)
  INTERRUPT_CHECK (26, LABEL_190_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_190_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_190_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_190_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_190_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_191_4 3
#define LABEL_191_5 5
#define LABEL_191_6 7
#define ENVIRONMENT_LABEL_191_3 13
#define DEBUGGING_LABEL_191_2 12
#define OBJECT_191_3 11
#define OBJECT_191_2 10
#define OBJECT_191_1 9
#define OBJECT_191_0 8
#define FREE_REFERENCES_LABEL_191_0 8
#define NUMBER_OF_LINKER_SECTIONS_191_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_191 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_191_4);
      goto x_graphics_withdraw_window_2;

    case 1:
      current_block = (Rpc - LABEL_191_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_191_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_withdraw_window_7)
DEFLABEL (x_graphics_withdraw_window_2)
  INTERRUPT_CHECK (26, LABEL_191_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_191_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_191_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_191_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_191_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_191_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_191_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_191_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_192_4 3
#define LABEL_192_5 5
#define LABEL_192_6 7
#define ENVIRONMENT_LABEL_192_3 13
#define DEBUGGING_LABEL_192_2 12
#define OBJECT_192_3 11
#define OBJECT_192_2 10
#define OBJECT_192_1 9
#define OBJECT_192_0 8
#define FREE_REFERENCES_LABEL_192_0 8
#define NUMBER_OF_LINKER_SECTIONS_192_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_192 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_192_4);
      goto x_graphics_iconify_window_2;

    case 1:
      current_block = (Rpc - LABEL_192_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_192_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_iconify_window_7)
DEFLABEL (x_graphics_iconify_window_2)
  INTERRUPT_CHECK (26, LABEL_192_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_192_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_192_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_192_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_192_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_192_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_192_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_192_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_193_4 3
#define LABEL_193_5 5
#define LABEL_193_6 7
#define ENVIRONMENT_LABEL_193_3 13
#define DEBUGGING_LABEL_193_2 12
#define OBJECT_193_3 11
#define OBJECT_193_2 10
#define OBJECT_193_1 9
#define OBJECT_193_0 8
#define FREE_REFERENCES_LABEL_193_0 8
#define NUMBER_OF_LINKER_SECTIONS_193_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_193 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_193_4);
      goto x_graphics_raise_window_2;

    case 1:
      current_block = (Rpc - LABEL_193_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_193_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_raise_window_7)
DEFLABEL (x_graphics_raise_window_2)
  INTERRUPT_CHECK (26, LABEL_193_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_193_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_193_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_193_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_193_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_193_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_194_4 3
#define LABEL_194_5 5
#define LABEL_194_6 7
#define ENVIRONMENT_LABEL_194_3 13
#define DEBUGGING_LABEL_194_2 12
#define OBJECT_194_3 11
#define OBJECT_194_2 10
#define OBJECT_194_1 9
#define OBJECT_194_0 8
#define FREE_REFERENCES_LABEL_194_0 8
#define NUMBER_OF_LINKER_SECTIONS_194_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_194 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_194_4);
      goto x_graphics_lower_window_2;

    case 1:
      current_block = (Rpc - LABEL_194_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_194_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_lower_window_7)
DEFLABEL (x_graphics_lower_window_2)
  INTERRUPT_CHECK (26, LABEL_194_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_194_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_194_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_194_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_194_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_194_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_195_4 3
#define LABEL_195_5 5
#define LABEL_195_6 7
#define ENVIRONMENT_LABEL_195_3 13
#define DEBUGGING_LABEL_195_2 12
#define OBJECT_195_3 11
#define OBJECT_195_2 10
#define OBJECT_195_1 9
#define OBJECT_195_0 8
#define FREE_REFERENCES_LABEL_195_0 8
#define NUMBER_OF_LINKER_SECTIONS_195_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_195 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_195_4);
      goto x_graphics_set_icon_name_2;

    case 1:
      current_block = (Rpc - LABEL_195_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_195_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_icon_name_7)
DEFLABEL (x_graphics_set_icon_name_2)
  INTERRUPT_CHECK (26, LABEL_195_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_195_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_195_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_195_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_195_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_195_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_195_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_195_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_196_4 3
#define LABEL_196_5 5
#define LABEL_196_6 7
#define ENVIRONMENT_LABEL_196_3 13
#define DEBUGGING_LABEL_196_2 12
#define OBJECT_196_3 11
#define OBJECT_196_2 10
#define OBJECT_196_1 9
#define OBJECT_196_0 8
#define FREE_REFERENCES_LABEL_196_0 8
#define NUMBER_OF_LINKER_SECTIONS_196_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_196 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_196_4);
      goto x_graphics_set_window_name_2;

    case 1:
      current_block = (Rpc - LABEL_196_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_196_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_window_name_7)
DEFLABEL (x_graphics_set_window_name_2)
  INTERRUPT_CHECK (26, LABEL_196_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_196_3]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_196_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_196_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_196_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_196_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_196_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_196_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_197_4 3
#define LABEL_197_5 5
#define LABEL_197_6 7
#define ENVIRONMENT_LABEL_197_3 13
#define DEBUGGING_LABEL_197_2 12
#define OBJECT_197_3 11
#define OBJECT_197_2 10
#define OBJECT_197_1 9
#define OBJECT_197_0 8
#define FREE_REFERENCES_LABEL_197_0 8
#define NUMBER_OF_LINKER_SECTIONS_197_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_197 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_197_4);
      goto x_graphics_move_window_2;

    case 1:
      current_block = (Rpc - LABEL_197_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_197_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_move_window_7)
DEFLABEL (x_graphics_move_window_2)
  INTERRUPT_CHECK (26, LABEL_197_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_197_3]), 3);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_197_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_197_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_197_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_197_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_197_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_197_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_198_4 3
#define LABEL_198_5 5
#define LABEL_198_6 7
#define ENVIRONMENT_LABEL_198_3 13
#define DEBUGGING_LABEL_198_2 12
#define OBJECT_198_3 11
#define OBJECT_198_2 10
#define OBJECT_198_1 9
#define OBJECT_198_0 8
#define FREE_REFERENCES_LABEL_198_0 8
#define NUMBER_OF_LINKER_SECTIONS_198_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_198 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_198_4);
      goto x_graphics_resize_window_2;

    case 1:
      current_block = (Rpc - LABEL_198_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_198_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_resize_window_7)
DEFLABEL (x_graphics_resize_window_2)
  INTERRUPT_CHECK (26, LABEL_198_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_198_3]), 3);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_198_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_198_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_198_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_198_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_199_4 3
#define ENVIRONMENT_LABEL_199_3 5
#define DEBUGGING_LABEL_199_2 4
#define FREE_REFERENCES_LABEL_199_0 4
#define NUMBER_OF_LINKER_SECTIONS_199_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_199 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_199_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_199_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_200_4 3
#define ENVIRONMENT_LABEL_200_3 5
#define DEBUGGING_LABEL_200_2 4
#define FREE_REFERENCES_LABEL_200_0 4
#define NUMBER_OF_LINKER_SECTIONS_200_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_200 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_200_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_200_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_201_4 3
#define ENVIRONMENT_LABEL_201_3 5
#define DEBUGGING_LABEL_201_2 4
#define FREE_REFERENCES_LABEL_201_0 4
#define NUMBER_OF_LINKER_SECTIONS_201_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_201 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_201_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_201_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_202_4 3
#define ENVIRONMENT_LABEL_202_3 5
#define DEBUGGING_LABEL_202_2 4
#define FREE_REFERENCES_LABEL_202_0 4
#define NUMBER_OF_LINKER_SECTIONS_202_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_202 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_202_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_202_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_203_4 3
#define ENVIRONMENT_LABEL_203_3 5
#define DEBUGGING_LABEL_203_2 4
#define FREE_REFERENCES_LABEL_203_0 4
#define NUMBER_OF_LINKER_SECTIONS_203_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_203 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_203_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_203_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_204_4 3
#define ENVIRONMENT_LABEL_204_3 5
#define DEBUGGING_LABEL_204_2 4
#define FREE_REFERENCES_LABEL_204_0 4
#define NUMBER_OF_LINKER_SECTIONS_204_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_204 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_204_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_204_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_205_4 3
#define ENVIRONMENT_LABEL_205_3 5
#define DEBUGGING_LABEL_205_2 4
#define FREE_REFERENCES_LABEL_205_0 4
#define NUMBER_OF_LINKER_SECTIONS_205_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_205 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_205_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_205_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_206_4 3
#define ENVIRONMENT_LABEL_206_3 5
#define DEBUGGING_LABEL_206_2 4
#define FREE_REFERENCES_LABEL_206_0 4
#define NUMBER_OF_LINKER_SECTIONS_206_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_206 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_206_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_206_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_207_4 3
#define ENVIRONMENT_LABEL_207_3 5
#define DEBUGGING_LABEL_207_2 4
#define FREE_REFERENCES_LABEL_207_0 4
#define NUMBER_OF_LINKER_SECTIONS_207_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_207 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_207_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_207_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_208_4 3
#define ENVIRONMENT_LABEL_208_3 5
#define DEBUGGING_LABEL_208_2 4
#define FREE_REFERENCES_LABEL_208_0 4
#define NUMBER_OF_LINKER_SECTIONS_208_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_208 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_208_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_208_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_209_4 3
#define ENVIRONMENT_LABEL_209_3 5
#define DEBUGGING_LABEL_209_2 4
#define FREE_REFERENCES_LABEL_209_0 4
#define NUMBER_OF_LINKER_SECTIONS_209_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_209 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_209_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_209_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_210_4 3
#define ENVIRONMENT_LABEL_210_3 5
#define DEBUGGING_LABEL_210_2 4
#define FREE_REFERENCES_LABEL_210_0 4
#define NUMBER_OF_LINKER_SECTIONS_210_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_210 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_210_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_210_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_211_4 3
#define ENVIRONMENT_LABEL_211_3 5
#define DEBUGGING_LABEL_211_2 4
#define FREE_REFERENCES_LABEL_211_0 4
#define NUMBER_OF_LINKER_SECTIONS_211_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_211 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_211_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_211_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_212_4 3
#define ENVIRONMENT_LABEL_212_3 5
#define DEBUGGING_LABEL_212_2 4
#define FREE_REFERENCES_LABEL_212_0 4
#define NUMBER_OF_LINKER_SECTIONS_212_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_212 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_212_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_212_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_213_4 3
#define ENVIRONMENT_LABEL_213_3 5
#define DEBUGGING_LABEL_213_2 4
#define FREE_REFERENCES_LABEL_213_0 4
#define NUMBER_OF_LINKER_SECTIONS_213_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_213 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_213_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_213_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_214_4 3
#define ENVIRONMENT_LABEL_214_3 5
#define DEBUGGING_LABEL_214_2 4
#define FREE_REFERENCES_LABEL_214_0 4
#define NUMBER_OF_LINKER_SECTIONS_214_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_214 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_214_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_214_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_215_4 3
#define ENVIRONMENT_LABEL_215_3 5
#define DEBUGGING_LABEL_215_2 4
#define FREE_REFERENCES_LABEL_215_0 4
#define NUMBER_OF_LINKER_SECTIONS_215_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_215 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_215_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_215_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_216_4 3
#define ENVIRONMENT_LABEL_216_3 5
#define DEBUGGING_LABEL_216_2 4
#define FREE_REFERENCES_LABEL_216_0 4
#define NUMBER_OF_LINKER_SECTIONS_216_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_216 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_216_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_216_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_217_4 3
#define ENVIRONMENT_LABEL_217_3 5
#define DEBUGGING_LABEL_217_2 4
#define FREE_REFERENCES_LABEL_217_0 4
#define NUMBER_OF_LINKER_SECTIONS_217_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_217 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_217_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_217_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_218_4 3
#define ENVIRONMENT_LABEL_218_3 7
#define DEBUGGING_LABEL_218_2 6
#define OBJECT_218_1 5
#define OBJECT_218_0 4
#define FREE_REFERENCES_LABEL_218_0 4
#define NUMBER_OF_LINKER_SECTIONS_218_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_218 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_218_4);
      goto x_image_descriptor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_descriptor_3)
DEFLABEL (x_image_descriptor_0)
  INTERRUPT_CHECK (26, LABEL_218_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_218_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_218_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_219_4 3
#define ENVIRONMENT_LABEL_219_3 7
#define DEBUGGING_LABEL_219_2 6
#define OBJECT_219_1 5
#define OBJECT_219_0 4
#define FREE_REFERENCES_LABEL_219_0 4
#define NUMBER_OF_LINKER_SECTIONS_219_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_219 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_219_4);
      goto x_image_window_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_window_3)
DEFLABEL (x_image_window_0)
  INTERRUPT_CHECK (26, LABEL_219_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_219_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_219_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_220_4 3
#define ENVIRONMENT_LABEL_220_3 7
#define DEBUGGING_LABEL_220_2 6
#define OBJECT_220_1 5
#define OBJECT_220_0 4
#define FREE_REFERENCES_LABEL_220_0 4
#define NUMBER_OF_LINKER_SECTIONS_220_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_220 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_220_4);
      goto x_image_width_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_width_3)
DEFLABEL (x_image_width_0)
  INTERRUPT_CHECK (26, LABEL_220_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_220_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_220_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_221_4 3
#define ENVIRONMENT_LABEL_221_3 7
#define DEBUGGING_LABEL_221_2 6
#define OBJECT_221_1 5
#define OBJECT_221_0 4
#define FREE_REFERENCES_LABEL_221_0 4
#define NUMBER_OF_LINKER_SECTIONS_221_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_221 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_221_4);
      goto x_image_height_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_height_3)
DEFLABEL (x_image_height_0)
  INTERRUPT_CHECK (26, LABEL_221_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_221_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_221_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_222_4 3
#define ENVIRONMENT_LABEL_222_3 8
#define DEBUGGING_LABEL_222_2 7
#define OBJECT_222_2 6
#define OBJECT_222_1 5
#define OBJECT_222_0 4
#define FREE_REFERENCES_LABEL_222_0 4
#define NUMBER_OF_LINKER_SECTIONS_222_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_222 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_222_4);
      goto set_x_image_descriptorB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_image_descriptorB_3)
DEFLABEL (set_x_image_descriptorB_0)
  INTERRUPT_CHECK (26, LABEL_222_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_222_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_222_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [2]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_222_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_223_4 3
#define ENVIRONMENT_LABEL_223_3 8
#define DEBUGGING_LABEL_223_2 7
#define OBJECT_223_2 6
#define OBJECT_223_1 5
#define OBJECT_223_0 4
#define FREE_REFERENCES_LABEL_223_0 4
#define NUMBER_OF_LINKER_SECTIONS_223_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_223 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_223_4);
      goto set_x_image_windowB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_image_windowB_3)
DEFLABEL (set_x_image_windowB_0)
  INTERRUPT_CHECK (26, LABEL_223_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_223_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_223_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_223_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_224_4 3
#define ENVIRONMENT_LABEL_224_3 8
#define DEBUGGING_LABEL_224_2 7
#define OBJECT_224_2 6
#define OBJECT_224_1 5
#define OBJECT_224_0 4
#define FREE_REFERENCES_LABEL_224_0 4
#define NUMBER_OF_LINKER_SECTIONS_224_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_224 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_224_4);
      goto set_x_image_widthB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_image_widthB_3)
DEFLABEL (set_x_image_widthB_0)
  INTERRUPT_CHECK (26, LABEL_224_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_224_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_224_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [4]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_224_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_225_4 3
#define ENVIRONMENT_LABEL_225_3 8
#define DEBUGGING_LABEL_225_2 7
#define OBJECT_225_2 6
#define OBJECT_225_1 5
#define OBJECT_225_0 4
#define FREE_REFERENCES_LABEL_225_0 4
#define NUMBER_OF_LINKER_SECTIONS_225_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_225 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_225_4);
      goto set_x_image_heightB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_x_image_heightB_3)
DEFLABEL (set_x_image_heightB_0)
  INTERRUPT_CHECK (26, LABEL_225_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_225_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_225_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_225_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_226_4 3
#define LABEL_226_7 5
#define LABEL_226_8 7
#define LABEL_226_9 9
#define LABEL_226_10 11
#define LABEL_226_11 13
#define LABEL_226_12 15
#define LABEL_226_13 17
#define LABEL_226_5 19
#define LABEL_226_16 21
#define LABEL_226_17 23
#define LABEL_226_18 25
#define LABEL_226_19 27
#define LABEL_226_6 29
#define LABEL_226_22 31
#define LABEL_226_15 33
#define LABEL_226_24 35
#define LABEL_226_21 37
#define ENVIRONMENT_LABEL_226_3 73
#define DEBUGGING_LABEL_226_2 72
#define OBJECT_226_9 71
#define OBJECT_226_8 70
#define OBJECT_226_7 69
#define OBJECT_226_6 68
#define OBJECT_226_5 67
#define OBJECT_226_4 66
#define OBJECT_226_3 65
#define OBJECT_226_2 64
#define OBJECT_226_1 63
#define OBJECT_226_0 62
#define EXECUTE_CACHE_226_25 39
#define EXECUTE_CACHE_226_23 41
#define EXECUTE_CACHE_226_20 43
#define EXECUTE_CACHE_226_14 45
#define FREE_REFERENCE_226_11 48
#define FREE_REFERENCE_226_10 49
#define FREE_REFERENCE_226_9 50
#define FREE_REFERENCE_226_8 51
#define FREE_REFERENCE_226_7 52
#define FREE_REFERENCE_226_6 53
#define FREE_REFERENCE_226_5 54
#define FREE_REFERENCE_226_4 55
#define FREE_REFERENCE_226_3 56
#define FREE_REFERENCE_226_2 57
#define FREE_REFERENCE_226_1 58
#define FREE_REFERENCE_226_0 59
#define FREE_ASSIGNMENT_226_0 61
#define FREE_REFERENCES_LABEL_226_0 38
#define NUMBER_OF_LINKER_SECTIONS_226_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_226 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd26;
  machine_word Wrd30;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd140;
  machine_word Wrd136;
  machine_word Wrd138;
  machine_word Wrd139;
  machine_word Wrd132;
  machine_word Wrd134;
  machine_word Wrd135;
  machine_word Wrd126;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd121;
  machine_word Wrd117;
  machine_word Wrd119;
  machine_word Wrd120;
  machine_word Wrd113;
  machine_word Wrd115;
  machine_word Wrd116;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd102;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd101;
  machine_word Wrd94;
  machine_word Wrd96;
  machine_word Wrd97;
  machine_word Wrd88;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd83;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd78;
  machine_word Wrd69;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd63;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd59;
  machine_word Wrd50;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_226_4);
      goto initialize_image_datatype_25;

    case 1:
      current_block = (Rpc - LABEL_226_7);
      goto label_27;

    case 2:
      current_block = (Rpc - LABEL_226_8);
      goto label_28;

    case 3:
      current_block = (Rpc - LABEL_226_9);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_226_10);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_226_11);
      goto label_31;

    case 6:
      current_block = (Rpc - LABEL_226_12);
      goto label_32;

    case 7:
      current_block = (Rpc - LABEL_226_13);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_226_5);
      goto continuation_23;

    case 9:
      current_block = (Rpc - LABEL_226_16);
      goto label_34;

    case 10:
      current_block = (Rpc - LABEL_226_17);
      goto label_35;

    case 11:
      current_block = (Rpc - LABEL_226_18);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_226_19);
      goto label_37;

    case 13:
      current_block = (Rpc - LABEL_226_6);
      goto continuation_22;

    case 14:
      current_block = (Rpc - LABEL_226_22);
      goto label_38;

    case 15:
      current_block = (Rpc - LABEL_226_15);
      goto continuation_24;

    case 16:
      current_block = (Rpc - LABEL_226_24);
      goto label_39;

    case 17:
      current_block = (Rpc - LABEL_226_21);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_image_datatype_41)
DEFLABEL (initialize_image_datatype_25)
  INTERRUPT_CHECK (26, LABEL_226_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_68;
  Wrd12 = Wrd16;

DEFLABEL (label_67)
  (Wrd21.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_226_1]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_1]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_66;
  Wrd31 = Wrd35;

DEFLABEL (label_65)
  (Wrd40.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (Wrd44.Obj) = (current_block [OBJECT_226_2]);
  (* (Rhp++)) = (Wrd44.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (Wrd45.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd47.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd47.pObj)));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_2]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_64;
  Wrd50 = Wrd54;

DEFLABEL (label_63)
  (Wrd59.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd50.Obj);
  (* (Rhp++)) = (Wrd59.Obj);
  (Wrd58.pObj) = (& (Rhp [-2]));
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd58.pObj)));
  (Wrd63.Obj) = (current_block [OBJECT_226_3]);
  (* (Rhp++)) = (Wrd63.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (Wrd62.pObj) = (& (Rhp [-2]));
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd62.pObj)));
  (Wrd64.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd60.Obj);
  (* (Rhp++)) = (Wrd64.Obj);
  (Wrd66.pObj) = (& (Rhp [-2]));
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd66.pObj)));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd70.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_3]));
  (Wrd73.Obj) = ((Wrd70.pObj) [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 50)
    goto label_62;
  Wrd69 = Wrd73;

DEFLABEL (label_61)
  (Wrd78.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd69.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd77.pObj) = (& (Rhp [-2]));
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd77.pObj)));
  (Wrd82.Obj) = (current_block [OBJECT_226_4]);
  (* (Rhp++)) = (Wrd82.Obj);
  (* (Rhp++)) = (Wrd75.Obj);
  (Wrd81.pObj) = (& (Rhp [-2]));
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd81.pObj)));
  (Wrd83.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd79.Obj);
  (* (Rhp++)) = (Wrd83.Obj);
  (Wrd85.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd85.pObj)));
  (* (--Rsp)) = (Wrd86.Obj);
  (Wrd89.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_4]));
  (Wrd92.Obj) = ((Wrd89.pObj) [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd93.uLng) == 50)
    goto label_60;
  Wrd88 = Wrd92;

DEFLABEL (label_59)
  (Wrd97.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd88.Obj);
  (* (Rhp++)) = (Wrd97.Obj);
  (Wrd96.pObj) = (& (Rhp [-2]));
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd96.pObj)));
  (Wrd101.Obj) = (current_block [OBJECT_226_5]);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd94.Obj);
  (Wrd100.pObj) = (& (Rhp [-2]));
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd100.pObj)));
  (Wrd102.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd98.Obj);
  (* (Rhp++)) = (Wrd102.Obj);
  (Wrd104.pObj) = (& (Rhp [-2]));
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd104.pObj)));
  (* (--Rsp)) = (Wrd105.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_5]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_58;
  Wrd107 = Wrd111;

DEFLABEL (label_57)
  (Wrd116.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd107.Obj);
  (* (Rhp++)) = (Wrd116.Obj);
  (Wrd115.pObj) = (& (Rhp [-2]));
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd115.pObj)));
  (Wrd120.Obj) = (current_block [OBJECT_226_6]);
  (* (Rhp++)) = (Wrd120.Obj);
  (* (Rhp++)) = (Wrd113.Obj);
  (Wrd119.pObj) = (& (Rhp [-2]));
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd119.pObj)));
  (Wrd121.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd117.Obj);
  (* (Rhp++)) = (Wrd121.Obj);
  (Wrd123.pObj) = (& (Rhp [-2]));
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd123.pObj)));
  (* (--Rsp)) = (Wrd124.Obj);
  (Wrd127.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_6]));
  (Wrd130.Obj) = ((Wrd127.pObj) [0]);
  (Wrd131.uLng) = (OBJECT_TYPE (Wrd130.Obj));
  if ((Wrd131.uLng) == 50)
    goto label_56;
  Wrd126 = Wrd130;

DEFLABEL (label_55)
  (Wrd135.Obj) = (current_block [OBJECT_226_0]);
  (* (Rhp++)) = (Wrd126.Obj);
  (* (Rhp++)) = (Wrd135.Obj);
  (Wrd134.pObj) = (& (Rhp [-2]));
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd134.pObj)));
  (Wrd139.Obj) = (current_block [OBJECT_226_7]);
  (* (Rhp++)) = (Wrd139.Obj);
  (* (Rhp++)) = (Wrd132.Obj);
  (Wrd138.pObj) = (& (Rhp [-2]));
  (Wrd136.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd138.pObj)));
  (Wrd140.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd136.Obj);
  (* (Rhp++)) = (Wrd140.Obj);
  (Wrd142.pObj) = (& (Rhp [-2]));
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd142.pObj)));
  (* (--Rsp)) = (Wrd143.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_226_14]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_226_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_226_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226_21]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_11]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_54;
  Wrd9 = Wrd13;

DEFLABEL (label_53)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_226_23]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_226_21);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_226_25]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_226_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_7]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_52;
  Wrd8 = Wrd12;

DEFLABEL (label_51)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_8]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_50;
  Wrd14 = Wrd18;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_9]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_48;
  Wrd20 = Wrd24;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_226_10]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_46;
  Wrd26 = Wrd30;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_226_20]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_226_15);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_226_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_44;

DEFLABEL (label_43)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_42)
  Rvl = (current_block [OBJECT_226_9]);
  goto pop_return;

DEFLABEL (label_44)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_43;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_226_24])), (Wrd6.pObj), Rvl);

DEFLABEL (label_39)
  goto label_42;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_19])), (Wrd27.pObj));

DEFLABEL (label_37)
  (Wrd26.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_18])), (Wrd21.pObj));

DEFLABEL (label_36)
  (Wrd20.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_17])), (Wrd15.pObj));

DEFLABEL (label_35)
  (Wrd14.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_16])), (Wrd9.pObj));

DEFLABEL (label_34)
  (Wrd8.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_22])), (Wrd10.pObj));

DEFLABEL (label_38)
  (Wrd9.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_13])), (Wrd127.pObj));

DEFLABEL (label_33)
  (Wrd126.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_12])), (Wrd108.pObj));

DEFLABEL (label_32)
  (Wrd107.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_11])), (Wrd89.pObj));

DEFLABEL (label_31)
  (Wrd88.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_10])), (Wrd70.pObj));

DEFLABEL (label_30)
  (Wrd69.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_9])), (Wrd51.pObj));

DEFLABEL (label_29)
  (Wrd50.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_8])), (Wrd32.pObj));

DEFLABEL (label_28)
  (Wrd31.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226_7])), (Wrd13.pObj));

DEFLABEL (label_27)
  (Wrd12.Obj) = Rvl;
  goto label_67;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_227_4 3
#define LABEL_227_5 5
#define LABEL_227_6 7
#define LABEL_227_7 9
#define LABEL_227_9 11
#define LABEL_227_8 13
#define ENVIRONMENT_LABEL_227_3 26
#define DEBUGGING_LABEL_227_2 25
#define OBJECT_227_3 24
#define OBJECT_227_2 23
#define OBJECT_227_1 22
#define OBJECT_227_0 21
#define EXECUTE_CACHE_227_11 15
#define EXECUTE_CACHE_227_10 17
#define FREE_REFERENCE_227_0 20
#define FREE_REFERENCES_LABEL_227_0 14
#define NUMBER_OF_LINKER_SECTIONS_227_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_227 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_227_4);
      goto create_x_image_5;

    case 1:
      current_block = (Rpc - LABEL_227_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_227_6);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_227_7);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_227_9);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_227_8);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (create_x_image_11)
DEFLABEL (create_x_image_5)
  INTERRUPT_CHECK (26, LABEL_227_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_17;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_17;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_16)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_15;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_15;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_14)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_227_3]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_227_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_227_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_227_7);
  (Rsp [3]) = Rvl;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_227_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_13;
  Wrd7 = Wrd11;

DEFLABEL (label_12)
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_227_10]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_227_9])), (Wrd8.pObj));

DEFLABEL (label_9)
  (Wrd7.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd30.Obj) = (current_block [OBJECT_227_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_227_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_227_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_227_1]), 2);

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_228_4 3
#define LABEL_228_5 5
#define ENVIRONMENT_LABEL_228_3 12
#define DEBUGGING_LABEL_228_2 11
#define EXECUTE_CACHE_228_6 7
#define FREE_REFERENCE_228_0 10
#define FREE_REFERENCES_LABEL_228_0 6
#define NUMBER_OF_LINKER_SECTIONS_228_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_228 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_228_4);
      goto x_image_destroy_0;

    case 1:
      current_block = (Rpc - LABEL_228_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_destroy_4)
DEFLABEL (x_image_destroy_0)
  INTERRUPT_CHECK (26, LABEL_228_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_228_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_228_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_228_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_229_4 3
#define LABEL_229_5 5
#define ENVIRONMENT_LABEL_229_3 10
#define DEBUGGING_LABEL_229_2 9
#define OBJECT_229_2 8
#define OBJECT_229_1 7
#define OBJECT_229_0 6
#define FREE_REFERENCES_LABEL_229_0 6
#define NUMBER_OF_LINKER_SECTIONS_229_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_229 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_229_4);
      goto x_image_get_pixel_1;

    case 1:
      current_block = (Rpc - LABEL_229_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_get_pixel_5)
DEFLABEL (x_image_get_pixel_1)
  INTERRUPT_CHECK (26, LABEL_229_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_229_2]), 3);

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_229_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_229_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_229_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_230_4 3
#define LABEL_230_5 5
#define ENVIRONMENT_LABEL_230_3 10
#define DEBUGGING_LABEL_230_2 9
#define OBJECT_230_2 8
#define OBJECT_230_1 7
#define OBJECT_230_0 6
#define FREE_REFERENCES_LABEL_230_0 6
#define NUMBER_OF_LINKER_SECTIONS_230_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_230 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_230_4);
      goto x_image_set_pixel_1;

    case 1:
      current_block = (Rpc - LABEL_230_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_set_pixel_5)
DEFLABEL (x_image_set_pixel_1)
  INTERRUPT_CHECK (26, LABEL_230_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_230_2]), 4);

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_230_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_230_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_230_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_231_4 3
#define LABEL_231_5 5
#define LABEL_231_7 7
#define LABEL_231_8 9
#define LABEL_231_9 11
#define LABEL_231_10 13
#define LABEL_231_11 15
#define ENVIRONMENT_LABEL_231_3 27
#define DEBUGGING_LABEL_231_2 26
#define OBJECT_231_6 25
#define OBJECT_231_5 24
#define OBJECT_231_4 23
#define OBJECT_231_3 22
#define OBJECT_231_2 21
#define OBJECT_231_1 20
#define OBJECT_231_0 19
#define EXECUTE_CACHE_231_6 17
#define FREE_REFERENCES_LABEL_231_0 16
#define NUMBER_OF_LINKER_SECTIONS_231_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_231 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd39;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_231_4);
      goto x_image_draw_6;

    case 1:
      current_block = (Rpc - LABEL_231_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_231_7);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_231_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_231_9);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_231_10);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_231_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_draw_13)
DEFLABEL (x_image_draw_6)
  INTERRUPT_CHECK (26, LABEL_231_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_231_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_231_5);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_21;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_21;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_20)
  (Wrd21.Obj) = (current_block [OBJECT_231_2]);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_19;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_19;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_18)
  (Wrd48.Obj) = (Rsp [5]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 62))
    goto label_17;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd47.Lng))))
    goto label_17;
  (Wrd39.Obj) = ((Wrd45.pObj) [4]);

DEFLABEL (label_16)
  (Rsp [6]) = (Wrd39.Obj);
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 62))
    goto label_15;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd63.Lng))))
    goto label_15;
  (Wrd57.Obj) = ((Wrd61.pObj) [5]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_14)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_11]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd74.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_231_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_231_11);
  (Rsp [6]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [7]) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_231_6]), 8);

DEFLABEL (label_15)
  (Wrd66.Obj) = (Rsp [5]);
  (Wrd67.Obj) = (current_block [OBJECT_231_5]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_10]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_231_1]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd50.Obj) = (Rsp [5]);
  (Wrd51.Obj) = (current_block [OBJECT_231_4]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_9]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_231_1]), 2);

DEFLABEL (label_10)
  (Wrd39.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.Obj) = (current_block [OBJECT_231_3]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_8]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_231_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_231_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_231_1]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_232_4 3
#define LABEL_232_5 5
#define LABEL_232_7 7
#define LABEL_232_8 9
#define LABEL_232_9 11
#define ENVIRONMENT_LABEL_232_3 20
#define DEBUGGING_LABEL_232_2 19
#define OBJECT_232_3 18
#define OBJECT_232_2 17
#define OBJECT_232_1 16
#define OBJECT_232_0 15
#define EXECUTE_CACHE_232_6 13
#define FREE_REFERENCES_LABEL_232_0 12
#define NUMBER_OF_LINKER_SECTIONS_232_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_232 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_232_4);
      goto x_image_draw_subimage_4;

    case 1:
      current_block = (Rpc - LABEL_232_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_232_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_232_8);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_232_9);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_draw_subimage_9)
DEFLABEL (x_image_draw_subimage_4)
  INTERRUPT_CHECK (26, LABEL_232_4);
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_232_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_232_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_232_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_232_7);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_13;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_12)
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd32.Obj) = (Rsp [7]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_11;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_11;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_10)
  (Wrd39.pObj) = (& (Rsp [15]));
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [8]));
    SCHEME_OBJECT * MFUp2 = (Wrd39.pObj);
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  INVOKE_PRIMITIVE ((current_block [OBJECT_232_3]), 8);

DEFLABEL (label_11)
  (Wrd34.Obj) = (Rsp [7]);
  (Wrd35.Obj) = (current_block [OBJECT_232_2]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232_9]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_232_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_232_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_232_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_233_4 3
#define LABEL_233_5 5
#define ENVIRONMENT_LABEL_233_3 10
#define DEBUGGING_LABEL_233_2 9
#define OBJECT_233_2 8
#define OBJECT_233_1 7
#define OBJECT_233_0 6
#define FREE_REFERENCES_LABEL_233_0 6
#define NUMBER_OF_LINKER_SECTIONS_233_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_233 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_233_4);
      goto x_image_fill_from_byte_vector_1;

    case 1:
      current_block = (Rpc - LABEL_233_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_image_fill_from_byte_vector_5)
DEFLABEL (x_image_fill_from_byte_vector_1)
  INTERRUPT_CHECK (26, LABEL_233_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_6)
  (Wrd21.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd21.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_233_2]), 2);

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_233_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_233_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_233_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_234_4 3
#define ENVIRONMENT_LABEL_234_3 8
#define DEBUGGING_LABEL_234_2 7
#define EXECUTE_CACHE_234_5 5
#define FREE_REFERENCES_LABEL_234_0 4
#define NUMBER_OF_LINKER_SECTIONS_234_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_234 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_234_4);
      goto x_graphics_create_image_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_create_image_3)
DEFLABEL (x_graphics_create_image_0)
  INTERRUPT_CHECK (26, LABEL_234_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_234_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_235_4 3
#define LABEL_235_5 5
#define ENVIRONMENT_LABEL_235_3 12
#define DEBUGGING_LABEL_235_2 11
#define OBJECT_235_1 10
#define OBJECT_235_0 9
#define EXECUTE_CACHE_235_6 7
#define FREE_REFERENCES_LABEL_235_0 6
#define NUMBER_OF_LINKER_SECTIONS_235_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_235 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_235_4);
      goto x_graphics_image_destroy_1;

    case 1:
      current_block = (Rpc - LABEL_235_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_destroy_5)
DEFLABEL (x_graphics_image_destroy_1)
  INTERRUPT_CHECK (26, LABEL_235_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_235_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_235_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_235_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_235_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_236_4 3
#define LABEL_236_5 5
#define ENVIRONMENT_LABEL_236_3 10
#define DEBUGGING_LABEL_236_2 9
#define OBJECT_236_2 8
#define OBJECT_236_1 7
#define OBJECT_236_0 6
#define FREE_REFERENCES_LABEL_236_0 6
#define NUMBER_OF_LINKER_SECTIONS_236_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_236 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_236_4);
      goto x_graphics_image_width_1;

    case 1:
      current_block = (Rpc - LABEL_236_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_width_5)
DEFLABEL (x_graphics_image_width_1)
  INTERRUPT_CHECK (26, LABEL_236_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_236_2]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_236_1]), 2);

DEFLABEL (label_7)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd31.Lng))))
    goto label_6;
  Rvl = ((Wrd29.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_236_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_236_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_236_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_237_4 3
#define LABEL_237_5 5
#define ENVIRONMENT_LABEL_237_3 10
#define DEBUGGING_LABEL_237_2 9
#define OBJECT_237_2 8
#define OBJECT_237_1 7
#define OBJECT_237_0 6
#define FREE_REFERENCES_LABEL_237_0 6
#define NUMBER_OF_LINKER_SECTIONS_237_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_237 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_237_4);
      goto x_graphics_image_height_1;

    case 1:
      current_block = (Rpc - LABEL_237_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_height_5)
DEFLABEL (x_graphics_image_height_1)
  INTERRUPT_CHECK (26, LABEL_237_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_9;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_8)
  (Wrd21.Obj) = (current_block [OBJECT_237_2]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 62)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_237_1]), 2);

DEFLABEL (label_7)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd31.Lng))))
    goto label_6;
  Rvl = ((Wrd29.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_237_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_237_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_237_1]), 2);

DEFLABEL (label_3)
  (* (--Rsp)) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_238_4 3
#define LABEL_238_5 5
#define LABEL_238_6 7
#define LABEL_238_7 9
#define LABEL_238_8 11
#define LABEL_238_9 13
#define LABEL_238_10 15
#define LABEL_238_11 17
#define LABEL_238_13 19
#define ENVIRONMENT_LABEL_238_3 31
#define DEBUGGING_LABEL_238_2 30
#define OBJECT_238_6 29
#define OBJECT_238_5 28
#define OBJECT_238_4 27
#define OBJECT_238_3 26
#define OBJECT_238_2 25
#define OBJECT_238_1 24
#define OBJECT_238_0 23
#define EXECUTE_CACHE_238_12 21
#define FREE_REFERENCES_LABEL_238_0 20
#define NUMBER_OF_LINKER_SECTIONS_238_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_238 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd85;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd92;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd69;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_238_4);
      goto x_graphics_image_draw_11;

    case 1:
      current_block = (Rpc - LABEL_238_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_238_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_238_7);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_238_8);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_238_9);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_238_10);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_238_11);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_238_13);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_draw_20)
DEFLABEL (x_graphics_image_draw_11)
  INTERRUPT_CHECK (26, LABEL_238_4);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_32;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_32;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_31)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_30;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd29.Lng))))
    goto label_30;
  (Wrd23.Obj) = ((Wrd27.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_29)
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 62))
    goto label_28;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_28;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_27)
  (Wrd62.Obj) = (Rsp [2]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 62))
    goto label_26;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd61.Lng))))
    goto label_26;
  (Wrd55.Obj) = ((Wrd59.pObj) [2]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_25)
  (Wrd78.Obj) = (Rsp [4]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 62))
    goto label_24;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd77.Lng))))
    goto label_24;
  (Wrd69.Obj) = ((Wrd75.pObj) [3]);

DEFLABEL (label_23)
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd92.uLng) == 62))
    goto label_22;
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd90.Obj) = ((Wrd89.pObj) [0]);
  (Wrd91.Lng) = (FIXNUM_TO_LONG (Wrd90.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd91.Lng))))
    goto label_22;
  (Wrd85.Obj) = ((Wrd89.pObj) [2]);

DEFLABEL (label_21)
  (Rsp [3]) = (Wrd85.Obj);
  (Wrd98.Obj) = (Rsp [1]);
  (Rsp [7]) = (Wrd98.Obj);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_11]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (Wrd102.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd102.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_238_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_238_11);
  (Rsp [4]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_238_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_238_13);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [6]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_238_5]);
  (Rsp [2]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_6]), 8);

DEFLABEL (label_22)
  (Wrd94.Obj) = (current_block [OBJECT_238_4]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_10]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_18)
  (Wrd85.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd80.Obj) = (Rsp [4]);
  (Wrd81.Obj) = (current_block [OBJECT_238_0]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_9]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_17)
  (Wrd69.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd64.Obj) = (Rsp [2]);
  (Wrd65.Obj) = (current_block [OBJECT_238_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_8]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd48.Obj) = (Rsp [1]);
  (Wrd49.Obj) = (current_block [OBJECT_238_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_7]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (current_block [OBJECT_238_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_238_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_238_1]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_239_4 3
#define LABEL_239_5 5
#define LABEL_239_6 7
#define LABEL_239_7 9
#define LABEL_239_8 11
#define LABEL_239_10 13
#define LABEL_239_11 15
#define ENVIRONMENT_LABEL_239_3 24
#define DEBUGGING_LABEL_239_2 23
#define OBJECT_239_3 22
#define OBJECT_239_2 21
#define OBJECT_239_1 20
#define OBJECT_239_0 19
#define EXECUTE_CACHE_239_9 17
#define FREE_REFERENCES_LABEL_239_0 16
#define NUMBER_OF_LINKER_SECTIONS_239_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_239 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd37;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_239_4);
      goto x_graphics_image_draw_subimage_7;

    case 1:
      current_block = (Rpc - LABEL_239_5);
      goto label_9;

    case 2:
      current_block = (Rpc - LABEL_239_6);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_239_7);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_239_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_239_10);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_239_11);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_draw_subimage_14)
DEFLABEL (x_graphics_image_draw_subimage_7)
  INTERRUPT_CHECK (26, LABEL_239_4);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_22;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_22;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_21)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_20;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_20;
  (Wrd21.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_19)
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd44.uLng) == 62))
    goto label_18;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd43.Lng))))
    goto label_18;
  (Wrd37.Obj) = ((Wrd41.pObj) [2]);

DEFLABEL (label_17)
  (Rsp [4]) = (Wrd37.Obj);
  (Wrd50.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_8]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_239_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_239_8);
  (Rsp [6]) = Rvl;
  (Wrd6.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_239_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_239_10);
  (Rsp [8]) = Rvl;
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_16;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_16;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_15)
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd22.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd22.Obj);
  (Wrd23.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd23.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_239_3]), 8);

DEFLABEL (label_16)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.Obj) = (current_block [OBJECT_239_2]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_11]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_239_1]), 2);

DEFLABEL (label_12)
  (Wrd6.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd46.Obj) = (current_block [OBJECT_239_2]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_7]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_239_1]), 2);

DEFLABEL (label_11)
  (Wrd37.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_239_0]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_239_1]), 2);

DEFLABEL (label_10)
  (Wrd21.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_239_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_239_1]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_240_4 3
#define LABEL_240_5 5
#define ENVIRONMENT_LABEL_240_3 12
#define DEBUGGING_LABEL_240_2 11
#define OBJECT_240_1 10
#define OBJECT_240_0 9
#define EXECUTE_CACHE_240_6 7
#define FREE_REFERENCES_LABEL_240_0 6
#define NUMBER_OF_LINKER_SECTIONS_240_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_240 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_240_4);
      goto x_graphics_image_fill_from_byte_vector_1;

    case 1:
      current_block = (Rpc - LABEL_240_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_fill_from_byte_vector_5)
DEFLABEL (x_graphics_image_fill_from_byte_vector_1)
  INTERRUPT_CHECK (26, LABEL_240_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_240_6]));

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_240_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_240_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_240_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_241_4 3
#define ENVIRONMENT_LABEL_241_3 5
#define DEBUGGING_LABEL_241_2 4
#define FREE_REFERENCES_LABEL_241_0 4
#define NUMBER_OF_LINKER_SECTIONS_241_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_241 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_241_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_241_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_242_4 3
#define ENVIRONMENT_LABEL_242_3 5
#define DEBUGGING_LABEL_242_2 4
#define FREE_REFERENCES_LABEL_242_0 4
#define NUMBER_OF_LINKER_SECTIONS_242_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_242 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_242_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_242_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_243_4 3
#define ENVIRONMENT_LABEL_243_3 5
#define DEBUGGING_LABEL_243_2 4
#define FREE_REFERENCES_LABEL_243_0 4
#define NUMBER_OF_LINKER_SECTIONS_243_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_243 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_243_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_243_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_244_4 3
#define ENVIRONMENT_LABEL_244_3 5
#define DEBUGGING_LABEL_244_2 4
#define FREE_REFERENCES_LABEL_244_0 4
#define NUMBER_OF_LINKER_SECTIONS_244_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_244 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_244_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_244_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_245_4 3
#define ENVIRONMENT_LABEL_245_3 5
#define DEBUGGING_LABEL_245_2 4
#define FREE_REFERENCES_LABEL_245_0 4
#define NUMBER_OF_LINKER_SECTIONS_245_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_245 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_245_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_245_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_246_4 3
#define ENVIRONMENT_LABEL_246_3 5
#define DEBUGGING_LABEL_246_2 4
#define FREE_REFERENCES_LABEL_246_0 4
#define NUMBER_OF_LINKER_SECTIONS_246_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_246 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_246_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_246_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_247_4 3
#define ENVIRONMENT_LABEL_247_3 5
#define DEBUGGING_LABEL_247_2 4
#define FREE_REFERENCES_LABEL_247_0 4
#define NUMBER_OF_LINKER_SECTIONS_247_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_247 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_247_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_247_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_248_4 3
#define ENVIRONMENT_LABEL_248_3 5
#define DEBUGGING_LABEL_248_2 4
#define FREE_REFERENCES_LABEL_248_0 4
#define NUMBER_OF_LINKER_SECTIONS_248_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_248 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_248_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_248_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_249_4 3
#define ENVIRONMENT_LABEL_249_3 5
#define DEBUGGING_LABEL_249_2 4
#define FREE_REFERENCES_LABEL_249_0 4
#define NUMBER_OF_LINKER_SECTIONS_249_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_249 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_249_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_249_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_250_4 3
#define ENVIRONMENT_LABEL_250_3 5
#define DEBUGGING_LABEL_250_2 4
#define FREE_REFERENCES_LABEL_250_0 4
#define NUMBER_OF_LINKER_SECTIONS_250_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_250 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_250_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_250_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_251_4 3
#define LABEL_251_6 5
#define LABEL_251_7 7
#define LABEL_251_8 9
#define LABEL_251_9 11
#define LABEL_251_5 13
#define LABEL_251_11 15
#define ENVIRONMENT_LABEL_251_3 28
#define DEBUGGING_LABEL_251_2 27
#define OBJECT_251_0 26
#define EXECUTE_CACHE_251_10 17
#define FREE_REFERENCE_251_3 20
#define FREE_REFERENCE_251_2 21
#define FREE_REFERENCE_251_1 22
#define FREE_REFERENCE_251_0 23
#define FREE_ASSIGNMENT_251_0 25
#define FREE_REFERENCES_LABEL_251_0 16
#define NUMBER_OF_LINKER_SECTIONS_251_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_251 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_251_4);
      goto initialize_colormap_datatype_1;

    case 1:
      current_block = (Rpc - LABEL_251_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_251_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_251_8);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_251_9);
      goto label_6;

    case 5:
      current_block = (Rpc - LABEL_251_5);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_251_11);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_colormap_datatype_9)
DEFLABEL (initialize_colormap_datatype_1)
  INTERRUPT_CHECK (26, LABEL_251_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_251_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_251_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_20;
  Wrd8 = Wrd12;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_251_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_18;
  Wrd14 = Wrd18;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_251_2]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_16;
  Wrd20 = Wrd24;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_251_3]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_14;
  Wrd26 = Wrd30;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_251_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_251_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_251_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_12;

DEFLABEL (label_11)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_251_0]);
  goto pop_return;

DEFLABEL (label_12)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_11;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_251_11])), (Wrd6.pObj), Rvl);

DEFLABEL (label_7)
  goto label_10;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_251_9])), (Wrd27.pObj));

DEFLABEL (label_6)
  (Wrd26.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_251_8])), (Wrd21.pObj));

DEFLABEL (label_5)
  (Wrd20.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_251_7])), (Wrd15.pObj));

DEFLABEL (label_4)
  (Wrd14.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_251_6])), (Wrd9.pObj));

DEFLABEL (label_3)
  (Wrd8.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_252_4 3
#define LABEL_252_5 5
#define LABEL_252_6 7
#define ENVIRONMENT_LABEL_252_3 16
#define DEBUGGING_LABEL_252_2 15
#define EXECUTE_CACHE_252_8 9
#define EXECUTE_CACHE_252_7 11
#define FREE_REFERENCE_252_0 14
#define FREE_REFERENCES_LABEL_252_0 8
#define NUMBER_OF_LINKER_SECTIONS_252_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_252 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_252_4);
      goto make_colormap_1;

    case 1:
      current_block = (Rpc - LABEL_252_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_252_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_colormap_5)
DEFLABEL (make_colormap_1)
  INTERRUPT_CHECK (26, LABEL_252_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_252_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_7;
  Wrd5 = Wrd9;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_252_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_252_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_252_6);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_252_8]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_252_5])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_253_4 3
#define LABEL_253_6 5
#define LABEL_253_7 7
#define LABEL_253_5 9
#define ENVIRONMENT_LABEL_253_3 18
#define DEBUGGING_LABEL_253_2 17
#define OBJECT_253_3 16
#define OBJECT_253_2 15
#define OBJECT_253_1 14
#define OBJECT_253_0 13
#define EXECUTE_CACHE_253_8 11
#define FREE_REFERENCES_LABEL_253_0 10
#define NUMBER_OF_LINKER_SECTIONS_253_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_253 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_253_4);
      goto x_graphics_get_colormap_3;

    case 1:
      current_block = (Rpc - LABEL_253_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_253_7);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_253_5);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_get_colormap_8)
DEFLABEL (x_graphics_get_colormap_3)
  INTERRUPT_CHECK (26, LABEL_253_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_12;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_12;
  (Wrd8.Obj) = ((Wrd14.pObj) [3]);

DEFLABEL (label_11)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_10;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_10;
  (Wrd25.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_253_3]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_253_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_253_8]));

DEFLABEL (label_10)
  (Wrd33.Obj) = (current_block [OBJECT_253_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_253_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_253_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_253_1]), 2);

DEFLABEL (label_5)
  (Wrd8.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_254_4 3
#define LABEL_254_5 5
#define LABEL_254_6 7
#define LABEL_254_7 9
#define ENVIRONMENT_LABEL_254_3 18
#define DEBUGGING_LABEL_254_2 17
#define OBJECT_254_3 16
#define OBJECT_254_2 15
#define OBJECT_254_1 14
#define OBJECT_254_0 13
#define EXECUTE_CACHE_254_8 11
#define FREE_REFERENCES_LABEL_254_0 10
#define NUMBER_OF_LINKER_SECTIONS_254_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_254 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_254_4);
      goto x_graphics_set_colormap_3;

    case 1:
      current_block = (Rpc - LABEL_254_5);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_254_6);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_254_7);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_set_colormap_8)
DEFLABEL (x_graphics_set_colormap_3)
  INTERRUPT_CHECK (26, LABEL_254_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_12;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_12;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_11)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_10;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_10;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd21.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_254_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_254_7);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_254_3]), 2);

DEFLABEL (label_10)
  (Wrd30.Obj) = (current_block [OBJECT_254_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_254_1]), 2);

DEFLABEL (label_6)
  (Wrd21.Obj) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_254_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_254_1]), 2);

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_255_4 3
#define LABEL_255_5 5
#define LABEL_255_6 7
#define LABEL_255_7 9
#define LABEL_255_8 11
#define LABEL_255_9 13
#define ENVIRONMENT_LABEL_255_3 24
#define DEBUGGING_LABEL_255_2 23
#define OBJECT_255_5 22
#define OBJECT_255_4 21
#define OBJECT_255_3 20
#define OBJECT_255_2 19
#define OBJECT_255_1 18
#define OBJECT_255_0 17
#define EXECUTE_CACHE_255_10 15
#define FREE_REFERENCES_LABEL_255_0 14
#define NUMBER_OF_LINKER_SECTIONS_255_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_255 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_255_4);
      goto create_x_colormap_8;

    case 1:
      current_block = (Rpc - LABEL_255_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_255_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_255_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_255_8);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_255_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (create_x_colormap_13)
DEFLABEL (create_x_colormap_8)
  INTERRUPT_CHECK (26, LABEL_255_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_17;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_17;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_16)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_15;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_15;
  (Wrd22.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_14)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_255_3]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_255_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_255_4]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_255_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_255_5]), 1);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_255_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd5.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_255_10]));

DEFLABEL (label_15)
  (Wrd30.Obj) = (current_block [OBJECT_255_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_255_1]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_255_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_255_1]), 2);

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_256_4 3
#define LABEL_256_5 5
#define ENVIRONMENT_LABEL_256_3 12
#define DEBUGGING_LABEL_256_2 11
#define EXECUTE_CACHE_256_6 7
#define FREE_REFERENCE_256_0 10
#define FREE_REFERENCES_LABEL_256_0 6
#define NUMBER_OF_LINKER_SECTIONS_256_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_256 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_256_4);
      goto x_colormap_free_0;

    case 1:
      current_block = (Rpc - LABEL_256_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_colormap_free_4)
DEFLABEL (x_colormap_free_0)
  INTERRUPT_CHECK (26, LABEL_256_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_256_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_256_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_256_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_257_4 3
#define LABEL_257_5 5
#define ENVIRONMENT_LABEL_257_3 11
#define DEBUGGING_LABEL_257_2 10
#define OBJECT_257_0 9
#define EXECUTE_CACHE_257_6 7
#define FREE_REFERENCES_LABEL_257_0 6
#define NUMBER_OF_LINKER_SECTIONS_257_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_257 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_257_4);
      goto x_colormap_allocate_color_1;

    case 1:
      current_block = (Rpc - LABEL_257_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_colormap_allocate_color_4)
DEFLABEL (x_colormap_allocate_color_1)
  INTERRUPT_CHECK (26, LABEL_257_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_257_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_257_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_257_5);
  (Rsp [0]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_257_0]), 4);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_258_4 3
#define LABEL_258_5 5
#define ENVIRONMENT_LABEL_258_3 11
#define DEBUGGING_LABEL_258_2 10
#define OBJECT_258_0 9
#define EXECUTE_CACHE_258_6 7
#define FREE_REFERENCES_LABEL_258_0 6
#define NUMBER_OF_LINKER_SECTIONS_258_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_258 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_258_4);
      goto x_colormap_query_color_1;

    case 1:
      current_block = (Rpc - LABEL_258_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_colormap_query_color_4)
DEFLABEL (x_colormap_query_color_1)
  INTERRUPT_CHECK (26, LABEL_258_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_258_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_258_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_258_5);
  (Rsp [0]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_258_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_259_4 3
#define LABEL_259_5 5
#define ENVIRONMENT_LABEL_259_3 11
#define DEBUGGING_LABEL_259_2 10
#define OBJECT_259_0 9
#define EXECUTE_CACHE_259_6 7
#define FREE_REFERENCES_LABEL_259_0 6
#define NUMBER_OF_LINKER_SECTIONS_259_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_259 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_259_4);
      goto x_colormap_store_color_1;

    case 1:
      current_block = (Rpc - LABEL_259_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_colormap_store_color_4)
DEFLABEL (x_colormap_store_color_1)
  INTERRUPT_CHECK (26, LABEL_259_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_259_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_259_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_259_5);
  (Rsp [0]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_259_0]), 5);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_260_4 3
#define LABEL_260_5 5
#define ENVIRONMENT_LABEL_260_3 11
#define DEBUGGING_LABEL_260_2 10
#define OBJECT_260_0 9
#define EXECUTE_CACHE_260_6 7
#define FREE_REFERENCES_LABEL_260_0 6
#define NUMBER_OF_LINKER_SECTIONS_260_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_260 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_260_4);
      goto x_colormap_store_colors_1;

    case 1:
      current_block = (Rpc - LABEL_260_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_colormap_store_colors_4)
DEFLABEL (x_colormap_store_colors_1)
  INTERRUPT_CHECK (26, LABEL_260_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_260_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_260_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_260_5);
  (Rsp [0]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_260_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_261_4 3
#define LABEL_261_5 5
#define LABEL_261_7 7
#define LABEL_261_8 9
#define LABEL_261_9 11
#define LABEL_261_10 13
#define ENVIRONMENT_LABEL_261_3 27
#define DEBUGGING_LABEL_261_2 26
#define OBJECT_261_8 25
#define OBJECT_261_7 24
#define OBJECT_261_6 23
#define OBJECT_261_5 22
#define OBJECT_261_4 21
#define OBJECT_261_3 20
#define OBJECT_261_2 19
#define OBJECT_261_1 18
#define OBJECT_261_0 17
#define EXECUTE_CACHE_261_6 15
#define FREE_REFERENCES_LABEL_261_0 14
#define NUMBER_OF_LINKER_SECTIONS_261_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_261 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd55;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd61;
  machine_word Wrd42;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_261_4);
      goto x_graphics_colorP_17;

    case 1:
      current_block = (Rpc - LABEL_261_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_261_7);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_261_8);
      goto loop_13;

    case 4:
      current_block = (Rpc - LABEL_261_9);
      goto label_20;

    case 5:
      current_block = (Rpc - LABEL_261_10);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_colorP_23)
DEFLABEL (x_graphics_colorP_17)
  INTERRUPT_CHECK (26, LABEL_261_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_261_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_261_5);
  (Rsp [0]) = Rvl;
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 10))
    goto label_26;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (Wrd10.Obj) = (MAKE_OBJECT (26, (Wrd9.uLng)));
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_25)
  (Wrd17.Obj) = (current_block [OBJECT_261_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  goto loop_13;

DEFLABEL (label_26)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_261_0]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (loop_24)
DEFLABEL (loop_13)
  INTERRUPT_CHECK (26, LABEL_261_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_27;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_37;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_37;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd20.Lng))))
    goto label_37;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd12.pObj) = (& ((Wrd18.pObj) [(Wrd9.Lng)]));
  (Wrd7.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_36)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_35;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd34.Lng))))
    goto label_35;
  (Wrd29.Obj) = ((Wrd32.pObj) [5]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_34)
  (Wrd42.Obj) = (Rsp [0]);
  if ((Wrd42.Obj) == (current_block [OBJECT_261_4]))
    goto label_33;
  if ((Wrd42.Obj) == (current_block [OBJECT_261_5]))
    goto label_33;
  if ((Wrd42.Obj) == (current_block [OBJECT_261_3]))
    goto label_33;
  if ((Wrd42.Obj) == (current_block [OBJECT_261_7]))
    goto label_29;
  (Wrd48.Obj) = (current_block [OBJECT_261_8]);
  goto label_28;

DEFLABEL (label_29)
  (Wrd48.Obj) = (current_block [OBJECT_261_6]);

DEFLABEL (label_28)
DEFLABEL (label_32)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_31)
  (Wrd51.Obj) = (Rsp [0]);
  if ((Wrd51.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  Rvl = (Wrd51.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_30)
  (Wrd56.Obj) = (Rsp [1]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  (Wrd58.Lng) = ((Wrd57.Lng) + 1L);
  (Wrd55.Obj) = (LONG_TO_FIXNUM (Wrd58.Lng));
  (Rsp [1]) = (Wrd55.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_13;

DEFLABEL (label_33)
  (Wrd61.Obj) = (current_block [OBJECT_261_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd61.Obj);
  goto label_31;

DEFLABEL (label_35)
  (Wrd37.Obj) = (current_block [OBJECT_261_3]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261_10]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_261_2]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261_9]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_261_2]), 2);

DEFLABEL (label_20)
  (Wrd7.Obj) = Rvl;
  goto label_36;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_262_4 3
#define LABEL_262_5 5
#define LABEL_262_6 7
#define ENVIRONMENT_LABEL_262_3 13
#define DEBUGGING_LABEL_262_2 12
#define OBJECT_262_3 11
#define OBJECT_262_2 10
#define OBJECT_262_1 9
#define OBJECT_262_0 8
#define FREE_REFERENCES_LABEL_262_0 8
#define NUMBER_OF_LINKER_SECTIONS_262_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_262 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_262_4);
      goto x_graphics_image_depth_2;

    case 1:
      current_block = (Rpc - LABEL_262_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_262_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_image_depth_7)
DEFLABEL (x_graphics_image_depth_2)
  INTERRUPT_CHECK (26, LABEL_262_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_10)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_9;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd27.Lng))))
    goto label_9;
  (Wrd21.Obj) = ((Wrd25.pObj) [2]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_262_3]), 1);

DEFLABEL (label_9)
  (Wrd30.Obj) = (current_block [OBJECT_262_2]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262_6]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_262_1]), 2);

DEFLABEL (label_5)
  (Wrd21.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_262_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_262_1]), 2);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_263_4 3
#define LABEL_263_5 5
#define LABEL_263_6 7
#define ENVIRONMENT_LABEL_263_3 13
#define DEBUGGING_LABEL_263_2 12
#define OBJECT_263_3 11
#define OBJECT_263_2 10
#define OBJECT_263_1 9
#define OBJECT_263_0 8
#define FREE_REFERENCES_LABEL_263_0 8
#define NUMBER_OF_LINKER_SECTIONS_263_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_263 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd13;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd22;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_263_4);
      goto x_graphics_visual_info_2;

    case 1:
      current_block = (Rpc - LABEL_263_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_263_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_graphics_visual_info_7)
DEFLABEL (x_graphics_visual_info_2)
  INTERRUPT_CHECK (26, LABEL_263_4);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.Obj) = (Rsp [8]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 62))
    goto label_11;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd21.Lng))))
    goto label_11;
  (Wrd13.Obj) = ((Wrd19.pObj) [3]);

DEFLABEL (label_10)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_9;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_9;
  (Wrd30.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_8)
  (Rsp [9]) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_263_3]), 10);

DEFLABEL (label_9)
  (Wrd38.Obj) = (current_block [OBJECT_263_2]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_263_6]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_263_1]), 2);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_8;

DEFLABEL (label_11)
  (Wrd24.Obj) = (Rsp [8]);
  (Wrd25.Obj) = (current_block [OBJECT_263_0]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_263_5]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_263_1]), 2);

DEFLABEL (label_4)
  (Wrd13.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_264_4 3
#define ENVIRONMENT_LABEL_264_3 5
#define DEBUGGING_LABEL_264_2 4
#define FREE_REFERENCES_LABEL_264_0 4
#define NUMBER_OF_LINKER_SECTIONS_264_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_264 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_264_4);
      goto make_visual_info_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_visual_info_3)
DEFLABEL (make_visual_info_0)
  INTERRUPT_CHECK (26, LABEL_264_4);
  (Wrd18.Obj) = (MAKE_OBJECT (0, 10));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.Obj) = (Rsp [4]);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (Wrd10.Obj) = (Rsp [8]);
  (Wrd11.Obj) = (Rsp [9]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-11]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [10]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_265_4 3
#define ENVIRONMENT_LABEL_265_3 7
#define DEBUGGING_LABEL_265_2 6
#define OBJECT_265_1 5
#define OBJECT_265_0 4
#define FREE_REFERENCES_LABEL_265_0 4
#define NUMBER_OF_LINKER_SECTIONS_265_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_265 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_265_4);
      goto x_visual_info_visual_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_visual_3)
DEFLABEL (x_visual_info_visual_0)
  INTERRUPT_CHECK (26, LABEL_265_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_265_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_265_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_266_4 3
#define ENVIRONMENT_LABEL_266_3 7
#define DEBUGGING_LABEL_266_2 6
#define OBJECT_266_1 5
#define OBJECT_266_0 4
#define FREE_REFERENCES_LABEL_266_0 4
#define NUMBER_OF_LINKER_SECTIONS_266_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_266 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_266_4);
      goto x_visual_info_visual_id_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_visual_id_3)
DEFLABEL (x_visual_info_visual_id_0)
  INTERRUPT_CHECK (26, LABEL_266_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_266_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_266_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_267_4 3
#define ENVIRONMENT_LABEL_267_3 7
#define DEBUGGING_LABEL_267_2 6
#define OBJECT_267_1 5
#define OBJECT_267_0 4
#define FREE_REFERENCES_LABEL_267_0 4
#define NUMBER_OF_LINKER_SECTIONS_267_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_267 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_267_4);
      goto x_visual_info_screen_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_screen_3)
DEFLABEL (x_visual_info_screen_0)
  INTERRUPT_CHECK (26, LABEL_267_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_267_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_267_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_268_4 3
#define ENVIRONMENT_LABEL_268_3 7
#define DEBUGGING_LABEL_268_2 6
#define OBJECT_268_1 5
#define OBJECT_268_0 4
#define FREE_REFERENCES_LABEL_268_0 4
#define NUMBER_OF_LINKER_SECTIONS_268_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_268 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_268_4);
      goto x_visual_info_depth_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_depth_3)
DEFLABEL (x_visual_info_depth_0)
  INTERRUPT_CHECK (26, LABEL_268_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_268_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_268_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_269_4 3
#define ENVIRONMENT_LABEL_269_3 7
#define DEBUGGING_LABEL_269_2 6
#define OBJECT_269_1 5
#define OBJECT_269_0 4
#define FREE_REFERENCES_LABEL_269_0 4
#define NUMBER_OF_LINKER_SECTIONS_269_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_269 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_269_4);
      goto x_visual_info_class_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_class_3)
DEFLABEL (x_visual_info_class_0)
  INTERRUPT_CHECK (26, LABEL_269_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_269_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_269_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_270_4 3
#define ENVIRONMENT_LABEL_270_3 7
#define DEBUGGING_LABEL_270_2 6
#define OBJECT_270_1 5
#define OBJECT_270_0 4
#define FREE_REFERENCES_LABEL_270_0 4
#define NUMBER_OF_LINKER_SECTIONS_270_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_270 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_270_4);
      goto x_visual_info_red_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_red_mask_3)
DEFLABEL (x_visual_info_red_mask_0)
  INTERRUPT_CHECK (26, LABEL_270_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_270_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_270_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_271_4 3
#define ENVIRONMENT_LABEL_271_3 7
#define DEBUGGING_LABEL_271_2 6
#define OBJECT_271_1 5
#define OBJECT_271_0 4
#define FREE_REFERENCES_LABEL_271_0 4
#define NUMBER_OF_LINKER_SECTIONS_271_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_271 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_271_4);
      goto x_visual_info_green_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_green_mask_3)
DEFLABEL (x_visual_info_green_mask_0)
  INTERRUPT_CHECK (26, LABEL_271_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_271_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_271_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_272_4 3
#define ENVIRONMENT_LABEL_272_3 7
#define DEBUGGING_LABEL_272_2 6
#define OBJECT_272_1 5
#define OBJECT_272_0 4
#define FREE_REFERENCES_LABEL_272_0 4
#define NUMBER_OF_LINKER_SECTIONS_272_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_272 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_272_4);
      goto x_visual_info_blue_mask_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_blue_mask_3)
DEFLABEL (x_visual_info_blue_mask_0)
  INTERRUPT_CHECK (26, LABEL_272_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_272_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_272_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_273_4 3
#define ENVIRONMENT_LABEL_273_3 7
#define DEBUGGING_LABEL_273_2 6
#define OBJECT_273_1 5
#define OBJECT_273_0 4
#define FREE_REFERENCES_LABEL_273_0 4
#define NUMBER_OF_LINKER_SECTIONS_273_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_273 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_273_4);
      goto x_visual_info_colormap_size_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_colormap_size_3)
DEFLABEL (x_visual_info_colormap_size_0)
  INTERRUPT_CHECK (26, LABEL_273_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_273_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_273_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [9]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_274_4 3
#define ENVIRONMENT_LABEL_274_3 7
#define DEBUGGING_LABEL_274_2 6
#define OBJECT_274_1 5
#define OBJECT_274_0 4
#define FREE_REFERENCES_LABEL_274_0 4
#define NUMBER_OF_LINKER_SECTIONS_274_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
x11graph_so_code_274 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_274_4);
      goto x_visual_info_bits_per_rgb_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (x_visual_info_bits_per_rgb_3)
DEFLABEL (x_visual_info_bits_per_rgb_0)
  INTERRUPT_CHECK (26, LABEL_274_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_274_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_274_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [10]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_12 7
#define LABEL_7 9
#define LABEL_8 11
#define LABEL_10 13
#define LABEL_11 15
#define LABEL_15 17
#define LABEL_20 19
#define LABEL_16 21
#define TAG_17 9
#define LABEL_22 23
#define LABEL_18 25
#define LABEL_19 27
#define LABEL_21 29
#define LABEL_28 31
#define LABEL_24 33
#define LABEL_25 35
#define TAG_26 16
#define LABEL_32 37
#define LABEL_27 39
#define LABEL_34 41
#define LABEL_29 43
#define LABEL_30 45
#define LABEL_33 47
#define LABEL_36 49
#define LABEL_35 51
#define LABEL_37 53
#define LABEL_38 55
#define LABEL_39 57
#define LABEL_40 59
#define LABEL_41 61
#define LABEL_42 63
#define LABEL_43 65
#define LABEL_44 67
#define LABEL_45 69
#define LABEL_46 71
#define LABEL_47 73
#define LABEL_49 75
#define LABEL_50 77
#define LABEL_51 79
#define LABEL_52 81
#define LABEL_48 83
#define LABEL_55 85
#define LABEL_57 87
#define LABEL_53 89
#define LABEL_60 91
#define LABEL_54 93
#define LABEL_56 95
#define LABEL_61 97
#define LABEL_63 99
#define LABEL_58 101
#define LABEL_59 103
#define LABEL_62 105
#define LABEL_64 107
#define LABEL_69 109
#define LABEL_65 111
#define TAG_66 54
#define LABEL_71 113
#define LABEL_67 115
#define LABEL_68 117
#define LABEL_70 119
#define LABEL_72 121
#define LABEL_73 123
#define TAG_74 60
#define LABEL_78 125
#define LABEL_75 127
#define LABEL_81 129
#define LABEL_76 131
#define LABEL_79 133
#define LABEL_80 135
#define LABEL_82 137
#define LABEL_83 139
#define LABEL_89 141
#define LABEL_84 143
#define TAG_85 70
#define LABEL_86 145
#define LABEL_87 147
#define LABEL_88 149
#define LABEL_90 151
#define LABEL_91 153
#define TAG_92 75
#define LABEL_96 155
#define LABEL_93 157
#define LABEL_99 159
#define LABEL_94 161
#define LABEL_97 163
#define LABEL_103 165
#define LABEL_98 167
#define LABEL_101 169
#define LABEL_107 171
#define LABEL_102 173
#define LABEL_105 175
#define LABEL_111 177
#define LABEL_106 179
#define LABEL_109 181
#define LABEL_110 183
#define LABEL_113 185
#define LABEL_114 187
#define LABEL_115 189
#define LABEL_116 191
#define LABEL_117 193
#define ENVIRONMENT_LABEL_3 347
#define DEBUGGING_LABEL_2 346
#define PURIFICATION_ROOT 345
#define OBJECT_118 344
#define OBJECT_117 343
#define OBJECT_116 342
#define OBJECT_115 341
#define OBJECT_114 340
#define OBJECT_113 339
#define OBJECT_112 338
#define OBJECT_111 337
#define OBJECT_110 336
#define OBJECT_109 335
#define OBJECT_108 334
#define OBJECT_107 333
#define OBJECT_106 332
#define OBJECT_105 331
#define OBJECT_104 330
#define OBJECT_103 329
#define OBJECT_102 328
#define OBJECT_101 327
#define OBJECT_100 326
#define OBJECT_99 325
#define OBJECT_98 324
#define OBJECT_97 323
#define OBJECT_96 322
#define OBJECT_95 321
#define OBJECT_94 320
#define OBJECT_93 319
#define OBJECT_92 318
#define OBJECT_91 317
#define OBJECT_90 316
#define OBJECT_89 315
#define OBJECT_88 314
#define OBJECT_87 313
#define OBJECT_86 312
#define OBJECT_85 311
#define OBJECT_84 310
#define OBJECT_83 309
#define OBJECT_82 308
#define OBJECT_81 307
#define OBJECT_80 306
#define OBJECT_79 305
#define OBJECT_78 304
#define OBJECT_77 303
#define OBJECT_76 302
#define OBJECT_75 301
#define OBJECT_74 300
#define OBJECT_73 299
#define OBJECT_72 298
#define OBJECT_71 297
#define OBJECT_70 296
#define OBJECT_69 295
#define OBJECT_68 294
#define OBJECT_67 293
#define OBJECT_66 292
#define OBJECT_65 291
#define OBJECT_64 290
#define OBJECT_63 289
#define OBJECT_62 288
#define OBJECT_61 287
#define OBJECT_60 286
#define OBJECT_59 285
#define OBJECT_58 284
#define OBJECT_57 283
#define OBJECT_56 282
#define OBJECT_55 281
#define OBJECT_54 280
#define OBJECT_53 279
#define OBJECT_52 278
#define OBJECT_51 277
#define OBJECT_50 276
#define OBJECT_49 275
#define OBJECT_48 274
#define OBJECT_47 273
#define OBJECT_46 272
#define OBJECT_45 271
#define OBJECT_44 270
#define OBJECT_43 269
#define OBJECT_42 268
#define OBJECT_41 267
#define OBJECT_40 266
#define OBJECT_39 265
#define OBJECT_38 264
#define OBJECT_37 263
#define OBJECT_36 262
#define OBJECT_35 261
#define OBJECT_34 260
#define OBJECT_33 259
#define OBJECT_32 258
#define OBJECT_31 257
#define OBJECT_30 256
#define OBJECT_29 255
#define OBJECT_28 254
#define OBJECT_27 253
#define OBJECT_26 252
#define OBJECT_25 251
#define OBJECT_24 250
#define OBJECT_23 249
#define OBJECT_22 248
#define OBJECT_21 247
#define OBJECT_20 246
#define OBJECT_19 245
#define OBJECT_18 244
#define OBJECT_17 243
#define OBJECT_16 242
#define OBJECT_15 241
#define OBJECT_14 240
#define OBJECT_13 239
#define OBJECT_12 238
#define OBJECT_11 237
#define OBJECT_10 236
#define OBJECT_9 235
#define OBJECT_8 234
#define OBJECT_7 233
#define OBJECT_6 232
#define OBJECT_5 231
#define OBJECT_4 230
#define OBJECT_3 229
#define OBJECT_2 228
#define OBJECT_1 227
#define OBJECT_0 226
#define EXECUTE_CACHE_112 195
#define EXECUTE_CACHE_108 197
#define EXECUTE_CACHE_104 199
#define EXECUTE_CACHE_100 201
#define EXECUTE_CACHE_95 203
#define EXECUTE_CACHE_31 205
#define EXECUTE_CACHE_9 207
#define FREE_REFERENCE_4 210
#define FREE_REFERENCE_3 211
#define FREE_REFERENCE_2 212
#define FREE_REFERENCE_1 213
#define FREE_REFERENCE_0 214
#define GLOBAL_EXECUTE_CACHE_77 216
#define GLOBAL_EXECUTE_CACHE_23 218
#define GLOBAL_EXECUTE_CACHE_14 220
#define GLOBAL_EXECUTE_CACHE_13 222
#define GLOBAL_EXECUTE_CACHE_5 224
#define FREE_REFERENCES_LABEL_0 194
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
x11graph_so_9437ec791784179c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd22;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd87;
  machine_word Wrd89;
  machine_word Wrd90;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd86;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd99;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd107;
  machine_word Wrd60;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd123;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd110;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd116;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd139;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd126;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd132;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd153;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd141;
  machine_word Wrd146;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd147;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd167;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd155;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd161;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd181;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd169;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd172;
  machine_word Wrd175;
  machine_word Wrd195;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd183;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd186;
  machine_word Wrd189;
  machine_word Wrd209;
  machine_word Wrd206;
  machine_word Wrd205;
  machine_word Wrd197;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd203;
  machine_word Wrd19;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_8;

    case 2:
      current_block = (Rpc - LABEL_12);
      goto label_109;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_16;

    case 6:
      current_block = (Rpc - LABEL_11);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_15);
      goto continuation_17;

    case 8:
      current_block = (Rpc - LABEL_20);
      goto label_110;

    case 9:
      current_block = (Rpc - LABEL_16);
      goto make_x_display_146;

    case 10:
      current_block = (Rpc - LABEL_22);
      goto label_111;

    case 11:
      current_block = (Rpc - LABEL_18);
      goto continuation_24;

    case 12:
      current_block = (Rpc - LABEL_19);
      goto continuation_18;

    case 13:
      current_block = (Rpc - LABEL_21);
      goto continuation_12;

    case 14:
      current_block = (Rpc - LABEL_28);
      goto label_112;

    case 15:
      current_block = (Rpc - LABEL_24);
      goto continuation_25;

    case 16:
      current_block = (Rpc - LABEL_25);
      goto x_displayP_147;

    case 17:
      current_block = (Rpc - LABEL_32);
      goto label_113;

    case 18:
      current_block = (Rpc - LABEL_27);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_34);
      goto label_114;

    case 20:
      current_block = (Rpc - LABEL_29);
      goto continuation_27;

    case 21:
      current_block = (Rpc - LABEL_30);
      goto continuation_26;

    case 22:
      current_block = (Rpc - LABEL_33);
      goto continuation_11;

    case 23:
      current_block = (Rpc - LABEL_36);
      goto continuation_42;

    case 24:
      current_block = (Rpc - LABEL_35);
      goto continuation_28;

    case 25:
      current_block = (Rpc - LABEL_37);
      goto label_115;

    case 26:
      current_block = (Rpc - LABEL_38);
      goto label_129;

    case 27:
      current_block = (Rpc - LABEL_39);
      goto label_116;

    case 28:
      current_block = (Rpc - LABEL_40);
      goto label_128;

    case 29:
      current_block = (Rpc - LABEL_41);
      goto label_117;

    case 30:
      current_block = (Rpc - LABEL_42);
      goto label_127;

    case 31:
      current_block = (Rpc - LABEL_43);
      goto label_118;

    case 32:
      current_block = (Rpc - LABEL_44);
      goto label_126;

    case 33:
      current_block = (Rpc - LABEL_45);
      goto label_119;

    case 34:
      current_block = (Rpc - LABEL_46);
      goto label_125;

    case 35:
      current_block = (Rpc - LABEL_47);
      goto label_120;

    case 36:
      current_block = (Rpc - LABEL_49);
      goto label_124;

    case 37:
      current_block = (Rpc - LABEL_50);
      goto label_121;

    case 38:
      current_block = (Rpc - LABEL_51);
      goto label_123;

    case 39:
      current_block = (Rpc - LABEL_52);
      goto label_122;

    case 40:
      current_block = (Rpc - LABEL_48);
      goto lambda_41;

    case 41:
      current_block = (Rpc - LABEL_55);
      goto label_130;

    case 42:
      current_block = (Rpc - LABEL_57);
      goto label_131;

    case 43:
      current_block = (Rpc - LABEL_53);
      goto continuation_53;

    case 44:
      current_block = (Rpc - LABEL_60);
      goto label_132;

    case 45:
      current_block = (Rpc - LABEL_54);
      goto continuation_51;

    case 46:
      current_block = (Rpc - LABEL_56);
      goto continuation_36;

    case 47:
      current_block = (Rpc - LABEL_61);
      goto label_134;

    case 48:
      current_block = (Rpc - LABEL_63);
      goto label_133;

    case 49:
      current_block = (Rpc - LABEL_58);
      goto continuation_59;

    case 50:
      current_block = (Rpc - LABEL_59);
      goto continuation_54;

    case 51:
      current_block = (Rpc - LABEL_62);
      goto continuation_39;

    case 52:
      current_block = (Rpc - LABEL_64);
      goto continuation_60;

    case 53:
      current_block = (Rpc - LABEL_69);
      goto label_135;

    case 54:
      current_block = (Rpc - LABEL_65);
      goto make_x_window_149;

    case 55:
      current_block = (Rpc - LABEL_71);
      goto label_136;

    case 56:
      current_block = (Rpc - LABEL_67);
      goto continuation_67;

    case 57:
      current_block = (Rpc - LABEL_68);
      goto continuation_61;

    case 58:
      current_block = (Rpc - LABEL_70);
      goto continuation_56;

    case 59:
      current_block = (Rpc - LABEL_72);
      goto continuation_68;

    case 60:
      current_block = (Rpc - LABEL_73);
      goto x_windowP_150;

    case 61:
      current_block = (Rpc - LABEL_78);
      goto label_137;

    case 62:
      current_block = (Rpc - LABEL_75);
      goto continuation_79;

    case 63:
      current_block = (Rpc - LABEL_81);
      goto label_138;

    case 64:
      current_block = (Rpc - LABEL_76);
      goto continuation_72;

    case 65:
      current_block = (Rpc - LABEL_79);
      goto continuation_84;

    case 66:
      current_block = (Rpc - LABEL_80);
      goto continuation_80;

    case 67:
      current_block = (Rpc - LABEL_82);
      goto continuation_77;

    case 68:
      current_block = (Rpc - LABEL_83);
      goto continuation_85;

    case 69:
      current_block = (Rpc - LABEL_89);
      goto label_139;

    case 70:
      current_block = (Rpc - LABEL_84);
      goto make_x_image_151;

    case 71:
      current_block = (Rpc - LABEL_86);
      goto continuation_70;

    case 72:
      current_block = (Rpc - LABEL_87);
      goto continuation_92;

    case 73:
      current_block = (Rpc - LABEL_88);
      goto continuation_86;

    case 74:
      current_block = (Rpc - LABEL_90);
      goto continuation_93;

    case 75:
      current_block = (Rpc - LABEL_91);
      goto x_imageP_152;

    case 76:
      current_block = (Rpc - LABEL_96);
      goto label_140;

    case 77:
      current_block = (Rpc - LABEL_93);
      goto continuation_95;

    case 78:
      current_block = (Rpc - LABEL_99);
      goto label_141;

    case 79:
      current_block = (Rpc - LABEL_94);
      goto continuation_94;

    case 80:
      current_block = (Rpc - LABEL_97);
      goto continuation_97;

    case 81:
      current_block = (Rpc - LABEL_103);
      goto label_142;

    case 82:
      current_block = (Rpc - LABEL_98);
      goto continuation_96;

    case 83:
      current_block = (Rpc - LABEL_101);
      goto continuation_99;

    case 84:
      current_block = (Rpc - LABEL_107);
      goto label_143;

    case 85:
      current_block = (Rpc - LABEL_102);
      goto continuation_98;

    case 86:
      current_block = (Rpc - LABEL_105);
      goto continuation_101;

    case 87:
      current_block = (Rpc - LABEL_111);
      goto label_144;

    case 88:
      current_block = (Rpc - LABEL_106);
      goto continuation_100;

    case 89:
      current_block = (Rpc - LABEL_109);
      goto continuation_103;

    case 90:
      current_block = (Rpc - LABEL_110);
      goto continuation_102;

    case 91:
      current_block = (Rpc - LABEL_113);
      goto continuation_106;

    case 92:
      current_block = (Rpc - LABEL_114);
      goto continuation_105;

    case 93:
      current_block = (Rpc - LABEL_115);
      goto label_154;

    case 94:
      current_block = (Rpc - LABEL_116);
      goto label_155;

    case 95:
      current_block = (Rpc - LABEL_117);
      goto expression_108;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_108)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_116])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_155)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_154)
  {
    static const short sections [] =
      {
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	2,
	3,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	0,
	0,
	1,
	1,
	0,
	1,
	1,
	0,
	0,
	2,
	2,
	3,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	2,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	0,
	1,
	1,
	0,
	1,
	2,
	1,
	1,
	0,
	1,
	0,
	1,
	1,
	0,
	0,
	0,
	1,
	1,
	2,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	0,
	1,
	2,
	1,
	1,
	1,
	2,
	0,
	2,
	2,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	2,
	0,
	0,
	1,
	3,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 274)
      goto label_153;
    blocks = (current_block [OBJECT_118]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_115])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_153)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_8);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_6]);
  (Wrd9.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_8]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_9]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_10]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_11]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_208;
  Wrd11 = Wrd15;

DEFLABEL (label_207)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_11);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_206;
  Wrd11 = Wrd15;

DEFLABEL (label_205)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_19);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_25])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_30);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_35);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_204;
  Wrd6 = Wrd10;

DEFLABEL (label_203)
  Wrd5 = Wrd6;
  (Wrd203.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd203.uLng) == 10))
    goto label_202;
  (Wrd200.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd201.Obj) = ((Wrd200.pObj) [0]);
  (Wrd202.Lng) = (FIXNUM_TO_LONG (Wrd201.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd202.Lng))))
    goto label_202;
  (Wrd197.Obj) = (current_block [OBJECT_30]);
  ((Wrd200.pObj) [3]) = (Wrd197.Obj);

DEFLABEL (label_201)
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_200;
  Wrd13 = Wrd17;

DEFLABEL (label_199)
  Wrd12 = Wrd13;
  (Wrd189.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd189.uLng) == 10))
    goto label_198;
  (Wrd186.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd187.Obj) = ((Wrd186.pObj) [0]);
  (Wrd188.Lng) = (FIXNUM_TO_LONG (Wrd187.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd188.Lng))))
    goto label_198;
  (Wrd183.Obj) = (current_block [OBJECT_33]);
  ((Wrd186.pObj) [11]) = (Wrd183.Obj);

DEFLABEL (label_197)
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_196;
  Wrd20 = Wrd24;

DEFLABEL (label_195)
  Wrd19 = Wrd20;
  (Wrd175.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd175.uLng) == 10))
    goto label_194;
  (Wrd172.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd173.Obj) = ((Wrd172.pObj) [0]);
  (Wrd174.Lng) = (FIXNUM_TO_LONG (Wrd173.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd174.Lng))))
    goto label_194;
  (Wrd169.Obj) = (current_block [OBJECT_35]);
  ((Wrd172.pObj) [12]) = (Wrd169.Obj);

DEFLABEL (label_193)
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_192;
  Wrd27 = Wrd31;

DEFLABEL (label_191)
  Wrd26 = Wrd27;
  (Wrd161.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd161.uLng) == 10))
    goto label_190;
  (Wrd158.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd159.Obj) = ((Wrd158.pObj) [0]);
  (Wrd160.Lng) = (FIXNUM_TO_LONG (Wrd159.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd160.Lng))))
    goto label_190;
  (Wrd155.Obj) = (current_block [OBJECT_37]);
  ((Wrd158.pObj) [13]) = (Wrd155.Obj);

DEFLABEL (label_189)
  (Wrd35.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd38.Obj) = ((Wrd35.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_188;
  Wrd34 = Wrd38;

DEFLABEL (label_187)
  Wrd33 = Wrd34;
  (Wrd147.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd147.uLng) == 10))
    goto label_186;
  (Wrd144.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd145.Obj) = ((Wrd144.pObj) [0]);
  (Wrd146.Lng) = (FIXNUM_TO_LONG (Wrd145.Obj));
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd146.Lng))))
    goto label_186;
  (Wrd141.Obj) = (current_block [OBJECT_39]);
  ((Wrd144.pObj) [15]) = (Wrd141.Obj);

DEFLABEL (label_185)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd45.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd48.Obj) = ((Wrd45.pObj) [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if ((Wrd49.uLng) == 50)
    goto label_184;
  Wrd44 = Wrd48;

DEFLABEL (label_183)
  Wrd43 = Wrd44;
  (Wrd132.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd132.uLng) == 10))
    goto label_182;
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd130.Obj) = ((Wrd129.pObj) [0]);
  (Wrd131.Lng) = (FIXNUM_TO_LONG (Wrd130.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd131.Lng))))
    goto label_182;
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  ((Wrd129.pObj) [1]) = (Wrd126.Obj);

DEFLABEL (label_181)
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_180;
  Wrd51 = Wrd55;

DEFLABEL (label_179)
  Wrd50 = Wrd51;
  (Wrd116.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd116.uLng) == 10))
    goto label_178;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd115.Lng))))
    goto label_178;
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  ((Wrd113.pObj) [2]) = (Wrd110.Obj);

DEFLABEL (label_177)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd61.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd64.Obj) = ((Wrd61.pObj) [0]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if ((Wrd65.uLng) == 50)
    goto label_176;
  Wrd60 = Wrd64;

DEFLABEL (label_175)
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if ((Wrd107.uLng) == 10)
    goto label_157;

DEFLABEL (label_156)
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_157)
  (Wrd103.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd104.Obj) = ((Wrd103.pObj) [0]);
  (Wrd105.Lng) = (FIXNUM_TO_LONG (Wrd104.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd105.Lng))))
    goto label_156;
  (Wrd99.Obj) = (Rsp [2]);
  ((Wrd103.pObj) [9]) = (Wrd99.Obj);
  Rsp = (& (Rsp [4]));

DEFLABEL (label_174)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd77.Obj) = (current_block [OBJECT_43]);
  (Wrd78.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd77.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd76.pObj) = (& (Rhp [-2]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd76.pObj)));
  (Wrd82.Obj) = (current_block [OBJECT_44]);
  (* (Rhp++)) = (Wrd82.Obj);
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd81.pObj) = (& (Rhp [-2]));
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd81.pObj)));
  (Wrd86.Obj) = (current_block [OBJECT_45]);
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd79.Obj);
  (Wrd85.pObj) = (& (Rhp [-2]));
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd85.pObj)));
  (Wrd90.Obj) = (current_block [OBJECT_46]);
  (* (Rhp++)) = (Wrd90.Obj);
  (* (Rhp++)) = (Wrd83.Obj);
  (Wrd89.pObj) = (& (Rhp [-2]));
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd89.pObj)));
  (Wrd94.Obj) = (current_block [OBJECT_47]);
  (* (Rhp++)) = (Wrd94.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd92.pObj) = (& (Rhp [-2]));
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd92.pObj)));
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd95.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd96.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd96.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_54);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 2));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-3]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_53);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_173;
  Wrd11 = Wrd15;

DEFLABEL (label_172)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_59);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_66);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_65])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_171;
  Wrd11 = Wrd15;

DEFLABEL (label_170)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_68);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_73])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_72);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd21.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd22.Obj) = (current_block [OBJECT_61]);
  (Wrd23.Obj) = (current_block [OBJECT_62]);
  (Wrd24.Obj) = (current_block [OBJECT_63]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_64]);
  (Wrd18.Obj) = (current_block [OBJECT_65]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd15.pObj) = (& (Rhp [-6]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_66]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_68]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_77]));

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_76);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.Obj) = (current_block [OBJECT_70]);
  (Wrd13.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_71]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (current_block [OBJECT_72]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_73]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_77)
  INTERRUPT_CHECK (27, LABEL_82);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd23.Obj) = (MAKE_OBJECT (0, 10));
  (Wrd24.Obj) = (current_block [OBJECT_79]);
  (Wrd25.Obj) = (current_block [OBJECT_80]);
  (Wrd26.Obj) = (current_block [OBJECT_81]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_82]);
  (Wrd18.Obj) = (current_block [OBJECT_83]);
  (Wrd19.Obj) = (current_block [OBJECT_84]);
  (Wrd20.Obj) = (current_block [OBJECT_85]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_86]);
  (Wrd15.Obj) = (current_block [OBJECT_87]);
  (Wrd16.Obj) = (current_block [OBJECT_88]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd12.pObj) = (& (Rhp [-11]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_90]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_91]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_77]));

DEFLABEL (continuation_70)
  INTERRUPT_CHECK (27, LABEL_86);
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd6.Obj) = (* (Rsp++));
  (Wrd13.Obj) = (MAKE_OBJECT (0, 3));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-4]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_92]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_75);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_169;
  Wrd11 = Wrd15;

DEFLABEL (label_168)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_80)
  INTERRUPT_CHECK (27, LABEL_80);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_85);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_84])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_78]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_79);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_76]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_77]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_83);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_167;
  Wrd11 = Wrd15;

DEFLABEL (label_166)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_88);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_91])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_95]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_92)
  INTERRUPT_CHECK (27, LABEL_87);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_94]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_93)
  INTERRUPT_CHECK (27, LABEL_90);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_96]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_97]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95]));

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_94);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_97]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_93);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_96]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_165;
  Wrd12 = Wrd16;

DEFLABEL (label_164)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_98);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_98]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_97);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_163;
  Wrd11 = Wrd15;

DEFLABEL (label_162)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104]));

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_102);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_100]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_101);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_99]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_161;
  Wrd12 = Wrd16;

DEFLABEL (label_160)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_106);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_101]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_105);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_99]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_159;
  Wrd12 = Wrd16;

DEFLABEL (label_158)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_112]));

DEFLABEL (continuation_102)
  INTERRUPT_CHECK (27, LABEL_110);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_114]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_109);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd26.Obj) = (MAKE_OBJECT (0, 10));
  (Wrd27.Obj) = (current_block [OBJECT_102]);
  (Wrd28.Obj) = (current_block [OBJECT_103]);
  (Wrd29.Obj) = (current_block [OBJECT_104]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_105]);
  (Wrd21.Obj) = (current_block [OBJECT_106]);
  (Wrd22.Obj) = (current_block [OBJECT_107]);
  (Wrd23.Obj) = (current_block [OBJECT_108]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_109]);
  (Wrd18.Obj) = (current_block [OBJECT_110]);
  (Wrd19.Obj) = (current_block [OBJECT_111]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd15.pObj) = (& (Rhp [-11]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_112]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_113]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_77]));

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_114);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_117]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 3);

DEFLABEL (continuation_106)
  INTERRUPT_CHECK (27, LABEL_113);
  (Wrd5.Obj) = (current_block [OBJECT_115]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_116]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_159)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_111])), (Wrd13.pObj));

DEFLABEL (label_144)
  (Wrd12.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_161)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107])), (Wrd13.pObj));

DEFLABEL (label_143)
  (Wrd12.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_163)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103])), (Wrd12.pObj));

DEFLABEL (label_142)
  (Wrd11.Obj) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99])), (Wrd13.pObj));

DEFLABEL (label_141)
  (Wrd12.Obj) = Rvl;
  goto label_164;

DEFLABEL (label_167)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89])), (Wrd12.pObj));

DEFLABEL (label_139)
  (Wrd11.Obj) = Rvl;
  goto label_166;

DEFLABEL (label_169)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_81])), (Wrd12.pObj));

DEFLABEL (label_138)
  (Wrd11.Obj) = Rvl;
  goto label_168;

DEFLABEL (label_171)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69])), (Wrd12.pObj));

DEFLABEL (label_135)
  (Wrd11.Obj) = Rvl;
  goto label_170;

DEFLABEL (label_173)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd12.pObj));

DEFLABEL (label_132)
  (Wrd11.Obj) = Rvl;
  goto label_172;

DEFLABEL (label_176)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52])), (Wrd61.pObj));

DEFLABEL (label_122)
  (Wrd60.Obj) = Rvl;
  goto label_175;

DEFLABEL (label_178)
  (Wrd118.Obj) = (current_block [OBJECT_41]);
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_123)
  goto label_177;

DEFLABEL (label_180)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50])), (Wrd52.pObj));

DEFLABEL (label_121)
  (Wrd51.Obj) = Rvl;
  goto label_179;

DEFLABEL (label_182)
  (Wrd134.Obj) = (current_block [OBJECT_23]);
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd134.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_124)
  goto label_181;

DEFLABEL (label_184)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47])), (Wrd45.pObj));

DEFLABEL (label_120)
  (Wrd44.Obj) = Rvl;
  goto label_183;

DEFLABEL (label_186)
  (Wrd149.Obj) = (current_block [OBJECT_40]);
  (Wrd150.Obj) = (current_block [OBJECT_39]);
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd153.Obj);
  (* (--Rsp)) = (Wrd150.Obj);
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_125)
  goto label_185;

DEFLABEL (label_188)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_45])), (Wrd35.pObj));

DEFLABEL (label_119)
  (Wrd34.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  (Wrd163.Obj) = (current_block [OBJECT_38]);
  (Wrd164.Obj) = (current_block [OBJECT_37]);
  (Wrd167.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd167.Obj);
  (* (--Rsp)) = (Wrd164.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_126)
  goto label_189;

DEFLABEL (label_192)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_43])), (Wrd28.pObj));

DEFLABEL (label_118)
  (Wrd27.Obj) = Rvl;
  goto label_191;

DEFLABEL (label_194)
  (Wrd177.Obj) = (current_block [OBJECT_36]);
  (Wrd178.Obj) = (current_block [OBJECT_35]);
  (Wrd181.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd181.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_127)
  goto label_193;

DEFLABEL (label_196)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41])), (Wrd21.pObj));

DEFLABEL (label_117)
  (Wrd20.Obj) = Rvl;
  goto label_195;

DEFLABEL (label_198)
  (Wrd191.Obj) = (current_block [OBJECT_34]);
  (Wrd192.Obj) = (current_block [OBJECT_33]);
  (Wrd195.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd195.Obj);
  (* (--Rsp)) = (Wrd192.Obj);
  (* (--Rsp)) = (Wrd191.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_128)
  goto label_197;

DEFLABEL (label_200)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_39])), (Wrd14.pObj));

DEFLABEL (label_116)
  (Wrd13.Obj) = Rvl;
  goto label_199;

DEFLABEL (label_202)
  (Wrd205.Obj) = (current_block [OBJECT_31]);
  (Wrd206.Obj) = (current_block [OBJECT_30]);
  (Wrd209.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd209.Obj);
  (* (--Rsp)) = (Wrd206.Obj);
  (* (--Rsp)) = (Wrd205.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_129)
  goto label_201;

DEFLABEL (label_204)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37])), (Wrd7.pObj));

DEFLABEL (label_115)
  (Wrd6.Obj) = Rvl;
  goto label_203;

DEFLABEL (label_206)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20])), (Wrd12.pObj));

DEFLABEL (label_110)
  (Wrd11.Obj) = Rvl;
  goto label_205;

DEFLABEL (label_208)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12])), (Wrd12.pObj));

DEFLABEL (label_109)
  (Wrd11.Obj) = Rvl;
  goto label_207;

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_36);
  goto label_174;

DEFLABEL (make_x_display_146)
  CLOSURE_HEADER (LABEL_16);

DEFLABEL (make_x_display_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_214;
  Wrd9 = Wrd13;

DEFLABEL (label_213)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_23]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_21);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_212;
  Wrd9 = Wrd13;

DEFLABEL (label_211)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_23]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_27);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_210;
  Wrd9 = Wrd13;

DEFLABEL (label_209)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_23]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd6.Obj) = (* (Rsp++));
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd10.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd10.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_210)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34])), (Wrd10.pObj));

DEFLABEL (label_114)
  (Wrd9.Obj) = Rvl;
  goto label_209;

DEFLABEL (label_212)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28])), (Wrd10.pObj));

DEFLABEL (label_112)
  (Wrd9.Obj) = Rvl;
  goto label_211;

DEFLABEL (label_214)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22])), (Wrd10.pObj));

DEFLABEL (label_111)
  (Wrd9.Obj) = Rvl;
  goto label_213;

DEFLABEL (x_displayP_147)
  CLOSURE_HEADER (LABEL_25);

DEFLABEL (x_displayP_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_217;

DEFLABEL (label_216)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_215)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_217)
  if (! ((Wrd6.uLng) == 62))
    goto label_219;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_219;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_218)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_216;
  Rvl = (current_block [OBJECT_25]);
  goto label_215;

DEFLABEL (label_219)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_23]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24]), 2);

DEFLABEL (label_113)
  (Wrd9.Obj) = Rvl;
  goto label_218;

DEFLABEL (lambda_148)
DEFLABEL (lambda_41)
  INTERRUPT_CHECK (26, LABEL_48);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_229;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_229;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_228)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_227;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_227;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_226)
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 2);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_56);
  (Wrd5.Obj) = Rvl;
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_225;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_225;
  ((Wrd32.pObj) [3]) = Rvl;

DEFLABEL (label_224)
  (Wrd6.Obj) = (current_block [OBJECT_26]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_223;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd18.Lng))))
    goto label_223;
  (Wrd12.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_222)
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53]), 2);

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_62);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [2]) = Rvl;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_221;

DEFLABEL (label_220)
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_221)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_220;
  ((Wrd15.pObj) [4]) = Rvl;
  Rvl = (current_block [OBJECT_57]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_223)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_26]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 2);

DEFLABEL (label_133)
  (* (--Rsp)) = Rvl;
  goto label_222;

DEFLABEL (label_225)
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.Obj) = (current_block [OBJECT_31]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32]), 3);

DEFLABEL (label_134)
  goto label_224;

DEFLABEL (label_227)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_31]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 2);

DEFLABEL (label_131)
  (* (--Rsp)) = Rvl;
  goto label_226;

DEFLABEL (label_229)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_41]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 2);

DEFLABEL (label_130)
  (* (--Rsp)) = Rvl;
  goto label_228;

DEFLABEL (make_x_window_149)
  CLOSURE_HEADER (LABEL_65);

DEFLABEL (make_x_window_57)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_231;
  Wrd9 = Wrd13;

DEFLABEL (label_230)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_23]));

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_70);
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd8.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_231)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71])), (Wrd10.pObj));

DEFLABEL (label_136)
  (Wrd9.Obj) = Rvl;
  goto label_230;

DEFLABEL (x_windowP_150)
  CLOSURE_HEADER (LABEL_73);

DEFLABEL (x_windowP_65)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_234;

DEFLABEL (label_233)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_232)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_234)
  if (! ((Wrd6.uLng) == 62))
    goto label_236;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_236;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_235)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_233;
  Rvl = (current_block [OBJECT_25]);
  goto label_232;

DEFLABEL (label_236)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_23]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24]), 2);

DEFLABEL (label_137)
  (Wrd9.Obj) = Rvl;
  goto label_235;

DEFLABEL (make_x_image_151)
  CLOSURE_HEADER (LABEL_84);

DEFLABEL (make_x_image_82)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (x_imageP_152)
  CLOSURE_HEADER (LABEL_91);

DEFLABEL (x_imageP_90)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_239;

DEFLABEL (label_238)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_237)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_239)
  if (! ((Wrd6.uLng) == 62))
    goto label_241;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_241;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_240)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_238;
  Rvl = (current_block [OBJECT_25]);
  goto label_237;

DEFLABEL (label_241)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_23]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24]), 2);

DEFLABEL (label_140)
  (Wrd9.Obj) = Rvl;
  goto label_240;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_x11graph_so_9437ec791784179c [274] =
  {
    { "x11graph_so_code_1", 1, x11graph_so_code_1 },
    { "x11graph_so_code_2", 1, x11graph_so_code_2 },
    { "x11graph_so_code_3", 1, x11graph_so_code_3 },
    { "x11graph_so_code_4", 1, x11graph_so_code_4 },
    { "x11graph_so_code_5", 1, x11graph_so_code_5 },
    { "x11graph_so_code_6", 1, x11graph_so_code_6 },
    { "x11graph_so_code_7", 1, x11graph_so_code_7 },
    { "x11graph_so_code_8", 1, x11graph_so_code_8 },
    { "x11graph_so_code_9", 1, x11graph_so_code_9 },
    { "x11graph_so_code_10", 1, x11graph_so_code_10 },
    { "x11graph_so_code_11", 1, x11graph_so_code_11 },
    { "x11graph_so_code_12", 1, x11graph_so_code_12 },
    { "x11graph_so_code_13", 1, x11graph_so_code_13 },
    { "x11graph_so_code_14", 1, x11graph_so_code_14 },
    { "x11graph_so_code_15", 1, x11graph_so_code_15 },
    { "x11graph_so_code_16", 1, x11graph_so_code_16 },
    { "x11graph_so_code_17", 1, x11graph_so_code_17 },
    { "x11graph_so_code_18", 1, x11graph_so_code_18 },
    { "x11graph_so_code_19", 1, x11graph_so_code_19 },
    { "x11graph_so_code_20", 1, x11graph_so_code_20 },
    { "x11graph_so_code_21", 1, x11graph_so_code_21 },
    { "x11graph_so_code_22", 1, x11graph_so_code_22 },
    { "x11graph_so_code_23", 1, x11graph_so_code_23 },
    { "x11graph_so_code_24", 1, x11graph_so_code_24 },
    { "x11graph_so_code_25", 1, x11graph_so_code_25 },
    { "x11graph_so_code_26", 1, x11graph_so_code_26 },
    { "x11graph_so_code_27", 1, x11graph_so_code_27 },
    { "x11graph_so_code_28", 1, x11graph_so_code_28 },
    { "x11graph_so_code_29", 1, x11graph_so_code_29 },
    { "x11graph_so_code_30", 1, x11graph_so_code_30 },
    { "x11graph_so_code_31", 1, x11graph_so_code_31 },
    { "x11graph_so_code_32", 1, x11graph_so_code_32 },
    { "x11graph_so_code_33", 1, x11graph_so_code_33 },
    { "x11graph_so_code_34", 1, x11graph_so_code_34 },
    { "x11graph_so_code_35", 1, x11graph_so_code_35 },
    { "x11graph_so_code_36", 1, x11graph_so_code_36 },
    { "x11graph_so_code_37", 1, x11graph_so_code_37 },
    { "x11graph_so_code_38", 1, x11graph_so_code_38 },
    { "x11graph_so_code_39", 1, x11graph_so_code_39 },
    { "x11graph_so_code_40", 1, x11graph_so_code_40 },
    { "x11graph_so_code_41", 1, x11graph_so_code_41 },
    { "x11graph_so_code_42", 1, x11graph_so_code_42 },
    { "x11graph_so_code_43", 1, x11graph_so_code_43 },
    { "x11graph_so_code_44", 1, x11graph_so_code_44 },
    { "x11graph_so_code_45", 1, x11graph_so_code_45 },
    { "x11graph_so_code_46", 1, x11graph_so_code_46 },
    { "x11graph_so_code_47", 1, x11graph_so_code_47 },
    { "x11graph_so_code_48", 1, x11graph_so_code_48 },
    { "x11graph_so_code_49", 1, x11graph_so_code_49 },
    { "x11graph_so_code_50", 1, x11graph_so_code_50 },
    { "x11graph_so_code_51", 1, x11graph_so_code_51 },
    { "x11graph_so_code_52", 1, x11graph_so_code_52 },
    { "x11graph_so_code_53", 1, x11graph_so_code_53 },
    { "x11graph_so_code_54", 1, x11graph_so_code_54 },
    { "x11graph_so_code_55", 1, x11graph_so_code_55 },
    { "x11graph_so_code_56", 1, x11graph_so_code_56 },
    { "x11graph_so_code_57", 1, x11graph_so_code_57 },
    { "x11graph_so_code_58", 1, x11graph_so_code_58 },
    { "x11graph_so_code_59", 1, x11graph_so_code_59 },
    { "x11graph_so_code_60", 1, x11graph_so_code_60 },
    { "x11graph_so_code_61", 1, x11graph_so_code_61 },
    { "x11graph_so_code_62", 1, x11graph_so_code_62 },
    { "x11graph_so_code_63", 1, x11graph_so_code_63 },
    { "x11graph_so_code_64", 1, x11graph_so_code_64 },
    { "x11graph_so_code_65", 1, x11graph_so_code_65 },
    { "x11graph_so_code_66", 1, x11graph_so_code_66 },
    { "x11graph_so_code_67", 1, x11graph_so_code_67 },
    { "x11graph_so_code_68", 1, x11graph_so_code_68 },
    { "x11graph_so_code_69", 1, x11graph_so_code_69 },
    { "x11graph_so_code_70", 1, x11graph_so_code_70 },
    { "x11graph_so_code_71", 1, x11graph_so_code_71 },
    { "x11graph_so_code_72", 1, x11graph_so_code_72 },
    { "x11graph_so_code_73", 1, x11graph_so_code_73 },
    { "x11graph_so_code_74", 1, x11graph_so_code_74 },
    { "x11graph_so_code_75", 67, x11graph_so_code_75 },
    { "x11graph_so_code_76", 1, x11graph_so_code_76 },
    { "x11graph_so_code_77", 1, x11graph_so_code_77 },
    { "x11graph_so_code_78", 1, x11graph_so_code_78 },
    { "x11graph_so_code_79", 4, x11graph_so_code_79 },
    { "x11graph_so_code_80", 1, x11graph_so_code_80 },
    { "x11graph_so_code_81", 1, x11graph_so_code_81 },
    { "x11graph_so_code_82", 3, x11graph_so_code_82 },
    { "x11graph_so_code_83", 1, x11graph_so_code_83 },
    { "x11graph_so_code_84", 1, x11graph_so_code_84 },
    { "x11graph_so_code_85", 1, x11graph_so_code_85 },
    { "x11graph_so_code_86", 1, x11graph_so_code_86 },
    { "x11graph_so_code_87", 1, x11graph_so_code_87 },
    { "x11graph_so_code_88", 1, x11graph_so_code_88 },
    { "x11graph_so_code_89", 1, x11graph_so_code_89 },
    { "x11graph_so_code_90", 16, x11graph_so_code_90 },
    { "x11graph_so_code_91", 6, x11graph_so_code_91 },
    { "x11graph_so_code_92", 2, x11graph_so_code_92 },
    { "x11graph_so_code_93", 14, x11graph_so_code_93 },
    { "x11graph_so_code_94", 5, x11graph_so_code_94 },
    { "x11graph_so_code_95", 6, x11graph_so_code_95 },
    { "x11graph_so_code_96", 8, x11graph_so_code_96 },
    { "x11graph_so_code_97", 16, x11graph_so_code_97 },
    { "x11graph_so_code_98", 2, x11graph_so_code_98 },
    { "x11graph_so_code_99", 6, x11graph_so_code_99 },
    { "x11graph_so_code_100", 1, x11graph_so_code_100 },
    { "x11graph_so_code_101", 1, x11graph_so_code_101 },
    { "x11graph_so_code_102", 1, x11graph_so_code_102 },
    { "x11graph_so_code_103", 2, x11graph_so_code_103 },
    { "x11graph_so_code_104", 1, x11graph_so_code_104 },
    { "x11graph_so_code_105", 1, x11graph_so_code_105 },
    { "x11graph_so_code_106", 1, x11graph_so_code_106 },
    { "x11graph_so_code_107", 1, x11graph_so_code_107 },
    { "x11graph_so_code_108", 1, x11graph_so_code_108 },
    { "x11graph_so_code_109", 1, x11graph_so_code_109 },
    { "x11graph_so_code_110", 1, x11graph_so_code_110 },
    { "x11graph_so_code_111", 1, x11graph_so_code_111 },
    { "x11graph_so_code_112", 1, x11graph_so_code_112 },
    { "x11graph_so_code_113", 1, x11graph_so_code_113 },
    { "x11graph_so_code_114", 1, x11graph_so_code_114 },
    { "x11graph_so_code_115", 1, x11graph_so_code_115 },
    { "x11graph_so_code_116", 1, x11graph_so_code_116 },
    { "x11graph_so_code_117", 1, x11graph_so_code_117 },
    { "x11graph_so_code_118", 2, x11graph_so_code_118 },
    { "x11graph_so_code_119", 2, x11graph_so_code_119 },
    { "x11graph_so_code_120", 3, x11graph_so_code_120 },
    { "x11graph_so_code_121", 3, x11graph_so_code_121 },
    { "x11graph_so_code_122", 2, x11graph_so_code_122 },
    { "x11graph_so_code_123", 3, x11graph_so_code_123 },
    { "x11graph_so_code_124", 3, x11graph_so_code_124 },
    { "x11graph_so_code_125", 3, x11graph_so_code_125 },
    { "x11graph_so_code_126", 9, x11graph_so_code_126 },
    { "x11graph_so_code_127", 13, x11graph_so_code_127 },
    { "x11graph_so_code_128", 10, x11graph_so_code_128 },
    { "x11graph_so_code_129", 17, x11graph_so_code_129 },
    { "x11graph_so_code_130", 3, x11graph_so_code_130 },
    { "x11graph_so_code_131", 9, x11graph_so_code_131 },
    { "x11graph_so_code_132", 8, x11graph_so_code_132 },
    { "x11graph_so_code_133", 5, x11graph_so_code_133 },
    { "x11graph_so_code_134", 7, x11graph_so_code_134 },
    { "x11graph_so_code_135", 3, x11graph_so_code_135 },
    { "x11graph_so_code_136", 5, x11graph_so_code_136 },
    { "x11graph_so_code_137", 3, x11graph_so_code_137 },
    { "x11graph_so_code_138", 5, x11graph_so_code_138 },
    { "x11graph_so_code_139", 5, x11graph_so_code_139 },
    { "x11graph_so_code_140", 10, x11graph_so_code_140 },
    { "x11graph_so_code_141", 5, x11graph_so_code_141 },
    { "x11graph_so_code_142", 3, x11graph_so_code_142 },
    { "x11graph_so_code_143", 7, x11graph_so_code_143 },
    { "x11graph_so_code_144", 7, x11graph_so_code_144 },
    { "x11graph_so_code_145", 3, x11graph_so_code_145 },
    { "x11graph_so_code_146", 10, x11graph_so_code_146 },
    { "x11graph_so_code_147", 3, x11graph_so_code_147 },
    { "x11graph_so_code_148", 3, x11graph_so_code_148 },
    { "x11graph_so_code_149", 3, x11graph_so_code_149 },
    { "x11graph_so_code_150", 3, x11graph_so_code_150 },
    { "x11graph_so_code_151", 3, x11graph_so_code_151 },
    { "x11graph_so_code_152", 3, x11graph_so_code_152 },
    { "x11graph_so_code_153", 3, x11graph_so_code_153 },
    { "x11graph_so_code_154", 3, x11graph_so_code_154 },
    { "x11graph_so_code_155", 9, x11graph_so_code_155 },
    { "x11graph_so_code_156", 7, x11graph_so_code_156 },
    { "x11graph_so_code_157", 7, x11graph_so_code_157 },
    { "x11graph_so_code_158", 5, x11graph_so_code_158 },
    { "x11graph_so_code_159", 9, x11graph_so_code_159 },
    { "x11graph_so_code_160", 4, x11graph_so_code_160 },
    { "x11graph_so_code_161", 3, x11graph_so_code_161 },
    { "x11graph_so_code_162", 3, x11graph_so_code_162 },
    { "x11graph_so_code_163", 3, x11graph_so_code_163 },
    { "x11graph_so_code_164", 3, x11graph_so_code_164 },
    { "x11graph_so_code_165", 3, x11graph_so_code_165 },
    { "x11graph_so_code_166", 2, x11graph_so_code_166 },
    { "x11graph_so_code_167", 10, x11graph_so_code_167 },
    { "x11graph_so_code_168", 6, x11graph_so_code_168 },
    { "x11graph_so_code_169", 9, x11graph_so_code_169 },
    { "x11graph_so_code_170", 2, x11graph_so_code_170 },
    { "x11graph_so_code_171", 2, x11graph_so_code_171 },
    { "x11graph_so_code_172", 4, x11graph_so_code_172 },
    { "x11graph_so_code_173", 1, x11graph_so_code_173 },
    { "x11graph_so_code_174", 1, x11graph_so_code_174 },
    { "x11graph_so_code_175", 1, x11graph_so_code_175 },
    { "x11graph_so_code_176", 1, x11graph_so_code_176 },
    { "x11graph_so_code_177", 1, x11graph_so_code_177 },
    { "x11graph_so_code_178", 1, x11graph_so_code_178 },
    { "x11graph_so_code_179", 1, x11graph_so_code_179 },
    { "x11graph_so_code_180", 1, x11graph_so_code_180 },
    { "x11graph_so_code_181", 1, x11graph_so_code_181 },
    { "x11graph_so_code_182", 1, x11graph_so_code_182 },
    { "x11graph_so_code_183", 1, x11graph_so_code_183 },
    { "x11graph_so_code_184", 1, x11graph_so_code_184 },
    { "x11graph_so_code_185", 1, x11graph_so_code_185 },
    { "x11graph_so_code_186", 1, x11graph_so_code_186 },
    { "x11graph_so_code_187", 1, x11graph_so_code_187 },
    { "x11graph_so_code_188", 1, x11graph_so_code_188 },
    { "x11graph_so_code_189", 1, x11graph_so_code_189 },
    { "x11graph_so_code_190", 2, x11graph_so_code_190 },
    { "x11graph_so_code_191", 3, x11graph_so_code_191 },
    { "x11graph_so_code_192", 3, x11graph_so_code_192 },
    { "x11graph_so_code_193", 3, x11graph_so_code_193 },
    { "x11graph_so_code_194", 3, x11graph_so_code_194 },
    { "x11graph_so_code_195", 3, x11graph_so_code_195 },
    { "x11graph_so_code_196", 3, x11graph_so_code_196 },
    { "x11graph_so_code_197", 3, x11graph_so_code_197 },
    { "x11graph_so_code_198", 3, x11graph_so_code_198 },
    { "x11graph_so_code_199", 1, x11graph_so_code_199 },
    { "x11graph_so_code_200", 1, x11graph_so_code_200 },
    { "x11graph_so_code_201", 1, x11graph_so_code_201 },
    { "x11graph_so_code_202", 1, x11graph_so_code_202 },
    { "x11graph_so_code_203", 1, x11graph_so_code_203 },
    { "x11graph_so_code_204", 1, x11graph_so_code_204 },
    { "x11graph_so_code_205", 1, x11graph_so_code_205 },
    { "x11graph_so_code_206", 1, x11graph_so_code_206 },
    { "x11graph_so_code_207", 1, x11graph_so_code_207 },
    { "x11graph_so_code_208", 1, x11graph_so_code_208 },
    { "x11graph_so_code_209", 1, x11graph_so_code_209 },
    { "x11graph_so_code_210", 1, x11graph_so_code_210 },
    { "x11graph_so_code_211", 1, x11graph_so_code_211 },
    { "x11graph_so_code_212", 1, x11graph_so_code_212 },
    { "x11graph_so_code_213", 1, x11graph_so_code_213 },
    { "x11graph_so_code_214", 1, x11graph_so_code_214 },
    { "x11graph_so_code_215", 1, x11graph_so_code_215 },
    { "x11graph_so_code_216", 1, x11graph_so_code_216 },
    { "x11graph_so_code_217", 1, x11graph_so_code_217 },
    { "x11graph_so_code_218", 1, x11graph_so_code_218 },
    { "x11graph_so_code_219", 1, x11graph_so_code_219 },
    { "x11graph_so_code_220", 1, x11graph_so_code_220 },
    { "x11graph_so_code_221", 1, x11graph_so_code_221 },
    { "x11graph_so_code_222", 1, x11graph_so_code_222 },
    { "x11graph_so_code_223", 1, x11graph_so_code_223 },
    { "x11graph_so_code_224", 1, x11graph_so_code_224 },
    { "x11graph_so_code_225", 1, x11graph_so_code_225 },
    { "x11graph_so_code_226", 18, x11graph_so_code_226 },
    { "x11graph_so_code_227", 6, x11graph_so_code_227 },
    { "x11graph_so_code_228", 2, x11graph_so_code_228 },
    { "x11graph_so_code_229", 2, x11graph_so_code_229 },
    { "x11graph_so_code_230", 2, x11graph_so_code_230 },
    { "x11graph_so_code_231", 7, x11graph_so_code_231 },
    { "x11graph_so_code_232", 5, x11graph_so_code_232 },
    { "x11graph_so_code_233", 2, x11graph_so_code_233 },
    { "x11graph_so_code_234", 1, x11graph_so_code_234 },
    { "x11graph_so_code_235", 2, x11graph_so_code_235 },
    { "x11graph_so_code_236", 2, x11graph_so_code_236 },
    { "x11graph_so_code_237", 2, x11graph_so_code_237 },
    { "x11graph_so_code_238", 9, x11graph_so_code_238 },
    { "x11graph_so_code_239", 7, x11graph_so_code_239 },
    { "x11graph_so_code_240", 2, x11graph_so_code_240 },
    { "x11graph_so_code_241", 1, x11graph_so_code_241 },
    { "x11graph_so_code_242", 1, x11graph_so_code_242 },
    { "x11graph_so_code_243", 1, x11graph_so_code_243 },
    { "x11graph_so_code_244", 1, x11graph_so_code_244 },
    { "x11graph_so_code_245", 1, x11graph_so_code_245 },
    { "x11graph_so_code_246", 1, x11graph_so_code_246 },
    { "x11graph_so_code_247", 1, x11graph_so_code_247 },
    { "x11graph_so_code_248", 1, x11graph_so_code_248 },
    { "x11graph_so_code_249", 1, x11graph_so_code_249 },
    { "x11graph_so_code_250", 1, x11graph_so_code_250 },
    { "x11graph_so_code_251", 7, x11graph_so_code_251 },
    { "x11graph_so_code_252", 3, x11graph_so_code_252 },
    { "x11graph_so_code_253", 4, x11graph_so_code_253 },
    { "x11graph_so_code_254", 4, x11graph_so_code_254 },
    { "x11graph_so_code_255", 6, x11graph_so_code_255 },
    { "x11graph_so_code_256", 2, x11graph_so_code_256 },
    { "x11graph_so_code_257", 2, x11graph_so_code_257 },
    { "x11graph_so_code_258", 2, x11graph_so_code_258 },
    { "x11graph_so_code_259", 2, x11graph_so_code_259 },
    { "x11graph_so_code_260", 2, x11graph_so_code_260 },
    { "x11graph_so_code_261", 6, x11graph_so_code_261 },
    { "x11graph_so_code_262", 3, x11graph_so_code_262 },
    { "x11graph_so_code_263", 3, x11graph_so_code_263 },
    { "x11graph_so_code_264", 1, x11graph_so_code_264 },
    { "x11graph_so_code_265", 1, x11graph_so_code_265 },
    { "x11graph_so_code_266", 1, x11graph_so_code_266 },
    { "x11graph_so_code_267", 1, x11graph_so_code_267 },
    { "x11graph_so_code_268", 1, x11graph_so_code_268 },
    { "x11graph_so_code_269", 1, x11graph_so_code_269 },
    { "x11graph_so_code_270", 1, x11graph_so_code_270 },
    { "x11graph_so_code_271", 1, x11graph_so_code_271 },
    { "x11graph_so_code_272", 1, x11graph_so_code_272 },
    { "x11graph_so_code_273", 1, x11graph_so_code_273 },
    { "x11graph_so_code_274", 1, x11graph_so_code_274 }
  };

int
decl_x11graph_so_9437ec791784179c (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_x11graph_so_9437ec791784179c);
  return (0);
}

DECLARE_COMPILED_CODE ("x11graph.so", 96, decl_x11graph_so_9437ec791784179c, x11graph_so_9437ec791784179c)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_x11graph_so_data_9437ec791784179c [25019] =
  "\xde\x02\x83\x03\xc1\x30\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc0\x22"
  "\x29\x21\x9d\x2b\xb9\x1d\xb0\x82\x88\xc1\xba\x22\x29\x21\x9d\x2b"
  "\xbb\x1d\xb0\x83\x88\xc3\xbc\x22\x29\x21\x9d\x2b\xbd\x1d\xb0\x84"
  "\x88\xc2\xbe\x22\x29\x21\x9d\x2b\xbf\x1d\xb0\x85\x88\xc2\x1c\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x86\x88\xc1\x22\x29\x21\x9d\x2b\x1c"
  "\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88"
  "\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29"
  "\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x22\x29\x21\x9d\x2b\x1c\x1d"
  "\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1"
  "\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21"
  "\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d"
  "\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1"
  "\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21"
  "\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d"
  "\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\x1f\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x1f\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc5\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc4\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc4\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c"
  "\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\xc5\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b"
  "\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02"
  "\x88\xc5\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b"
  "\x1c\x1d\xb0\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02"
  "\x88\xc1\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x1f\x1c\x22\x29"
  "\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x22\x29\x21\x9d\x2b\x1c"
  "\x1d\xb0\x02\x88\xc4\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88"
  "\xc4\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x22\x29"
  "\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc1\x22\x29\x21\x9d\x2b\x1c\x1d"
  "\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xc5\x1c\x22\x29\x21"
  "\x9d\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x22\x29\x21\x9d\x2b\x1c\x1d"
  "\xb0\x02\x88\xc1\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\xc1\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x1c\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x1c\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x1c\x0d\x0d\x0d\x0d\x0d\x0d\x08\x0d\x1c"
  "\x0d\x1c\x25\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x24\x28\x0d\x28\x0d\x1c\x28"
  "\x0d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x0d\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\xc1\x0d\x1c\x0d\x1c\x0d\x1c\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x0d\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x0d\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x81"
  "\x0f\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\xc3\x1c\x1d\x82\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d"
  "\x84\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x0c\x1b\x81\xc1\x0c"
  "\x0c\x0c\x0d\x1c\x1b\x0d\x1c\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x1d\x1b\x82\x1b\x24\x28"
  "\x0d\x1c\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x82\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\xb6\x08\xb2\x1b"
  "\x82\x0d\x1c\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\xb6\x81\xb2\x1b\x82\x07"
  "\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\xb6\x82\x1b\x84\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x07\x85\x84\xc3\x1c\x02\x80\x1d\x1b\x83\xc2\xbe\x81\x0d\xba\x24"
  "\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x1d\xb2\x24\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x1d\x07\x0d\x1c\x1b\x1b\x81\x82\xb6\x83\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x07\x83"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x83\x22\x29\x21"
  "\x9f\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x0d\x0d\x81\x84\x0d\x1c\x80"
  "\xb6\x82\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\x81\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82"
  "\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d"
  "\x81\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x83\x22\x29"
  "\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x84\x22\x29\x21\x9f\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1d\x85\x22\x29\x21\x9f\x2b\x1c\x1d\xb0"
  "\x02\x88\x81\x1b\x82\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x82\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07"
  "\x83\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x84\x1b\x82\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x07\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x82\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x1b\x82\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\x0c\x28\x0d"
  "\x1c\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x83\x1b\x02\x1b\x1b\x82\x0d\x1d\x0d\x1c\x24\x28\x1b\x28"
  "\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x82"
  "\x1d\x1b\x83\x1b\x1b\x81\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x81\x0c\x0c\x07\x0c"
  "\xb6\x80\x83\xc1\x1c\xc1\xc1\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x80\xb6\x1b\x81\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80\x1b\x1b\x81\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc1\x1b\x84"
  "\x07\x83\x1b\x82\x0d\x1c\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb6\x0c"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x9e\x80\x1b\x81\x1b\x82\x0c\x1b\x02\x28"
  "\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x09\x09\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x07\x09\x09\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x81\x1b\x82\x1b\x24\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x02\x81\x1b\x82\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\xbc\x1d\xb0\x02\x88\x1b\x02\x81\x1b\x82\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x85\x1b\x82"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x84\x1b"
  "\xb6\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x84\x82\xb6\x83\x80\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x02"
  "\x80\xb6\x81\x1b\x82\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x82\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\xb6\x80\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\xb6\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\xb6\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x83\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x84\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\xb6\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\xb6\x86\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x02\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x02\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\xb6\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\xb6\x80\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\xb6\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0"
  "\x02\x88\xb6\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x83"
  "\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x84\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b"
  "\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b"
  "\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22"
  "\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b"
  "\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22"
  "\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1d\x81\x22\x29\x21\x9f\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x1d\x82\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x1d\x83\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x84\x22"
  "\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1d\x0d\x0d\x0d\x0d\x1c\x0d"
  "\x1c\x0d\x1b\x0d\x08\x0d\x1c\x25\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x24"
  "\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x1b\x24\x28\x1b\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x81\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1b\x81\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x84\x83\x81\x80\x1b\x82\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x81"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x23\x22"
  "\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x1b\x82\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x84\x1b\x82\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x81\x84\x83\x1b\x82"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b"
  "\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0"
  "\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x0d\x1c\x25\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x24\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x81\x1b"
  "\x82\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x85\x07\x83\x82\x84\xb6"
  "\x80\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x82\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1f\x81\x1b\x82\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\xb6\x80\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\xb6\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6"
  "\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x83\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x84\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\xb6\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6"
  "\x86\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x02\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\xb6\x02\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\xb6\x02\x22\x29\x21\x9e\x2b\xb8\x17\x1c\x88\x1b\x0d"
  "\x85\x84\x83\x82\x81\x80\xb0\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x17\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x0d\x0d\x0d\x0d"
  "\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x17\x1b\x0c\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x1b\x0d\x1c\x1b\x0d\x1c"
  "\x1b\x08\x88\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d"
  "\x1b\x1b\x1b\x1b\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1e\x17\x0d\x1c\x0d\x0d\x9a\x0c\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x1c\x17\x02\x02\x02\x86\x85\x84\x83\x82\x81"
  "\x80\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x1b\x9f"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x9f\x0c\x1b\x0d\x1b\x1b\x08\x8b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x0d\x0c\x0d\x0d\x1b\x0d\x0d\x9c\x84\x83\x82\x81\x80\x9c\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x1b\x0d\x0d\x1b\x0d\x1b\x0d\x0d\x0d\x1b\x0d\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x0d\x0d\x0d\x1b\x0d\x17\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\xb4\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x06\x0c\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x17\x1d\x1b\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x0d\x1b\x17\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x17\x1b\x0d\x1c\x1b\x99\x1b\xb6\x0c\x0d\x0d\x0d\x0d\x0d\x08\x8c"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x02\x81\x02\x1b\x2a\x02"
  "\x1b\x2a\x02\x1b\x2a\x02\x1b\x2a\x1b\x82\x1b\x2a\xb2\x0d\x1b\x2a"
  "\x83\x07\x1b\x80\x02\x85\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x1b\x9f"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x9f\x84\x1b\x0d\x1b\x0d\x0d\x0d\x1b\x0d\x9e\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9e\x0c\x1b\x0d\x0d\x0d\x0d"
  "\x08\x8c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x08\x1b\x2a\xc3\x0d\x1c"
  "\x0d\x1b\x2a\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b"
  "\x0d\x0d\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x17\x1e\x1e\x1b\x2a\x1b\x2a\x81\x02\x02\x02\x02"
  "\x02\x02\x02\x02\x02\x02\x02\x86\x85\x84\x83\x82\x81\x80\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb5\x2a\xb3\x2a"
  "\xb1\x2a\x17\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x26\x1b"
  "\xb2\x1b\x1b\x1b\x24\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63"
  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
  "\x2e\x30\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
  "\x63\x2d\x39\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
  "\x69\x6d\x65\x2f\x78\x31\x31\x67\x72\x61\x70\x68\x2e\x69\x6e\x66"
  "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
  "\x72\x6f\x6f\x74\x5d\x02\x15\x78\x2d\x63\x6c\x6f\x73\x65\x2d\x61"
  "\x6c\x6c\x2d\x64\x69\x73\x70\x6c\x61\x79\x73\x61\x04\x82\x02\x03"
  "\x02\x15\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2d\x64\x65\x73\x63"
  "\x72\x69\x70\x74\x6f\x72\x62\x04\x83\x04\x03\x02\x16\x78\x2d\x64"
  "\x69\x73\x70\x6c\x61\x79\x2d\x67\x65\x74\x2d\x64\x65\x66\x61\x75"
  "\x6c\x74\x63\x04\x85\x08\x03\x02\x19\x78\x2d\x64\x69\x73\x70\x6c"
  "\x61\x79\x2d\x70\x72\x6f\x63\x65\x73\x73\x2d\x65\x76\x65\x6e\x74"
  "\x73\x64\x04\x84\x06\x03\x02\x11\x78\x2d\x66\x6f\x6e\x74\x2d\x73"
  "\x74\x72\x75\x63\x74\x75\x72\x65\x09\x65\x04\x84\x06\x03\x0a\x02"
  "\x0e\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x62\x65\x65\x70\x66\x04"
  "\x83\x04\x03\x0b\x02\x08\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d"
  "\x63\x6c\x65\x61\x72\x0c\x67\x04\x83\x04\x03\x0d\x02\x09\x12\x78"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70"
  "\x0e\x68\x04\x83\x04\x03\x0f\x02\x0a\x0f\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2d\x64\x65\x70\x74\x68\x10\x69\x04\x83\x04\x03\x11\x02"
  "\x0b\x14\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x65\x76\x65\x6e\x74"
  "\x2d\x6d\x61\x73\x6b\x6a\x04\x83\x04\x03\x12\x02\x0c\x0f\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2d\x66\x6c\x75\x73\x68\x13\x6b\x04\x83"
  "\x04\x03\x14\x02\x0d\x11\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x69"
  "\x63\x6f\x6e\x69\x66\x79\x15\x6c\x04\x83\x04\x03\x16\x02\x0e\x0c"
  "\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x69\x64\x17\x6d\x04\x83\x04"
  "\x03\x18\x02\x0f\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x6c\x6f"
  "\x77\x65\x72\x19\x6e\x04\x83\x04\x03\x1a\x02\x10\x0d\x78\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x2d\x6d\x61\x70\x1b\x6f\x04\x83\x04\x03\x1c"
  "\x02\x11\x17\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x71\x75\x65\x72"
  "\x79\x2d\x70\x6f\x69\x6e\x74\x65\x72\x1d\x70\x04\x83\x04\x03\x1e"
  "\x02\x12\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x72\x61\x69\x73"
  "\x65\x1f\x71\x04\x83\x04\x03\x20\x02\x13\x1e\x78\x2d\x77\x69\x6e"
  "\x64\x6f\x77\x2d\x73\x65\x74\x2d\x62\x61\x63\x6b\x67\x72\x6f\x75"
  "\x6e\x64\x2d\x63\x6f\x6c\x6f\x72\x21\x72\x04\x84\x06\x03\x22\x02"
  "\x14\x1a\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x62"
  "\x6f\x72\x64\x65\x72\x2d\x63\x6f\x6c\x6f\x72\x23\x73\x04\x84\x06"
  "\x03\x24\x02\x15\x1a\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65"
  "\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69\x64\x74\x68\x25\x74"
  "\x04\x84\x06\x03\x26\x02\x16\x1a\x78\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2d\x73\x65\x74\x2d\x63\x75\x72\x73\x6f\x72\x2d\x63\x6f\x6c\x6f"
  "\x72\x75\x04\x84\x06\x03\x27\x02\x17\x18\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2d\x73\x65\x74\x2d\x65\x76\x65\x6e\x74\x2d\x6d\x61\x73"
  "\x6b\x28\x76\x04\x84\x06\x03\x29\x02\x18\x12\x78\x2d\x77\x69\x6e"
  "\x64\x6f\x77\x2d\x73\x65\x74\x2d\x66\x6f\x6e\x74\x2a\x77\x04\x84"
  "\x06\x03\x2b\x02\x19\x1e\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73"
  "\x65\x74\x2d\x66\x6f\x72\x65\x67\x72\x6f\x75\x6e\x64\x2d\x63\x6f"
  "\x6c\x6f\x72\x2c\x78\x04\x84\x06\x03\x2d\x02\x1a\x17\x78\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x69\x63\x6f\x6e\x2d\x6e"
  "\x61\x6d\x65\x2e\x79\x04\x84\x06\x03\x2f\x02\x1b\x18\x78\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x69\x6e\x70\x75\x74\x2d"
  "\x68\x69\x6e\x74\x30\x7a\x04\x84\x06\x03\x31\x02\x1c\x23\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x69\x6e\x74\x65\x72"
  "\x6e\x61\x6c\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69\x64\x74\x68"
  "\x32\x7b\x04\x84\x06\x03\x33\x02\x1d\x19\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2d\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65\x2d\x63\x6f\x6c"
  "\x6f\x72\x34\x7c\x04\x84\x06\x03\x35\x02\x1e\x19\x78\x2d\x77\x69"
  "\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65\x2d\x73"
  "\x68\x61\x70\x65\x36\x7d\x04\x84\x06\x03\x37\x02\x1f\x12\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x6e\x61\x6d\x65\x38"
  "\x7e\x04\x84\x06\x03\x39\x02\x20\x16\x78\x2d\x77\x69\x6e\x64\x6f"
  "\x77\x2d\x73\x65\x74\x2d\x70\x6f\x73\x69\x74\x69\x6f\x6e\x3a\x7f"
  "\x04\x85\x08\x03\x3b\x02\x21\x12\x78\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2d\x73\x65\x74\x2d\x73\x69\x7a\x65\x3c\x80\x01\x04\x85\x08\x03"
  "\x3d\x02\x22\x1b\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x74\x61"
  "\x72\x62\x61\x73\x65\x2d\x66\x69\x6c\x65\x6e\x61\x6d\x65\x3e\x81"
  "\x01\x04\x83\x04\x03\x3f\x02\x23\x10\x78\x2d\x77\x69\x6e\x64\x6f"
  "\x77\x2d\x76\x69\x73\x75\x61\x6c\x40\x82\x01\x04\x83\x04\x03\x41"
  "\x02\x24\x12\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x77\x69\x74\x68"
  "\x64\x72\x61\x77\x42\x83\x01\x04\x83\x04\x03\x43\x02\x25\x10\x78"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x78\x2d\x73\x69\x7a\x65\x44\x84"
  "\x01\x04\x83\x04\x03\x45\x02\x26\x10\x78\x2d\x77\x69\x6e\x64\x6f"
  "\x77\x2d\x79\x2d\x73\x69\x7a\x65\x46\x85\x01\x04\x83\x04\x03\x47"
  "\x02\x27\x09\x15\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x63"
  "\x6f\x70\x79\x2d\x61\x72\x65\x61\x48\x86\x01\x04\x8a\x12\x03\x49"
  "\x02\x28\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72"
  "\x61\x67\x2d\x63\x75\x72\x73\x6f\x72\x4a\x87\x01\x04\x85\x08\x03"
  "\x4b\x02\x29\x09\x14\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d"
  "\x64\x72\x61\x77\x2d\x61\x72\x63\x4c\x88\x01\x04\x8a\x12\x03\x4d"
  "\x02\x2a\x15\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72"
  "\x61\x77\x2d\x6c\x69\x6e\x65\x4e\x89\x01\x04\x87\x0c\x03\x4f\x02"
  "\x2b\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72\x61"
  "\x77\x2d\x6c\x69\x6e\x65\x73\x50\x8a\x01\x04\x85\x08\x03\x51\x02"
  "\x2c\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72\x61"
  "\x77\x2d\x70\x6f\x69\x6e\x74\x52\x8b\x01\x04\x85\x08\x03\x53\x02"
  "\x2d\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72\x61"
  "\x77\x2d\x70\x6f\x69\x6e\x74\x73\x54\x8c\x01\x04\x85\x08\x03\x55"
  "\x02\x2e\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72"
  "\x61\x77\x2d\x73\x74\x72\x69\x6e\x67\x56\x8d\x01\x04\x86\x0a\x03"
  "\x57\x02\x2f\x1d\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64"
  "\x72\x61\x77\x2d\x69\x6d\x61\x67\x65\x2d\x73\x74\x72\x69\x6e\x67"
  "\x58\x8e\x01\x04\x86\x0a\x03\x59\x02\x30\x18\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2d\x66\x69\x6c\x6c\x2d\x70\x6f\x6c\x79\x67"
  "\x6f\x6e\x5a\x8f\x01\x04\x84\x06\x03\x5b\x02\x31\x1c\x78\x2d\x67"
  "\x72\x61\x70\x68\x69\x63\x73\x2d\x6d\x61\x70\x2d\x78\x2d\x63\x6f"
  "\x6f\x72\x64\x69\x6e\x61\x74\x65\x5c\x90\x01\x04\x84\x06\x03\x5d"
  "\x02\x32\x1c\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x6d\x61"
  "\x70\x2d\x79\x2d\x63\x6f\x6f\x72\x64\x69\x6e\x61\x74\x65\x5e\x91"
  "\x01\x04\x84\x06\x03\x5f\x02\x33\x17\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2d\x6d\x6f\x76\x65\x2d\x63\x75\x72\x73\x6f\x72\x60"
  "\x92\x01\x04\x85\x08\x03\x61\x02\x34\x17\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2d\x6f\x70\x65\x6e\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x62\x93\x01\x04\x85\x08\x03\x63\x02\x35\x17\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2d\x72\x65\x63\x6f\x6e\x66\x69\x67\x75\x72"
  "\x65\x64\x94\x01\x04\x85\x08\x03\x65\x02\x36\x20\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2d\x72\x65\x73\x65\x74\x2d\x63\x6c\x69"
  "\x70\x2d\x72\x65\x63\x74\x61\x6e\x67\x6c\x65\x66\x95\x01\x04\x83"
  "\x04\x03\x67\x02\x37\x1e\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2d\x73\x65\x74\x2d\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e"
  "\x67\x6c\x65\x68\x96\x01\x04\x87\x0c\x03\x69\x02\x38\x16\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74\x2d\x64\x61\x73"
  "\x68\x65\x73\x6a\x97\x01\x04\x85\x08\x03\x6b\x02\x39\x1a\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74\x2d\x66\x69\x6c"
  "\x6c\x2d\x73\x74\x79\x6c\x65\x98\x01\x04\x84\x06\x03\x6c\x02\x3a"
  "\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74\x2d"
  "\x66\x75\x6e\x63\x74\x69\x6f\x6e\x6d\x99\x01\x04\x84\x06\x03\x6e"
  "\x02\x3b\x1a\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65"
  "\x74\x2d\x6c\x69\x6e\x65\x2d\x73\x74\x79\x6c\x65\x6f\x9a\x01\x04"
  "\x84\x06\x03\x70\x02\x3c\x1a\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2d\x73\x65\x74\x2d\x76\x64\x63\x2d\x65\x78\x74\x65\x6e\x74"
  "\x71\x9b\x01\x04\x87\x0c\x03\x72\x02\x3d\x16\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2d\x76\x64\x63\x2d\x65\x78\x74\x65\x6e\x74"
  "\x73\x9c\x01\x04\x83\x04\x03\x74\x02\x3e\x13\x78\x2d\x62\x79\x74"
  "\x65\x73\x2d\x69\x6e\x74\x6f\x2d\x69\x6d\x61\x67\x65\x75\x9d\x01"
  "\x04\x84\x06\x03\x76\x02\x3f\x0f\x78\x2d\x63\x72\x65\x61\x74\x65"
  "\x2d\x69\x6d\x61\x67\x65\x77\x9e\x01\x04\x85\x08\x03\x78\x02\x40"
  "\x10\x78\x2d\x64\x65\x73\x74\x72\x6f\x79\x2d\x69\x6d\x61\x67\x65"
  "\x9f\x01\x04\x83\x04\x03\x79\x02\x41\x09\x10\x78\x2d\x64\x69\x73"
  "\x70\x6c\x61\x79\x2d\x69\x6d\x61\x67\x65\x7a\xa0\x01\x04\x8a\x12"
  "\x03\x7b\x02\x42\x17\x78\x2d\x67\x65\x74\x2d\x70\x69\x78\x65\x6c"
  "\x2d\x66\x72\x6f\x6d\x2d\x69\x6d\x61\x67\x65\x7c\xa1\x01\x04\x85"
  "\x08\x03\x7d\x02\x43\x15\x78\x2d\x73\x65\x74\x2d\x70\x69\x78\x65"
  "\x6c\x2d\x69\x6e\x2d\x69\x6d\x61\x67\x65\x7e\xa2\x01\x04\x86\x0a"
  "\x03\x7f\x02\x44\x11\x78\x2d\x61\x6c\x6c\x6f\x63\x61\x74\x65\x2d"
  "\x63\x6f\x6c\x6f\x72\x80\x01\xa3\x01\x04\x86\x0a\x03\x81\x01\x02"
  "\x45\x12\x78\x2d\x63\x72\x65\x61\x74\x65\x2d\x63\x6f\x6c\x6f\x72"
  "\x6d\x61\x70\x82\x01\xa4\x01\x04\x85\x08\x03\x83\x01\x02\x46\x10"
  "\x78\x2d\x66\x72\x65\x65\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\xa5"
  "\x01\x04\x83\x04\x03\x84\x01\x02\x47\x0e\x78\x2d\x71\x75\x65\x72"
  "\x79\x2d\x63\x6f\x6c\x6f\x72\x85\x01\xa6\x01\x04\x84\x06\x03\x86"
  "\x01\x02\x48\x16\x78\x2d\x73\x65\x74\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x87\x01\xa7\x01\x04\x84\x06"
  "\x03\x88\x01\x02\x49\x0e\x78\x2d\x73\x74\x6f\x72\x65\x2d\x63\x6f"
  "\x6c\x6f\x72\x89\x01\xa8\x01\x04\x87\x0c\x03\x8a\x01\x02\x4a\x0f"
  "\x78\x2d\x73\x74\x6f\x72\x65\x2d\x63\x6f\x6c\x6f\x72\x73\x8b\x01"
  "\xa9\x01\x04\x84\x06\x03\x8c\x01\x02\x4b\x14\x78\x2d\x76\x69\x73"
  "\x75\x61\x6c\x2d\x64\x65\x61\x6c\x6c\x6f\x63\x61\x74\x65\x8d\x01"
  "\xaa\x01\x04\x83\x04\x03\x8e\x01\x02\x4c\x02\x78\x10\x78\x2d\x63"
  "\x6c\x6f\x73\x65\x2d\x64\x69\x73\x70\x6c\x61\x79\x0b\x61\x76\x61"
  "\x69\x6c\x61\x62\x6c\x65\x3f\x06\x63\x6c\x65\x61\x72\x06\x63\x6c"
  "\x6f\x73\x65\x07\x63\x6f\x6c\x6f\x72\x3f\x12\x63\x6f\x6f\x72\x64"
  "\x69\x6e\x61\x74\x65\x2d\x6c\x69\x6d\x69\x74\x73\x0a\x63\x6f\x70"
  "\x79\x2d\x61\x72\x65\x61\x10\x63\x72\x65\x61\x74\x65\x2d\x63\x6f"
  "\x6c\x6f\x72\x6d\x61\x70\x0d\x63\x72\x65\x61\x74\x65\x2d\x69\x6d"
  "\x61\x67\x65\x19\x64\x65\x76\x69\x63\x65\x2d\x63\x6f\x6f\x72\x64"
  "\x69\x6e\x61\x74\x65\x2d\x6c\x69\x6d\x69\x74\x73\x0c\x64\x72\x61"
  "\x67\x2d\x63\x75\x72\x73\x6f\x72\x09\x64\x72\x61\x77\x2d\x61\x72"
  "\x63\x0c\x64\x72\x61\x77\x2d\x63\x69\x72\x63\x6c\x65\x0b\x64\x72"
  "\x61\x77\x2d\x69\x6d\x61\x67\x65\x0a\x64\x72\x61\x77\x2d\x6c\x69"
  "\x6e\x65\x0b\x64\x72\x61\x77\x2d\x6c\x69\x6e\x65\x73\x0b\x64\x72"
  "\x61\x77\x2d\x70\x6f\x69\x6e\x74\x0c\x64\x72\x61\x77\x2d\x70\x6f"
  "\x69\x6e\x74\x73\x0e\x64\x72\x61\x77\x2d\x73\x75\x62\x69\x6d\x61"
  "\x67\x65\x8f\x01\x0a\x64\x72\x61\x77\x2d\x74\x65\x78\x74\x11\x64"
  "\x72\x61\x77\x2d\x74\x65\x78\x74\x2d\x6f\x70\x61\x71\x75\x65\x0c"
  "\x66\x69\x6c\x6c\x2d\x63\x69\x72\x63\x6c\x65\x0d\x66\x69\x6c\x6c"
  "\x2d\x70\x6f\x6c\x79\x67\x6f\x6e\x06\x66\x6c\x75\x73\x68\x0f\x66"
  "\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x0d\x67\x65"
  "\x74\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x0c\x67\x65\x74\x2d\x64"
  "\x65\x66\x61\x75\x6c\x74\x0f\x69\x63\x6f\x6e\x69\x66\x79\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x0c\x69\x6d\x61\x67\x65\x2d\x64\x65\x70\x74"
  "\x68\x0d\x6c\x6f\x77\x65\x72\x2d\x77\x69\x6e\x64\x6f\x77\x0b\x6d"
  "\x61\x70\x2d\x77\x69\x6e\x64\x6f\x77\x90\x01\x0c\x6d\x6f\x76\x65"
  "\x2d\x63\x75\x72\x73\x6f\x72\x0c\x6d\x6f\x76\x65\x2d\x77\x69\x6e"
  "\x64\x6f\x77\x05\x6f\x70\x65\x6e\x06\x6f\x70\x65\x6e\x3f\x0e\x71"
  "\x75\x65\x72\x79\x2d\x70\x6f\x69\x6e\x74\x65\x72\x0d\x72\x61\x69"
  "\x73\x65\x2d\x77\x69\x6e\x64\x6f\x77\x15\x72\x65\x73\x65\x74\x2d"
  "\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e\x67\x6c\x65\x0e\x72"
  "\x65\x73\x69\x7a\x65\x2d\x77\x69\x6e\x64\x6f\x77\x15\x73\x65\x74"
  "\x2d\x62\x61\x63\x6b\x67\x72\x6f\x75\x6e\x64\x2d\x63\x6f\x6c\x6f"
  "\x72\x11\x73\x65\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x63\x6f\x6c"
  "\x6f\x72\x11\x73\x65\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69"
  "\x64\x74\x68\x13\x73\x65\x74\x2d\x63\x6c\x69\x70\x2d\x72\x65\x63"
  "\x74\x61\x6e\x67\x6c\x65\x0d\x73\x65\x74\x2d\x63\x6f\x6c\x6f\x72"
  "\x6d\x61\x70\x16\x73\x65\x74\x2d\x63\x6f\x6f\x72\x64\x69\x6e\x61"
  "\x74\x65\x2d\x6c\x69\x6d\x69\x74\x73\x11\x73\x65\x74\x2d\x64\x72"
  "\x61\x77\x69\x6e\x67\x2d\x6d\x6f\x64\x65\x09\x73\x65\x74\x2d\x66"
  "\x6f\x6e\x74\x15\x73\x65\x74\x2d\x66\x6f\x72\x65\x67\x72\x6f\x75"
  "\x6e\x64\x2d\x63\x6f\x6c\x6f\x72\x0e\x73\x65\x74\x2d\x69\x63\x6f"
  "\x6e\x2d\x6e\x61\x6d\x65\x0f\x73\x65\x74\x2d\x69\x6e\x70\x75\x74"
  "\x2d\x68\x69\x6e\x74\x1a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x6e"
  "\x61\x6c\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69\x64\x74\x68\x0f"
  "\x73\x65\x74\x2d\x6c\x69\x6e\x65\x2d\x73\x74\x79\x6c\x65\x91\x01"
  "\x10\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65\x2d\x63\x6f\x6c\x6f\x72"
  "\x10\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65\x2d\x73\x68\x61\x70\x65"
  "\x10\x73\x65\x74\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x6e\x61\x6d\x65"
  "\x12\x73\x74\x61\x72\x62\x61\x73\x65\x2d\x66\x69\x6c\x65\x6e\x61"
  "\x6d\x65\x0c\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x10\x77"
  "\x69\x74\x68\x64\x72\x61\x77\x2d\x77\x69\x6e\x64\x6f\x77\x17\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x65\x76\x69\x63\x65"
  "\x2d\x74\x79\x70\x65\x92\x01\x12\x64\x69\x73\x70\x6c\x61\x79\x2d"
  "\x66\x69\x6e\x61\x6c\x69\x7a\x65\x72\x93\x01\x03\x1b\x78\x2d\x67"
  "\x72\x61\x70\x68\x69\x63\x73\x2f\x77\x69\x74\x68\x64\x72\x61\x77"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x94\x01\x17\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f"
  "\x95\x01\x1d\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x74"
  "\x61\x72\x62\x61\x73\x65\x2d\x66\x69\x6c\x65\x6e\x61\x6d\x65\x96"
  "\x01\x1b\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x6e\x61\x6d\x65\x97\x01\x1b\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74\x2d\x6d\x6f"
  "\x75\x73\x65\x2d\x73\x68\x61\x70\x65\x98\x01\x1b\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65"
  "\x2d\x63\x6f\x6c\x6f\x72\x99\x01\x1a\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2f\x73\x65\x74\x2d\x6c\x69\x6e\x65\x2d\x73\x74\x79"
  "\x6c\x65\x9a\x01\x25\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f"
  "\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x62\x6f\x72"
  "\x64\x65\x72\x2d\x77\x69\x64\x74\x68\x9b\x01\x1a\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74\x2d\x69\x6e\x70\x75\x74"
  "\x2d\x68\x69\x6e\x74\x9c\x01\x19\x78\x2d\x67\x72\x61\x70\x68\x69"
  "\x63\x73\x2f\x73\x65\x74\x2d\x69\x63\x6f\x6e\x2d\x6e\x61\x6d\x65"
  "\x9d\x01\x20\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x65"
  "\x74\x2d\x66\x6f\x72\x65\x67\x72\x6f\x75\x6e\x64\x2d\x63\x6f\x6c"
  "\x6f\x72\x9e\x01\x14\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f"
  "\x73\x65\x74\x2d\x66\x6f\x6e\x74\x9f\x01\x1c\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2f\x73\x65\x74\x2d\x64\x72\x61\x77\x69\x6e"
  "\x67\x2d\x6d\x6f\x64\x65\xa0\x01\x21\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2f\x73\x65\x74\x2d\x63\x6f\x6f\x72\x64\x69\x6e\x61"
  "\x74\x65\x2d\x6c\x69\x6d\x69\x74\x73\xa1\x01\x18\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74\x2d\x63\x6f\x6c\x6f\x72"
  "\x6d\x61\x70\xa2\x01\x1e\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2f\x73\x65\x74\x2d\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e"
  "\x67\x6c\x65\xa3\x01\x1c\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2f\x73\x65\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69\x64\x74"
  "\x68\xa4\x01\x1c\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73"
  "\x65\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x63\x6f\x6c\x6f\x72\xa5"
  "\x01\x20\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x74"
  "\x2d\x62\x61\x63\x6b\x67\x72\x6f\x75\x6e\x64\x2d\x63\x6f\x6c\x6f"
  "\x72\xa6\x01\x19\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x72"
  "\x65\x73\x69\x7a\x65\x2d\x77\x69\x6e\x64\x6f\x77\xa7\x01\x20\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x72\x65\x73\x65\x74\x2d"
  "\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e\x67\x6c\x65\xa8\x01"
  "\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x72\x61\x69\x73"
  "\x65\x2d\x77\x69\x6e\x64\x6f\x77\xa9\x01\x19\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2f\x71\x75\x65\x72\x79\x2d\x70\x6f\x69\x6e"
  "\x74\x65\x72\xaa\x01\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2f\x6f\x70\x65\x6e\x2d\x77\x69\x6e\x64\x6f\x77\x3f\xab\x01\x10"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x6f\x70\x65\x6e\xac"
  "\x01\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x6d\x6f\x76"
  "\x65\x2d\x77\x69\x6e\x64\x6f\x77\xad\x01\x17\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2f\x6d\x6f\x76\x65\x2d\x63\x75\x72\x73\x6f"
  "\x72\xae\x01\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x6d"
  "\x61\x70\x2d\x77\x69\x6e\x64\x6f\x77\xaf\x01\x18\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2f\x6c\x6f\x77\x65\x72\x2d\x77\x69\x6e"
  "\x64\x6f\x77\xb0\x01\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2f\x69\x6d\x61\x67\x65\x2d\x64\x65\x70\x74\x68\xb1\x01\x1a\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x69\x63\x6f\x6e\x69\x66"
  "\x79\x2d\x77\x69\x6e\x64\x6f\x77\xb2\x01\x17\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2f\x67\x65\x74\x2d\x64\x65\x66\x61\x75\x6c"
  "\x74\xb3\x01\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x67"
  "\x65\x74\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\xb4\x01\x1a\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x66\x6f\x6e\x74\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\xb5\x01\x11\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x66\x6c\x75\x73\x68\xb6\x01\x18\x78\x2d\x67"
  "\x72\x61\x70\x68\x69\x63\x73\x2f\x66\x69\x6c\x6c\x2d\x70\x6f\x6c"
  "\x79\x67\x6f\x6e\xb7\x01\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2f\x66\x69\x6c\x6c\x2d\x63\x69\x72\x63\x6c\x65\xb8\x01\x1c"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72\x61\x77\x2d"
  "\x74\x65\x78\x74\x2d\x6f\x70\x61\x71\x75\x65\xb9\x01\x15\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72\x61\x77\x2d\x74\x65"
  "\x78\x74\xba\x01\x14\x69\x6d\x61\x67\x65\x2f\x64\x72\x61\x77\x2d"
  "\x73\x75\x62\x69\x6d\x61\x67\x65\x17\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2f\x64\x72\x61\x77\x2d\x70\x6f\x69\x6e\x74\x73\xbb"
  "\x01\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72\x61"
  "\x77\x2d\x70\x6f\x69\x6e\x74\xbc\x01\x16\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x64\x72\x61\x77\x2d\x6c\x69\x6e\x65\x73\xbd"
  "\x01\x15\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72\x61"
  "\x77\x2d\x6c\x69\x6e\x65\xbe\x01\x0b\x69\x6d\x61\x67\x65\x2f\x64"
  "\x72\x61\x77\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64"
  "\x72\x61\x77\x2d\x63\x69\x72\x63\x6c\x65\xbf\x01\x14\x78\x2d\x67"
  "\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72\x61\x77\x2d\x61\x72\x63"
  "\xc0\x01\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x72"
  "\x61\x67\x2d\x63\x75\x72\x73\x6f\x72\xc1\x01\x24\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2f\x64\x65\x76\x69\x63\x65\x2d\x63\x6f"
  "\x6f\x72\x64\x69\x6e\x61\x74\x65\x2d\x6c\x69\x6d\x69\x74\x73\xc2"
  "\x01\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x63\x72\x65"
  "\x61\x74\x65\x2d\x69\x6d\x61\x67\x65\xc3\x01\x12\x63\x72\x65\x61"
  "\x74\x65\x2d\x78\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\xc4\x01\x15"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x63\x6f\x70\x79\x2d"
  "\x61\x72\x65\x61\xc5\x01\x1d\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2f\x63\x6f\x6f\x72\x64\x69\x6e\x61\x74\x65\x2d\x6c\x69\x6d"
  "\x69\x74\x73\xc6\x01\x12\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2f\x63\x6f\x6c\x6f\x72\x3f\xc7\x01\x18\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x63\x6c\x6f\x73\x65\x2d\x77\x69\x6e\x64\x6f"
  "\x77\xc8\x01\x11\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x63"
  "\x6c\x65\x61\x72\xc9\x01\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2f\x61\x76\x61\x69\x6c\x61\x62\x6c\x65\x3f\xca\x01\x12\x73"
  "\x65\x74\x2d\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2f\x78\x64\x21"
  "\xcb\x01\x0d\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2f\x78\x64\xcc"
  "\x01\x0b\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x3f\xcd\x01\x3d\x3b"
  "\x05\x6c\x69\x73\x74\x06\x12\x6d\x61\x6b\x65\x2d\x67\x63\x2d\x66"
  "\x69\x6e\x61\x6c\x69\x7a\x65\x72\xce\x01\x04\x1a\x6d\x61\x6b\x65"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x65\x76\x69\x63\x65"
  "\x2d\x74\x79\x70\x65\x02\x1a\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a"
  "\x65\x2d\x69\x6d\x61\x67\x65\x2d\x64\x61\x74\x61\x74\x79\x70\x65"
  "\xcf\x01\x02\x1d\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x63"
  "\x6f\x6c\x6f\x72\x6d\x61\x70\x2d\x64\x61\x74\x61\x74\x79\x70\x65"
  "\xd0\x01\x06\xed\x01\x88\x01\x81\x81\x02\xec\x01\x86\x01\x81\x81"
  "\x02\xeb\x01\x84\x01\x81\x81\x02\xea\x01\x82\x01\x81\x83\x02\xe9"
  "\x01\x80\x01\x81\x87\x02\xe8\x01\x7e\x81\x85\x02\xe7\x01\x7c\x81"
  "\x83\x02\xe6\x01\x7a\x81\x81\x02\xe5\x01\x78\x81\x81\x02\xe4\x01"
  "\x76\x81\xf5\x02\xe3\x01\x74\x81\xf3\x02\xe2\x01\x72\x81\xf1\x02"
  "\xe1\x01\x70\x81\xef\x02\xe0\x01\x6e\x81\xed\x02\xdf\x01\x6c\x81"
  "\xeb\x02\xde\x01\x6a\x81\xe9\x02\xdd\x01\x68\x81\xe7\x02\xdc\x01"
  "\x66\x81\xe5\x02\xdb\x01\x64\x81\xe3\x02\xda\x01\x62\x81\xe1\x02"
  "\xd9\x01\x60\x81\xdf\x02\xd8\x01\x5e\x81\xdd\x02\xd7\x01\x5c\x81"
  "\xdb\x02\xd6\x01\x5a\x81\xd9\x02\xd5\x01\x58\x81\xd7\x02\xd4\x01"
  "\x56\x81\xd5\x02\xd3\x01\x54\x81\xd3\x02\xd2\x01\x52\x81\xd1\x02"
  "\xd1\x01\x50\x81\xcf\x02\xd0\x01\x4e\x81\xcd\x02\xcf\x01\x4c\x81"
  "\xcb\x02\xce\x01\x4a\x81\xc9\x02\xcd\x01\x48\x81\xc7\x02\xcc\x01"
  "\x46\x81\xc5\x02\xcb\x01\x44\x81\xc3\x02\xca\x01\x42\x81\xc1\x02"
  "\xc9\x01\x40\x81\xbf\x02\xc8\x01\x3e\x81\xbd\x02\xc7\x01\x3c\x81"
  "\xbb\x02\xc6\x01\x3a\x81\xb9\x02\xc5\x01\x38\x81\xb7\x02\xc4\x01"
  "\x36\x81\xb5\x02\xc3\x01\x34\x81\xb3\x02\xc2\x01\x32\x81\xb1\x02"
  "\xc1\x01\x30\x81\xaf\x02\xc0\x01\x2e\x81\xad\x02\xbf\x01\x2c\x81"
  "\xab\x02\xbe\x01\x2a\x81\xa9\x02\xbd\x01\x28\x81\xa7\x02\xbc\x01"
  "\x26\x81\xa5\x02\xbb\x01\x24\x81\xa3\x02\xba\x01\x22\x81\xa1\x02"
  "\xb9\x01\x20\x81\x9f\x02\xb8\x01\x1e\x81\x9d\x02\xb7\x01\x1c\x81"
  "\x9b\x02\xb6\x01\x1a\x81\x99\x02\xb5\x01\x18\x81\x97\x02\xb4\x01"
  "\x16\x81\x95\x02\xb3\x01\x14\x81\x93\x02\xb2\x01\x12\x81\x91\x02"
  "\xb1\x01\x10\x81\x8f\x02\xb0\x01\x0e\x81\x8d\x02\xaf\x01\x0c\x81"
  "\x8b\x02\xae\x01\x0a\x81\x89\x02\xad\x01\x08\x81\x87\x02\xac\x01"
  "\x06\x81\x85\x02\xab\x01\x04\x82\x02\x87\x01\x91\x02\xd1\x01\x02"
  "\x4d\x62\x03\x21\x69\x6d\x70\x6c\x65\x6d\x65\x6e\x74\x65\x64\x2d"
  "\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65\x64"
  "\x75\x72\x65\x3f\x02\xee\x01\x04\x82\x02\x03\x0a\xd2\x01\x02\x4e"
  "\xef\x01\x04\x82\x02\x03\xd3\x01\x02\x4f\xf0\x01\x04\x82\x02\x03"
  "\xd4\x01\x02\x50\x0f\x78\x2d\x63\x6c\x6f\x73\x65\x2d\x77\x69\x6e"
  "\x64\x6f\x77\x11\x73\x65\x74\x2d\x78\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2f\x78\x77\x21\xd5\x01\x0c\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2f"
  "\x78\x77\xd6\x01\x0a\x78\x2d\x77\x69\x6e\x64\x6f\x77\x3f\xd7\x01"
  "\x04\x06\xce\x01\x02\xf4\x01\x0a\x81\x85\x02\xf3\x01\x08\x81\x83"
  "\x02\xf2\x01\x06\x81\x81\x02\xf1\x01\x04\x82\x02\x09\x14\xd8\x01"
  "\x02\x51\x02\x0b\x6d\x61\x6b\x65\x2d\x71\x75\x65\x75\x65\x02\xf5"
  "\x01\x04\x82\x02\x03\xd9\x01\x02\x52\x02\x0e\x6d\x61\x6b\x65\x2d"
  "\x31\x64\x2d\x74\x61\x62\x6c\x65\x02\xf6\x01\x04\x82\x02\x03\xda"
  "\x01\x02\x53\x0c\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66\xdb"
  "\x01\x01\x21\x04\x0b\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x04"
  "\x06\x77\x72\x69\x74\x65\x03\xf9\x01\x08\x81\x85\x02\xf8\x01\x06"
  "\x81\x85\x02\xf7\x01\x04\x84\x06\x07\x12\xdc\x01\x02\x54\xdb\x01"
  "\xfa\x01\x04\x83\x04\x03\xdd\x01\x02\x55\xdb\x01\xfb\x01\x04\x83"
  "\x04\x03\xde\x01\x02\x56\xdb\x01\xfc\x01\x04\x83\x04\x03\xdf\x01"
  "\x02\x57\xdb\x01\xfd\x01\x04\x83\x04\x03\xe0\x01\x02\x58\xdb\x01"
  "\xfe\x01\x04\x83\x04\x03\xe1\x01\x02\x59\x0d\x25\x72\x65\x63\x6f"
  "\x72\x64\x2d\x73\x65\x74\x21\xe2\x01\x02\xff\x01\x04\x84\x06\x03"
  "\xe3\x01\x02\x5a\xe2\x01\x02\x80\x02\x04\x84\x06\x03\xe4\x01\x02"
  "\x5b\x18\x55\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x6f\x70\x65\x6e"
  "\x20\x64\x69\x73\x70\x6c\x61\x79\x3a\xdb\x01\x0f\x78\x2d\x6f\x70"
  "\x65\x6e\x2d\x64\x69\x73\x70\x6c\x61\x79\x0d\x73\x74\x72\x69\x6e"
  "\x67\x20\x6f\x72\x20\x23\x66\x08\x44\x49\x53\x50\x4c\x41\x59\x21"
  "\x4e\x6f\x20\x44\x49\x53\x50\x4c\x41\x59\x20\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
  "\x20\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x65\x66\x61"
  "\x75\x6c\x74\x2d\x64\x69\x73\x70\x6c\x61\x79\x2d\x6e\x61\x6d\x65"
  "\xe5\x01\x93\x01\x18\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f"
  "\x6f\x70\x65\x6e\x2d\x64\x69\x73\x70\x6c\x61\x79\xe6\x01\x04\x03"
  "\x06\x65\x72\x72\x6f\x72\xe7\x01\x04\xe7\x01\x03\x19\x67\x65\x74"
  "\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x76\x61\x72"
  "\x69\x61\x62\x6c\x65\x04\x14\x73\x65\x61\x72\x63\x68\x2d\x67\x63"
  "\x2d\x66\x69\x6e\x61\x6c\x69\x7a\x65\x72\xe8\x01\x05\x1a\x65\x72"
  "\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61"
  "\x72\x67\x75\x6d\x65\x6e\x74\xe9\x01\x04\x09\x73\x74\x72\x69\x6e"
  "\x67\x3d\x3f\x04\x0f\x6d\x61\x6b\x65\x2d\x78\x2d\x64\x69\x73\x70"
  "\x6c\x61\x79\xea\x01\x04\x15\x61\x64\x64\x2d\x74\x6f\x2d\x67\x63"
  "\x2d\x66\x69\x6e\x61\x6c\x69\x7a\x65\x72\x21\xeb\x01\x03\x15\x6d"
  "\x61\x6b\x65\x2d\x65\x76\x65\x6e\x74\x2d\x70\x72\x65\x76\x69\x65"
  "\x77\x65\x72\xec\x01\x0a\x90\x02\x22\x81\x83\x02\x8f\x02\x20\x81"
  "\x83\x02\x8e\x02\x1e\x81\x87\x02\x8d\x02\x1c\x81\x85\x02\x8c\x02"
  "\x1a\x81\x85\x02\x8b\x02\x18\x81\x85\x02\x8a\x02\x16\x81\x87\x02"
  "\x89\x02\x14\x81\x85\x02\x88\x02\x12\x81\x83\x02\x87\x02\x10\x81"
  "\x85\x02\x86\x02\x0e\x81\x87\x02\x85\x02\x0c\x81\x85\x02\x84\x02"
  "\x0a\x83\x04\x83\x02\x08\x81\x83\x02\x82\x02\x06\x81\x83\x02\x81"
  "\x02\x04\x81\x83\x02\x21\x42\xed\x01\x02\x5c\x02\xdb\x01\x93\x01"
  "\x02\x03\x13\x77\x69\x74\x68\x6f\x75\x74\x2d\x69\x6e\x74\x65\x72"
  "\x72\x75\x70\x74\x73\xee\x01\x03\x1e\x72\x65\x6d\x6f\x76\x65\x2d"
  "\x61\x6c\x6c\x2d\x66\x72\x6f\x6d\x2d\x67\x63\x2d\x66\x69\x6e\x61"
  "\x6c\x69\x7a\x65\x72\x21\x04\x1a\x72\x65\x6d\x6f\x76\x65\x2d\x66"
  "\x72\x6f\x6d\x2d\x67\x63\x2d\x66\x69\x6e\x61\x6c\x69\x7a\x65\x72"
  "\x21\xef\x01\x04\x96\x02\x0e\x81\x83\x02\x95\x02\x0c\x81\x83\x02"
  "\x94\x02\x0a\x81\x85\x02\x93\x02\x08\x81\x83\x02\x92\x02\x06\x81"
  "\x83\x02\x91\x02\x04\x83\x04\x0d\x1d\xf0\x01\x02\x5d\xdb\x01\x98"
  "\x02\x06\x81\x83\x02\x97\x02\x04\x83\x04\x05\x0b\xf1\x01\x02\x5e"
  "\x02\xdb\x01\x05\x72\x65\x61\x64\xf2\x01\x23\x63\x6f\x6e\x64\x69"
  "\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x77\x72\x6f\x6e\x67\x2d"
  "\x74\x79\x70\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x22\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65\x3a\x62\x61\x64"
  "\x2d\x72\x61\x6e\x67\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x03"
  "\x02\x0f\x63\x75\x72\x72\x65\x6e\x74\x2d\x74\x68\x72\x65\x61\x64"
  "\x03\x1f\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x63\x75\x72\x72"
  "\x65\x6e\x74\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e"
  "\x05\x17\x62\x69\x6e\x64\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x2d\x68\x61\x6e\x64\x6c\x65\x72\x06\x25\x70\x65\x72\x6d\x61\x6e"
  "\x65\x6e\x74\x6c\x79\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x69"
  "\x6f\x2d\x74\x68\x72\x65\x61\x64\x2d\x65\x76\x65\x6e\x74\x03\x1b"
  "\x64\x65\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x69\x6f\x2d\x74\x68"
  "\x72\x65\x61\x64\x2d\x65\x76\x65\x6e\x74\x04\x0e\x70\x72\x6f\x63"
  "\x65\x73\x73\x2d\x65\x76\x65\x6e\x74\xf3\x01\x07\xa6\x02\x1e\x81"
  "\x85\x02\xa5\x02\x1c\x81\x83\x02\xa4\x02\x1a\x81\x85\x02\xa3\x02"
  "\x18\x81\x87\x02\xa2\x02\x16\x81\x83\x02\xa1\x02\x14\x81\x8d\x02"
  "\xa0\x02\x12\x81\x87\x02\x9f\x02\x10\x81\x85\x02\x9e\x02\x0e\x81"
  "\x85\x02\x9d\x02\x0c\x81\x8f\x02\x9c\x02\x0a\x81\x89\x02\x9b\x02"
  "\x08\x81\x85\x02\x9a\x02\x06\x81\x85\x02\x99\x02\x04\x83\x04\x1d"
  "\x37\xf4\x01\x02\x5f\xdb\x01\x03\x1b\x77\x69\x74\x68\x2d\x74\x68"
  "\x72\x65\x61\x64\x2d\x65\x76\x65\x6e\x74\x73\x2d\x62\x6c\x6f\x63"
  "\x6b\x65\x64\xf5\x01\x03\x0d\x71\x75\x65\x75\x65\x2d\x65\x6d\x70"
  "\x74\x79\x3f\xf6\x01\x03\x09\x64\x65\x71\x75\x65\x75\x65\x21\xf7"
  "\x01\x03\x18\x25\x72\x65\x61\x64\x2d\x61\x6e\x64\x2d\x70\x72\x6f"
  "\x63\x65\x73\x73\x2d\x65\x76\x65\x6e\x74\xf8\x01\x05\xab\x02\x0c"
  "\x81\x83\x02\xaa\x02\x0a\x81\x83\x02\xa9\x02\x08\x81\x83\x02\xa8"
  "\x02\x06\x81\x85\x02\xa7\x02\x04\x83\x04\x0b\x19\xf9\x01\x02\x60"
  "\x02\xdb\x01\xf2\x01\x04\xf3\x01\x05\x1a\x74\x65\x73\x74\x2d\x66"
  "\x6f\x72\x2d\x69\x6f\x2d\x6f\x6e\x2d\x64\x65\x73\x63\x72\x69\x70"
  "\x74\x6f\x72\x03\xb1\x02\x0e\x81\x8b\x02\xb0\x02\x0c\x81\x83\x02"
  "\xaf\x02\x0a\x81\x87\x02\xae\x02\x08\x81\x85\x02\xad\x02\x06\x81"
  "\x8d\x02\xac\x02\x04\x83\x04\x0d\x1d\xf2\x01\x02\x61\x02\xdb\x01"
  "\x03\xf5\x01\x03\xf6\x01\x03\xf7\x01\x04\xf3\x01\x05\xb9\x02\x12"
  "\x81\x85\x02\xb8\x02\x10\x81\x83\x02\xb7\x02\x0e\x81\x83\x02\xb6"
  "\x02\x0c\x81\x87\x02\xb5\x02\x0a\x81\x83\x02\xb4\x02\x08\x81\x83"
  "\x02\xb3\x02\x06\x81\x85\x02\xb2\x02\x04\x83\x04\x11\x22\xf7\x01"
  "\x02\x62\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\xf6\x01"
  "\x0b\x02\xdb\x01\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x0f"
  "\x65\x76\x65\x6e\x74\x2d\x68\x61\x6e\x64\x6c\x65\x72\x73\x02\x03"
  "\xee\x01\x04\xe8\x01\x04\x10\x65\x6e\x71\x75\x65\x75\x65\x21\x2f"
  "\x75\x6e\x73\x61\x66\x65\x04\xc9\x02\x22\x81\x85\x02\xc8\x02\x20"
  "\x81\x85\x02\xc7\x02\x1e\x81\x87\x02\xc6\x02\x1c\x81\x87\x02\xc5"
  "\x02\x1a\x81\x87\x02\xc4\x02\x18\x81\x87\x02\xc3\x02\x16\x81\x87"
  "\x02\xc2\x02\x14\x81\x89\x02\xc1\x02\x12\x81\x89\x02\xc0\x02\x10"
  "\x81\x85\x02\xbf\x02\x0e\x81\x83\x02\xbe\x02\x0c\x81\x87\x02\xbd"
  "\x02\x0a\x81\x87\x02\xbc\x02\x08\x81\x85\x02\xbb\x02\x06\x81\x83"
  "\x02\xba\x02\x04\x84\x06\x21\x38\xe8\x01\x02\x63\xf6\x01\x02\x02"
  "\xcb\x02\x06\x81\x85\x02\xca\x02\x04\x84\x06\x05\x0c\xfa\x01\x02"
  "\x64\xe2\x01\x02\x06\x6e\x65\x76\x65\x72\xfb\x01\xdb\x01\x64\xd1"
  "\x02\x0e\x81\x85\x02\xd0\x02\x0c\x81\x85\x02\xcf\x02\x0a\x81\x8b"
  "\x02\xce\x02\x08\x81\x89\x02\xcd\x02\x06\x81\x87\x02\xcc\x02\x04"
  "\x84\x06\x0d\x1a\x64\x02\x65\x03\x0f\x63\x6c\x6f\x73\x65\x2d\x78"
  "\x2d\x77\x69\x6e\x64\x6f\x77\xfc\x01\x02\xd2\x02\x04\x84\x06\x03"
  "\xfd\x01\x02\x66\xe2\x01\x02\xd3\x02\x04\x84\x06\x03\x0a\xfe\x01"
  "\x02\x67\xe2\x01\x02\xd4\x02\x04\x84\x06\x03\xff\x01\x02\x68\x02"
  "\xe2\x01\x09\x6f\x62\x73\x63\x75\x72\x65\x64\x13\x70\x61\x72\x74"
  "\x69\x61\x6c\x6c\x79\x2d\x6f\x62\x73\x63\x75\x72\x65\x64\x0b\x75"
  "\x6e\x6f\x62\x73\x63\x75\x72\x65\x64\x80\x02\xd6\x02\x06\x81\x85"
  "\x02\xd5\x02\x04\x84\x06\x05\x12\x81\x02\x02\x69\xd7\x02\x04\x82"
  "\x02\x03\x82\x02\x02\x6a\xd8\x02\x04\x82\x02\x03\x83\x02\x02\x6b"
  "\xfb\x01\xd9\x02\x04\x82\x02\x03\xfb\x01\x02\x6c\xda\x02\x04\x82"
  "\x02\x03\x84\x02\x02\x6d\xdb\x02\x04\x82\x02\x03\x85\x02\x02\x6e"
  "\xdb\x01\xdc\x02\x04\x83\x04\x03\x86\x02\x02\x6f\xdb\x01\xdd\x02"
  "\x04\x83\x04\x03\x87\x02\x02\x70\xdb\x01\xde\x02\x04\x83\x04\x03"
  "\x88\x02\x02\x71\xdb\x01\xdf\x02\x04\x83\x04\x03\x89\x02\x02\x72"
  "\xdb\x01\xe0\x02\x04\x83\x04\x03\x8a\x02\x02\x73\xe2\x01\x02\xe1"
  "\x02\x04\x84\x06\x03\x8b\x02\x02\x74\xe2\x01\x02\xe2\x02\x04\x84"
  "\x06\x03\x8c\x02\x02\x75\xe2\x01\x02\xe3\x02\x04\x84\x06\x03\x8d"
  "\x02\x02\x76\xe2\x01\x02\xe4\x02\x04\x84\x06\x03\x8e\x02\x02\x77"
  "\xdb\x01\xe6\x02\x06\x81\x83\x02\xe5\x02\x04\x83\x04\x05\x0b\x8f"
  "\x02\x02\x78\xdb\x01\xe8\x02\x06\x81\x83\x02\xe7\x02\x04\x83\x04"
  "\x05\x0a\x90\x02\x02\x79\xdb\x01\xeb\x02\x08\x81\x83\x02\xea\x02"
  "\x06\x81\x83\x02\xe9\x02\x04\x83\x04\x07\x0c\x91\x02\x02\x7a\xdb"
  "\x01\xee\x02\x08\x81\x83\x02\xed\x02\x06\x81\x83\x02\xec\x02\x04"
  "\x83\x04\x07\x0e\x92\x02\x02\x7b\xdb\x01\xf0\x02\x06\x81\x83\x02"
  "\xef\x02\x04\x83\x04\x05\x0b\x93\x02\x02\x7c\xdb\x01\xf3\x02\x08"
  "\x81\x83\x02\xf2\x02\x06\x81\x83\x02\xf1\x02\x04\x83\x04\x07\x0e"
  "\x94\x02\x02\x7d\xdb\x01\x03\xee\x01\x03\xfc\x01\x03\xf6\x02\x08"
  "\x81\x83\x02\xf5\x02\x06\x81\x83\x02\xf4\x02\x04\x83\x04\x07\x11"
  "\xee\x01\x02\x7e\xdb\x01\x04\xef\x01\x02\xf9\x02\x08\x81\x83\x02"
  "\xf8\x02\x06\x81\x83\x02\xf7\x02\x04\x83\x04\x07\x10\x95\x02\x02"
  "\x7f\x02\x2b\x02\x78\x01\x04\x0e\x73\x74\x72\x69\x6e\x67\x2d\x61"
  "\x70\x70\x65\x6e\x64\x96\x02\x05\x96\x02\x06\x96\x02\x03\x0f\x6e"
  "\x75\x6d\x62\x65\x72\x2d\x3e\x73\x74\x72\x69\x6e\x67\x05\x82\x03"
  "\x14\x81\x91\x02\x81\x03\x12\x81\x8f\x02\x80\x03\x10\x81\x8f\x02"
  "\xff\x02\x0e\x81\x8d\x02\xfe\x02\x0c\x81\x8b\x02\xfd\x02\x0a\x81"
  "\x8b\x02\xfc\x02\x08\x86\x0a\xfb\x02\x06\x81\x89\x02\xfa\x02\x04"
  "\x81\x89\x02\x13\x22\x96\x02\x02\x80\x01\x28\x80\xbc\x01\x62\xdb"
  "\x01\x15\x6d\x61\x6b\x65\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d"
  "\x64\x65\x76\x69\x63\x65\x08\x1c\x78\x2d\x67\x72\x61\x70\x68\x69"
  "\x63\x73\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d\x67\x65\x6f\x6d\x65"
  "\x74\x72\x79\x62\x02\x03\xcd\x01\x03\xe6\x01\x04\x18\x64\x65\x63"
  "\x6f\x64\x65\x2d\x73\x75\x70\x70\x72\x65\x73\x73\x2d\x6d\x61\x70"
  "\x2d\x61\x72\x67\x97\x02\x04\x0e\x6d\x61\x6b\x65\x2d\x78\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x98\x02\x04\xeb\x01\x03\x90\x01\x07\x8f\x03"
  "\x1c\x81\x8b\x02\x8e\x03\x1a\x81\x8b\x02\x8d\x03\x18\x81\x8f\x02"
  "\x8c\x03\x16\x81\x8b\x02\x8b\x03\x14\x81\x8b\x02\x8a\x03\x12\x81"
  "\x89\x02\x89\x03\x10\x81\x8d\x02\x88\x03\x0e\x81\x8f\x02\x87\x03"
  "\x0c\x81\x8d\x02\x86\x03\x0a\x81\x89\x02\x85\x03\x08\x81\x89\x02"
  "\x84\x03\x06\x81\x83\x02\x83\x03\x04\x86\x04\x1b\x35\x99\x02\x02"
  "\x81\x01\x02\x13\x1b\xdb\x01\x03\x09\x62\x6f\x6f\x6c\x65\x61\x6e"
  "\x3f\x1b\x03\xf5\x01\x03\xf8\x01\x04\x99\x03\x16\x81\x83\x02\x98"
  "\x03\x14\x81\x83\x02\x97\x03\x12\x81\x83\x02\x96\x03\x10\x81\x85"
  "\x02\x95\x03\x0e\x81\x85\x02\x94\x03\x0c\x81\x85\x02\x93\x03\x0a"
  "\x81\x87\x02\x92\x03\x08\x81\x85\x02\x91\x03\x06\x81\x83\x02\x90"
  "\x03\x04\x83\x04\x15\x27\xf5\x01\x02\x82\x01\x0f\x53\x63\x68\x65"
  "\x6d\x65\x47\x72\x61\x70\x68\x69\x63\x73\x0f\x73\x63\x68\x65\x6d"
  "\x65\x47\x72\x61\x70\x68\x69\x63\x73\x13\x58\x20\x73\x75\x70\x70"
  "\x72\x65\x73\x73\x2d\x6d\x61\x70\x20\x61\x72\x67\x0e\x76\x65\x63"
  "\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x13\x04\x63\x64\x72\x04"
  "\x63\x61\x72\x03\x1b\x05\xe9\x01\x03\xaa\x03\x24\x81\x85\x02\xa9"
  "\x03\x22\x81\x85\x02\xa8\x03\x20\x81\x87\x02\xa7\x03\x1e\x81\x87"
  "\x02\xa6\x03\x1c\x81\x85\x02\xa5\x03\x1a\x81\x85\x02\xa4\x03\x18"
  "\x81\x85\x02\xa3\x03\x16\x81\x85\x02\xa2\x03\x14\x81\x85\x02\xa1"
  "\x03\x12\x81\x87\x02\xa0\x03\x10\x81\x85\x02\x9f\x03\x0e\x81\x85"
  "\x02\x9e\x03\x0c\x81\x85\x02\x9d\x03\x0a\x81\x85\x02\x9c\x03\x08"
  "\x81\x85\x02\x9b\x03\x06\x81\x85\x02\x9a\x03\x04\x84\x06\x23\x37"
  "\x1b\x02\x83\x01\x0c\xdb\x01\xad\x03\x08\x81\x83\x02\xac\x03\x06"
  "\x81\x83\x02\xab\x03\x04\x83\x04\x07\x0e\x0c\x02\x84\x01\x73\xdb"
  "\x01\xb6\x03\x14\x81\x85\x02\xb5\x03\x12\x81\x89\x02\xb4\x03\x10"
  "\x81\x87\x02\xb3\x03\x0e\x81\x85\x02\xb2\x03\x0c\x81\x83\x02\xb1"
  "\x03\x0a\x81\x83\x02\xb0\x03\x08\x81\x85\x02\xaf\x03\x06\x81\x85"
  "\x02\xae\x03\x04\x83\x04\x13\x1d\x73\x02\x85\x01\x44\x46\xdb\x01"
  "\xbe\x03\x12\x81\x85\x02\xbd\x03\x10\x81\x85\x02\xbc\x03\x0e\x81"
  "\x85\x02\xbb\x03\x0c\x81\x83\x02\xba\x03\x0a\x81\x83\x02\xb9\x03"
  "\x08\x81\x83\x02\xb8\x03\x06\x81\x83\x02\xb7\x03\x04\x83\x04\x11"
  "\x1a\x46\x02\x86\x01\x4a\xdb\x01\x03\x09\x2d\x3e\x66\x6c\x6f\x6e"
  "\x75\x6d\x4a\x02\xc3\x03\x0c\x81\x87\x02\xc2\x03\x0a\x81\x87\x02"
  "\xc1\x03\x08\x81\x87\x02\xc0\x03\x06\x81\x87\x02\xbf\x03\x04\x85"
  "\x08\x0b\x15\x44\x02\x87\x01\x4e\xdb\x01\x03\x4a\x02\xca\x03\x10"
  "\x81\x8b\x02\xc9\x03\x0e\x81\x8b\x02\xc8\x03\x0c\x81\x8b\x02\xc7"
  "\x03\x0a\x81\x8b\x02\xc6\x03\x08\x81\x8b\x02\xc5\x03\x06\x81\x8b"
  "\x02\xc4\x03\x04\x87\x0c\x0f\x19\x4e\x02\x88\x01\x50\xdb\x01\xcd"
  "\x03\x08\x81\x87\x02\xcc\x03\x06\x81\x87\x02\xcb\x03\x04\x85\x08"
  "\x07\x0e\x50\x02\x89\x01\x52\xdb\x01\x03\x4a\x02\xd2\x03\x0c\x81"
  "\x87\x02\xd1\x03\x0a\x81\x87\x02\xd0\x03\x08\x81\x87\x02\xcf\x03"
  "\x06\x81\x87\x02\xce\x03\x04\x85\x08\x0b\x15\x52\x02\x8a\x01\x54"
  "\xdb\x01\xd5\x03\x08\x81\x87\x02\xd4\x03\x06\x81\x87\x02\xd3\x03"
  "\x04\x85\x08\x07\x0e\x54\x02\x8b\x01\x56\xdb\x01\x03\x4a\x02\xda"
  "\x03\x0c\x81\x89\x02\xd9\x03\x0a\x81\x89\x02\xd8\x03\x08\x81\x89"
  "\x02\xd7\x03\x06\x81\x89\x02\xd6\x03\x04\x86\x0a\x0b\x15\x56\x02"
  "\x8c\x01\x58\xdb\x01\x03\x4a\x02\xdf\x03\x0c\x81\x89\x02\xde\x03"
  "\x0a\x81\x89\x02\xdd\x03\x08\x81\x89\x02\xdc\x03\x06\x81\x89\x02"
  "\xdb\x03\x04\x86\x0a\x0b\x15\x58\x02\x8d\x01\x10\x78\x2d\x64\x69"
  "\x73\x70\x6c\x61\x79\x2d\x66\x6c\x75\x73\x68\x80\x02\xdb\x01\x17"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x3a\x61\x75\x74\x6f\x2d"
  "\x72\x61\x69\x73\x65\x3f\x80\x02\x02\x03\xa9\x01\x02\xe9\x03\x16"
  "\x81\x83\x02\xe8\x03\x14\x81\x83\x02\xe7\x03\x12\x81\x83\x02\xe6"
  "\x03\x10\x81\x83\x02\xe5\x03\x0e\x81\x83\x02\xe4\x03\x0c\x81\x83"
  "\x02\xe3\x03\x0a\x81\x83\x02\xe2\x03\x08\x81\x83\x02\xe1\x03\x06"
  "\x83\x04\xe0\x03\x04\x81\x83\x02\x15\x24\x9a\x02\x02\x8e\x01\x60"
  "\xdb\x01\x03\x4a\x02\xee\x03\x0c\x81\x87\x02\xed\x03\x0a\x81\x87"
  "\x02\xec\x03\x08\x81\x87\x02\xeb\x03\x06\x81\x87\x02\xea\x03\x04"
  "\x85\x08\x0b\x15\x60\x02\x8f\x01\x66\xdb\x01\xf1\x03\x08\x81\x83"
  "\x02\xf0\x03\x06\x81\x83\x02\xef\x03\x04\x83\x04\x07\x0e\x66\x02"
  "\x90\x01\x68\xdb\x01\x03\x4a\x02\xf8\x03\x10\x81\x8b\x02\xf7\x03"
  "\x0e\x81\x8b\x02\xf6\x03\x0c\x81\x8b\x02\xf5\x03\x0a\x81\x8b\x02"
  "\xf4\x03\x08\x81\x8b\x02\xf3\x03\x06\x81\x8b\x02\xf2\x03\x04\x87"
  "\x0c\x0f\x19\x68\x02\x91\x01\x71\xdb\x01\x03\x4a\x02\xff\x03\x10"
  "\x81\x8b\x02\xfe\x03\x0e\x81\x8b\x02\xfd\x03\x0c\x81\x8b\x02\xfc"
  "\x03\x0a\x81\x8b\x02\xfb\x03\x08\x81\x8b\x02\xfa\x03\x06\x81\x8b"
  "\x02\xf9\x03\x04\x87\x0c\x0f\x19\x71\x02\x92\x01\x6d\xdb\x01\x82"
  "\x04\x08\x81\x85\x02\x81\x04\x06\x81\x85\x02\x80\x04\x04\x84\x06"
  "\x07\x0e\x6d\x02\x93\x01\x6a\x07\x09\x01\x02\x01\x02\x01\x05\x0c"
  "\x01\x02\x01\x03\x0b\x05\x07\x0b\x01\x01\x01\x01\x01\x05\x0d\x01"
  "\x01\x01\x03\x01\x01\x03\x08\x08\x6f\xdb\x01\x14\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x20\x6c\x69\x6e\x65\x20\x73\x74\x79\x6c\x65\x91"
  "\x01\x09\x03\x1b\x65\x78\x61\x63\x74\x2d\x6e\x6f\x6e\x6e\x65\x67"
  "\x61\x74\x69\x76\x65\x2d\x69\x6e\x74\x65\x67\x65\x72\x3f\x05\xe9"
  "\x01\x03\x8c\x04\x16\x81\x87\x02\x8b\x04\x14\x81\x87\x02\x8a\x04"
  "\x12\x81\x87\x02\x89\x04\x10\x81\x87\x02\x88\x04\x0e\x81\x85\x02"
  "\x87\x04\x0c\x81\x85\x02\x86\x04\x0a\x81\x85\x02\x85\x04\x08\x81"
  "\x85\x02\x84\x04\x06\x81\x85\x02\x83\x04\x04\x84\x06\x15\x28\xe9"
  "\x01\x02\x94\x01\x21\xdb\x01\x8f\x04\x08\x81\x85\x02\x8e\x04\x06"
  "\x81\x85\x02\x8d\x04\x04\x84\x06\x07\x0e\x91\x01\x02\x95\x01\x23"
  "\xdb\x01\x92\x04\x08\x81\x85\x02\x91\x04\x06\x81\x85\x02\x90\x04"
  "\x04\x84\x06\x07\x0e\x6f\x02\x96\x01\x25\xdb\x01\x95\x04\x08\x81"
  "\x85\x02\x94\x04\x06\x81\x85\x02\x93\x04\x04\x84\x06\x07\x0e\x6a"
  "\x02\x97\x01\x2a\xdb\x01\x98\x04\x08\x81\x85\x02\x97\x04\x06\x81"
  "\x85\x02\x96\x04\x04\x84\x06\x07\x0e\x2a\x02\x98\x01\x2c\xdb\x01"
  "\x9b\x04\x08\x81\x85\x02\x9a\x04\x06\x81\x85\x02\x99\x04\x04\x84"
  "\x06\x07\x0e\x2c\x02\x99\x01\x32\xdb\x01\x9e\x04\x08\x81\x85\x02"
  "\x9d\x04\x06\x81\x85\x02\x9c\x04\x04\x84\x06\x07\x0e\x32\x02\x9a"
  "\x01\x34\xdb\x01\xa1\x04\x08\x81\x85\x02\xa0\x04\x06\x81\x85\x02"
  "\x9f\x04\x04\x84\x06\x07\x0e\x34\x02\x9b\x01\x36\xdb\x01\xa4\x04"
  "\x08\x81\x85\x02\xa3\x04\x06\x81\x85\x02\xa2\x04\x04\x84\x06\x07"
  "\x0e\x36\x02\x9c\x01\x4c\xdb\x01\x03\x4a\x02\xad\x04\x14\x81\x91"
  "\x02\xac\x04\x12\x81\x91\x02\xab\x04\x10\x81\x91\x02\xaa\x04\x0e"
  "\x81\x91\x02\xa9\x04\x0c\x81\x91\x02\xa8\x04\x0a\x81\x91\x02\xa7"
  "\x04\x08\x81\x91\x02\xa6\x04\x06\x81\x91\x02\xa5\x04\x04\x8a\x12"
  "\x13\x1d\x25\x02\x9d\x01\x4c\x05\x33\x36\x30\x2e\x03\x30\x2e\xdb"
  "\x01\x03\x4a\x02\xb4\x04\x10\x81\x91\x02\xb3\x04\x0e\x81\x8f\x02"
  "\xb2\x04\x0c\x81\x8f\x02\xb1\x04\x0a\x81\x8d\x02\xb0\x04\x08\x81"
  "\x8b\x02\xaf\x04\x06\x81\x89\x02\xae\x04\x04\x86\x0a\x0f\x1b\x23"
  "\x02\x9e\x01\x4c\x05\x33\x36\x30\x2e\x03\x30\x2e\xdb\x01\x03\x4a"
  "\x02\xbb\x04\x10\x81\x91\x02\xba\x04\x0e\x81\x8f\x02\xb9\x04\x0c"
  "\x81\x8f\x02\xb8\x04\x0a\x81\x8d\x02\xb7\x04\x08\x81\x8b\x02\xb6"
  "\x04\x06\x81\x89\x02\xb5\x04\x04\x86\x0a\x0f\x1c\x4c\x02\x9f\x01"
  "\x5a\xdb\x01\x4a\x02\x04\x0b\x76\x65\x63\x74\x6f\x72\x2d\x6d\x61"
  "\x70\x02\xc0\x04\x0c\x81\x85\x02\xbf\x04\x0a\x81\x89\x02\xbe\x04"
  "\x08\x81\x85\x02\xbd\x04\x06\x81\x85\x02\xbc\x04\x04\x84\x06\x0b"
  "\x17\x5a\x02\xa0\x01\x48\xdb\x01\x03\x4a\x02\xc9\x04\x14\x81\x91"
  "\x02\xc8\x04\x12\x81\x91\x02\xc7\x04\x10\x81\x91\x02\xc6\x04\x0e"
  "\x81\x91\x02\xc5\x04\x0c\x81\x91\x02\xc4\x04\x0a\x81\x91\x02\xc3"
  "\x04\x08\x81\x8f\x02\xc2\x04\x06\x81\x8f\x02\xc1\x04\x04\x89\x10"
  "\x13\x1d\x48\x02\xa1\x01\xdb\x01\xcd\x04\x0a\x81\x87\x02\xcc\x04"
  "\x08\x81\x87\x02\xcb\x04\x06\x81\x87\x02\xca\x04\x04\x85\x08\x09"
  "\x0f\x21\x02\xa2\x01\x3e\xdb\x01\xd0\x04\x08\x81\x83\x02\xcf\x04"
  "\x06\x81\x83\x02\xce\x04\x04\x83\x04\x07\x0e\x3e\x02\xa3\x01\x17"
  "\xdb\x01\xd3\x04\x08\x81\x83\x02\xd2\x04\x06\x81\x83\x02\xd1\x04"
  "\x04\x83\x04\x07\x0e\x17\x02\xa4\x01\x30\xdb\x01\xd6\x04\x08\x81"
  "\x85\x02\xd5\x04\x06\x81\x85\x02\xd4\x04\x04\x84\x06\x07\x0e\x30"
  "\x02\xa5\x01\x28\x80\xfc\x01\xdb\x01\xd9\x04\x08\x81\x83\x02\xd8"
  "\x04\x06\x81\x83\x02\xd7\x04\x04\x83\x04\x07\x0f\x02\xa6\x01\x28"
  "\x80\xbc\x01\xdb\x01\xdc\x04\x08\x81\x83\x02\xdb\x04\x06\x81\x83"
  "\x02\xda\x04\x04\x83\x04\x07\x0f\x28\x02\xa7\x01\xe2\x01\x02\xdb"
  "\x01\xde\x04\x06\x81\x85\x02\xdd\x04\x04\x84\x06\x05\x0d\x9b\x02"
  "\x02\xa8\x01\x5e\x5c\x1d\xdb\x01\xe8\x04\x16\x81\x85\x02\xe7\x04"
  "\x14\x81\x89\x02\xe6\x04\x12\x81\x8b\x02\xe5\x04\x10\x81\x87\x02"
  "\xe4\x04\x0e\x81\x85\x02\xe3\x04\x0c\x81\x87\x02\xe2\x04\x0a\x81"
  "\x83\x02\xe1\x04\x08\x81\x83\x02\xe0\x04\x06\x81\x83\x02\xdf\x04"
  "\x04\x83\x04\x15\x21\x1d\x02\xa9\x01\x04\x13\x72\x65\x61\x64\x2d"
  "\x65\x76\x65\x6e\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x9c\x02\x02"
  "\xee\x04\x0e\x81\x85\x02\xed\x04\x0c\x81\x87\x02\xec\x04\x0a\x81"
  "\x85\x02\xeb\x04\x08\x81\x83\x02\xea\x04\x06\x81\x83\x02\xe9\x04"
  "\x04\x83\x04\x0d\x18\x9d\x02\x02\xaa\x01\x2b\x57\x69\x6e\x64\x6f"
  "\x77\x20\x63\x6c\x6f\x73\x65\x64\x20\x77\x68\x69\x6c\x65\x20\x77"
  "\x61\x69\x74\x69\x6e\x67\x20\x74\x6f\x20\x72\x65\x61\x64\x20\x65"
  "\x76\x65\x6e\x74\x2e\x0b\xdb\x01\x03\x13\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x64\x69\x73\x70\x6c\x61\x79\x9e\x02\x03\x0b"
  "\x72\x65\x61\x64\x2d\x65\x76\x65\x6e\x74\x9f\x02\x03\xe7\x01\x04"
  "\xf7\x04\x14\x81\x8b\x02\xf6\x04\x12\x81\x8b\x02\xf5\x04\x10\x81"
  "\x8b\x02\xf4\x04\x0e\x81\x89\x02\xf3\x04\x0c\x81\x8b\x02\xf2\x04"
  "\x0a\x81\x89\x02\xf1\x04\x08\x81\x87\x02\xf0\x04\x06\x81\x85\x02"
  "\xef\x04\x04\x84\x06\x13\x24\xe7\x01\x02\xab\x01\x03\x9e\x02\x03"
  "\x9f\x02\x03\xf9\x04\x06\x81\x83\x02\xf8\x04\x04\x83\x04\x05\x0d"
  "\xa0\x02\x02\xac\x01\x03\x9e\x02\x03\x0f\x64\x69\x73\x63\x61\x72"
  "\x64\x2d\x65\x76\x65\x6e\x74\x73\xa1\x02\x03\xfb\x04\x06\x81\x83"
  "\x02\xfa\x04\x04\x83\x04\x05\x0d\xa2\x02\x02\xad\x01\x09\xdb\x01"
  "\xff\x04\x0a\x81\x85\x02\xfe\x04\x08\x81\x85\x02\xfd\x04\x06\x81"
  "\x85\x02\xfc\x04\x04\x84\x06\x09\x0f\x09\x02\xae\x01\x80\x05\x04"
  "\x8c\x16\x03\xa3\x02\x02\xaf\x01\x81\x05\x04\x83\x04\x03\xa4\x02"
  "\x02\xb0\x01\x82\x05\x04\x83\x04\x03\xa5\x02\x02\xb1\x01\x83\x05"
  "\x04\x83\x04\x03\xa6\x02\x02\xb2\x01\x84\x05\x04\x83\x04\x03\xa7"
  "\x02\x02\xb3\x01\x85\x05\x04\x83\x04\x03\xa8\x02\x02\xb4\x01\x86"
  "\x05\x04\x83\x04\x03\xa9\x02\x02\xb5\x01\x87\x05\x04\x83\x04\x03"
  "\xaa\x02\x02\xb6\x01\x08\x88\x05\x04\x83\x04\x03\xab\x02\x02\xb7"
  "\x01\x09\x89\x05\x04\x83\x04\x03\xac\x02\x02\xb8\x01\x0a\x8a\x05"
  "\x04\x83\x04\x03\xad\x02\x02\xb9\x01\x8b\x05\x04\x87\x0c\x03\xae"
  "\x02\x02\xba\x01\x8c\x05\x04\x83\x04\x03\xaf\x02\x02\xbb\x01\x8d"
  "\x05\x04\x83\x04\x03\xb0\x02\x02\xbc\x01\x8e\x05\x04\x83\x04\x03"
  "\xb1\x02\x02\xbd\x01\x8f\x05\x04\x83\x04\x03\xb2\x02\x02\xbe\x01"
  "\x90\x05\x04\x83\x04\x03\xb3\x02\x02\xbf\x01\xdb\x01\x03\x90\x01"
  "\x02\x92\x05\x06\x81\x83\x02\x91\x05\x04\x83\x04\x05\x0d\xb4\x02"
  "\x02\xc0\x01\x42\xdb\x01\x95\x05\x08\x81\x83\x02\x94\x05\x06\x81"
  "\x83\x02\x93\x05\x04\x83\x04\x07\x0e\x42\x02\xc1\x01\x15\xdb\x01"
  "\x98\x05\x08\x81\x83\x02\x97\x05\x06\x81\x83\x02\x96\x05\x04\x83"
  "\x04\x07\x0e\x15\x02\xc2\x01\x1f\xdb\x01\x9b\x05\x08\x81\x83\x02"
  "\x9a\x05\x06\x81\x83\x02\x99\x05\x04\x83\x04\x07\x0e\x1f\x02\xc3"
  "\x01\x19\xdb\x01\x9e\x05\x08\x81\x83\x02\x9d\x05\x06\x81\x83\x02"
  "\x9c\x05\x04\x83\x04\x07\x0e\x19\x02\xc4\x01\x2e\xdb\x01\xa1\x05"
  "\x08\x81\x85\x02\xa0\x05\x06\x81\x85\x02\x9f\x05\x04\x84\x06\x07"
  "\x0e\x2e\x02\xc5\x01\x38\xdb\x01\xa4\x05\x08\x81\x85\x02\xa3\x05"
  "\x06\x81\x85\x02\xa2\x05\x04\x84\x06\x07\x0e\x38\x02\xc6\x01\x3a"
  "\xdb\x01\xa7\x05\x08\x81\x87\x02\xa6\x05\x06\x81\x87\x02\xa5\x05"
  "\x04\x85\x08\x07\x0e\x3a\x02\xc7\x01\x3c\xdb\x01\xaa\x05\x08\x81"
  "\x87\x02\xa9\x05\x06\x81\x87\x02\xa8\x05\x04\x85\x08\x07\x0e\x3c"
  "\x02\xc8\x01\xab\x05\x04\x82\x02\x03\xb5\x02\x02\xc9\x01\xac\x05"
  "\x04\x82\x02\x03\xb6\x02\x02\xca\x01\xad\x05\x04\x82\x02\x03\xb7"
  "\x02\x02\xcb\x01\xae\x05\x04\x82\x02\x03\xb8\x02\x02\xcc\x01\xaf"
  "\x05\x04\x82\x02\x03\xb9\x02\x02\xcd\x01\xb0\x05\x04\x82\x02\x03"
  "\xba\x02\x02\xce\x01\xb1\x05\x04\x82\x02\x03\xbb\x02\x02\xcf\x01"
  "\xb2\x05\x04\x82\x02\x03\xbc\x02\x02\xd0\x01\xb3\x05\x04\x82\x02"
  "\x03\xbd\x02\x02\xd1\x01\xb4\x05\x04\x82\x02\x03\xbe\x02\x02\xd2"
  "\x01\xb5\x05\x04\x82\x02\x03\xbf\x02\x02\xd3\x01\xb6\x05\x04\x82"
  "\x02\x03\xc0\x02\x02\xd4\x01\xb7\x05\x04\x82\x02\x03\xc1\x02\x02"
  "\xd5\x01\xb8\x05\x04\x82\x02\x03\xc2\x02\x02\xd6\x01\xb9\x05\x04"
  "\x82\x02\x03\xc3\x02\x02\xd7\x01\xba\x05\x04\x82\x02\x03\xc4\x02"
  "\x02\xd8\x01\xbb\x05\x04\x82\x02\x03\xc5\x02\x02\xd9\x01\xbc\x05"
  "\x04\x82\x02\x03\xc6\x02\x02\xda\x01\xbd\x05\x04\x82\x02\x03\xc7"
  "\x02\x02\xdb\x01\xdb\x01\xbe\x05\x04\x83\x04\x03\xc8\x02\x02\xdc"
  "\x01\xdb\x01\xbf\x05\x04\x83\x04\x03\xc9\x02\x02\xdd\x01\xdb\x01"
  "\xc0\x05\x04\x83\x04\x03\xca\x02\x02\xde\x01\xdb\x01\xc1\x05\x04"
  "\x83\x04\x03\xcb\x02\x02\xdf\x01\xe2\x01\x02\xc2\x05\x04\x84\x06"
  "\x03\xcc\x02\x02\xe0\x01\xe2\x01\x02\xc3\x05\x04\x84\x06\x03\xcd"
  "\x02\x02\xe1\x01\xe2\x01\x02\xc4\x05\x04\x84\x06\x03\xce\x02\x02"
  "\xe2\x01\xe2\x01\x02\xc5\x05\x04\x84\x06\x03\xe2\x01\x02\xe3\x01"
  "\x02\x0b\x69\x6d\x61\x67\x65\x2d\x74\x79\x70\x65\x07\x63\x72\x65"
  "\x61\x74\x65\x08\x64\x65\x73\x74\x72\x6f\x79\x06\x77\x69\x64\x74"
  "\x68\xcf\x02\x07\x68\x65\x69\x67\x68\x74\xd0\x02\x05\x64\x72\x61"
  "\x77\x8f\x01\x16\x66\x69\x6c\x6c\x2d\x66\x72\x6f\x6d\x2d\x62\x79"
  "\x74\x65\x2d\x76\x65\x63\x74\x6f\x72\x0b\x69\x6d\x61\x67\x65\x2d"
  "\x6c\x69\x73\x74\x8f\x01\x02\x27\x78\x2d\x67\x72\x61\x70\x68\x69"
  "\x63\x73\x2d\x69\x6d\x61\x67\x65\x2f\x66\x69\x6c\x6c\x2d\x66\x72"
  "\x6f\x6d\x2d\x62\x79\x74\x65\x2d\x76\x65\x63\x74\x6f\x72\xd1\x02"
  "\x1f\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x69\x6d\x61\x67"
  "\x65\x2f\x64\x72\x61\x77\x2d\x73\x75\x62\x69\x6d\x61\x67\x65\xd2"
  "\x02\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x69\x6d\x61"
  "\x67\x65\x2f\x64\x72\x61\x77\xd3\x02\x18\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2d\x69\x6d\x61\x67\x65\x2f\x68\x65\x69\x67\x68"
  "\x74\xd4\x02\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x69"
  "\x6d\x61\x67\x65\x2f\x77\x69\x64\x74\x68\xd5\x02\x19\x78\x2d\x67"
  "\x72\x61\x70\x68\x69\x63\x73\x2d\x69\x6d\x61\x67\x65\x2f\x64\x65"
  "\x73\x74\x72\x6f\x79\xd6\x02\x0f\x63\x72\x65\x61\x74\x65\x2d\x78"
  "\x2d\x69\x6d\x61\x67\x65\xd7\x02\x18\x73\x65\x74\x2d\x78\x2d\x69"
  "\x6d\x61\x67\x65\x2f\x64\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x21"
  "\xd8\x02\x13\x78\x2d\x69\x6d\x61\x67\x65\x2f\x64\x65\x73\x63\x72"
  "\x69\x70\x74\x6f\x72\xd9\x02\x09\x78\x2d\x69\x6d\x61\x67\x65\x3f"
  "\xda\x02\x10\x78\x2d\x64\x65\x73\x74\x72\x6f\x79\x2d\x69\x6d\x61"
  "\x67\x65\xdb\x02\x92\x01\x0d\x03\x10\x6d\x61\x6b\x65\x2d\x69\x6d"
  "\x61\x67\x65\x2d\x74\x79\x70\x65\x06\xce\x01\x03\x19\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2d\x74\x79\x70\x65\x2d\x70\x72\x6f\x70\x65"
  "\x72\x74\x69\x65\x73\x05\x0e\x31\x64\x2d\x74\x61\x62\x6c\x65\x2f"
  "\x70\x75\x74\x21\x05\xd7\x05\x26\x81\x87\x02\xd6\x05\x24\x81\x81"
  "\x02\xd5\x05\x22\x81\x81\x02\xd4\x05\x20\x81\x89\x02\xd3\x05\x1e"
  "\x81\x83\x02\xd2\x05\x1c\x81\x89\x02\xd1\x05\x1a\x81\x87\x02\xd0"
  "\x05\x18\x81\x85\x02\xcf\x05\x16\x81\x83\x02\xce\x05\x14\x81\x81"
  "\x02\xcd\x05\x12\x81\x87\x02\xcc\x05\x10\x81\x87\x02\xcb\x05\x0e"
  "\x81\x87\x02\xca\x05\x0c\x81\x87\x02\xc9\x05\x0a\x81\x87\x02\xc8"
  "\x05\x08\x81\x87\x02\xc7\x05\x06\x81\x85\x02\xc6\x05\x04\x82\x02"
  "\x25\x4a\xdc\x02\x02\xe4\x01\x77\xdb\x01\x8f\x01\x02\x04\xeb\x01"
  "\x06\x0d\x6d\x61\x6b\x65\x2d\x78\x2d\x69\x6d\x61\x67\x65\x77\x03"
  "\xdd\x05\x0e\x81\x91\x02\xdc\x05\x0c\x81\x89\x02\xdb\x05\x0a\x81"
  "\x89\x02\xda\x05\x08\x81\x87\x02\xd9\x05\x06\x81\x87\x02\xd8\x05"
  "\x04\x85\x08\x0d\x1b\xdd\x02\x02\xe5\x01\x8f\x01\x02\x04\xef\x01"
  "\x02\xdf\x05\x06\x81\x83\x02\xde\x05\x04\x83\x04\x05\x0d\xde\x02"
  "\x02\xe6\x01\x7c\xdb\x01\xe1\x05\x06\x81\x87\x02\xe0\x05\x04\x85"
  "\x08\x05\x0b\x7c\x02\xe7\x01\x7e\xdb\x01\xe3\x05\x06\x81\x89\x02"
  "\xe2\x05\x04\x86\x0a\x05\x0b\x7e\x02\xe8\x01\x7a\xdb\x01\x03\x4a"
  "\x02\xea\x05\x10\x81\x93\x02\xe9\x05\x0e\x81\x91\x02\xe8\x05\x0c"
  "\x81\x91\x02\xe7\x05\x0a\x81\x8f\x02\xe6\x05\x08\x81\x89\x02\xe5"
  "\x05\x06\x81\x87\x02\xe4\x05\x04\x85\x08\x0f\x1c\xdf\x02\x02\xe9"
  "\x01\x7a\xdb\x01\x03\x4a\x02\xef\x05\x0c\x81\x9d\x02\xee\x05\x0a"
  "\x81\x97\x02\xed\x05\x08\x81\x95\x02\xec\x05\x06\x81\x93\x02\xeb"
  "\x05\x04\x89\x10\x0b\x15\xe0\x02\x02\xea\x01\x75\xdb\x01\xf1\x05"
  "\x06\x81\x85\x02\xf0\x05\x04\x84\x06\x05\x0b\x75\x02\xeb\x01\x05"
  "\x0d\x69\x6d\x61\x67\x65\x2f\x63\x72\x65\x61\x74\x65\x02\xf2\x05"
  "\x04\x85\x08\x03\xe1\x02\x02\xec\x01\xdb\x01\x03\x10\x78\x2d\x69"
  "\x6d\x61\x67\x65\x2f\x64\x65\x73\x74\x72\x6f\x79\xe2\x02\x02\xf4"
  "\x05\x06\x81\x83\x02\xf3\x05\x04\x83\x04\x05\x0d\xe3\x02\x02\xed"
  "\x01\xdb\x01\xf6\x05\x06\x81\x83\x02\xf5\x05\x04\x83\x04\x05\x0b"
  "\xe4\x02\x02\xee\x01\xdb\x01\xf8\x05\x06\x81\x83\x02\xf7\x05\x04"
  "\x83\x04\x05\x0b\xe5\x02\x02\xef\x01\x7a\xdb\x01\x03\x4a\x02\x81"
  "\x06\x14\x81\x91\x02\x80\x06\x12\x81\x91\x02\xff\x05\x10\x81\x91"
  "\x02\xfe\x05\x0e\x81\x91\x02\xfd\x05\x0c\x81\x8f\x02\xfc\x05\x0a"
  "\x81\x8d\x02\xfb\x05\x08\x81\x8b\x02\xfa\x05\x06\x81\x89\x02\xf9"
  "\x05\x04\x86\x0a\x13\x20\xe6\x02\x02\xf0\x01\x7a\xdb\x01\x03\x4a"
  "\x02\x88\x06\x10\x81\x97\x02\x87\x06\x0e\x81\x97\x02\x86\x06\x0c"
  "\x81\x95\x02\x85\x06\x0a\x81\x93\x02\x84\x06\x08\x81\x93\x02\x83"
  "\x06\x06\x81\x91\x02\x82\x06\x04\x8a\x12\x0f\x19\x7a\x02\xf1\x01"
  "\xdb\x01\x04\x1e\x78\x2d\x69\x6d\x61\x67\x65\x2f\x66\x69\x6c\x6c"
  "\x2d\x66\x72\x6f\x6d\x2d\x62\x79\x74\x65\x2d\x76\x65\x63\x74\x6f"
  "\x72\x4a\x02\x8a\x06\x06\x81\x85\x02\x89\x06\x04\x84\x06\x05\x0d"
  "\xe7\x02\x02\xf2\x01\x8b\x06\x04\x82\x02\x03\xe8\x02\x02\xf3\x01"
  "\x8c\x06\x04\x82\x02\x03\xe9\x02\x02\xf4\x01\x8d\x06\x04\x82\x02"
  "\x03\xea\x02\x02\xf5\x01\x8e\x06\x04\x82\x02\x03\xeb\x02\x02\xf6"
  "\x01\x8f\x06\x04\x82\x02\x03\xec\x02\x02\xf7\x01\x90\x06\x04\x82"
  "\x02\x03\xed\x02\x02\xf8\x01\x91\x06\x04\x82\x02\x03\xee\x02\x02"
  "\xf9\x01\x92\x06\x04\x82\x02\x03\xef\x02\x02\xfa\x01\x93\x06\x04"
  "\x82\x02\x03\xf0\x02\x02\xfb\x01\x94\x06\x04\x82\x02\x03\xf1\x02"
  "\x02\xfc\x01\x02\x0e\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2d\x6c\x69"
  "\x73\x74\xf2\x02\x02\x19\x73\x65\x74\x2d\x63\x6f\x6c\x6f\x72\x6d"
  "\x61\x70\x2f\x64\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x21\xf3\x02"
  "\x14\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2f\x64\x65\x73\x63\x72\x69"
  "\x70\x74\x6f\x72\xf4\x02\x0c\x78\x2d\x63\x6f\x6c\x6f\x72\x6d\x61"
  "\x70\x3f\xf5\x02\x10\x78\x2d\x66\x72\x65\x65\x2d\x63\x6f\x6c\x6f"
  "\x72\x6d\x61\x70\xf6\x02\x05\x06\xce\x01\x02\x9b\x06\x10\x81\x81"
  "\x02\x9a\x06\x0e\x81\x81\x02\x99\x06\x0c\x81\x89\x02\x98\x06\x0a"
  "\x81\x87\x02\x97\x06\x08\x81\x85\x02\x96\x06\x06\x81\x83\x02\x95"
  "\x06\x04\x82\x02\x0f\x1d\xce\x01\x02\xfd\x01\xf2\x02\x02\x03\x0f"
  "\x25\x6d\x61\x6b\x65\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\xf7\x02"
  "\x04\xeb\x01\x03\x9e\x06\x08\x81\x85\x02\x9d\x06\x06\x81\x83\x02"
  "\x9c\x06\x04\x83\x04\x07\x11\xeb\x01\x02\xfe\x01\x0e\xdb\x01\x03"
  "\x0e\x6d\x61\x6b\x65\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x0e\x02"
  "\xa2\x06\x0a\x81\x83\x02\xa1\x06\x08\x81\x85\x02\xa0\x06\x06\x81"
  "\x85\x02\x9f\x06\x04\x83\x04\x09\x13\xf8\x02\x02\xff\x01\x87\x01"
  "\xdb\x01\x03\xf4\x02\x02\xa6\x06\x0a\x81\x85\x02\xa5\x06\x08\x81"
  "\x85\x02\xa4\x06\x06\x81\x85\x02\xa3\x06\x04\x84\x06\x09\x13\x87"
  "\x01\x02\x80\x02\x8d\x01\x82\x01\x40\xdb\x01\x03\x0e\x02\xac\x06"
  "\x0e\x81\x8b\x02\xab\x06\x0c\x81\x89\x02\xaa\x06\x0a\x81\x87\x02"
  "\xa9\x06\x08\x81\x85\x02\xa8\x06\x06\x81\x85\x02\xa7\x06\x04\x84"
  "\x06\x0d\x19\x8d\x01\x02\x81\x02\xf2\x02\x02\x04\xef\x01\x02\xae"
  "\x06\x06\x81\x83\x02\xad\x06\x04\x83\x04\x05\x0d\xef\x01\x02\x82"
  "\x02\x80\x01\x03\xf4\x02\x02\xb0\x06\x06\x81\x89\x02\xaf\x06\x04"
  "\x86\x0a\x05\x0c\x82\x01\x02\x83\x02\x85\x01\x03\xf4\x02\x02\xb2"
  "\x06\x06\x81\x85\x02\xb1\x06\x04\x84\x06\x05\x0c\x85\x01\x02\x84"
  "\x02\x89\x01\x03\xf4\x02\x02\xb4\x06\x06\x81\x8b\x02\xb3\x06\x04"
  "\x87\x0c\x05\x0c\x89\x01\x02\x85\x02\x8b\x01\x03\xf4\x02\x02\xb6"
  "\x06\x06\x81\x85\x02\xb5\x06\x04\x84\x06\x05\x0c\x8b\x01\x02\x86"
  "\x02\x13\x03\x95\x01\x02\xbc\x06\x0e\x81\x87\x02\xbb\x06\x0c\x81"
  "\x87\x02\xba\x06\x0a\x81\x87\x02\xb9\x06\x08\x81\x83\x02\xb8\x06"
  "\x06\x81\x83\x02\xb7\x06\x04\x83\x04\x0d\x1c\x80\x01\x02\x87\x02"
  "\x10\xdb\x01\xbf\x06\x08\x81\x83\x02\xbe\x06\x06\x81\x83\x02\xbd"
  "\x06\x04\x83\x04\x07\x0e\x40\x02\x88\x02\x0b\x12\x78\x2d\x67\x65"
  "\x74\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\xdb\x01\xc2"
  "\x06\x08\x81\x93\x02\xc1\x06\x06\x81\x93\x02\xc0\x06\x04\x83\x04"
  "\x07\x0e\x13\x02\x89\x02\xc3\x06\x04\x8c\x16\x03\x10\x02\x8a\x02"
  "\xc4\x06\x04\x83\x04\x03\xf9\x02\x02\x8b\x02\xc5\x06\x04\x83\x04"
  "\x03\xfa\x02\x02\x8c\x02\xc6\x06\x04\x83\x04\x03\xfb\x02\x02\x8d"
  "\x02\xc7\x06\x04\x83\x04\x03\xfc\x02\x02\x8e\x02\xc8\x06\x04\x83"
  "\x04\x03\xfd\x02\x02\x8f\x02\xc9\x06\x04\x83\x04\x03\xfe\x02\x02"
  "\x90\x02\xca\x06\x04\x83\x04\x03\xff\x02\x02\x91\x02\x08\xcb\x06"
  "\x04\x83\x04\x03\x80\x03\x02\x92\x02\x09\xcc\x06\x04\x83\x04\x03"
  "\x81\x03\x02\x93\x02\x0a\xcd\x06\x04\x83\x04\x03\x93\x02\x82\x03"
  "\x82\x03\x10\x72\x74\x64\x3a\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e"
  "\x66\x6f\x04\x81\x03\x04\x80\x03\x04\xff\x02\x04\xfe\x02\x04\xfd"
  "\x02\x04\xfc\x02\x04\xfb\x02\x04\xfa\x02\x04\xf9\x02\x04\x10\x04"
  "\x13\x04\x40\x04\x80\x01\x04\x8b\x01\x04\x89\x01\x04\x85\x01\x04"
  "\x82\x01\x04\xef\x01\x04\x8d\x01\x04\x87\x01\x04\xf8\x02\x04\xeb"
  "\x01\x04\xce\x01\x04\x20\x1c\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d"
  "\x63\x6c\x61\x73\x73\x3a\x64\x69\x72\x65\x63\x74\x2d\x63\x6f\x6c"
  "\x6f\x72\x1a\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x63\x6c\x61\x73"
  "\x73\x3a\x74\x72\x75\x65\x2d\x63\x6f\x6c\x6f\x72\x1c\x78\x2d\x76"
  "\x69\x73\x75\x61\x6c\x2d\x63\x6c\x61\x73\x73\x3a\x70\x73\x65\x75"
  "\x64\x6f\x2d\x63\x6f\x6c\x6f\x72\x1c\x78\x2d\x76\x69\x73\x75\x61"
  "\x6c\x2d\x63\x6c\x61\x73\x73\x3a\x73\x74\x61\x74\x69\x63\x2d\x63"
  "\x6f\x6c\x6f\x72\x1a\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x63\x6c"
  "\x61\x73\x73\x3a\x67\x72\x61\x79\x2d\x73\x63\x61\x6c\x65\x1b\x78"
  "\x2d\x76\x69\x73\x75\x61\x6c\x2d\x63\x6c\x61\x73\x73\x3a\x73\x74"
  "\x61\x74\x69\x63\x2d\x67\x72\x61\x79\x1b\x78\x2d\x76\x69\x73\x75"
  "\x61\x6c\x2d\x69\x6e\x66\x6f\x2f\x62\x69\x74\x73\x2d\x70\x65\x72"
  "\x2d\x72\x67\x62\x1c\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e"
  "\x66\x6f\x2f\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2d\x73\x69\x7a\x65"
  "\x18\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x2f\x62"
  "\x6c\x75\x65\x2d\x6d\x61\x73\x6b\x19\x78\x2d\x76\x69\x73\x75\x61"
  "\x6c\x2d\x69\x6e\x66\x6f\x2f\x67\x72\x65\x65\x6e\x2d\x6d\x61\x73"
  "\x6b\x17\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x2f"
  "\x72\x65\x64\x2d\x6d\x61\x73\x6b\x14\x78\x2d\x76\x69\x73\x75\x61"
  "\x6c\x2d\x69\x6e\x66\x6f\x2f\x63\x6c\x61\x73\x73\x14\x78\x2d\x76"
  "\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x2f\x64\x65\x70\x74\x68"
  "\x15\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x2f\x73"
  "\x63\x72\x65\x65\x6e\x18\x78\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69"
  "\x6e\x66\x6f\x2f\x76\x69\x73\x75\x61\x6c\x2d\x69\x64\x15\x78\x2d"
  "\x76\x69\x73\x75\x61\x6c\x2d\x69\x6e\x66\x6f\x2f\x76\x69\x73\x75"
  "\x61\x6c\x11\x6d\x61\x6b\x65\x2d\x76\x69\x73\x75\x61\x6c\x2d\x69"
  "\x6e\x66\x6f\x95\x01\xb1\x01\xc7\x01\x18\x78\x2d\x63\x6f\x6c\x6f"
  "\x72\x6d\x61\x70\x2f\x73\x74\x6f\x72\x65\x2d\x63\x6f\x6c\x6f\x72"
  "\x73\x17\x78\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2f\x73\x74\x6f"
  "\x72\x65\x2d\x63\x6f\x6c\x6f\x72\x17\x78\x2d\x63\x6f\x6c\x6f\x72"
  "\x6d\x61\x70\x2f\x71\x75\x65\x72\x79\x2d\x63\x6f\x6c\x6f\x72\x1a"
  "\x78\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2f\x61\x6c\x6c\x6f\x63"
  "\x61\x74\x65\x2d\x63\x6f\x6c\x6f\x72\x10\x78\x2d\x63\x6f\x6c\x6f"
  "\x72\x6d\x61\x70\x2f\x66\x72\x65\x65\xc4\x01\xa2\x01\xb4\x01\x0e"
  "\xd0\x01\xf2\x02\x20\xf3\x02\x0c\x76\x69\x73\x75\x61\x6c\x2d\x69"
  "\x6e\x66\x6f\x0d\x62\x69\x74\x73\x2d\x70\x65\x72\x2d\x72\x67\x62"
  "\x0e\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x2d\x73\x69\x7a\x65\x0a\x62"
  "\x6c\x75\x65\x2d\x6d\x61\x73\x6b\x0b\x67\x72\x65\x65\x6e\x2d\x6d"
  "\x61\x73\x6b\x09\x72\x65\x64\x2d\x6d\x61\x73\x6b\x06\x63\x6c\x61"
  "\x73\x73\x06\x64\x65\x70\x74\x68\x07\x73\x63\x72\x65\x65\x6e\x0a"
  "\x76\x69\x73\x75\x61\x6c\x2d\x69\x64\x07\x76\x69\x73\x75\x61\x6c"
  "\x0b\xf1\x02\x04\xf0\x02\x04\xef\x02\x04\xee\x02\x04\xed\x02\x04"
  "\xec\x02\x04\xeb\x02\x04\xea\x02\x04\xe9\x02\x04\xe8\x02\x04\xf4"
  "\x02\xf5\x02\x0b\x64\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x82\x03"
  "\xf7\x02\x0b\x3c\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x3e\x81\x03\x82"
  "\x03\xda\x02\xd1\x02\xd2\x02\xd3\x02\xd4\x02\xd5\x02\xd6\x02\xc3"
  "\x01\x4a\x16\x78\x2d\x69\x6d\x61\x67\x65\x2f\x64\x72\x61\x77\x2d"
  "\x73\x75\x62\x69\x6d\x61\x67\x65\x0d\x78\x2d\x69\x6d\x61\x67\x65"
  "\x2f\x64\x72\x61\x77\x12\x78\x2d\x69\x6d\x61\x67\x65\x2f\x73\x65"
  "\x74\x2d\x70\x69\x78\x65\x6c\x12\x78\x2d\x69\x6d\x61\x67\x65\x2f"
  "\x67\x65\x74\x2d\x70\x69\x78\x65\x6c\xe2\x02\xd7\x02\xcf\x01\x8f"
  "\x01\x11\xe7\x02\x04\x7a\x04\xe6\x02\x04\xe5\x02\x04\xe4\x02\x04"
  "\xe3\x02\x04\xe1\x02\x04\x75\x04\xe0\x02\x04\xdf\x02\x04\x7e\x04"
  "\x7c\x04\xde\x02\x04\xdd\x02\x04\xdc\x02\x04\x11\x0c\x72\x74\x64"
  "\x3a\x78\x2d\x69\x6d\x61\x67\x65\x80\x03\x17\x72\x74\x64\x3a\x78"
  "\x2d\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e\x64"
  "\x73\x15\x72\x74\x64\x3a\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72"
  "\x75\x63\x74\x75\x72\x65\x11\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\x0c\x6d\x61\x78\x2d\x64\x65\x73\x63"
  "\x65\x6e\x74\x0b\x6d\x61\x78\x2d\x61\x73\x63\x65\x6e\x74\x11\x63"
  "\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e\x64\x73\x0c"
  "\x73\x74\x61\x72\x74\x2d\x69\x6e\x64\x65\x78\x0b\x6d\x61\x78\x2d"
  "\x62\x6f\x75\x6e\x64\x73\x0b\x6d\x69\x6e\x2d\x62\x6f\x75\x6e\x64"
  "\x73\x0d\x64\x65\x66\x61\x75\x6c\x74\x2d\x63\x68\x61\x72\x11\x61"
  "\x6c\x6c\x2d\x63\x68\x61\x72\x73\x2d\x65\x78\x69\x73\x74\x3f\x0a"
  "\x64\x69\x72\x65\x63\x74\x69\x6f\x6e\x05\x6e\x61\x6d\x65\xff\x02"
  "\x0b\x0a\x09\x08\x0b\xbe\x02\x04\xbd\x02\x04\xbc\x02\x04\xbb\x02"
  "\x04\xba\x02\x04\xb9\x02\x04\xb8\x02\x04\xb7\x02\x04\xb6\x02\x04"
  "\xb5\x02\x04\x77\x14\x73\x65\x74\x2d\x78\x2d\x69\x6d\x61\x67\x65"
  "\x2f\x68\x65\x69\x67\x68\x74\x21\x13\x73\x65\x74\x2d\x78\x2d\x69"
  "\x6d\x61\x67\x65\x2f\x77\x69\x64\x74\x68\x21\x14\x73\x65\x74\x2d"
  "\x78\x2d\x69\x6d\x61\x67\x65\x2f\x77\x69\x6e\x64\x6f\x77\x21\xd8"
  "\x02\x0f\x78\x2d\x69\x6d\x61\x67\x65\x2f\x68\x65\x69\x67\x68\x74"
  "\x0e\x78\x2d\x69\x6d\x61\x67\x65\x2f\x77\x69\x64\x74\x68\x0f\x78"
  "\x2d\x69\x6d\x61\x67\x65\x2f\x77\x69\x6e\x64\x6f\x77\xd9\x02\xe2"
  "\x01\x04\xce\x02\x04\xcd\x02\x04\xcc\x02\x04\xcb\x02\x04\xca\x02"
  "\x04\xc9\x02\x04\xc8\x02\x04\x08\x78\x2d\x69\x6d\x61\x67\x65\x82"
  "\x03\x07\x77\x69\x6e\x64\x6f\x77\xcf\x02\xd0\x02\xc4\x02\x04\xc5"
  "\x02\x04\xc6\x02\x04\xc7\x02\x04\x07\x76\x65\x63\x74\x6f\x72\x13"
  "\x78\x2d\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e"
  "\x64\x73\x08\x64\x65\x73\x63\x65\x6e\x74\x07\x61\x73\x63\x65\x6e"
  "\x74\xcf\x02\x09\x72\x62\x65\x61\x72\x69\x6e\x67\x09\x6c\x62\x65"
  "\x61\x72\x69\x6e\x67\xc3\x02\x04\xc2\x02\x04\xc1\x02\x04\xc0\x02"
  "\x04\xbf\x02\x04\xd7\x01\xa7\x01\xad\x01\x97\x01\x9d\x01\xb0\x01"
  "\xa9\x01\xb2\x01\x94\x01\xaf\x01\x1b\x78\x2d\x63\x68\x61\x72\x61"
  "\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e\x64\x73\x2f\x64\x65\x73\x63"
  "\x65\x6e\x74\x1a\x78\x2d\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d"
  "\x62\x6f\x75\x6e\x64\x73\x2f\x61\x73\x63\x65\x6e\x74\x19\x78\x2d"
  "\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e\x64\x73"
  "\x2f\x77\x69\x64\x74\x68\x1c\x78\x2d\x63\x68\x61\x72\x61\x63\x74"
  "\x65\x72\x2d\x62\x6f\x75\x6e\x64\x73\x2f\x72\x62\x65\x61\x72\x69"
  "\x6e\x67\x1c\x78\x2d\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62"
  "\x6f\x75\x6e\x64\x73\x2f\x6c\x62\x65\x61\x72\x69\x6e\x67\x18\x6d"
  "\x61\x6b\x65\x2d\x78\x2d\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d"
  "\x62\x6f\x75\x6e\x64\x73\x1d\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\x2f\x6d\x61\x78\x2d\x64\x65\x73\x63"
  "\x65\x6e\x74\x1c\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63"
  "\x74\x75\x72\x65\x2f\x6d\x61\x78\x2d\x61\x73\x63\x65\x6e\x74\x22"
  "\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65"
  "\x2f\x63\x68\x61\x72\x61\x63\x74\x65\x72\x2d\x62\x6f\x75\x6e\x64"
  "\x73\x1d\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x2f\x73\x74\x61\x72\x74\x2d\x69\x6e\x64\x65\x78\x1c\x78"
  "\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2f"
  "\x6d\x61\x78\x2d\x62\x6f\x75\x6e\x64\x73\x1c\x78\x2d\x66\x6f\x6e"
  "\x74\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2f\x6d\x69\x6e\x2d"
  "\x62\x6f\x75\x6e\x64\x73\x1e\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\x2f\x64\x65\x66\x61\x75\x6c\x74\x2d"
  "\x63\x68\x61\x72\x22\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75"
  "\x63\x74\x75\x72\x65\x2f\x61\x6c\x6c\x2d\x63\x68\x61\x72\x73\x2d"
  "\x65\x78\x69\x73\x74\x3f\x1b\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74"
  "\x72\x75\x63\x74\x75\x72\x65\x2f\x64\x69\x72\x65\x63\x74\x69\x6f"
  "\x6e\x16\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x2f\x6e\x61\x6d\x65\x16\x6d\x61\x6b\x65\x2d\x78\x2d\x66"
  "\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\xb5\x01\x1a"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x69\x73\x63\x61"
  "\x72\x64\x2d\x65\x76\x65\x6e\x74\x73\x1b\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x72\x65\x61\x64\x2d\x75\x73\x65\x72\x2d\x65"
  "\x76\x65\x6e\x74\x9c\x02\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2f\x72\x65\x61\x64\x2d\x62\x75\x74\x74\x6f\x6e\xaa\x01\x1e"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x73\x65\x6c\x65\x63"
  "\x74\x2d\x75\x73\x65\x72\x2d\x65\x76\x65\x6e\x74\x73\x21\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x65\x6e\x61\x62\x6c\x65\x2d"
  "\x6b\x65\x79\x62\x6f\x61\x72\x64\x2d\x66\x6f\x63\x75\x73\x22\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x64\x69\x73\x61\x62\x6c"
  "\x65\x2d\x6b\x65\x79\x62\x6f\x61\x72\x64\x2d\x66\x6f\x63\x75\x73"
  "\x9c\x01\x15\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x77\x69"
  "\x6e\x64\x6f\x77\x2d\x69\x64\x96\x01\xb3\x01\xc5\x01\xb7\x01\xb8"
  "\x01\xbf\x01\xc0\x01\x98\x01\x99\x01\x9b\x01\x9e\x01\x9f\x01\xa4"
  "\x01\xa5\x01\xa6\x01\x9a\x01\xa0\x01\xa1\x01\xa3\x01\xa8\x01\xae"
  "\x01\xb6\x01\xb9\x01\xba\x01\xbb\x01\xbc\x01\xbd\x01\xbe\x01\xc1"
  "\x01\xc2\x01\xc6\x01\xc9\x01\x97\x02\x90\x01\xac\x01\xe5\x01\x62"
  "\x12\x78\x2d\x67\x65\x6f\x6d\x65\x74\x72\x79\x2d\x73\x74\x72\x69"
  "\x6e\x67\xfc\x01\xc8\x01\xab\x01\x1d\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2d\x64\x65\x76\x69\x63\x65\x2f\x76\x69\x73\x69\x62"
  "\x69\x6c\x69\x74\x79\x1a\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73"
  "\x2d\x64\x65\x76\x69\x63\x65\x2f\x6d\x61\x70\x70\x65\x64\x3f\x15"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x65\x76\x69\x63"
  "\x65\x2f\x78\x64\x9e\x02\x15\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2d\x64\x65\x76\x69\x63\x65\x2f\x78\x77\x54\x3c\x04\x3a\x04"
  "\x38\x04\x2e\x04\x19\x04\x1f\x04\x15\x04\x42\x04\xb4\x02\x04\xb3"
  "\x02\x04\xb2\x02\x04\xb1\x02\x04\xb0\x02\x04\xaf\x02\x04\xae\x02"
  "\x04\xad\x02\x04\xac\x02\x04\xab\x02\x04\xaa\x02\x04\xa9\x02\x04"
  "\xa8\x02\x04\xa7\x02\x04\xa6\x02\x04\xa5\x02\x04\xa4\x02\x04\xa3"
  "\x02\x04\x09\x04\xa2\x02\x04\xa0\x02\x04\xe7\x01\x04\x9d\x02\x04"
  "\x1d\x04\x9b\x02\x04\x28\x04\x04\x30\x04\x17\x04\x3e\x04\x21\x04"
  "\x48\x04\x5a\x04\x4c\x04\x23\x04\x25\x04\x36\x04\x34\x04\x32\x04"
  "\x2c\x04\x2a\x04\x6a\x04\x6f\x04\x91\x01\x04\xe9\x01\x04\x6d\x04"
  "\x71\x04\x68\x04\x66\x04\x60\x04\x9a\x02\x06\x58\x04\x56\x04\x54"
  "\x04\x52\x04\x50\x04\x4e\x04\x44\x04\x46\x04\x73\x04\x0c\x04\x1b"
  "\x04\xf5\x01\x04\x99\x02\x04\x08\x35\x31\x32\x78\x35\x31\x32\x96"
  "\x02\x08\x95\x02\x04\xee\x01\x04\x94\x02\x04\x93\x02\x04\x92\x02"
  "\x04\x91\x02\x04\x90\x02\x04\x8f\x02\x04\x54\x02\x98\x02\x1e\x73"
  "\x65\x74\x2d\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2f\x75\x73\x65\x72"
  "\x2d\x65\x76\x65\x6e\x74\x2d\x6d\x61\x73\x6b\x21\x19\x73\x65\x74"
  "\x2d\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2f\x76\x69\x73\x69\x62\x69"
  "\x6c\x69\x74\x79\x21\x16\x73\x65\x74\x2d\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2f\x6d\x61\x70\x70\x65\x64\x3f\x21\xd5\x01\x19\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2f\x75\x73\x65\x72\x2d\x65\x76\x65\x6e"
  "\x74\x2d\x6d\x61\x73\x6b\x14\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2f"
  "\x76\x69\x73\x69\x62\x69\x6c\x69\x74\x79\x11\x78\x2d\x77\x69\x6e"
  "\x64\x6f\x77\x2f\x6d\x61\x70\x70\x65\x64\x3f\x11\x78\x2d\x77\x69"
  "\x6e\x64\x6f\x77\x2f\x64\x69\x73\x70\x6c\x61\x79\xd6\x01\x0a\x8e"
  "\x02\x04\x8d\x02\x04\x8c\x02\x04\x8b\x02\x04\x8a\x02\x04\x89\x02"
  "\x04\x88\x02\x04\x87\x02\x04\x86\x02\x04\x0a\x5e\x0d\x72\x74\x64"
  "\x3a\x78\x2d\x77\x69\x6e\x64\x6f\x77\x82\x03\x80\x02\x5c\x09\x78"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x03\x78\x77\x08\x64\x69\x73\x70\x6c"
  "\x61\x79\x08\x6d\x61\x70\x70\x65\x64\x3f\x0b\x76\x69\x73\x69\x62"
  "\x69\x6c\x69\x74\x79\x10\x75\x73\x65\x72\x2d\x65\x76\x65\x6e\x74"
  "\x2d\x6d\x61\x73\x6b\x82\x02\x04\x83\x02\x04\xfb\x01\x04\x84\x02"
  "\x04\x85\x02\x04\x09\x0f\x81\x02\x04\x0d\xff\x01\x04\x0c\xfe\x01"
  "\x04\x0b\xfd\x01\x04\xf6\x01\x64\x04\x15\x64\x65\x66\x69\x6e\x65"
  "\x2d\x65\x76\x65\x6e\x74\x2d\x68\x61\x6e\x64\x6c\x65\x72\xfa\x01"
  "\x04\xdb\x01\x10\xcd\x01\xf3\x01\xa1\x02\xf8\x01\x9f\x02\xec\x01"
  "\x19\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2f\x6f\x70\x65\x6e"
  "\x2d\x64\x69\x73\x70\x6c\x61\x79\x3f\x19\x78\x2d\x67\x72\x61\x70"
  "\x68\x69\x63\x73\x2f\x63\x6c\x6f\x73\x65\x2d\x64\x69\x73\x70\x6c"
  "\x61\x79\xe6\x01\xe8\x01\x04\xf7\x01\x04\xf2\x01\x04\xf9\x01\x04"
  "\xf4\x01\x04\xf1\x01\x04\xf0\x01\x04\xed\x01\x0a\xea\x01\x1b\x73"
  "\x65\x74\x2d\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2f\x65\x76\x65"
  "\x6e\x74\x2d\x71\x75\x65\x75\x65\x21\xcb\x01\x15\x78\x2d\x64\x69"
  "\x73\x70\x6c\x61\x79\x2f\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73"
  "\x16\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2f\x65\x76\x65\x6e\x74"
  "\x2d\x71\x75\x65\x75\x65\x1b\x78\x2d\x64\x69\x73\x70\x6c\x61\x79"
  "\x2f\x77\x69\x6e\x64\x6f\x77\x2d\x66\x69\x6e\x61\x6c\x69\x7a\x65"
  "\x72\xcc\x01\x0f\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2f\x6e\x61"
  "\x6d\x65\xe4\x01\x04\xe3\x01\x04\xe1\x01\x04\xe0\x01\x04\xdf\x01"
  "\x04\xde\x01\x04\xdd\x01\x04\x0a\x78\x2d\x64\x69\x73\x70\x6c\x61"
  "\x79\xff\x02\x03\x78\x64\x11\x77\x69\x6e\x64\x6f\x77\x2d\x66\x69"
  "\x6e\x61\x6c\x69\x7a\x65\x72\x0c\x65\x76\x65\x6e\x74\x2d\x71\x75"
  "\x65\x75\x65\x0b\x70\x72\x6f\x70\x65\x72\x74\x69\x65\x73\xd3\x01"
  "\x04\xd4\x01\x04\xd8\x01\x04\xd9\x01\x04\xda\x01\x04\x11\x6c\x6f"
  "\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0e\x72"
  "\x74\x64\x3a\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\xff\x02\x0a\x78"
  "\x2d\x64\x69\x73\x70\x6c\x61\x79\xdc\x01\x04\x93\x01\x92\x01\xca"
  "\x01\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x70\x61\x63"
  "\x6b\x61\x67\x65\x21\x18\x75\x73\x65\x72\x2d\x65\x76\x65\x6e\x74"
  "\x2d\x6d\x61\x73\x6b\x3a\x64\x65\x66\x61\x75\x6c\x74\x18\x65\x76"
  "\x65\x6e\x74\x2d\x6d\x61\x73\x6b\x3a\x69\x67\x6e\x6f\x72\x65\x2d"
  "\x66\x6f\x63\x75\x73\x12\x65\x76\x65\x6e\x74\x2d\x6d\x61\x73\x6b"
  "\x3a\x6e\x6f\x72\x6d\x61\x6c\x16\x6e\x75\x6d\x62\x65\x72\x2d\x6f"
  "\x66\x2d\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x73\x16\x65\x76"
  "\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a\x76\x69\x73\x69\x62\x69\x6c"
  "\x69\x74\x79\x16\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a\x74"
  "\x61\x6b\x65\x2d\x66\x6f\x63\x75\x73\x11\x65\x76\x65\x6e\x74\x2d"
  "\x74\x79\x70\x65\x3a\x75\x6e\x6d\x61\x70\x0f\x65\x76\x65\x6e\x74"
  "\x2d\x74\x79\x70\x65\x3a\x6d\x61\x70\x19\x65\x76\x65\x6e\x74\x2d"
  "\x74\x79\x70\x65\x3a\x64\x65\x6c\x65\x74\x65\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x12\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a\x65\x78"
  "\x70\x6f\x73\x65\x12\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a"
  "\x6d\x6f\x74\x69\x6f\x6e\x11\x65\x76\x65\x6e\x74\x2d\x74\x79\x70"
  "\x65\x3a\x6c\x65\x61\x76\x65\x15\x65\x76\x65\x6e\x74\x2d\x74\x79"
  "\x70\x65\x3a\x6b\x65\x79\x2d\x70\x72\x65\x73\x73\x15\x65\x76\x65"
  "\x6e\x74\x2d\x74\x79\x70\x65\x3a\x66\x6f\x63\x75\x73\x2d\x6f\x75"
  "\x74\x14\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a\x66\x6f\x63"
  "\x75\x73\x2d\x69\x6e\x11\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65"
  "\x3a\x65\x6e\x74\x65\x72\x15\x65\x76\x65\x6e\x74\x2d\x74\x79\x70"
  "\x65\x3a\x63\x6f\x6e\x66\x69\x67\x75\x72\x65\x15\x65\x76\x65\x6e"
  "\x74\x2d\x74\x79\x70\x65\x3a\x62\x75\x74\x74\x6f\x6e\x2d\x75\x70"
  "\x17\x65\x76\x65\x6e\x74\x2d\x74\x79\x70\x65\x3a\x62\x75\x74\x74"
  "\x6f\x6e\x2d\x64\x6f\x77\x6e\x14\x78\x2d\x76\x69\x73\x75\x61\x6c"
  "\x2d\x64\x65\x61\x6c\x6c\x6f\x63\x61\x74\x65\x0f\x78\x2d\x73\x74"
  "\x6f\x72\x65\x2d\x63\x6f\x6c\x6f\x72\x73\x0e\x78\x2d\x73\x74\x6f"
  "\x72\x65\x2d\x63\x6f\x6c\x6f\x72\x16\x78\x2d\x73\x65\x74\x2d\x77"
  "\x69\x6e\x64\x6f\x77\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70\x0e\x78"
  "\x2d\x71\x75\x65\x72\x79\x2d\x63\x6f\x6c\x6f\x72\xf6\x02\x12\x78"
  "\x2d\x63\x72\x65\x61\x74\x65\x2d\x63\x6f\x6c\x6f\x72\x6d\x61\x70"
  "\x11\x78\x2d\x61\x6c\x6c\x6f\x63\x61\x74\x65\x2d\x63\x6f\x6c\x6f"
  "\x72\x15\x78\x2d\x73\x65\x74\x2d\x70\x69\x78\x65\x6c\x2d\x69\x6e"
  "\x2d\x69\x6d\x61\x67\x65\x17\x78\x2d\x67\x65\x74\x2d\x70\x69\x78"
  "\x65\x6c\x2d\x66\x72\x6f\x6d\x2d\x69\x6d\x61\x67\x65\x10\x78\x2d"
  "\x64\x69\x73\x70\x6c\x61\x79\x2d\x69\x6d\x61\x67\x65\xdb\x02\x0f"
  "\x78\x2d\x63\x72\x65\x61\x74\x65\x2d\x69\x6d\x61\x67\x65\x13\x78"
  "\x2d\x62\x79\x74\x65\x73\x2d\x69\x6e\x74\x6f\x2d\x69\x6d\x61\x67"
  "\x65\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x76\x64\x63"
  "\x2d\x65\x78\x74\x65\x6e\x74\x1a\x78\x2d\x67\x72\x61\x70\x68\x69"
  "\x63\x73\x2d\x73\x65\x74\x2d\x76\x64\x63\x2d\x65\x78\x74\x65\x6e"
  "\x74\x1a\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74"
  "\x2d\x6c\x69\x6e\x65\x2d\x73\x74\x79\x6c\x65\x18\x78\x2d\x67\x72"
  "\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74\x2d\x66\x75\x6e\x63\x74"
  "\x69\x6f\x6e\x1a\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73"
  "\x65\x74\x2d\x66\x69\x6c\x6c\x2d\x73\x74\x79\x6c\x65\x16\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73\x65\x74\x2d\x64\x61\x73"
  "\x68\x65\x73\x1e\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x73"
  "\x65\x74\x2d\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e\x67\x6c"
  "\x65\x20\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x72\x65\x73"
  "\x65\x74\x2d\x63\x6c\x69\x70\x2d\x72\x65\x63\x74\x61\x6e\x67\x6c"
  "\x65\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x72\x65\x63"
  "\x6f\x6e\x66\x69\x67\x75\x72\x65\x17\x78\x2d\x67\x72\x61\x70\x68"
  "\x69\x63\x73\x2d\x6f\x70\x65\x6e\x2d\x77\x69\x6e\x64\x6f\x77\x17"
  "\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x6d\x6f\x76\x65\x2d"
  "\x63\x75\x72\x73\x6f\x72\x1c\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2d\x6d\x61\x70\x2d\x79\x2d\x63\x6f\x6f\x72\x64\x69\x6e\x61"
  "\x74\x65\x1c\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x6d\x61"
  "\x70\x2d\x78\x2d\x63\x6f\x6f\x72\x64\x69\x6e\x61\x74\x65\x18\x78"
  "\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x66\x69\x6c\x6c\x2d\x70"
  "\x6f\x6c\x79\x67\x6f\x6e\x1d\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2d\x64\x72\x61\x77\x2d\x69\x6d\x61\x67\x65\x2d\x73\x74\x72"
  "\x69\x6e\x67\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64"
  "\x72\x61\x77\x2d\x73\x74\x72\x69\x6e\x67\x17\x78\x2d\x67\x72\x61"
  "\x70\x68\x69\x63\x73\x2d\x64\x72\x61\x77\x2d\x70\x6f\x69\x6e\x74"
  "\x73\x16\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72\x61"
  "\x77\x2d\x70\x6f\x69\x6e\x74\x16\x78\x2d\x67\x72\x61\x70\x68\x69"
  "\x63\x73\x2d\x64\x72\x61\x77\x2d\x6c\x69\x6e\x65\x73\x15\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72\x61\x77\x2d\x6c\x69"
  "\x6e\x65\x14\x78\x2d\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x64\x72"
  "\x61\x77\x2d\x61\x72\x63\x17\x78\x2d\x67\x72\x61\x70\x68\x69\x63"
  "\x73\x2d\x64\x72\x61\x67\x2d\x63\x75\x72\x73\x6f\x72\x15\x78\x2d"
  "\x67\x72\x61\x70\x68\x69\x63\x73\x2d\x63\x6f\x70\x79\x2d\x61\x72"
  "\x65\x61\x10\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x79\x2d\x73\x69"
  "\x7a\x65\x10\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x78\x2d\x73\x69"
  "\x7a\x65\x12\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x77\x69\x74\x68"
  "\x64\x72\x61\x77\x10\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x76\x69"
  "\x73\x75\x61\x6c\x1b\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x74"
  "\x61\x72\x62\x61\x73\x65\x2d\x66\x69\x6c\x65\x6e\x61\x6d\x65\x12"
  "\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x73\x69\x7a"
  "\x65\x16\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x70"
  "\x6f\x73\x69\x74\x69\x6f\x6e\x12\x78\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2d\x73\x65\x74\x2d\x6e\x61\x6d\x65\x19\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2d\x73\x65\x74\x2d\x6d\x6f\x75\x73\x65\x2d\x73\x68\x61"
  "\x70\x65\x19\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d"
  "\x6d\x6f\x75\x73\x65\x2d\x63\x6f\x6c\x6f\x72\x23\x78\x2d\x77\x69"
  "\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x6e\x61"
  "\x6c\x2d\x62\x6f\x72\x64\x65\x72\x2d\x77\x69\x64\x74\x68\x18\x78"
  "\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x69\x6e\x70\x75"
  "\x74\x2d\x68\x69\x6e\x74\x17\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d"
  "\x73\x65\x74\x2d\x69\x63\x6f\x6e\x2d\x6e\x61\x6d\x65\x1e\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x66\x6f\x72\x65\x67"
  "\x72\x6f\x75\x6e\x64\x2d\x63\x6f\x6c\x6f\x72\x12\x78\x2d\x77\x69"
  "\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x66\x6f\x6e\x74\x18\x78\x2d"
  "\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x65\x76\x65\x6e\x74"
  "\x2d\x6d\x61\x73\x6b\x1a\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73"
  "\x65\x74\x2d\x63\x75\x72\x73\x6f\x72\x2d\x63\x6f\x6c\x6f\x72\x1a"
  "\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74\x2d\x62\x6f\x72"
  "\x64\x65\x72\x2d\x77\x69\x64\x74\x68\x1a\x78\x2d\x77\x69\x6e\x64"
  "\x6f\x77\x2d\x73\x65\x74\x2d\x62\x6f\x72\x64\x65\x72\x2d\x63\x6f"
  "\x6c\x6f\x72\x1e\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x73\x65\x74"
  "\x2d\x62\x61\x63\x6b\x67\x72\x6f\x75\x6e\x64\x2d\x63\x6f\x6c\x6f"
  "\x72\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x72\x61\x69\x73\x65"
  "\x17\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x71\x75\x65\x72\x79\x2d"
  "\x70\x6f\x69\x6e\x74\x65\x72\x0d\x78\x2d\x77\x69\x6e\x64\x6f\x77"
  "\x2d\x6d\x61\x70\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x6c\x6f"
  "\x77\x65\x72\x0c\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x69\x64\x11"
  "\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x69\x63\x6f\x6e\x69\x66\x79"
  "\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x66\x6c\x75\x73\x68\x14"
  "\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x65\x76\x65\x6e\x74\x2d\x6d"
  "\x61\x73\x6b\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x64\x65\x70"
  "\x74\x68\x12\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x63\x6f\x6c\x6f"
  "\x72\x6d\x61\x70\x0f\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x63\x6c"
  "\x65\x61\x72\x0e\x78\x2d\x77\x69\x6e\x64\x6f\x77\x2d\x62\x65\x65"
  "\x70\x11\x78\x2d\x66\x6f\x6e\x74\x2d\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x19\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2d\x70\x72\x6f"
  "\x63\x65\x73\x73\x2d\x65\x76\x65\x6e\x74\x73\x16\x78\x2d\x64\x69"
  "\x73\x70\x6c\x61\x79\x2d\x67\x65\x74\x2d\x64\x65\x66\x61\x75\x6c"
  "\x74\x15\x78\x2d\x64\x69\x73\x70\x6c\x61\x79\x2d\x64\x65\x73\x63"
  "\x72\x69\x70\x74\x6f\x72\x15\x78\x2d\x63\x6c\x6f\x73\x65\x2d\x61"
  "\x6c\x6c\x2d\x64\x69\x73\x70\x6c\x61\x79\x73\x62\xd2\x01\x04\xd1"
  "\x01\x04\x80\xfc\x01\x80\xbc\x01\x10\x0f\x0e\x0d\x0c\x0b\x0a\x09"
  "\x08\x8e\x01\x04\x8c\x01\x04\x8a\x01\x04\x88\x01\x04\x86\x01\x04"
  "\x84\x01\x04\x83\x01\x04\x81\x01\x04\x7f\x04\x7d\x04\x7b\x04\x79"
  "\x04\x78\x04\x76\x04\x74\x04\x72\x04\x70\x04\x6e\x04\x6c\x04\x6b"
  "\x04\x69\x04\x67\x04\x65\x04\x63\x04\x61\x04\x5f\x04\x5d\x04\x5b"
  "\x04\x59\x04\x57\x04\x55\x04\x53\x04\x51\x04\x4f\x04\x4d\x04\x4b"
  "\x04\x49\x04\x47\x04\x45\x04\x43\x04\x41\x04\x3f\x04\x3d\x04\x3b"
  "\x04\x39\x04\x37\x04\x35\x04\x33\x04\x31\x04\x2f\x04\x2d\x04\x2b"
  "\x04\x29\x04\x27\x04\x26\x04\x24\x04\x22\x04\x20\x04\x1e\x04\x1c"
  "\x04\x1a\x04\x18\x04\x16\x04\x14\x04\x12\x04\x11\x04\x0f\x04\x0d"
  "\x04\x0b\x04\x0a\x04\x04\x04\x04\x04\x62\x05\x10\x64\x65\x66\x69"
  "\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x03\x19\x72\x65\x63"
  "\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61\x74\x63"
  "\x68\x2d\x74\x61\x67\x06\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63\x6f"
  "\x72\x64\x2d\x74\x79\x70\x65\xfe\x02\x04\x23\x72\x65\x63\x6f\x72"
  "\x64\x2d\x74\x79\x70\x65\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d\x76"
  "\x61\x6c\x75\x65\x2d\x62\x79\x2d\x69\x6e\x64\x65\x78\x0a\x1b\x6d"
  "\x61\x6b\x65\x2d\x64\x65\x66\x69\x6e\x65\x2d\x73\x74\x72\x75\x63"
  "\x74\x75\x72\x65\x2d\x74\x79\x70\x65\x06\xff\x02\x82\x03\x80\x03"
  "\x81\x03\x06\x04\x19\x73\x74\x61\x6e\x64\x61\x72\x64\x2d\x75\x6e"
  "\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x04\x0c\x6d"
  "\x61\x6b\x65\x2d\x76\x65\x63\x74\x6f\x72\x04\xfe\x02\x04\x13\x72"
  "\x65\x63\x6f\x72\x64\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x6f"
  "\x72\x03\x11\x72\x65\x63\x6f\x72\x64\x2d\x70\x72\x65\x64\x69\x63"
  "\x61\x74\x65\x04\x10\x72\x65\x63\x6f\x72\x64\x2d\x61\x63\x63\x65"
  "\x73\x73\x6f\x72\x04\x10\x72\x65\x63\x6f\x72\x64\x2d\x6d\x6f\x64"
  "\x69\x66\x69\x65\x72\x08\x60\xc2\x01\x80\x80\x04\x5f\xc0\x01\x81"
  "\x81\x02\x5e\xbe\x01\x81\x81\x02\x5d\xbc\x01\x81\x85\x02\x5c\xba"
  "\x01\x81\x83\x02\x5b\xb8\x01\x81\x85\x02\x5a\xb6\x01\x81\x83\x02"
  "\x59\xb4\x01\x81\x85\x02\x58\xb2\x01\x81\x89\x02\x57\xb0\x01\x81"
  "\x83\x02\x56\xae\x01\x81\x85\x02\x55\xac\x01\x81\x89\x02\x54\xaa"
  "\x01\x81\x83\x02\x53\xa8\x01\x81\x85\x02\x52\xa6\x01\x81\x87\x02"
  "\x51\xa4\x01\x81\x83\x02\x50\xa2\x01\x81\x85\x02\x4f\xa0\x01\x81"
  "\x89\x02\x4e\x9e\x01\x81\x83\x02\x4d\x9c\x01\x81\x85\x02\x4c\x9a"
  "\x01\x81\x85\x02\x4b\x98\x01\x81\x83\x02\x4a\x96\x01\x81\x85\x02"
  "\x49\x94\x01\x81\x83\x02\x48\x92\x01\x81\x89\x02\x47\x90\x01\x81"
  "\x8b\x02\x46\x8e\x01\x81\x87\x02\x45\x8c\x01\x81\x83\x02\x44\x8a"
  "\x01\x81\x87\x02\x43\x88\x01\x81\x85\x02\x42\x86\x01\x81\x83\x02"
  "\x41\x84\x01\x81\x85\x02\x40\x82\x01\x81\x87\x02\x3f\x80\x01\x81"
  "\x83\x02\x3e\x7e\x81\x85\x02\x3d\x7c\x81\x85\x02\x3c\x7a\x81\x83"
  "\x02\x3b\x78\x81\x87\x02\x3a\x76\x81\x85\x02\x39\x74\x81\x83\x02"
  "\x38\x72\x81\x8b\x02\x37\x70\x81\x87\x02\x36\x6e\x81\x87\x02\x35"
  "\x6c\x81\x83\x02\x34\x6a\x81\x87\x02\x33\x68\x81\x85\x02\x32\x66"
  "\x81\x83\x02\x31\x64\x81\x89\x02\x30\x62\x81\x87\x02\x2f\x60\x81"
  "\x87\x02\x2e\x5e\x81\x85\x02\x2d\x5c\x81\x87\x02\x2c\x5a\x81\x83"
  "\x02\x2b\x58\x81\x89\x02\x2a\x56\x81\x85\x02\x29\x54\x84\x06\x28"
  "\x52\x81\x85\x02\x27\x50\x81\x81\x02\x26\x4e\x81\x81\x02\x25\x4c"
  "\x81\x81\x02\x24\x4a\x81\x81\x02\x23\x48\x81\x83\x02\x22\x46\x81"
  "\x83\x02\x21\x44\x81\x83\x02\x20\x42\x81\x83\x02\x1f\x40\x81\x83"
  "\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x83\x02\x1c\x3a\x81\x83\x02"
  "\x1b\x38\x81\x83\x02\x1a\x36\x81\x83\x02\x19\x34\x81\x83\x02\x18"
  "\x32\x81\x83\x02\x17\x30\x81\x8b\x02\x16\x2e\x81\x85\x02\x15\x2c"
  "\x81\x83\x02\x14\x2a\x81\x8f\x02\x13\x28\x81\x89\x02\x12\x26\x81"
  "\x85\x02\x11\x24\x81\x85\x02\x10\x22\x81\x83\x02\x0f\x20\x81\x8d"
  "\x02\x0e\x1e\x81\x87\x02\x0d\x1c\x81\x85\x02\x0c\x1a\x81\x83\x02"
  "\x0b\x18\x81\x8b\x02\x0a\x16\x81\x87\x02\x09\x14\x81\x87\x02\x08"
  "\x12\x81\x83\x02\x07\x10\x81\x85\x02\x06\x0e\x81\x83\x02\x05\x0c"
  "\x81\x87\x02\x04\x0a\x81\x85\x02\x03\x08\x81\x87\x02\x02\x06\x81"
  "\x83\x02\x01\x04\x81\x83\x02\xc1\x01\xdc\x02";

SCHEME_OBJECT *
x11graph_so_data_9437ec791784179c (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_x11graph_so_data_9437ec791784179c [0]))), (sizeof (prog_x11graph_so_data_9437ec791784179c)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_117]));
}

DECLARE_COMPILED_DATA_NS ("x11graph.so", x11graph_so_data_9437ec791784179c)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("x11graph.so", "cae702efa17e3d91")
