/* Emacs: this is -*- C -*- code, */
/* generated 2010-03-09T19:21:14-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 5
#define DEBUGGING_LABEL_1_2 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 5
#define DEBUGGING_LABEL_2_2 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 5
#define DEBUGGING_LABEL_4_2 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 5
#define DEBUGGING_LABEL_5_2 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 5
#define DEBUGGING_LABEL_6_2 4
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define ENVIRONMENT_LABEL_7_3 5
#define DEBUGGING_LABEL_7_2 4
#define FREE_REFERENCES_LABEL_7_0 4
#define NUMBER_OF_LINKER_SECTIONS_7_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 5
#define DEBUGGING_LABEL_8_2 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 5
#define DEBUGGING_LABEL_9_2 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define ENVIRONMENT_LABEL_10_3 5
#define DEBUGGING_LABEL_10_2 4
#define FREE_REFERENCES_LABEL_10_0 4
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define ENVIRONMENT_LABEL_11_3 5
#define DEBUGGING_LABEL_11_2 4
#define FREE_REFERENCES_LABEL_11_0 4
#define NUMBER_OF_LINKER_SECTIONS_11_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_11_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 5
#define DEBUGGING_LABEL_12_2 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define ENVIRONMENT_LABEL_13_3 5
#define DEBUGGING_LABEL_13_2 4
#define FREE_REFERENCES_LABEL_13_0 4
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_13_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 5
#define DEBUGGING_LABEL_14_2 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 5
#define DEBUGGING_LABEL_15_2 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 5
#define DEBUGGING_LABEL_16_2 4
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_16_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define ENVIRONMENT_LABEL_17_3 7
#define DEBUGGING_LABEL_17_2 6
#define OBJECT_17_1 5
#define OBJECT_17_0 4
#define FREE_REFERENCES_LABEL_17_0 4
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto tree_type_key_P_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_key_P_3)
DEFLABEL (tree_type_key_P_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_17_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define ENVIRONMENT_LABEL_18_3 7
#define DEBUGGING_LABEL_18_2 6
#define OBJECT_18_1 5
#define OBJECT_18_0 4
#define FREE_REFERENCES_LABEL_18_0 4
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto tree_type_alist__tree_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_alist__tree_3)
DEFLABEL (tree_type_alist__tree_0)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_18_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define ENVIRONMENT_LABEL_19_3 7
#define DEBUGGING_LABEL_19_2 6
#define OBJECT_19_1 5
#define OBJECT_19_0 4
#define FREE_REFERENCES_LABEL_19_0 4
#define NUMBER_OF_LINKER_SECTIONS_19_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto tree_type_add_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_add_3)
DEFLABEL (tree_type_add_0)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_19_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define ENVIRONMENT_LABEL_20_3 7
#define DEBUGGING_LABEL_20_2 6
#define OBJECT_20_1 5
#define OBJECT_20_0 4
#define FREE_REFERENCES_LABEL_20_0 4
#define NUMBER_OF_LINKER_SECTIONS_20_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto tree_type_insertB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_insertB_3)
DEFLABEL (tree_type_insertB_0)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_20_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 7
#define DEBUGGING_LABEL_21_2 6
#define OBJECT_21_1 5
#define OBJECT_21_0 4
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto tree_type_delete_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_delete_3)
DEFLABEL (tree_type_delete_0)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_21_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 7
#define DEBUGGING_LABEL_22_2 6
#define OBJECT_22_1 5
#define OBJECT_22_0 4
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto tree_type_deleteB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_deleteB_3)
DEFLABEL (tree_type_deleteB_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_22_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define ENVIRONMENT_LABEL_23_3 7
#define DEBUGGING_LABEL_23_2 6
#define OBJECT_23_1 5
#define OBJECT_23_0 4
#define FREE_REFERENCES_LABEL_23_0 4
#define NUMBER_OF_LINKER_SECTIONS_23_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto tree_type_memberP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_memberP_3)
DEFLABEL (tree_type_memberP_0)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_23_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define ENVIRONMENT_LABEL_24_3 7
#define DEBUGGING_LABEL_24_2 6
#define OBJECT_24_1 5
#define OBJECT_24_0 4
#define FREE_REFERENCES_LABEL_24_0 4
#define NUMBER_OF_LINKER_SECTIONS_24_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto tree_type_lookup_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_lookup_3)
DEFLABEL (tree_type_lookup_0)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_24_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [9]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define ENVIRONMENT_LABEL_25_3 7
#define DEBUGGING_LABEL_25_2 6
#define OBJECT_25_1 5
#define OBJECT_25_0 4
#define FREE_REFERENCES_LABEL_25_0 4
#define NUMBER_OF_LINKER_SECTIONS_25_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto tree_type_split_lt_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_split_lt_3)
DEFLABEL (tree_type_split_lt_0)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_25_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [10]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 7
#define DEBUGGING_LABEL_26_2 6
#define OBJECT_26_1 5
#define OBJECT_26_0 4
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto tree_type_split_gt_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_split_gt_3)
DEFLABEL (tree_type_split_gt_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_26_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [11]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 7
#define DEBUGGING_LABEL_27_2 6
#define OBJECT_27_1 5
#define OBJECT_27_0 4
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto tree_type_union_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_union_3)
DEFLABEL (tree_type_union_0)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_27_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [12]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 7
#define DEBUGGING_LABEL_28_2 6
#define OBJECT_28_1 5
#define OBJECT_28_0 4
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto tree_type_union_merge_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_union_merge_3)
DEFLABEL (tree_type_union_merge_0)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_28_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [13]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define ENVIRONMENT_LABEL_29_3 7
#define DEBUGGING_LABEL_29_2 6
#define OBJECT_29_1 5
#define OBJECT_29_0 4
#define FREE_REFERENCES_LABEL_29_0 4
#define NUMBER_OF_LINKER_SECTIONS_29_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto tree_type_intersection_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_intersection_3)
DEFLABEL (tree_type_intersection_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_29_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 13L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [14]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define ENVIRONMENT_LABEL_30_3 7
#define DEBUGGING_LABEL_30_2 6
#define OBJECT_30_1 5
#define OBJECT_30_0 4
#define FREE_REFERENCES_LABEL_30_0 4
#define NUMBER_OF_LINKER_SECTIONS_30_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto tree_type_difference_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_difference_3)
DEFLABEL (tree_type_difference_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_30_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [15]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define ENVIRONMENT_LABEL_31_3 7
#define DEBUGGING_LABEL_31_2 6
#define OBJECT_31_1 5
#define OBJECT_31_0 4
#define FREE_REFERENCES_LABEL_31_0 4
#define NUMBER_OF_LINKER_SECTIONS_31_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto tree_type_subsetP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_subsetP_3)
DEFLABEL (tree_type_subsetP_0)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_31_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 15L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [16]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define ENVIRONMENT_LABEL_32_3 7
#define DEBUGGING_LABEL_32_2 6
#define OBJECT_32_1 5
#define OBJECT_32_0 4
#define FREE_REFERENCES_LABEL_32_0 4
#define NUMBER_OF_LINKER_SECTIONS_32_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto tree_type_rank_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_rank_3)
DEFLABEL (tree_type_rank_0)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_32_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 16L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [17]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 5
#define DEBUGGING_LABEL_33_2 4
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_33_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 5
#define DEBUGGING_LABEL_34_2 4
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define ENVIRONMENT_LABEL_35_3 7
#define DEBUGGING_LABEL_35_2 6
#define OBJECT_35_1 5
#define OBJECT_35_0 4
#define FREE_REFERENCES_LABEL_35_0 4
#define NUMBER_OF_LINKER_SECTIONS_35_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto tree_type_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_type_3)
DEFLABEL (tree_type_0)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_35_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 7
#define DEBUGGING_LABEL_36_2 6
#define OBJECT_36_1 5
#define OBJECT_36_0 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto tree_root_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_root_3)
DEFLABEL (tree_root_0)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_36_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define ENVIRONMENT_LABEL_37_3 8
#define DEBUGGING_LABEL_37_2 7
#define OBJECT_37_2 6
#define OBJECT_37_1 5
#define OBJECT_37_0 4
#define FREE_REFERENCES_LABEL_37_0 4
#define NUMBER_OF_LINKER_SECTIONS_37_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto set_tree_rootB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_tree_rootB_3)
DEFLABEL (set_tree_rootB_0)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_37_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_37_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define ENVIRONMENT_LABEL_38_3 5
#define DEBUGGING_LABEL_38_2 4
#define FREE_REFERENCES_LABEL_38_0 4
#define NUMBER_OF_LINKER_SECTIONS_38_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto make_node_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_node_3)
DEFLABEL (make_node_0)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define ENVIRONMENT_LABEL_39_3 7
#define DEBUGGING_LABEL_39_2 6
#define OBJECT_39_1 5
#define OBJECT_39_0 4
#define FREE_REFERENCES_LABEL_39_0 4
#define NUMBER_OF_LINKER_SECTIONS_39_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto node_k_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_k_3)
DEFLABEL (node_k_0)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_39_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 7
#define DEBUGGING_LABEL_40_2 6
#define OBJECT_40_1 5
#define OBJECT_40_0 4
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto node_v_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_v_3)
DEFLABEL (node_v_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_40_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define ENVIRONMENT_LABEL_41_3 7
#define DEBUGGING_LABEL_41_2 6
#define OBJECT_41_1 5
#define OBJECT_41_0 4
#define FREE_REFERENCES_LABEL_41_0 4
#define NUMBER_OF_LINKER_SECTIONS_41_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto node_l_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_l_3)
DEFLABEL (node_l_0)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_41_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define ENVIRONMENT_LABEL_42_3 7
#define DEBUGGING_LABEL_42_2 6
#define OBJECT_42_1 5
#define OBJECT_42_0 4
#define FREE_REFERENCES_LABEL_42_0 4
#define NUMBER_OF_LINKER_SECTIONS_42_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto node_r_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_r_3)
DEFLABEL (node_r_0)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_42_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define ENVIRONMENT_LABEL_43_3 7
#define DEBUGGING_LABEL_43_2 6
#define OBJECT_43_1 5
#define OBJECT_43_0 4
#define FREE_REFERENCES_LABEL_43_0 4
#define NUMBER_OF_LINKER_SECTIONS_43_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto node_w_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_w_3)
DEFLABEL (node_w_0)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_43_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define ENVIRONMENT_LABEL_44_3 7
#define DEBUGGING_LABEL_44_2 6
#define OBJECT_44_1 5
#define OBJECT_44_0 4
#define FREE_REFERENCES_LABEL_44_0 4
#define NUMBER_OF_LINKER_SECTIONS_44_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto emptyP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (emptyP_3)
DEFLABEL (emptyP_0)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == (current_block [OBJECT_44_0]))
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_4;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_44_1]);

DEFLABEL (label_4)
DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define ENVIRONMENT_LABEL_45_3 8
#define DEBUGGING_LABEL_45_2 7
#define OBJECT_45_2 6
#define OBJECT_45_1 5
#define OBJECT_45_0 4
#define FREE_REFERENCES_LABEL_45_0 4
#define NUMBER_OF_LINKER_SECTIONS_45_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto node_size_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_size_4)
DEFLABEL (node_size_1)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_45_0])))
    goto label_5;
  Rvl = (current_block [OBJECT_45_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_45_1]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_2]), 2);

DEFLABEL (label_7)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd18.Lng))))
    goto label_6;
  Rvl = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define ENVIRONMENT_LABEL_46_3 7
#define DEBUGGING_LABEL_46_2 6
#define OBJECT_46_1 5
#define OBJECT_46_0 4
#define FREE_REFERENCES_LABEL_46_0 4
#define NUMBER_OF_LINKER_SECTIONS_46_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto node_singleton_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_singleton_3)
DEFLABEL (node_singleton_0)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (current_block [OBJECT_46_0]);
  (Wrd15.Obj) = (current_block [OBJECT_46_1]);
  (Wrd16.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define LABEL_47_6 7
#define LABEL_47_7 9
#define LABEL_47_8 11
#define ENVIRONMENT_LABEL_47_3 18
#define DEBUGGING_LABEL_47_2 17
#define OBJECT_47_4 16
#define OBJECT_47_3 15
#define OBJECT_47_2 14
#define OBJECT_47_1 13
#define OBJECT_47_0 12
#define FREE_REFERENCES_LABEL_47_0 12
#define NUMBER_OF_LINKER_SECTIONS_47_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto with_n_node_4;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_47_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_47_7);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_47_8);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (with_n_node_11)
DEFLABEL (with_n_node_4)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_19;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_19;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_18)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_17;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_17;
  (Wrd23.Obj) = ((Wrd27.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_16)
  (Wrd37.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_15;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd46.Lng))))
    goto label_15;
  (Wrd38.Obj) = ((Wrd44.pObj) [4]);

DEFLABEL (label_14)
  (Rsp [4]) = (Wrd38.Obj);
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_13;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd62.Lng))))
    goto label_13;
  (Wrd54.Obj) = ((Wrd60.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [3]) = (Wrd54.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_13)
  (Wrd65.Obj) = (Rsp [3]);
  (Wrd66.Obj) = (current_block [OBJECT_47_4]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_8]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_9)
  (Wrd54.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.Obj) = (current_block [OBJECT_47_3]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_7]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_8)
  (Wrd38.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_47_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_47_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_5 3
#define LABEL_48_6 5
#define LABEL_48_4 7
#define LABEL_48_7 9
#define LABEL_48_8 11
#define ENVIRONMENT_LABEL_48_3 16
#define DEBUGGING_LABEL_48_2 15
#define OBJECT_48_2 14
#define OBJECT_48_1 13
#define OBJECT_48_0 12
#define FREE_REFERENCES_LABEL_48_0 12
#define NUMBER_OF_LINKER_SECTIONS_48_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd59;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd70;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd33;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_48_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_48_4);
      goto n_join_6;

    case 3:
      current_block = (Rpc - LABEL_48_7);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_48_8);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (n_join_11)
DEFLABEL (n_join_6)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  if ((Wrd8.Obj) == (current_block [OBJECT_48_0]))
    goto label_19;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_18;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_18;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_17)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_16)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  if ((Wrd30.Obj) == (current_block [OBJECT_48_0]))
    goto label_15;
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_14;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd41.Lng))))
    goto label_14;
  (Wrd33.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_13)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_12)
  (Wrd49.Obj) = (* (Rsp++));
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  (Wrd55.Lng) = ((Wrd51.Lng) + (Wrd52.Lng));
  (Wrd56.Lng) = ((Wrd55.Lng) + 1L);
  (Wrd54.Obj) = (LONG_TO_FIXNUM (Wrd56.Lng));
  (Wrd65.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd66.Obj) = (Rsp [2]);
  (Wrd67.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd65.Obj);
  (* (Rhp++)) = (Wrd54.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd61.Obj) = (Rsp [3]);
  (Wrd62.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd62.Obj);
  (Wrd59.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd59.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd44.Obj) = (Rsp [4]);
  (Wrd45.Obj) = (current_block [OBJECT_48_1]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_8]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 2);

DEFLABEL (label_9)
  (Wrd33.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_15)
  (Wrd33.Obj) = (current_block [OBJECT_48_1]);
  goto label_13;

DEFLABEL (label_18)
  (Wrd22.Obj) = (Rsp [4]);
  (Wrd23.Obj) = (current_block [OBJECT_48_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_7]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 2);

DEFLABEL (label_8)
  (Wrd11.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  (Wrd70.Obj) = (current_block [OBJECT_48_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd70.Obj);
  goto label_16;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_48_5);
  (Wrd33.Obj) = Rvl;
  goto label_12;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_48_6);
  (* (--Rsp)) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_5 3
#define LABEL_49_6 5
#define LABEL_49_7 7
#define LABEL_49_8 9
#define LABEL_49_4 11
#define LABEL_49_9 13
#define LABEL_49_10 15
#define LABEL_49_11 17
#define LABEL_49_12 19
#define LABEL_49_13 21
#define LABEL_49_14 23
#define LABEL_49_15 25
#define LABEL_49_16 27
#define ENVIRONMENT_LABEL_49_3 36
#define DEBUGGING_LABEL_49_2 35
#define OBJECT_49_6 34
#define OBJECT_49_5 33
#define OBJECT_49_4 32
#define OBJECT_49_3 31
#define OBJECT_49_2 30
#define OBJECT_49_1 29
#define OBJECT_49_0 28
#define FREE_REFERENCES_LABEL_49_0 28
#define NUMBER_OF_LINKER_SECTIONS_49_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd193;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd175;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd177;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd160;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd145;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd155;
  machine_word Wrd204;
  machine_word Wrd142;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd126;
  machine_word Wrd128;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd122;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd79;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd89;
  machine_word Wrd208;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd101;
  machine_word Wrd167;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_13;

    case 1:
      current_block = (Rpc - LABEL_49_6);
      goto continuation_15;

    case 2:
      current_block = (Rpc - LABEL_49_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_49_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_49_4);
      goto single_l_20;

    case 5:
      current_block = (Rpc - LABEL_49_9);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_49_10);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_49_11);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_49_12);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_49_13);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_49_14);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_49_15);
      goto label_28;

    case 12:
      current_block = (Rpc - LABEL_49_16);
      goto label_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (single_l_31)
DEFLABEL (single_l_20)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_55;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_55;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_54)
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_53;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_53;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_52)
  (Wrd46.Obj) = (Rsp [5]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_51;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_51;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_50)
  (Wrd62.Obj) = (Rsp [6]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_49;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_49;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_48)
  (Wrd69.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd70.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd71.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_8]))));
  (* (--Rsp)) = (Wrd75.Obj);
  if ((Wrd69.Obj) == (current_block [OBJECT_49_5]))
    goto label_47;
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd89.uLng) == 10))
    goto label_46;
  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd86.Obj) = ((Wrd85.pObj) [0]);
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd86.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd87.Lng))))
    goto label_46;
  (Wrd79.Obj) = ((Wrd85.pObj) [1]);

DEFLABEL (label_45)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd79.Obj);

DEFLABEL (label_44)
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_7]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd98.Obj) = (Rsp [4]);
  if ((Wrd98.Obj) == (current_block [OBJECT_49_5]))
    goto label_43;
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_42;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd109.Lng))))
    goto label_42;
  (Wrd101.Obj) = ((Wrd107.pObj) [1]);

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_40)
  (Wrd117.Obj) = (* (Rsp++));
  (Wrd119.Lng) = (FIXNUM_TO_LONG (Wrd101.Obj));
  (Wrd120.Lng) = (FIXNUM_TO_LONG (Wrd117.Obj));
  (Wrd123.Lng) = ((Wrd119.Lng) + (Wrd120.Lng));
  (Wrd124.Lng) = ((Wrd123.Lng) + 1L);
  (Wrd122.Obj) = (LONG_TO_FIXNUM (Wrd124.Lng));
  (Wrd133.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd134.Obj) = (Rsp [2]);
  (Wrd135.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd133.Obj);
  (* (Rhp++)) = (Wrd122.Obj);
  (* (Rhp++)) = (Wrd134.Obj);
  (* (Rhp++)) = (Wrd135.Obj);
  (Wrd129.Obj) = (Rsp [3]);
  (Wrd130.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd129.Obj);
  (* (Rhp++)) = (Wrd130.Obj);
  (Wrd128.pObj) = (& (Rhp [-6]));
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd128.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [6]) = (Wrd126.Obj);
  (Wrd136.Obj) = (Rsp [3]);
  (Rsp [7]) = (Wrd136.Obj);
  (Wrd137.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd137.Obj);
  (Wrd138.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd138.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_6]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd142.Obj) = (Rsp [4]);
  if ((Wrd142.Obj) == (current_block [OBJECT_49_5]))
    goto label_39;
  (Wrd155.uLng) = (OBJECT_TYPE (Wrd142.Obj));
  if (! ((Wrd155.uLng) == 10))
    goto label_38;
  (Wrd151.pObj) = (OBJECT_ADDRESS (Wrd142.Obj));
  (Wrd152.Obj) = ((Wrd151.pObj) [0]);
  (Wrd153.Lng) = (FIXNUM_TO_LONG (Wrd152.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd153.Lng))))
    goto label_38;
  (Wrd145.Obj) = ((Wrd151.pObj) [1]);

DEFLABEL (label_37)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd145.Obj);

DEFLABEL (label_36)
  (Wrd163.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd163.Obj);
  (Wrd164.Obj) = (Rsp [4]);
  if ((Wrd164.Obj) == (current_block [OBJECT_49_5]))
    goto label_35;
  (Wrd177.uLng) = (OBJECT_TYPE (Wrd164.Obj));
  if (! ((Wrd177.uLng) == 10))
    goto label_34;
  (Wrd173.pObj) = (OBJECT_ADDRESS (Wrd164.Obj));
  (Wrd174.Obj) = ((Wrd173.pObj) [0]);
  (Wrd175.Lng) = (FIXNUM_TO_LONG (Wrd174.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd175.Lng))))
    goto label_34;
  (Wrd167.Obj) = ((Wrd173.pObj) [1]);

DEFLABEL (label_33)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_32)
  (Wrd183.Obj) = (* (Rsp++));
  (Wrd185.Lng) = (FIXNUM_TO_LONG (Wrd167.Obj));
  (Wrd186.Lng) = (FIXNUM_TO_LONG (Wrd183.Obj));
  (Wrd189.Lng) = ((Wrd185.Lng) + (Wrd186.Lng));
  (Wrd190.Lng) = ((Wrd189.Lng) + 1L);
  (Wrd188.Obj) = (LONG_TO_FIXNUM (Wrd190.Lng));
  (Wrd199.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd200.Obj) = (Rsp [2]);
  (Wrd201.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd199.Obj);
  (* (Rhp++)) = (Wrd188.Obj);
  (* (Rhp++)) = (Wrd200.Obj);
  (* (Rhp++)) = (Wrd201.Obj);
  (Wrd195.Obj) = (Rsp [3]);
  (Wrd196.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd195.Obj);
  (* (Rhp++)) = (Wrd196.Obj);
  (Wrd193.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd193.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd178.Obj) = (Rsp [4]);
  (Wrd179.Obj) = (current_block [OBJECT_49_6]);
  (Wrd182.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_16]))));
  (* (--Rsp)) = (Wrd182.Obj);
  (* (--Rsp)) = (Wrd179.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_29)
  (Wrd167.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_35)
  (Wrd167.Obj) = (current_block [OBJECT_49_6]);
  goto label_33;

DEFLABEL (label_38)
  (Wrd156.Obj) = (Rsp [4]);
  (Wrd157.Obj) = (current_block [OBJECT_49_6]);
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_15]))));
  (* (--Rsp)) = (Wrd160.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd156.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_28)
  (Wrd145.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_39)
  (Wrd204.Obj) = (current_block [OBJECT_49_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd204.Obj);
  goto label_36;

DEFLABEL (label_42)
  (Wrd112.Obj) = (Rsp [4]);
  (Wrd113.Obj) = (current_block [OBJECT_49_6]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_14]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_27)
  (Wrd101.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_43)
  (Wrd101.Obj) = (current_block [OBJECT_49_6]);
  goto label_41;

DEFLABEL (label_46)
  (Wrd90.Obj) = (Rsp [4]);
  (Wrd91.Obj) = (current_block [OBJECT_49_6]);
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_13]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_26)
  (Wrd79.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd208.Obj) = (current_block [OBJECT_49_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd208.Obj);
  goto label_44;

DEFLABEL (label_49)
  (Wrd64.Obj) = (Rsp [6]);
  (Wrd65.Obj) = (current_block [OBJECT_49_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_12]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd48.Obj) = (Rsp [5]);
  (Wrd49.Obj) = (current_block [OBJECT_49_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_11]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (current_block [OBJECT_49_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_10]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_49_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (Wrd167.Obj) = Rvl;
  goto label_32;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_49_6);
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_49_7);
  (Wrd101.Obj) = Rvl;
  goto label_40;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_49_8);
  (* (--Rsp)) = Rvl;
  goto label_44;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_5 3
#define LABEL_50_6 5
#define LABEL_50_7 7
#define LABEL_50_8 9
#define LABEL_50_9 11
#define LABEL_50_10 13
#define LABEL_50_4 15
#define LABEL_50_11 17
#define LABEL_50_12 19
#define LABEL_50_13 21
#define LABEL_50_14 23
#define LABEL_50_15 25
#define LABEL_50_16 27
#define LABEL_50_17 29
#define LABEL_50_18 31
#define LABEL_50_19 33
#define LABEL_50_20 35
#define LABEL_50_21 37
#define LABEL_50_22 39
#define LABEL_50_23 41
#define LABEL_50_24 43
#define ENVIRONMENT_LABEL_50_3 52
#define DEBUGGING_LABEL_50_2 51
#define OBJECT_50_6 50
#define OBJECT_50_5 49
#define OBJECT_50_4 48
#define OBJECT_50_3 47
#define OBJECT_50_2 46
#define OBJECT_50_1 45
#define OBJECT_50_0 44
#define FREE_REFERENCES_LABEL_50_0 44
#define NUMBER_OF_LINKER_SECTIONS_50_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd323;
  machine_word Wrd326;
  machine_word Wrd325;
  machine_word Wrd331;
  machine_word Wrd330;
  machine_word Wrd329;
  machine_word Wrd318;
  machine_word Wrd320;
  machine_word Wrd319;
  machine_word Wrd316;
  machine_word Wrd315;
  machine_word Wrd313;
  machine_word Wrd312;
  machine_word Wrd309;
  machine_word Wrd308;
  machine_word Wrd305;
  machine_word Wrd304;
  machine_word Wrd303;
  machine_word Wrd307;
  machine_word Wrd294;
  machine_word Wrd293;
  machine_word Wrd290;
  machine_word Wrd287;
  machine_word Wrd286;
  machine_word Wrd275;
  machine_word Wrd283;
  machine_word Wrd282;
  machine_word Wrd281;
  machine_word Wrd285;
  machine_word Wrd334;
  machine_word Wrd272;
  machine_word Wrd271;
  machine_word Wrd268;
  machine_word Wrd267;
  machine_word Wrd257;
  machine_word Wrd259;
  machine_word Wrd261;
  machine_word Wrd260;
  machine_word Wrd266;
  machine_word Wrd265;
  machine_word Wrd264;
  machine_word Wrd253;
  machine_word Wrd255;
  machine_word Wrd254;
  machine_word Wrd251;
  machine_word Wrd250;
  machine_word Wrd248;
  machine_word Wrd247;
  machine_word Wrd244;
  machine_word Wrd243;
  machine_word Wrd240;
  machine_word Wrd239;
  machine_word Wrd238;
  machine_word Wrd242;
  machine_word Wrd229;
  machine_word Wrd228;
  machine_word Wrd225;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd210;
  machine_word Wrd218;
  machine_word Wrd217;
  machine_word Wrd216;
  machine_word Wrd220;
  machine_word Wrd338;
  machine_word Wrd206;
  machine_word Wrd203;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd190;
  machine_word Wrd192;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd199;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd186;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd181;
  machine_word Wrd180;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd173;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd175;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd155;
  machine_word Wrd154;
  machine_word Wrd143;
  machine_word Wrd151;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd153;
  machine_word Wrd341;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd119;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd103;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd71;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd165;
  machine_word Wrd232;
  machine_word Wrd297;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_25;

    case 1:
      current_block = (Rpc - LABEL_50_6);
      goto continuation_27;

    case 2:
      current_block = (Rpc - LABEL_50_7);
      goto continuation_18;

    case 3:
      current_block = (Rpc - LABEL_50_8);
      goto continuation_20;

    case 4:
      current_block = (Rpc - LABEL_50_9);
      goto continuation_10;

    case 5:
      current_block = (Rpc - LABEL_50_10);
      goto continuation_12;

    case 6:
      current_block = (Rpc - LABEL_50_4);
      goto double_l_33;

    case 7:
      current_block = (Rpc - LABEL_50_11);
      goto label_35;

    case 8:
      current_block = (Rpc - LABEL_50_12);
      goto label_36;

    case 9:
      current_block = (Rpc - LABEL_50_13);
      goto label_37;

    case 10:
      current_block = (Rpc - LABEL_50_14);
      goto label_38;

    case 11:
      current_block = (Rpc - LABEL_50_15);
      goto label_39;

    case 12:
      current_block = (Rpc - LABEL_50_16);
      goto label_40;

    case 13:
      current_block = (Rpc - LABEL_50_17);
      goto label_41;

    case 14:
      current_block = (Rpc - LABEL_50_18);
      goto label_42;

    case 15:
      current_block = (Rpc - LABEL_50_19);
      goto label_43;

    case 16:
      current_block = (Rpc - LABEL_50_20);
      goto label_44;

    case 17:
      current_block = (Rpc - LABEL_50_21);
      goto label_45;

    case 18:
      current_block = (Rpc - LABEL_50_22);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_50_23);
      goto label_47;

    case 20:
      current_block = (Rpc - LABEL_50_24);
      goto label_48;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (double_l_50)
DEFLABEL (double_l_33)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_90;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_90;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_89)
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_88;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_88;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_87)
  (Wrd46.Obj) = (Rsp [5]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_86;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_86;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_85)
  (Wrd62.Obj) = (Rsp [6]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_84;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_84;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_83)
  (Wrd78.Obj) = (Rsp [2]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 10))
    goto label_82;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd77.Lng))))
    goto label_82;
  (Wrd71.Obj) = ((Wrd75.pObj) [4]);
  (* (--Rsp)) = (Wrd71.Obj);

DEFLABEL (label_81)
  (Wrd94.Obj) = (Rsp [3]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_80;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_80;
  (Wrd87.Obj) = ((Wrd91.pObj) [2]);
  (* (--Rsp)) = (Wrd87.Obj);

DEFLABEL (label_79)
  (Wrd110.Obj) = (Rsp [4]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_78;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd109.Lng))))
    goto label_78;
  (Wrd103.Obj) = ((Wrd107.pObj) [5]);
  (* (--Rsp)) = (Wrd103.Obj);

DEFLABEL (label_77)
  (Wrd126.Obj) = (Rsp [5]);
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd126.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_76;
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd126.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [0]);
  (Wrd125.Lng) = (FIXNUM_TO_LONG (Wrd124.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd125.Lng))))
    goto label_76;
  (Wrd119.Obj) = ((Wrd123.pObj) [3]);
  (* (--Rsp)) = (Wrd119.Obj);

DEFLABEL (label_75)
  (Wrd133.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd133.Obj);
  (Wrd134.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd134.Obj);
  (Wrd135.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd135.Obj);
  (Wrd136.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd136.Obj);
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_10]))));
  (* (--Rsp)) = (Wrd139.Obj);
  if ((Wrd133.Obj) == (current_block [OBJECT_50_5]))
    goto label_74;
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd133.Obj));
  if (! ((Wrd153.uLng) == 10))
    goto label_73;
  (Wrd149.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd150.Obj) = ((Wrd149.pObj) [0]);
  (Wrd151.Lng) = (FIXNUM_TO_LONG (Wrd150.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd151.Lng))))
    goto label_73;
  (Wrd143.Obj) = ((Wrd149.pObj) [1]);

DEFLABEL (label_72)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_71)
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_9]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (Wrd162.Obj) = (Rsp [4]);
  if ((Wrd162.Obj) == (current_block [OBJECT_50_5]))
    goto label_70;
  (Wrd175.uLng) = (OBJECT_TYPE (Wrd162.Obj));
  if (! ((Wrd175.uLng) == 10))
    goto label_69;
  (Wrd171.pObj) = (OBJECT_ADDRESS (Wrd162.Obj));
  (Wrd172.Obj) = ((Wrd171.pObj) [0]);
  (Wrd173.Lng) = (FIXNUM_TO_LONG (Wrd172.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd173.Lng))))
    goto label_69;
  (Wrd165.Obj) = ((Wrd171.pObj) [1]);

DEFLABEL (label_68)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_67)
  (Wrd181.Obj) = (* (Rsp++));
  (Wrd183.Lng) = (FIXNUM_TO_LONG (Wrd165.Obj));
  (Wrd184.Lng) = (FIXNUM_TO_LONG (Wrd181.Obj));
  (Wrd187.Lng) = ((Wrd183.Lng) + (Wrd184.Lng));
  (Wrd188.Lng) = ((Wrd187.Lng) + 1L);
  (Wrd186.Obj) = (LONG_TO_FIXNUM (Wrd188.Lng));
  (Wrd197.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd198.Obj) = (Rsp [2]);
  (Wrd199.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd197.Obj);
  (* (Rhp++)) = (Wrd186.Obj);
  (* (Rhp++)) = (Wrd198.Obj);
  (* (Rhp++)) = (Wrd199.Obj);
  (Wrd193.Obj) = (Rsp [3]);
  (Wrd194.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd193.Obj);
  (* (Rhp++)) = (Wrd194.Obj);
  (Wrd192.pObj) = (& (Rhp [-6]));
  (Wrd190.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd192.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [10]) = (Wrd190.Obj);
  (Wrd200.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd200.Obj);
  (Wrd201.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd201.Obj);
  (Wrd202.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd202.Obj);
  (Wrd203.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd203.Obj);
  (Wrd206.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_8]))));
  (* (--Rsp)) = (Wrd206.Obj);
  if ((Wrd200.Obj) == (current_block [OBJECT_50_5]))
    goto label_66;
  (Wrd220.uLng) = (OBJECT_TYPE (Wrd200.Obj));
  if (! ((Wrd220.uLng) == 10))
    goto label_65;
  (Wrd216.pObj) = (OBJECT_ADDRESS (Wrd200.Obj));
  (Wrd217.Obj) = ((Wrd216.pObj) [0]);
  (Wrd218.Lng) = (FIXNUM_TO_LONG (Wrd217.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd218.Lng))))
    goto label_65;
  (Wrd210.Obj) = ((Wrd216.pObj) [1]);

DEFLABEL (label_64)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd210.Obj);

DEFLABEL (label_63)
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_7]))));
  (* (--Rsp)) = (Wrd228.Obj);
  (Wrd229.Obj) = (Rsp [4]);
  if ((Wrd229.Obj) == (current_block [OBJECT_50_5]))
    goto label_62;
  (Wrd242.uLng) = (OBJECT_TYPE (Wrd229.Obj));
  if (! ((Wrd242.uLng) == 10))
    goto label_61;
  (Wrd238.pObj) = (OBJECT_ADDRESS (Wrd229.Obj));
  (Wrd239.Obj) = ((Wrd238.pObj) [0]);
  (Wrd240.Lng) = (FIXNUM_TO_LONG (Wrd239.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd240.Lng))))
    goto label_61;
  (Wrd232.Obj) = ((Wrd238.pObj) [1]);

DEFLABEL (label_60)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_59)
  (Wrd248.Obj) = (* (Rsp++));
  (Wrd250.Lng) = (FIXNUM_TO_LONG (Wrd232.Obj));
  (Wrd251.Lng) = (FIXNUM_TO_LONG (Wrd248.Obj));
  (Wrd254.Lng) = ((Wrd250.Lng) + (Wrd251.Lng));
  (Wrd255.Lng) = ((Wrd254.Lng) + 1L);
  (Wrd253.Obj) = (LONG_TO_FIXNUM (Wrd255.Lng));
  (Wrd264.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd265.Obj) = (Rsp [2]);
  (Wrd266.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd264.Obj);
  (* (Rhp++)) = (Wrd253.Obj);
  (* (Rhp++)) = (Wrd265.Obj);
  (* (Rhp++)) = (Wrd266.Obj);
  (Wrd260.Obj) = (Rsp [3]);
  (Wrd261.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd260.Obj);
  (* (Rhp++)) = (Wrd261.Obj);
  (Wrd259.pObj) = (& (Rhp [-6]));
  (Wrd257.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd259.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [11]) = (Wrd257.Obj);
  (Wrd267.Obj) = (Rsp [0]);
  (Rsp [8]) = (Wrd267.Obj);
  (Wrd268.Obj) = (Rsp [1]);
  (Rsp [9]) = (Wrd268.Obj);
  Rsp = (& (Rsp [8]));
  (Wrd271.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_6]))));
  (* (--Rsp)) = (Wrd271.Obj);
  (Wrd272.Obj) = (Rsp [4]);
  if ((Wrd272.Obj) == (current_block [OBJECT_50_5]))
    goto label_58;
  (Wrd285.uLng) = (OBJECT_TYPE (Wrd272.Obj));
  if (! ((Wrd285.uLng) == 10))
    goto label_57;
  (Wrd281.pObj) = (OBJECT_ADDRESS (Wrd272.Obj));
  (Wrd282.Obj) = ((Wrd281.pObj) [0]);
  (Wrd283.Lng) = (FIXNUM_TO_LONG (Wrd282.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd283.Lng))))
    goto label_57;
  (Wrd275.Obj) = ((Wrd281.pObj) [1]);

DEFLABEL (label_56)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd275.Obj);

DEFLABEL (label_55)
  (Wrd293.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd293.Obj);
  (Wrd294.Obj) = (Rsp [4]);
  if ((Wrd294.Obj) == (current_block [OBJECT_50_5]))
    goto label_54;
  (Wrd307.uLng) = (OBJECT_TYPE (Wrd294.Obj));
  if (! ((Wrd307.uLng) == 10))
    goto label_53;
  (Wrd303.pObj) = (OBJECT_ADDRESS (Wrd294.Obj));
  (Wrd304.Obj) = ((Wrd303.pObj) [0]);
  (Wrd305.Lng) = (FIXNUM_TO_LONG (Wrd304.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd305.Lng))))
    goto label_53;
  (Wrd297.Obj) = ((Wrd303.pObj) [1]);

DEFLABEL (label_52)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_51)
  (Wrd313.Obj) = (* (Rsp++));
  (Wrd315.Lng) = (FIXNUM_TO_LONG (Wrd297.Obj));
  (Wrd316.Lng) = (FIXNUM_TO_LONG (Wrd313.Obj));
  (Wrd319.Lng) = ((Wrd315.Lng) + (Wrd316.Lng));
  (Wrd320.Lng) = ((Wrd319.Lng) + 1L);
  (Wrd318.Obj) = (LONG_TO_FIXNUM (Wrd320.Lng));
  (Wrd329.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd330.Obj) = (Rsp [2]);
  (Wrd331.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd329.Obj);
  (* (Rhp++)) = (Wrd318.Obj);
  (* (Rhp++)) = (Wrd330.Obj);
  (* (Rhp++)) = (Wrd331.Obj);
  (Wrd325.Obj) = (Rsp [3]);
  (Wrd326.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd325.Obj);
  (* (Rhp++)) = (Wrd326.Obj);
  (Wrd323.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd323.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_53)
  (Wrd308.Obj) = (Rsp [4]);
  (Wrd309.Obj) = (current_block [OBJECT_50_6]);
  (Wrd312.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_24]))));
  (* (--Rsp)) = (Wrd312.Obj);
  (* (--Rsp)) = (Wrd309.Obj);
  (* (--Rsp)) = (Wrd308.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_48)
  (Wrd297.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_54)
  (Wrd297.Obj) = (current_block [OBJECT_50_6]);
  goto label_52;

DEFLABEL (label_57)
  (Wrd286.Obj) = (Rsp [4]);
  (Wrd287.Obj) = (current_block [OBJECT_50_6]);
  (Wrd290.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_23]))));
  (* (--Rsp)) = (Wrd290.Obj);
  (* (--Rsp)) = (Wrd287.Obj);
  (* (--Rsp)) = (Wrd286.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_47)
  (Wrd275.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_58)
  (Wrd334.Obj) = (current_block [OBJECT_50_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd334.Obj);
  goto label_55;

DEFLABEL (label_61)
  (Wrd243.Obj) = (Rsp [4]);
  (Wrd244.Obj) = (current_block [OBJECT_50_6]);
  (Wrd247.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_22]))));
  (* (--Rsp)) = (Wrd247.Obj);
  (* (--Rsp)) = (Wrd244.Obj);
  (* (--Rsp)) = (Wrd243.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_46)
  (Wrd232.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_62)
  (Wrd232.Obj) = (current_block [OBJECT_50_6]);
  goto label_60;

DEFLABEL (label_65)
  (Wrd221.Obj) = (Rsp [4]);
  (Wrd222.Obj) = (current_block [OBJECT_50_6]);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_21]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (* (--Rsp)) = (Wrd222.Obj);
  (* (--Rsp)) = (Wrd221.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_45)
  (Wrd210.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_66)
  (Wrd338.Obj) = (current_block [OBJECT_50_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd338.Obj);
  goto label_63;

DEFLABEL (label_69)
  (Wrd176.Obj) = (Rsp [4]);
  (Wrd177.Obj) = (current_block [OBJECT_50_6]);
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_20]))));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd176.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_44)
  (Wrd165.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_70)
  (Wrd165.Obj) = (current_block [OBJECT_50_6]);
  goto label_68;

DEFLABEL (label_73)
  (Wrd154.Obj) = (Rsp [4]);
  (Wrd155.Obj) = (current_block [OBJECT_50_6]);
  (Wrd158.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_19]))));
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd154.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_43)
  (Wrd143.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_74)
  (Wrd341.Obj) = (current_block [OBJECT_50_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd341.Obj);
  goto label_71;

DEFLABEL (label_76)
  (Wrd128.Obj) = (Rsp [5]);
  (Wrd129.Obj) = (current_block [OBJECT_50_4]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_18]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd112.Obj) = (Rsp [4]);
  (Wrd113.Obj) = (current_block [OBJECT_50_3]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_17]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd96.Obj) = (Rsp [3]);
  (Wrd97.Obj) = (current_block [OBJECT_50_2]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_16]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd80.Obj) = (Rsp [2]);
  (Wrd81.Obj) = (current_block [OBJECT_50_0]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_15]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd64.Obj) = (Rsp [6]);
  (Wrd65.Obj) = (current_block [OBJECT_50_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_14]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd48.Obj) = (Rsp [5]);
  (Wrd49.Obj) = (current_block [OBJECT_50_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_13]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (current_block [OBJECT_50_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_12]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_50_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_11]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_89;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_50_5);
  (Wrd297.Obj) = Rvl;
  goto label_51;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_50_6);
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_50_7);
  (Wrd232.Obj) = Rvl;
  goto label_59;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_50_8);
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_50_9);
  (Wrd165.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_50_10);
  (* (--Rsp)) = Rvl;
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_5 3
#define LABEL_51_6 5
#define LABEL_51_7 7
#define LABEL_51_8 9
#define LABEL_51_4 11
#define LABEL_51_9 13
#define LABEL_51_10 15
#define LABEL_51_11 17
#define LABEL_51_12 19
#define LABEL_51_13 21
#define LABEL_51_14 23
#define LABEL_51_15 25
#define LABEL_51_16 27
#define ENVIRONMENT_LABEL_51_3 36
#define DEBUGGING_LABEL_51_2 35
#define OBJECT_51_6 34
#define OBJECT_51_5 33
#define OBJECT_51_4 32
#define OBJECT_51_3 31
#define OBJECT_51_2 30
#define OBJECT_51_1 29
#define OBJECT_51_0 28
#define FREE_REFERENCES_LABEL_51_0 28
#define NUMBER_OF_LINKER_SECTIONS_51_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd193;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd175;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd177;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd160;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd145;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd155;
  machine_word Wrd204;
  machine_word Wrd142;
  machine_word Wrd141;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd127;
  machine_word Wrd129;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd123;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd118;
  machine_word Wrd117;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd112;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd80;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd90;
  machine_word Wrd208;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd102;
  machine_word Wrd167;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_5);
      goto continuation_13;

    case 1:
      current_block = (Rpc - LABEL_51_6);
      goto continuation_15;

    case 2:
      current_block = (Rpc - LABEL_51_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_51_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_51_4);
      goto single_r_20;

    case 5:
      current_block = (Rpc - LABEL_51_9);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_51_10);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_51_11);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_51_12);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_51_13);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_51_14);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_51_15);
      goto label_28;

    case 12:
      current_block = (Rpc - LABEL_51_16);
      goto label_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (single_r_31)
DEFLABEL (single_r_20)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_55;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_55;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_54)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_53;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_53;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_52)
  (Wrd46.Obj) = (Rsp [4]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_51;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_51;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_50)
  (Wrd62.Obj) = (Rsp [5]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_49;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_49;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_48)
  (Wrd69.Obj) = (Rsp [2]);
  (Rsp [6]) = (Wrd69.Obj);
  (Wrd70.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd71.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd73.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_8]))));
  (* (--Rsp)) = (Wrd76.Obj);
  if ((Wrd70.Obj) == (current_block [OBJECT_51_5]))
    goto label_47;
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd90.uLng) == 10))
    goto label_46;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd87.Obj) = ((Wrd86.pObj) [0]);
  (Wrd88.Lng) = (FIXNUM_TO_LONG (Wrd87.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd88.Lng))))
    goto label_46;
  (Wrd80.Obj) = ((Wrd86.pObj) [1]);

DEFLABEL (label_45)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd80.Obj);

DEFLABEL (label_44)
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_7]))));
  (* (--Rsp)) = (Wrd98.Obj);
  (Wrd99.Obj) = (Rsp [4]);
  if ((Wrd99.Obj) == (current_block [OBJECT_51_5]))
    goto label_43;
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd112.uLng) == 10))
    goto label_42;
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd99.Obj));
  (Wrd109.Obj) = ((Wrd108.pObj) [0]);
  (Wrd110.Lng) = (FIXNUM_TO_LONG (Wrd109.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd110.Lng))))
    goto label_42;
  (Wrd102.Obj) = ((Wrd108.pObj) [1]);

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_40)
  (Wrd118.Obj) = (* (Rsp++));
  (Wrd120.Lng) = (FIXNUM_TO_LONG (Wrd102.Obj));
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd118.Obj));
  (Wrd124.Lng) = ((Wrd120.Lng) + (Wrd121.Lng));
  (Wrd125.Lng) = ((Wrd124.Lng) + 1L);
  (Wrd123.Obj) = (LONG_TO_FIXNUM (Wrd125.Lng));
  (Wrd134.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd135.Obj) = (Rsp [2]);
  (Wrd136.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd134.Obj);
  (* (Rhp++)) = (Wrd123.Obj);
  (* (Rhp++)) = (Wrd135.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (Wrd130.Obj) = (Rsp [3]);
  (Wrd131.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd130.Obj);
  (* (Rhp++)) = (Wrd131.Obj);
  (Wrd129.pObj) = (& (Rhp [-6]));
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd129.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [7]) = (Wrd127.Obj);
  (Wrd137.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd137.Obj);
  (Wrd138.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd138.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_6]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd142.Obj) = (Rsp [4]);
  if ((Wrd142.Obj) == (current_block [OBJECT_51_5]))
    goto label_39;
  (Wrd155.uLng) = (OBJECT_TYPE (Wrd142.Obj));
  if (! ((Wrd155.uLng) == 10))
    goto label_38;
  (Wrd151.pObj) = (OBJECT_ADDRESS (Wrd142.Obj));
  (Wrd152.Obj) = ((Wrd151.pObj) [0]);
  (Wrd153.Lng) = (FIXNUM_TO_LONG (Wrd152.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd153.Lng))))
    goto label_38;
  (Wrd145.Obj) = ((Wrd151.pObj) [1]);

DEFLABEL (label_37)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd145.Obj);

DEFLABEL (label_36)
  (Wrd163.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd163.Obj);
  (Wrd164.Obj) = (Rsp [4]);
  if ((Wrd164.Obj) == (current_block [OBJECT_51_5]))
    goto label_35;
  (Wrd177.uLng) = (OBJECT_TYPE (Wrd164.Obj));
  if (! ((Wrd177.uLng) == 10))
    goto label_34;
  (Wrd173.pObj) = (OBJECT_ADDRESS (Wrd164.Obj));
  (Wrd174.Obj) = ((Wrd173.pObj) [0]);
  (Wrd175.Lng) = (FIXNUM_TO_LONG (Wrd174.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd175.Lng))))
    goto label_34;
  (Wrd167.Obj) = ((Wrd173.pObj) [1]);

DEFLABEL (label_33)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_32)
  (Wrd183.Obj) = (* (Rsp++));
  (Wrd185.Lng) = (FIXNUM_TO_LONG (Wrd167.Obj));
  (Wrd186.Lng) = (FIXNUM_TO_LONG (Wrd183.Obj));
  (Wrd189.Lng) = ((Wrd185.Lng) + (Wrd186.Lng));
  (Wrd190.Lng) = ((Wrd189.Lng) + 1L);
  (Wrd188.Obj) = (LONG_TO_FIXNUM (Wrd190.Lng));
  (Wrd199.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd200.Obj) = (Rsp [2]);
  (Wrd201.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd199.Obj);
  (* (Rhp++)) = (Wrd188.Obj);
  (* (Rhp++)) = (Wrd200.Obj);
  (* (Rhp++)) = (Wrd201.Obj);
  (Wrd195.Obj) = (Rsp [3]);
  (Wrd196.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd195.Obj);
  (* (Rhp++)) = (Wrd196.Obj);
  (Wrd193.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd193.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd178.Obj) = (Rsp [4]);
  (Wrd179.Obj) = (current_block [OBJECT_51_6]);
  (Wrd182.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_16]))));
  (* (--Rsp)) = (Wrd182.Obj);
  (* (--Rsp)) = (Wrd179.Obj);
  (* (--Rsp)) = (Wrd178.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_29)
  (Wrd167.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_35)
  (Wrd167.Obj) = (current_block [OBJECT_51_6]);
  goto label_33;

DEFLABEL (label_38)
  (Wrd156.Obj) = (Rsp [4]);
  (Wrd157.Obj) = (current_block [OBJECT_51_6]);
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_15]))));
  (* (--Rsp)) = (Wrd160.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd156.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_28)
  (Wrd145.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_39)
  (Wrd204.Obj) = (current_block [OBJECT_51_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd204.Obj);
  goto label_36;

DEFLABEL (label_42)
  (Wrd113.Obj) = (Rsp [4]);
  (Wrd114.Obj) = (current_block [OBJECT_51_6]);
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_14]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_27)
  (Wrd102.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_43)
  (Wrd102.Obj) = (current_block [OBJECT_51_6]);
  goto label_41;

DEFLABEL (label_46)
  (Wrd91.Obj) = (Rsp [4]);
  (Wrd92.Obj) = (current_block [OBJECT_51_6]);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_13]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_26)
  (Wrd80.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd208.Obj) = (current_block [OBJECT_51_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd208.Obj);
  goto label_44;

DEFLABEL (label_49)
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.Obj) = (current_block [OBJECT_51_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_12]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.Obj) = (current_block [OBJECT_51_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_11]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (current_block [OBJECT_51_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_10]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_51_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_51_5);
  (Wrd167.Obj) = Rvl;
  goto label_32;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_51_6);
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_51_7);
  (Wrd102.Obj) = Rvl;
  goto label_40;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_51_8);
  (* (--Rsp)) = Rvl;
  goto label_44;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_5 3
#define LABEL_52_6 5
#define LABEL_52_7 7
#define LABEL_52_8 9
#define LABEL_52_9 11
#define LABEL_52_10 13
#define LABEL_52_4 15
#define LABEL_52_11 17
#define LABEL_52_12 19
#define LABEL_52_13 21
#define LABEL_52_14 23
#define LABEL_52_15 25
#define LABEL_52_16 27
#define LABEL_52_17 29
#define LABEL_52_18 31
#define LABEL_52_19 33
#define LABEL_52_20 35
#define LABEL_52_21 37
#define LABEL_52_22 39
#define LABEL_52_23 41
#define LABEL_52_24 43
#define ENVIRONMENT_LABEL_52_3 52
#define DEBUGGING_LABEL_52_2 51
#define OBJECT_52_6 50
#define OBJECT_52_5 49
#define OBJECT_52_4 48
#define OBJECT_52_3 47
#define OBJECT_52_2 46
#define OBJECT_52_1 45
#define OBJECT_52_0 44
#define FREE_REFERENCES_LABEL_52_0 44
#define NUMBER_OF_LINKER_SECTIONS_52_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd323;
  machine_word Wrd326;
  machine_word Wrd325;
  machine_word Wrd331;
  machine_word Wrd330;
  machine_word Wrd329;
  machine_word Wrd318;
  machine_word Wrd320;
  machine_word Wrd319;
  machine_word Wrd316;
  machine_word Wrd315;
  machine_word Wrd313;
  machine_word Wrd312;
  machine_word Wrd309;
  machine_word Wrd308;
  machine_word Wrd305;
  machine_word Wrd304;
  machine_word Wrd303;
  machine_word Wrd307;
  machine_word Wrd294;
  machine_word Wrd293;
  machine_word Wrd290;
  machine_word Wrd287;
  machine_word Wrd286;
  machine_word Wrd275;
  machine_word Wrd283;
  machine_word Wrd282;
  machine_word Wrd281;
  machine_word Wrd285;
  machine_word Wrd334;
  machine_word Wrd272;
  machine_word Wrd271;
  machine_word Wrd268;
  machine_word Wrd267;
  machine_word Wrd257;
  machine_word Wrd259;
  machine_word Wrd261;
  machine_word Wrd260;
  machine_word Wrd266;
  machine_word Wrd265;
  machine_word Wrd264;
  machine_word Wrd253;
  machine_word Wrd255;
  machine_word Wrd254;
  machine_word Wrd251;
  machine_word Wrd250;
  machine_word Wrd248;
  machine_word Wrd247;
  machine_word Wrd244;
  machine_word Wrd243;
  machine_word Wrd240;
  machine_word Wrd239;
  machine_word Wrd238;
  machine_word Wrd242;
  machine_word Wrd229;
  machine_word Wrd228;
  machine_word Wrd225;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd210;
  machine_word Wrd218;
  machine_word Wrd217;
  machine_word Wrd216;
  machine_word Wrd220;
  machine_word Wrd338;
  machine_word Wrd206;
  machine_word Wrd203;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd190;
  machine_word Wrd192;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd199;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd186;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd181;
  machine_word Wrd180;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd173;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd175;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd155;
  machine_word Wrd154;
  machine_word Wrd143;
  machine_word Wrd151;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd153;
  machine_word Wrd341;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd119;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd103;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd71;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd165;
  machine_word Wrd232;
  machine_word Wrd297;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_25;

    case 1:
      current_block = (Rpc - LABEL_52_6);
      goto continuation_27;

    case 2:
      current_block = (Rpc - LABEL_52_7);
      goto continuation_18;

    case 3:
      current_block = (Rpc - LABEL_52_8);
      goto continuation_20;

    case 4:
      current_block = (Rpc - LABEL_52_9);
      goto continuation_10;

    case 5:
      current_block = (Rpc - LABEL_52_10);
      goto continuation_12;

    case 6:
      current_block = (Rpc - LABEL_52_4);
      goto double_r_33;

    case 7:
      current_block = (Rpc - LABEL_52_11);
      goto label_35;

    case 8:
      current_block = (Rpc - LABEL_52_12);
      goto label_36;

    case 9:
      current_block = (Rpc - LABEL_52_13);
      goto label_37;

    case 10:
      current_block = (Rpc - LABEL_52_14);
      goto label_38;

    case 11:
      current_block = (Rpc - LABEL_52_15);
      goto label_39;

    case 12:
      current_block = (Rpc - LABEL_52_16);
      goto label_40;

    case 13:
      current_block = (Rpc - LABEL_52_17);
      goto label_41;

    case 14:
      current_block = (Rpc - LABEL_52_18);
      goto label_42;

    case 15:
      current_block = (Rpc - LABEL_52_19);
      goto label_43;

    case 16:
      current_block = (Rpc - LABEL_52_20);
      goto label_44;

    case 17:
      current_block = (Rpc - LABEL_52_21);
      goto label_45;

    case 18:
      current_block = (Rpc - LABEL_52_22);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_52_23);
      goto label_47;

    case 20:
      current_block = (Rpc - LABEL_52_24);
      goto label_48;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (double_r_50)
DEFLABEL (double_r_33)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_90;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_90;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_89)
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_88;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_88;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_87)
  (Wrd46.Obj) = (Rsp [4]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_86;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd45.Lng))))
    goto label_86;
  (Wrd39.Obj) = ((Wrd43.pObj) [5]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_85)
  (Wrd62.Obj) = (Rsp [5]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_84;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_84;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_83)
  (Wrd78.Obj) = (Rsp [3]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 10))
    goto label_82;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd77.Lng))))
    goto label_82;
  (Wrd71.Obj) = ((Wrd75.pObj) [4]);
  (* (--Rsp)) = (Wrd71.Obj);

DEFLABEL (label_81)
  (Wrd94.Obj) = (Rsp [4]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_80;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_80;
  (Wrd87.Obj) = ((Wrd91.pObj) [2]);
  (* (--Rsp)) = (Wrd87.Obj);

DEFLABEL (label_79)
  (Wrd110.Obj) = (Rsp [5]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_78;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd109.Lng))))
    goto label_78;
  (Wrd103.Obj) = ((Wrd107.pObj) [5]);
  (* (--Rsp)) = (Wrd103.Obj);

DEFLABEL (label_77)
  (Wrd126.Obj) = (Rsp [6]);
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd126.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_76;
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd126.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [0]);
  (Wrd125.Lng) = (FIXNUM_TO_LONG (Wrd124.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd125.Lng))))
    goto label_76;
  (Wrd119.Obj) = ((Wrd123.pObj) [3]);
  (* (--Rsp)) = (Wrd119.Obj);

DEFLABEL (label_75)
  (Wrd133.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd133.Obj);
  (Wrd134.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd134.Obj);
  (Wrd135.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd135.Obj);
  (Wrd136.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd136.Obj);
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_10]))));
  (* (--Rsp)) = (Wrd139.Obj);
  if ((Wrd133.Obj) == (current_block [OBJECT_52_5]))
    goto label_74;
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd133.Obj));
  if (! ((Wrd153.uLng) == 10))
    goto label_73;
  (Wrd149.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd150.Obj) = ((Wrd149.pObj) [0]);
  (Wrd151.Lng) = (FIXNUM_TO_LONG (Wrd150.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd151.Lng))))
    goto label_73;
  (Wrd143.Obj) = ((Wrd149.pObj) [1]);

DEFLABEL (label_72)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_71)
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_9]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (Wrd162.Obj) = (Rsp [4]);
  if ((Wrd162.Obj) == (current_block [OBJECT_52_5]))
    goto label_70;
  (Wrd175.uLng) = (OBJECT_TYPE (Wrd162.Obj));
  if (! ((Wrd175.uLng) == 10))
    goto label_69;
  (Wrd171.pObj) = (OBJECT_ADDRESS (Wrd162.Obj));
  (Wrd172.Obj) = ((Wrd171.pObj) [0]);
  (Wrd173.Lng) = (FIXNUM_TO_LONG (Wrd172.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd173.Lng))))
    goto label_69;
  (Wrd165.Obj) = ((Wrd171.pObj) [1]);

DEFLABEL (label_68)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_67)
  (Wrd181.Obj) = (* (Rsp++));
  (Wrd183.Lng) = (FIXNUM_TO_LONG (Wrd165.Obj));
  (Wrd184.Lng) = (FIXNUM_TO_LONG (Wrd181.Obj));
  (Wrd187.Lng) = ((Wrd183.Lng) + (Wrd184.Lng));
  (Wrd188.Lng) = ((Wrd187.Lng) + 1L);
  (Wrd186.Obj) = (LONG_TO_FIXNUM (Wrd188.Lng));
  (Wrd197.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd198.Obj) = (Rsp [2]);
  (Wrd199.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd197.Obj);
  (* (Rhp++)) = (Wrd186.Obj);
  (* (Rhp++)) = (Wrd198.Obj);
  (* (Rhp++)) = (Wrd199.Obj);
  (Wrd193.Obj) = (Rsp [3]);
  (Wrd194.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd193.Obj);
  (* (Rhp++)) = (Wrd194.Obj);
  (Wrd192.pObj) = (& (Rhp [-6]));
  (Wrd190.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd192.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [10]) = (Wrd190.Obj);
  (Wrd200.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd200.Obj);
  (Wrd201.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd201.Obj);
  (Wrd202.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd202.Obj);
  (Wrd203.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd203.Obj);
  (Wrd206.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_8]))));
  (* (--Rsp)) = (Wrd206.Obj);
  if ((Wrd200.Obj) == (current_block [OBJECT_52_5]))
    goto label_66;
  (Wrd220.uLng) = (OBJECT_TYPE (Wrd200.Obj));
  if (! ((Wrd220.uLng) == 10))
    goto label_65;
  (Wrd216.pObj) = (OBJECT_ADDRESS (Wrd200.Obj));
  (Wrd217.Obj) = ((Wrd216.pObj) [0]);
  (Wrd218.Lng) = (FIXNUM_TO_LONG (Wrd217.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd218.Lng))))
    goto label_65;
  (Wrd210.Obj) = ((Wrd216.pObj) [1]);

DEFLABEL (label_64)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd210.Obj);

DEFLABEL (label_63)
  (Wrd228.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_7]))));
  (* (--Rsp)) = (Wrd228.Obj);
  (Wrd229.Obj) = (Rsp [4]);
  if ((Wrd229.Obj) == (current_block [OBJECT_52_5]))
    goto label_62;
  (Wrd242.uLng) = (OBJECT_TYPE (Wrd229.Obj));
  if (! ((Wrd242.uLng) == 10))
    goto label_61;
  (Wrd238.pObj) = (OBJECT_ADDRESS (Wrd229.Obj));
  (Wrd239.Obj) = ((Wrd238.pObj) [0]);
  (Wrd240.Lng) = (FIXNUM_TO_LONG (Wrd239.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd240.Lng))))
    goto label_61;
  (Wrd232.Obj) = ((Wrd238.pObj) [1]);

DEFLABEL (label_60)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_59)
  (Wrd248.Obj) = (* (Rsp++));
  (Wrd250.Lng) = (FIXNUM_TO_LONG (Wrd232.Obj));
  (Wrd251.Lng) = (FIXNUM_TO_LONG (Wrd248.Obj));
  (Wrd254.Lng) = ((Wrd250.Lng) + (Wrd251.Lng));
  (Wrd255.Lng) = ((Wrd254.Lng) + 1L);
  (Wrd253.Obj) = (LONG_TO_FIXNUM (Wrd255.Lng));
  (Wrd264.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd265.Obj) = (Rsp [2]);
  (Wrd266.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd264.Obj);
  (* (Rhp++)) = (Wrd253.Obj);
  (* (Rhp++)) = (Wrd265.Obj);
  (* (Rhp++)) = (Wrd266.Obj);
  (Wrd260.Obj) = (Rsp [3]);
  (Wrd261.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd260.Obj);
  (* (Rhp++)) = (Wrd261.Obj);
  (Wrd259.pObj) = (& (Rhp [-6]));
  (Wrd257.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd259.pObj)));
  Rsp = (& (Rsp [4]));
  (Rsp [11]) = (Wrd257.Obj);
  (Wrd267.Obj) = (Rsp [0]);
  (Rsp [8]) = (Wrd267.Obj);
  (Wrd268.Obj) = (Rsp [1]);
  (Rsp [9]) = (Wrd268.Obj);
  Rsp = (& (Rsp [8]));
  (Wrd271.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_6]))));
  (* (--Rsp)) = (Wrd271.Obj);
  (Wrd272.Obj) = (Rsp [4]);
  if ((Wrd272.Obj) == (current_block [OBJECT_52_5]))
    goto label_58;
  (Wrd285.uLng) = (OBJECT_TYPE (Wrd272.Obj));
  if (! ((Wrd285.uLng) == 10))
    goto label_57;
  (Wrd281.pObj) = (OBJECT_ADDRESS (Wrd272.Obj));
  (Wrd282.Obj) = ((Wrd281.pObj) [0]);
  (Wrd283.Lng) = (FIXNUM_TO_LONG (Wrd282.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd283.Lng))))
    goto label_57;
  (Wrd275.Obj) = ((Wrd281.pObj) [1]);

DEFLABEL (label_56)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd275.Obj);

DEFLABEL (label_55)
  (Wrd293.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd293.Obj);
  (Wrd294.Obj) = (Rsp [4]);
  if ((Wrd294.Obj) == (current_block [OBJECT_52_5]))
    goto label_54;
  (Wrd307.uLng) = (OBJECT_TYPE (Wrd294.Obj));
  if (! ((Wrd307.uLng) == 10))
    goto label_53;
  (Wrd303.pObj) = (OBJECT_ADDRESS (Wrd294.Obj));
  (Wrd304.Obj) = ((Wrd303.pObj) [0]);
  (Wrd305.Lng) = (FIXNUM_TO_LONG (Wrd304.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd305.Lng))))
    goto label_53;
  (Wrd297.Obj) = ((Wrd303.pObj) [1]);

DEFLABEL (label_52)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_51)
  (Wrd313.Obj) = (* (Rsp++));
  (Wrd315.Lng) = (FIXNUM_TO_LONG (Wrd297.Obj));
  (Wrd316.Lng) = (FIXNUM_TO_LONG (Wrd313.Obj));
  (Wrd319.Lng) = ((Wrd315.Lng) + (Wrd316.Lng));
  (Wrd320.Lng) = ((Wrd319.Lng) + 1L);
  (Wrd318.Obj) = (LONG_TO_FIXNUM (Wrd320.Lng));
  (Wrd329.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd330.Obj) = (Rsp [2]);
  (Wrd331.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd329.Obj);
  (* (Rhp++)) = (Wrd318.Obj);
  (* (Rhp++)) = (Wrd330.Obj);
  (* (Rhp++)) = (Wrd331.Obj);
  (Wrd325.Obj) = (Rsp [3]);
  (Wrd326.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd325.Obj);
  (* (Rhp++)) = (Wrd326.Obj);
  (Wrd323.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd323.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_53)
  (Wrd308.Obj) = (Rsp [4]);
  (Wrd309.Obj) = (current_block [OBJECT_52_6]);
  (Wrd312.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_24]))));
  (* (--Rsp)) = (Wrd312.Obj);
  (* (--Rsp)) = (Wrd309.Obj);
  (* (--Rsp)) = (Wrd308.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_48)
  (Wrd297.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_54)
  (Wrd297.Obj) = (current_block [OBJECT_52_6]);
  goto label_52;

DEFLABEL (label_57)
  (Wrd286.Obj) = (Rsp [4]);
  (Wrd287.Obj) = (current_block [OBJECT_52_6]);
  (Wrd290.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_23]))));
  (* (--Rsp)) = (Wrd290.Obj);
  (* (--Rsp)) = (Wrd287.Obj);
  (* (--Rsp)) = (Wrd286.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_47)
  (Wrd275.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_58)
  (Wrd334.Obj) = (current_block [OBJECT_52_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd334.Obj);
  goto label_55;

DEFLABEL (label_61)
  (Wrd243.Obj) = (Rsp [4]);
  (Wrd244.Obj) = (current_block [OBJECT_52_6]);
  (Wrd247.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_22]))));
  (* (--Rsp)) = (Wrd247.Obj);
  (* (--Rsp)) = (Wrd244.Obj);
  (* (--Rsp)) = (Wrd243.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_46)
  (Wrd232.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_62)
  (Wrd232.Obj) = (current_block [OBJECT_52_6]);
  goto label_60;

DEFLABEL (label_65)
  (Wrd221.Obj) = (Rsp [4]);
  (Wrd222.Obj) = (current_block [OBJECT_52_6]);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_21]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (* (--Rsp)) = (Wrd222.Obj);
  (* (--Rsp)) = (Wrd221.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_45)
  (Wrd210.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_66)
  (Wrd338.Obj) = (current_block [OBJECT_52_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd338.Obj);
  goto label_63;

DEFLABEL (label_69)
  (Wrd176.Obj) = (Rsp [4]);
  (Wrd177.Obj) = (current_block [OBJECT_52_6]);
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_20]))));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd176.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_44)
  (Wrd165.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_70)
  (Wrd165.Obj) = (current_block [OBJECT_52_6]);
  goto label_68;

DEFLABEL (label_73)
  (Wrd154.Obj) = (Rsp [4]);
  (Wrd155.Obj) = (current_block [OBJECT_52_6]);
  (Wrd158.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_19]))));
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd154.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_43)
  (Wrd143.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_74)
  (Wrd341.Obj) = (current_block [OBJECT_52_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd341.Obj);
  goto label_71;

DEFLABEL (label_76)
  (Wrd128.Obj) = (Rsp [6]);
  (Wrd129.Obj) = (current_block [OBJECT_52_4]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_18]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd112.Obj) = (Rsp [5]);
  (Wrd113.Obj) = (current_block [OBJECT_52_3]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_17]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd96.Obj) = (Rsp [4]);
  (Wrd97.Obj) = (current_block [OBJECT_52_2]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_16]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd80.Obj) = (Rsp [3]);
  (Wrd81.Obj) = (current_block [OBJECT_52_0]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_15]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.Obj) = (current_block [OBJECT_52_4]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_14]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.Obj) = (current_block [OBJECT_52_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_13]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (current_block [OBJECT_52_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_12]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_52_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_11]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_89;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (Wrd297.Obj) = Rvl;
  goto label_51;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_52_6);
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_52_7);
  (Wrd232.Obj) = Rvl;
  goto label_59;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_52_8);
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_52_9);
  (Wrd165.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_52_10);
  (* (--Rsp)) = Rvl;
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_5 3
#define LABEL_53_6 5
#define LABEL_53_7 7
#define LABEL_53_8 9
#define LABEL_53_9 11
#define LABEL_53_10 13
#define LABEL_53_4 15
#define LABEL_53_11 17
#define LABEL_53_12 19
#define LABEL_53_13 21
#define LABEL_53_14 23
#define LABEL_53_15 25
#define LABEL_53_16 27
#define LABEL_53_17 29
#define LABEL_53_18 31
#define LABEL_53_21 33
#define LABEL_53_22 35
#define LABEL_53_23 37
#define LABEL_53_24 39
#define LABEL_53_25 41
#define LABEL_53_26 43
#define LABEL_53_29 45
#define LABEL_53_30 47
#define LABEL_53_31 49
#define LABEL_53_32 51
#define LABEL_53_33 53
#define ENVIRONMENT_LABEL_53_3 69
#define DEBUGGING_LABEL_53_2 68
#define OBJECT_53_4 67
#define OBJECT_53_3 66
#define OBJECT_53_2 65
#define OBJECT_53_1 64
#define OBJECT_53_0 63
#define EXECUTE_CACHE_53_28 55
#define EXECUTE_CACHE_53_27 57
#define EXECUTE_CACHE_53_20 59
#define EXECUTE_CACHE_53_19 61
#define FREE_REFERENCES_LABEL_53_0 54
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd59;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd67;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd49;
  machine_word Wrd70;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd176;
  machine_word Wrd173;
  machine_word Wrd170;
  machine_word Wrd169;
  machine_word Wrd168;
  machine_word Wrd171;
  machine_word Wrd162;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd147;
  machine_word Wrd155;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd145;
  machine_word Wrd142;
  machine_word Wrd141;
  machine_word Wrd130;
  machine_word Wrd138;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd129;
  machine_word Wrd126;
  machine_word Wrd123;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd121;
  machine_word Wrd112;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd97;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd80;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd79;
  machine_word Wrd75;
  machine_word Wrd288;
  machine_word Wrd286;
  machine_word Wrd285;
  machine_word Wrd284;
  machine_word Wrd281;
  machine_word Wrd278;
  machine_word Wrd277;
  machine_word Wrd276;
  machine_word Wrd279;
  machine_word Wrd270;
  machine_word Wrd267;
  machine_word Wrd266;
  machine_word Wrd255;
  machine_word Wrd263;
  machine_word Wrd262;
  machine_word Wrd261;
  machine_word Wrd265;
  machine_word Wrd264;
  machine_word Wrd253;
  machine_word Wrd250;
  machine_word Wrd249;
  machine_word Wrd238;
  machine_word Wrd246;
  machine_word Wrd245;
  machine_word Wrd244;
  machine_word Wrd248;
  machine_word Wrd247;
  machine_word Wrd237;
  machine_word Wrd234;
  machine_word Wrd231;
  machine_word Wrd228;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd229;
  machine_word Wrd220;
  machine_word Wrd217;
  machine_word Wrd216;
  machine_word Wrd205;
  machine_word Wrd213;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd215;
  machine_word Wrd214;
  machine_word Wrd203;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd188;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd187;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd33;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd295;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd297;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd114;
  machine_word Wrd164;
  machine_word Wrd222;
  machine_word Wrd272;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_26;

    case 1:
      current_block = (Rpc - LABEL_53_6);
      goto continuation_22;

    case 2:
      current_block = (Rpc - LABEL_53_7);
      goto continuation_16;

    case 3:
      current_block = (Rpc - LABEL_53_8);
      goto continuation_12;

    case 4:
      current_block = (Rpc - LABEL_53_9);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_53_10);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_53_4);
      goto t_join_39;

    case 7:
      current_block = (Rpc - LABEL_53_11);
      goto label_41;

    case 8:
      current_block = (Rpc - LABEL_53_12);
      goto label_42;

    case 9:
      current_block = (Rpc - LABEL_53_13);
      goto label_49;

    case 10:
      current_block = (Rpc - LABEL_53_14);
      goto label_50;

    case 11:
      current_block = (Rpc - LABEL_53_15);
      goto label_51;

    case 12:
      current_block = (Rpc - LABEL_53_16);
      goto label_52;

    case 13:
      current_block = (Rpc - LABEL_53_17);
      goto label_53;

    case 14:
      current_block = (Rpc - LABEL_53_18);
      goto label_54;

    case 15:
      current_block = (Rpc - LABEL_53_21);
      goto label_43;

    case 16:
      current_block = (Rpc - LABEL_53_22);
      goto label_44;

    case 17:
      current_block = (Rpc - LABEL_53_23);
      goto label_45;

    case 18:
      current_block = (Rpc - LABEL_53_24);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_53_25);
      goto label_47;

    case 20:
      current_block = (Rpc - LABEL_53_26);
      goto label_48;

    case 21:
      current_block = (Rpc - LABEL_53_29);
      goto continuation_32;

    case 22:
      current_block = (Rpc - LABEL_53_30);
      goto continuation_34;

    case 23:
      current_block = (Rpc - LABEL_53_31);
      goto simple_join_38;

    case 24:
      current_block = (Rpc - LABEL_53_32);
      goto label_55;

    case 25:
      current_block = (Rpc - LABEL_53_33);
      goto label_56;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (t_join_58)
DEFLABEL (t_join_39)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  if ((Wrd8.Obj) == (current_block [OBJECT_53_0]))
    goto label_104;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_103;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_103;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_102)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_101)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_9]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  if ((Wrd30.Obj) == (current_block [OBJECT_53_0]))
    goto label_100;
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_99;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd41.Lng))))
    goto label_99;
  (Wrd33.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_98)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_97)
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  (Wrd52.Obj) = (Rsp [1]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  (Wrd55.Lng) = ((Wrd51.Lng) + (Wrd53.Lng));
  if (! ((Wrd55.Lng) < 2L))
    goto label_61;

DEFLABEL (label_60)
  Rsp = (& (Rsp [2]));
  goto simple_join_38;

DEFLABEL (label_61)
  (Wrd60.Lng) = 5L;
  (Wrd66.Lng) = ((Wrd60.Lng) * (Wrd51.Lng));
  if ((Wrd53.Lng) > (Wrd66.Lng))
    goto label_79;
  (Wrd75.Lng) = ((Wrd60.Lng) * (Wrd53.Lng));
  if (! ((Wrd51.Lng) > (Wrd75.Lng)))
    goto label_60;
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_8]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd89.Obj) = (Rsp [5]);
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if (! ((Wrd90.uLng) == 10))
    goto label_78;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd87.Obj) = ((Wrd86.pObj) [0]);
  (Wrd88.Lng) = (FIXNUM_TO_LONG (Wrd87.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd88.Lng))))
    goto label_78;
  (Wrd80.Obj) = ((Wrd86.pObj) [2]);

DEFLABEL (label_77)
  if ((Wrd80.Obj) == (current_block [OBJECT_53_0]))
    goto label_76;
  (Wrd106.Obj) = (Rsp [5]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if (! ((Wrd107.uLng) == 10))
    goto label_75;
  (Wrd103.pObj) = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd104.Obj) = ((Wrd103.pObj) [0]);
  (Wrd105.Lng) = (FIXNUM_TO_LONG (Wrd104.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd105.Lng))))
    goto label_75;
  (Wrd97.Obj) = ((Wrd103.pObj) [2]);

DEFLABEL (label_74)
  (Wrd121.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd121.uLng) == 10))
    goto label_73;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd119.Obj) = ((Wrd118.pObj) [0]);
  (Wrd120.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd120.Lng))))
    goto label_73;
  (Wrd114.Obj) = ((Wrd118.pObj) [1]);

DEFLABEL (label_72)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_71)
  (Rsp [0]) = (Wrd114.Obj);
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_7]))));
  (* (--Rsp)) = (Wrd129.Obj);
  (Wrd139.Obj) = (Rsp [5]);
  (Wrd140.uLng) = (OBJECT_TYPE (Wrd139.Obj));
  if (! ((Wrd140.uLng) == 10))
    goto label_70;
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd137.Obj) = ((Wrd136.pObj) [0]);
  (Wrd138.Lng) = (FIXNUM_TO_LONG (Wrd137.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd138.Lng))))
    goto label_70;
  (Wrd130.Obj) = ((Wrd136.pObj) [4]);

DEFLABEL (label_69)
  if ((Wrd130.Obj) == (current_block [OBJECT_53_0]))
    goto label_68;
  (Wrd156.Obj) = (Rsp [5]);
  (Wrd157.uLng) = (OBJECT_TYPE (Wrd156.Obj));
  if (! ((Wrd157.uLng) == 10))
    goto label_67;
  (Wrd153.pObj) = (OBJECT_ADDRESS (Wrd156.Obj));
  (Wrd154.Obj) = ((Wrd153.pObj) [0]);
  (Wrd155.Lng) = (FIXNUM_TO_LONG (Wrd154.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd155.Lng))))
    goto label_67;
  (Wrd147.Obj) = ((Wrd153.pObj) [4]);

DEFLABEL (label_66)
  (Wrd171.uLng) = (OBJECT_TYPE (Wrd147.Obj));
  if (! ((Wrd171.uLng) == 10))
    goto label_65;
  (Wrd168.pObj) = (OBJECT_ADDRESS (Wrd147.Obj));
  (Wrd169.Obj) = ((Wrd168.pObj) [0]);
  (Wrd170.Lng) = (FIXNUM_TO_LONG (Wrd169.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd170.Lng))))
    goto label_65;
  (Wrd164.Obj) = ((Wrd168.pObj) [1]);

DEFLABEL (label_64)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_63)
  (Rsp [1]) = (Wrd164.Obj);
  (Wrd178.Lng) = (FIXNUM_TO_LONG (Wrd164.Obj));
  (Wrd179.Obj) = (Rsp [0]);
  (Wrd180.Lng) = (FIXNUM_TO_LONG (Wrd179.Obj));
  if ((Wrd178.Lng) < (Wrd180.Lng))
    goto label_62;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_28]));

DEFLABEL (label_62)
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_27]));

DEFLABEL (label_65)
  (Wrd173.Obj) = (current_block [OBJECT_53_1]);
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_26]))));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (--Rsp)) = (Wrd173.Obj);
  (* (--Rsp)) = (Wrd147.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_48)
  (Wrd164.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd158.Obj) = (Rsp [5]);
  (Wrd159.Obj) = (current_block [OBJECT_53_4]);
  (Wrd162.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_25]))));
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd159.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_47)
  (Wrd147.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_68)
  (Wrd164.Obj) = (current_block [OBJECT_53_1]);
  goto label_64;

DEFLABEL (label_70)
  (Wrd141.Obj) = (Rsp [5]);
  (Wrd142.Obj) = (current_block [OBJECT_53_4]);
  (Wrd145.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_24]))));
  (* (--Rsp)) = (Wrd145.Obj);
  (* (--Rsp)) = (Wrd142.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_46)
  (Wrd130.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_73)
  (Wrd123.Obj) = (current_block [OBJECT_53_1]);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_23]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_45)
  (Wrd114.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  (Wrd108.Obj) = (Rsp [5]);
  (Wrd109.Obj) = (current_block [OBJECT_53_3]);
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_22]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  (* (--Rsp)) = (Wrd108.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_44)
  (Wrd97.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_76)
  (Wrd114.Obj) = (current_block [OBJECT_53_1]);
  goto label_72;

DEFLABEL (label_78)
  (Wrd91.Obj) = (Rsp [5]);
  (Wrd92.Obj) = (current_block [OBJECT_53_3]);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_21]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_43)
  (Wrd80.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_79)
  (Wrd187.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_6]))));
  (* (--Rsp)) = (Wrd187.Obj);
  (Wrd197.Obj) = (Rsp [6]);
  (Wrd198.uLng) = (OBJECT_TYPE (Wrd197.Obj));
  if (! ((Wrd198.uLng) == 10))
    goto label_96;
  (Wrd194.pObj) = (OBJECT_ADDRESS (Wrd197.Obj));
  (Wrd195.Obj) = ((Wrd194.pObj) [0]);
  (Wrd196.Lng) = (FIXNUM_TO_LONG (Wrd195.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd196.Lng))))
    goto label_96;
  (Wrd188.Obj) = ((Wrd194.pObj) [2]);

DEFLABEL (label_95)
  if ((Wrd188.Obj) == (current_block [OBJECT_53_0]))
    goto label_94;
  (Wrd214.Obj) = (Rsp [6]);
  (Wrd215.uLng) = (OBJECT_TYPE (Wrd214.Obj));
  if (! ((Wrd215.uLng) == 10))
    goto label_93;
  (Wrd211.pObj) = (OBJECT_ADDRESS (Wrd214.Obj));
  (Wrd212.Obj) = ((Wrd211.pObj) [0]);
  (Wrd213.Lng) = (FIXNUM_TO_LONG (Wrd212.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd213.Lng))))
    goto label_93;
  (Wrd205.Obj) = ((Wrd211.pObj) [2]);

DEFLABEL (label_92)
  (Wrd229.uLng) = (OBJECT_TYPE (Wrd205.Obj));
  if (! ((Wrd229.uLng) == 10))
    goto label_91;
  (Wrd226.pObj) = (OBJECT_ADDRESS (Wrd205.Obj));
  (Wrd227.Obj) = ((Wrd226.pObj) [0]);
  (Wrd228.Lng) = (FIXNUM_TO_LONG (Wrd227.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd228.Lng))))
    goto label_91;
  (Wrd222.Obj) = ((Wrd226.pObj) [1]);

DEFLABEL (label_90)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_89)
  (Rsp [0]) = (Wrd222.Obj);
  (Wrd237.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd237.Obj);
  (Wrd247.Obj) = (Rsp [6]);
  (Wrd248.uLng) = (OBJECT_TYPE (Wrd247.Obj));
  if (! ((Wrd248.uLng) == 10))
    goto label_88;
  (Wrd244.pObj) = (OBJECT_ADDRESS (Wrd247.Obj));
  (Wrd245.Obj) = ((Wrd244.pObj) [0]);
  (Wrd246.Lng) = (FIXNUM_TO_LONG (Wrd245.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd246.Lng))))
    goto label_88;
  (Wrd238.Obj) = ((Wrd244.pObj) [4]);

DEFLABEL (label_87)
  if ((Wrd238.Obj) == (current_block [OBJECT_53_0]))
    goto label_86;
  (Wrd264.Obj) = (Rsp [6]);
  (Wrd265.uLng) = (OBJECT_TYPE (Wrd264.Obj));
  if (! ((Wrd265.uLng) == 10))
    goto label_85;
  (Wrd261.pObj) = (OBJECT_ADDRESS (Wrd264.Obj));
  (Wrd262.Obj) = ((Wrd261.pObj) [0]);
  (Wrd263.Lng) = (FIXNUM_TO_LONG (Wrd262.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd263.Lng))))
    goto label_85;
  (Wrd255.Obj) = ((Wrd261.pObj) [4]);

DEFLABEL (label_84)
  (Wrd279.uLng) = (OBJECT_TYPE (Wrd255.Obj));
  if (! ((Wrd279.uLng) == 10))
    goto label_83;
  (Wrd276.pObj) = (OBJECT_ADDRESS (Wrd255.Obj));
  (Wrd277.Obj) = ((Wrd276.pObj) [0]);
  (Wrd278.Lng) = (FIXNUM_TO_LONG (Wrd277.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd278.Lng))))
    goto label_83;
  (Wrd272.Obj) = ((Wrd276.pObj) [1]);

DEFLABEL (label_82)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_81)
  (Rsp [1]) = (Wrd272.Obj);
  (Wrd285.Obj) = (Rsp [0]);
  (Wrd286.Lng) = (FIXNUM_TO_LONG (Wrd285.Obj));
  (Wrd288.Lng) = (FIXNUM_TO_LONG (Wrd272.Obj));
  if ((Wrd286.Lng) < (Wrd288.Lng))
    goto label_80;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_20]));

DEFLABEL (label_80)
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_19]));

DEFLABEL (label_83)
  (Wrd281.Obj) = (current_block [OBJECT_53_1]);
  (Wrd284.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_18]))));
  (* (--Rsp)) = (Wrd284.Obj);
  (* (--Rsp)) = (Wrd281.Obj);
  (* (--Rsp)) = (Wrd255.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_54)
  (Wrd272.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  (Wrd266.Obj) = (Rsp [6]);
  (Wrd267.Obj) = (current_block [OBJECT_53_4]);
  (Wrd270.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_17]))));
  (* (--Rsp)) = (Wrd270.Obj);
  (* (--Rsp)) = (Wrd267.Obj);
  (* (--Rsp)) = (Wrd266.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_53)
  (Wrd255.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_86)
  (Wrd272.Obj) = (current_block [OBJECT_53_1]);
  goto label_82;

DEFLABEL (label_88)
  (Wrd249.Obj) = (Rsp [6]);
  (Wrd250.Obj) = (current_block [OBJECT_53_4]);
  (Wrd253.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_16]))));
  (* (--Rsp)) = (Wrd253.Obj);
  (* (--Rsp)) = (Wrd250.Obj);
  (* (--Rsp)) = (Wrd249.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_52)
  (Wrd238.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_91)
  (Wrd231.Obj) = (current_block [OBJECT_53_1]);
  (Wrd234.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_15]))));
  (* (--Rsp)) = (Wrd234.Obj);
  (* (--Rsp)) = (Wrd231.Obj);
  (* (--Rsp)) = (Wrd205.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_51)
  (Wrd222.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  (Wrd216.Obj) = (Rsp [6]);
  (Wrd217.Obj) = (current_block [OBJECT_53_3]);
  (Wrd220.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_14]))));
  (* (--Rsp)) = (Wrd220.Obj);
  (* (--Rsp)) = (Wrd217.Obj);
  (* (--Rsp)) = (Wrd216.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_50)
  (Wrd205.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_94)
  (Wrd222.Obj) = (current_block [OBJECT_53_1]);
  goto label_90;

DEFLABEL (label_96)
  (Wrd199.Obj) = (Rsp [6]);
  (Wrd200.Obj) = (current_block [OBJECT_53_3]);
  (Wrd203.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_13]))));
  (* (--Rsp)) = (Wrd203.Obj);
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd199.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_49)
  (Wrd188.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_99)
  (Wrd44.Obj) = (Rsp [4]);
  (Wrd45.Obj) = (current_block [OBJECT_53_1]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_12]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_42)
  (Wrd33.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_100)
  (Wrd295.Obj) = (current_block [OBJECT_53_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd295.Obj);
  goto label_97;

DEFLABEL (label_103)
  (Wrd22.Obj) = (Rsp [4]);
  (Wrd23.Obj) = (current_block [OBJECT_53_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_41)
  (Wrd11.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_104)
  (Wrd297.Obj) = (current_block [OBJECT_53_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd297.Obj);
  goto label_101;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_53_7);
  (Wrd164.Obj) = Rvl;
  goto label_63;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_53_8);
  (Wrd114.Obj) = Rvl;
  goto label_71;

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_53_5);
  (Wrd272.Obj) = Rvl;
  goto label_81;

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_53_6);
  (Wrd222.Obj) = Rvl;
  goto label_89;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_53_9);
  (* (--Rsp)) = Rvl;
  goto label_97;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_53_10);
  (* (--Rsp)) = Rvl;
  goto label_101;

DEFLABEL (simple_join_59)
DEFLABEL (simple_join_38)
  INTERRUPT_CHECK (26, LABEL_53_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  if ((Wrd8.Obj) == (current_block [OBJECT_53_0]))
    goto label_112;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_111;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_111;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_110)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_109)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_29]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  if ((Wrd30.Obj) == (current_block [OBJECT_53_0]))
    goto label_108;
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_107;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd41.Lng))))
    goto label_107;
  (Wrd33.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_106)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_105)
  (Wrd49.Obj) = (* (Rsp++));
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  (Wrd55.Lng) = ((Wrd51.Lng) + (Wrd52.Lng));
  (Wrd56.Lng) = ((Wrd55.Lng) + 1L);
  (Wrd54.Obj) = (LONG_TO_FIXNUM (Wrd56.Lng));
  (Wrd65.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd66.Obj) = (Rsp [2]);
  (Wrd67.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd65.Obj);
  (* (Rhp++)) = (Wrd54.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd61.Obj) = (Rsp [3]);
  (Wrd62.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd62.Obj);
  (Wrd59.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd59.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_107)
  (Wrd44.Obj) = (Rsp [4]);
  (Wrd45.Obj) = (current_block [OBJECT_53_1]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_33]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_56)
  (Wrd33.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_108)
  (Wrd33.Obj) = (current_block [OBJECT_53_1]);
  goto label_106;

DEFLABEL (label_111)
  (Wrd22.Obj) = (Rsp [4]);
  (Wrd23.Obj) = (current_block [OBJECT_53_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_32]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_2]), 2);

DEFLABEL (label_55)
  (Wrd11.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_112)
  (Wrd70.Obj) = (current_block [OBJECT_53_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd70.Obj);
  goto label_109;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_53_29);
  (Wrd33.Obj) = Rvl;
  goto label_105;

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_53_30);
  (* (--Rsp)) = Rvl;
  goto label_109;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_6 5
#define LABEL_54_7 7
#define ENVIRONMENT_LABEL_54_3 18
#define DEBUGGING_LABEL_54_2 17
#define OBJECT_54_3 16
#define OBJECT_54_2 15
#define OBJECT_54_1 14
#define OBJECT_54_0 13
#define EXECUTE_CACHE_54_8 9
#define EXECUTE_CACHE_54_5 11
#define FREE_REFERENCES_LABEL_54_0 8
#define NUMBER_OF_LINKER_SECTIONS_54_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd24;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd42;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto node_min_4;

    case 1:
      current_block = (Rpc - LABEL_54_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_54_7);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_min_9)
DEFLABEL (node_min_4)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_54_0])))
    goto label_10;
  (Wrd42.Obj) = (current_block [OBJECT_54_1]);
  (Rsp [0]) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_5]));

DEFLABEL (label_10)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_15;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_15;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_14)
  if (! ((Wrd7.Obj) == (current_block [OBJECT_54_0])))
    goto label_11;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_13;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd32.Lng))))
    goto label_13;
  (Wrd24.Obj) = ((Wrd30.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_8]));

DEFLABEL (label_13)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_54_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_3]), 2);

DEFLABEL (label_7)
  (Wrd24.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_54_2]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_3]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_6 5
#define LABEL_55_8 7
#define LABEL_55_7 9
#define LABEL_55_10 11
#define LABEL_55_11 13
#define LABEL_55_12 15
#define ENVIRONMENT_LABEL_55_3 31
#define DEBUGGING_LABEL_55_2 30
#define OBJECT_55_6 29
#define OBJECT_55_5 28
#define OBJECT_55_4 27
#define OBJECT_55_3 26
#define OBJECT_55_2 25
#define OBJECT_55_1 24
#define OBJECT_55_0 23
#define EXECUTE_CACHE_55_13 17
#define EXECUTE_CACHE_55_9 19
#define EXECUTE_CACHE_55_5 21
#define FREE_REFERENCES_LABEL_55_0 16
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd29;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd56;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd57;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto node_delmin_8;

    case 1:
      current_block = (Rpc - LABEL_55_6);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_55_8);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_55_7);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_55_10);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_55_11);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_55_12);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_delmin_16)
DEFLABEL (node_delmin_8)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_55_0])))
    goto label_17;
  (Wrd57.Obj) = (current_block [OBJECT_55_1]);
  (Rsp [0]) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_5]));

DEFLABEL (label_17)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_30;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_30;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_29)
  if ((Wrd7.Obj) == (current_block [OBJECT_55_0]))
    goto label_26;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_7]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_25;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_25;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_24)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_55_7);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_23;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_23;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_22)
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_21;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_21;
  (Wrd23.Obj) = ((Wrd27.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_20)
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_19;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd45.Lng))))
    goto label_19;
  (Wrd37.Obj) = ((Wrd43.pObj) [4]);

DEFLABEL (label_18)
  (Rsp [3]) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_13]));

DEFLABEL (label_19)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.Obj) = (current_block [OBJECT_55_4]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_12]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_14)
  (Wrd37.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.Obj) = (current_block [OBJECT_55_6]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_11]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_55_5]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.Obj) = (current_block [OBJECT_55_2]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_26)
  (Wrd43.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_55_4]);
  (Rsp [1]) = (Wrd44.Obj);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd56.uLng) == 10)
    goto label_28;

DEFLABEL (label_27)
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_28)
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd54.Lng))))
    goto label_27;
  Rvl = ((Wrd52.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_30)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_55_2]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 2);

DEFLABEL (label_10)
  (Wrd7.Obj) = Rvl;
  goto label_29;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define LABEL_56_7 7
#define LABEL_56_8 9
#define LABEL_56_9 11
#define ENVIRONMENT_LABEL_56_3 24
#define DEBUGGING_LABEL_56_2 23
#define OBJECT_56_3 22
#define OBJECT_56_2 21
#define OBJECT_56_1 20
#define OBJECT_56_0 19
#define EXECUTE_CACHE_56_11 13
#define EXECUTE_CACHE_56_10 15
#define EXECUTE_CACHE_56_6 17
#define FREE_REFERENCES_LABEL_56_0 12
#define NUMBER_OF_LINKER_SECTIONS_56_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto node_concat2_7;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_56_7);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_56_8);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_56_9);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_concat2_12)
DEFLABEL (node_concat2_7)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_56_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_19;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_17;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_56_5);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_16;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_16;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_15)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_14;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd29.Lng))))
    goto label_14;
  (Wrd21.Obj) = ((Wrd27.pObj) [5]);

DEFLABEL (label_13)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_56_9);
  (Rsp [3]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_11]));

DEFLABEL (label_14)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_56_3]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_2]), 2);

DEFLABEL (label_10)
  (Wrd21.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_56_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_2]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_17)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_18)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  Rvl = (Rsp [1]);
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_5 5
#define LABEL_57_6 7
#define LABEL_57_7 9
#define LABEL_57_8 11
#define LABEL_57_9 13
#define LABEL_57_10 15
#define LABEL_57_11 17
#define ENVIRONMENT_LABEL_57_3 25
#define DEBUGGING_LABEL_57_2 24
#define OBJECT_57_5 23
#define OBJECT_57_4 22
#define OBJECT_57_3 21
#define OBJECT_57_2 20
#define OBJECT_57_1 19
#define OBJECT_57_0 18
#define FREE_REFERENCES_LABEL_57_0 18
#define NUMBER_OF_LINKER_SECTIONS_57_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd101;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd78;
  machine_word Wrd86;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd69;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd58;
  machine_word Wrd66;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd49;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd18;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto node_inorder_fold_9;

    case 1:
      current_block = (Rpc - LABEL_57_5);
      goto fold_8;

    case 2:
      current_block = (Rpc - LABEL_57_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_57_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_57_8);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_57_9);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_57_10);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_57_11);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_inorder_fold_16)
DEFLABEL (node_inorder_fold_9)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  Rdl = (& (Rsp [6]));
  goto fold_8;

DEFLABEL (fold_17)
DEFLABEL (fold_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_57_5);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_57_0])))
    goto label_18;
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_18)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_26;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_26;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_25)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_24;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_24;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_23)
  (Wrd56.Obj) = (Rsp [3]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 10))
    goto label_22;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [0]);
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd54.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd55.Lng))))
    goto label_22;
  (Wrd49.Obj) = ((Wrd53.pObj) [5]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_21)
  (Wrd76.Obj) = (Rsp [4]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd77.uLng) == 10))
    goto label_20;
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd74.Obj) = ((Wrd73.pObj) [0]);
  (Wrd75.Lng) = (FIXNUM_TO_LONG (Wrd74.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd75.Lng))))
    goto label_20;
  (Wrd69.Obj) = ((Wrd73.pObj) [3]);
  (* (--Rsp)) = (Wrd69.Obj);

DEFLABEL (label_19)
  (Wrd87.Obj) = (Rsp [6]);
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd88.pObj)));
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd91.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd91.Obj);
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_10]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_11]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd106.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd107.Obj) = (Rsp [12]);
  (* (--Rsp)) = (Wrd107.Obj);
  Rdl = (& (Rsp [3]));
  goto fold_8;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_57_11);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [13]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_57_10);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = (& (Rsp [10]));
  {
    SCHEME_OBJECT * IPDLp1 = (((Wrd7.pObj) <= Rdl) ? (Wrd7.pObj) : Rdl);
    (* (--IPDLp1)) = (Rsp [2]);
    (* (--IPDLp1)) = (Rsp [1]);
    (* (--IPDLp1)) = (Rsp [0]);
    Rsp = IPDLp1;
  }
  goto fold_8;

DEFLABEL (label_20)
  (Wrd82.Obj) = (Rsp [4]);
  (Wrd83.Obj) = (current_block [OBJECT_57_5]);
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_9]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 2);

DEFLABEL (label_14)
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd62.Obj) = (Rsp [3]);
  (Wrd63.Obj) = (current_block [OBJECT_57_4]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_8]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 2);

DEFLABEL (label_13)
  (Wrd58.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd58.Obj));
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd42.Obj) = (Rsp [2]);
  (Wrd43.Obj) = (current_block [OBJECT_57_3]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_7]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 2);

DEFLABEL (label_12)
  (Wrd38.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd38.Obj));
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_57_1]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 2);

DEFLABEL (label_11)
  (Wrd18.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd18.Obj));
  (* (--Rsp)) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_5 5
#define LABEL_58_6 7
#define LABEL_58_7 9
#define LABEL_58_8 11
#define LABEL_58_9 13
#define LABEL_58_11 15
#define ENVIRONMENT_LABEL_58_3 27
#define DEBUGGING_LABEL_58_2 26
#define OBJECT_58_6 25
#define OBJECT_58_5 24
#define OBJECT_58_4 23
#define OBJECT_58_3 22
#define OBJECT_58_2 21
#define OBJECT_58_1 20
#define OBJECT_58_0 19
#define EXECUTE_CACHE_58_10 17
#define FREE_REFERENCES_LABEL_58_0 16
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd41;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto node_for_each_8;

    case 1:
      current_block = (Rpc - LABEL_58_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_58_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_58_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_58_8);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_58_9);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_58_11);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_for_each_15)
DEFLABEL (node_for_each_8)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_58_0])))
    goto label_16;
  Rvl = (current_block [OBJECT_58_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_24;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_24;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_23)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_22;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_22;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_21)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_20;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_20;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_19)
  (Wrd64.Obj) = (Rsp [4]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_18;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_18;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_17)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_9]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd75.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd75.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_58_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_58_11);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [5]) = (Wrd5.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

DEFLABEL (label_18)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.Obj) = (current_block [OBJECT_58_6]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_8]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_3]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.Obj) = (current_block [OBJECT_58_5]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_7]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_3]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.Obj) = (current_block [OBJECT_58_4]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_6]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_3]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_58_2]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_3]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_7 5
#define LABEL_59_5 7
#define LABEL_59_6 9
#define LABEL_59_10 11
#define LABEL_59_9 13
#define ENVIRONMENT_LABEL_59_3 25
#define DEBUGGING_LABEL_59_2 24
#define OBJECT_59_4 23
#define OBJECT_59_3 22
#define OBJECT_59_2 21
#define OBJECT_59_1 20
#define OBJECT_59_0 19
#define EXECUTE_CACHE_59_11 15
#define EXECUTE_CACHE_59_8 17
#define FREE_REFERENCES_LABEL_59_0 14
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto node_height_6;

    case 1:
      current_block = (Rpc - LABEL_59_7);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_59_6);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_59_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_59_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_height_11)
DEFLABEL (node_height_6)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_59_0])))
    goto label_12;
  Rvl = (current_block [OBJECT_59_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_18;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_18;
  (Wrd15.Obj) = ((Wrd19.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_17)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_59_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_16;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_16;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_15)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_59_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_59_5);
  (Rsp [0]) = Rvl;
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd8.uLng) == 26)
    goto label_14;

DEFLABEL (label_13)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_14)
  (Wrd11.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd9.Lng) = ((Wrd11.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd9.Lng)))
    goto label_13;
  Rvl = (LONG_TO_FIXNUM (Wrd9.Lng));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_59_4]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_3]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_59_2]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_3]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_5 3
#define LABEL_60_4 5
#define LABEL_60_6 7
#define LABEL_60_7 9
#define LABEL_60_8 11
#define LABEL_60_10 13
#define LABEL_60_11 15
#define LABEL_60_12 17
#define LABEL_60_13 19
#define LABEL_60_14 21
#define LABEL_60_15 23
#define LABEL_60_16 25
#define ENVIRONMENT_LABEL_60_3 36
#define DEBUGGING_LABEL_60_2 35
#define OBJECT_60_5 34
#define OBJECT_60_4 33
#define OBJECT_60_3 32
#define OBJECT_60_2 31
#define OBJECT_60_1 30
#define OBJECT_60_0 29
#define EXECUTE_CACHE_60_9 27
#define FREE_REFERENCES_LABEL_60_0 26
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd85;
  machine_word Wrd89;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd80;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd65;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd91;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd25;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd109;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd61;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd63;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_60_4);
      goto node_index_18;

    case 2:
      current_block = (Rpc - LABEL_60_6);
      goto label_20;

    case 3:
      current_block = (Rpc - LABEL_60_7);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_60_8);
      goto label_22;

    case 5:
      current_block = (Rpc - LABEL_60_10);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_60_11);
      goto loop_17;

    case 7:
      current_block = (Rpc - LABEL_60_12);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_60_13);
      goto label_24;

    case 9:
      current_block = (Rpc - LABEL_60_14);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_60_15);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_60_16);
      goto label_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (node_index_29)
DEFLABEL (node_index_18)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  if ((Wrd8.Obj) == (current_block [OBJECT_60_0]))
    goto label_41;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_40;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_40;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_39)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_38)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 26))
    goto label_37;
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  if ((Wrd61.Lng) < 0)
    goto label_32;

DEFLABEL (label_36)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 26))
    goto label_35;
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 26))
    goto label_35;
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if ((Wrd54.Lng) < (Wrd56.Lng))
    goto label_33;

DEFLABEL (label_32)
  (Wrd57.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd57.Obj);

DEFLABEL (label_31)
  (Wrd58.Obj) = (current_block [OBJECT_60_3]);
  (Rsp [2]) = (Wrd58.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_9]));

DEFLABEL (label_33)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 26))
    goto label_34;
  Rsp = (& (Rsp [1]));
  goto loop_17;

DEFLABEL (label_34)
  (Rsp [1]) = (Wrd47.Obj);
  goto label_31;

DEFLABEL (label_35)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_33;

DEFLABEL (label_37)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_21)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  goto label_32;

DEFLABEL (label_40)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_60_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_20)
  (Wrd11.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_41)
  (Wrd63.Obj) = (current_block [OBJECT_60_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd63.Obj);
  goto label_38;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (loop_30)
DEFLABEL (loop_17)
  INTERRUPT_CHECK (26, LABEL_60_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_56;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_56;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_55)
  if ((Wrd8.Obj) == (current_block [OBJECT_60_0]))
    goto label_54;
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_53;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_53;
  (Wrd25.Obj) = ((Wrd31.pObj) [2]);

DEFLABEL (label_52)
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_51;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd48.Lng))))
    goto label_51;
  (Wrd42.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_50)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_49)
  (Wrd55.Obj) = (Rsp [2]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  if ((Wrd56.Lng) < (Wrd58.Lng))
    goto label_46;
  if ((Wrd56.Lng) > (Wrd58.Lng))
    goto label_42;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd74.Obj) = (Rsp [1]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 10))
    goto label_45;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd72.Obj) = ((Wrd71.pObj) [0]);
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd72.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd73.Lng))))
    goto label_45;
  (Wrd65.Obj) = ((Wrd71.pObj) [4]);

DEFLABEL (label_44)
  (Rsp [1]) = (Wrd65.Obj);
  (Wrd82.Obj) = (Rsp [0]);
  (Wrd83.Lng) = (FIXNUM_TO_LONG (Wrd82.Obj));
  (Wrd84.Lng) = ((Wrd83.Lng) + 1L);
  (Wrd86.Obj) = (Rsp [2]);
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd86.Obj));
  (Wrd89.Lng) = ((Wrd87.Lng) - (Wrd84.Lng));
  (Wrd85.Obj) = (LONG_TO_FIXNUM (Wrd89.Lng));
  (Rsp [2]) = (Wrd85.Obj);

DEFLABEL (label_43)
  Rsp = (& (Rsp [1]));
  goto loop_17;

DEFLABEL (label_45)
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd77.Obj) = (current_block [OBJECT_60_5]);
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_16]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_26)
  (Wrd65.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  (Wrd100.Obj) = (Rsp [1]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 10))
    goto label_48;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd98.Obj) = ((Wrd97.pObj) [0]);
  (Wrd99.Lng) = (FIXNUM_TO_LONG (Wrd98.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd99.Lng))))
    goto label_48;
  (Wrd91.Obj) = ((Wrd97.pObj) [2]);

DEFLABEL (label_47)
  (Rsp [1]) = (Wrd91.Obj);
  goto label_43;

DEFLABEL (label_48)
  (Wrd102.Obj) = (Rsp [1]);
  (Wrd103.Obj) = (current_block [OBJECT_60_4]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_15]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_27)
  (Wrd91.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_51)
  (Wrd51.Obj) = (current_block [OBJECT_60_1]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_14]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_25)
  (Wrd42.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.Obj) = (current_block [OBJECT_60_4]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_13]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_24)
  (Wrd25.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_54)
  (Wrd109.Obj) = (current_block [OBJECT_60_1]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd109.Obj);
  goto label_49;

DEFLABEL (label_56)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_60_4]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_2]), 2);

DEFLABEL (label_23)
  (Wrd8.Obj) = Rvl;
  goto label_55;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_60_10);
  (* (--Rsp)) = Rvl;
  goto label_49;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define ENVIRONMENT_LABEL_61_3 9
#define DEBUGGING_LABEL_61_2 8
#define OBJECT_61_0 7
#define GLOBAL_EXECUTE_CACHE_61_5 5
#define FREE_REFERENCES_LABEL_61_0 4
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto error_empty_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_empty_3)
DEFLABEL (error_empty_0)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd5.Obj) = (current_block [OBJECT_61_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_61_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_61 5
#define LABEL_62_59 7
#define TAG_62_60 2
#define LABEL_62_57 9
#define TAG_62_58 3
#define LABEL_62_64 11
#define LABEL_62_55 13
#define TAG_62_56 5
#define LABEL_62_65 15
#define LABEL_62_66 17
#define LABEL_62_67 19
#define LABEL_62_68 21
#define LABEL_62_53 23
#define TAG_62_54 10
#define LABEL_62_70 25
#define LABEL_62_71 27
#define LABEL_62_72 29
#define LABEL_62_73 31
#define LABEL_62_51 33
#define TAG_62_52 15
#define LABEL_62_77 35
#define LABEL_62_78 37
#define LABEL_62_79 39
#define LABEL_62_80 41
#define LABEL_62_49 43
#define TAG_62_50 20
#define LABEL_62_81 45
#define LABEL_62_82 47
#define LABEL_62_83 49
#define LABEL_62_84 51
#define LABEL_62_85 53
#define LABEL_62_86 55
#define LABEL_62_88 57
#define LABEL_62_89 59
#define LABEL_62_90 61
#define LABEL_62_91 63
#define LABEL_62_93 65
#define LABEL_62_94 67
#define LABEL_62_47 69
#define TAG_62_48 33
#define LABEL_62_96 71
#define LABEL_62_45 73
#define TAG_62_46 35
#define LABEL_62_98 75
#define LABEL_62_43 77
#define TAG_62_44 37
#define LABEL_62_99 79
#define LABEL_62_100 81
#define LABEL_62_101 83
#define LABEL_62_102 85
#define LABEL_62_41 87
#define TAG_62_42 42
#define LABEL_62_104 89
#define LABEL_62_105 91
#define LABEL_62_106 93
#define LABEL_62_107 95
#define LABEL_62_39 97
#define TAG_62_40 47
#define LABEL_62_109 99
#define LABEL_62_110 101
#define LABEL_62_111 103
#define LABEL_62_37 105
#define TAG_62_38 51
#define LABEL_62_113 107
#define LABEL_62_114 109
#define LABEL_62_115 111
#define LABEL_62_116 113
#define LABEL_62_118 115
#define LABEL_62_119 117
#define LABEL_62_35 119
#define TAG_62_36 58
#define LABEL_62_120 121
#define LABEL_62_121 123
#define LABEL_62_122 125
#define LABEL_62_123 127
#define LABEL_62_124 129
#define LABEL_62_126 131
#define LABEL_62_33 133
#define TAG_62_34 65
#define LABEL_62_128 135
#define LABEL_62_31 137
#define TAG_62_32 67
#define LABEL_62_130 139
#define LABEL_62_29 141
#define TAG_62_30 69
#define LABEL_62_132 143
#define LABEL_62_27 145
#define TAG_62_28 71
#define LABEL_62_134 147
#define LABEL_62_25 149
#define TAG_62_26 73
#define LABEL_62_136 151
#define LABEL_62_23 153
#define TAG_62_24 75
#define LABEL_62_138 155
#define LABEL_62_21 157
#define TAG_62_22 77
#define LABEL_62_140 159
#define LABEL_62_141 161
#define LABEL_62_19 163
#define TAG_62_20 80
#define LABEL_62_143 165
#define LABEL_62_144 167
#define LABEL_62_17 169
#define TAG_62_18 83
#define LABEL_62_146 171
#define LABEL_62_147 173
#define LABEL_62_15 175
#define TAG_62_16 86
#define LABEL_62_149 177
#define LABEL_62_150 179
#define LABEL_62_13 181
#define TAG_62_14 89
#define LABEL_62_151 183
#define LABEL_62_152 185
#define LABEL_62_11 187
#define TAG_62_12 92
#define LABEL_62_9 189
#define TAG_62_10 93
#define LABEL_62_155 191
#define LABEL_62_7 193
#define TAG_62_8 95
#define LABEL_62_156 195
#define LABEL_62_5 197
#define TAG_62_6 97
#define LABEL_62_158 199
#define LABEL_62_159 201
#define LABEL_62_161 203
#define LABEL_62_163 205
#define LABEL_62_63 207
#define LABEL_62_165 209
#define LABEL_62_166 211
#define LABEL_62_69 213
#define LABEL_62_74 215
#define LABEL_62_75 217
#define LABEL_62_92 219
#define LABEL_62_87 221
#define LABEL_62_95 223
#define LABEL_62_175 225
#define LABEL_62_176 227
#define LABEL_62_97 229
#define LABEL_62_178 231
#define LABEL_62_179 233
#define LABEL_62_103 235
#define LABEL_62_108 237
#define LABEL_62_112 239
#define LABEL_62_117 241
#define LABEL_62_125 243
#define LABEL_62_185 245
#define LABEL_62_187 247
#define LABEL_62_127 249
#define LABEL_62_188 251
#define LABEL_62_129 253
#define LABEL_62_131 255
#define LABEL_62_190 257
#define LABEL_62_133 259
#define LABEL_62_135 261
#define LABEL_62_191 263
#define LABEL_62_137 265
#define LABEL_62_192 267
#define LABEL_62_139 269
#define LABEL_62_193 271
#define LABEL_62_142 273
#define LABEL_62_194 275
#define LABEL_62_145 277
#define LABEL_62_195 279
#define LABEL_62_148 281
#define LABEL_62_196 283
#define LABEL_62_197 285
#define LABEL_62_199 287
#define LABEL_62_200 289
#define LABEL_62_201 291
#define LABEL_62_202 293
#define LABEL_62_153 295
#define LABEL_62_154 297
#define LABEL_62_157 299
#define LABEL_62_162 301
#define LABEL_62_204 303
#define LABEL_62_205 305
#define LABEL_62_160 307
#define LABEL_62_206 309
#define LABEL_62_207 311
#define LABEL_62_164 313
#define LABEL_62_208 315
#define LABEL_62_209 317
#define LABEL_62_210 319
#define LABEL_62_211 321
#define LABEL_62_212 323
#define LABEL_62_213 325
#define LABEL_62_214 327
#define LABEL_62_168 329
#define LABEL_62_215 331
#define LABEL_62_216 333
#define LABEL_62_167 335
#define LABEL_62_217 337
#define LABEL_62_218 339
#define LABEL_62_170 341
#define LABEL_62_169 343
#define LABEL_62_171 345
#define LABEL_62_222 347
#define LABEL_62_223 349
#define LABEL_62_174 351
#define LABEL_62_224 353
#define LABEL_62_226 355
#define LABEL_62_177 357
#define LABEL_62_227 359
#define LABEL_62_229 361
#define LABEL_62_180 363
#define LABEL_62_181 365
#define LABEL_62_182 367
#define LABEL_62_183 369
#define LABEL_62_186 371
#define LABEL_62_184 373
#define LABEL_62_236 375
#define LABEL_62_238 377
#define LABEL_62_198 379
#define LABEL_62_239 381
#define LABEL_62_219 383
#define LABEL_62_221 385
#define LABEL_62_225 387
#define LABEL_62_240 389
#define LABEL_62_241 391
#define LABEL_62_228 393
#define LABEL_62_242 395
#define LABEL_62_243 397
#define LABEL_62_230 399
#define LABEL_62_245 401
#define LABEL_62_231 403
#define LABEL_62_247 405
#define LABEL_62_232 407
#define LABEL_62_233 409
#define LABEL_62_234 411
#define LABEL_62_237 413
#define LABEL_62_235 415
#define LABEL_62_252 417
#define LABEL_62_244 419
#define LABEL_62_246 421
#define LABEL_62_248 423
#define LABEL_62_250 425
#define LABEL_62_249 427
#define LABEL_62_251 429
#define LABEL_62_253 431
#define LABEL_62_254 433
#define LABEL_62_255 435
#define ENVIRONMENT_LABEL_62_3 468
#define DEBUGGING_LABEL_62_2 467
#define OBJECT_62_15 466
#define OBJECT_62_14 465
#define OBJECT_62_13 464
#define OBJECT_62_12 463
#define OBJECT_62_11 462
#define OBJECT_62_10 461
#define OBJECT_62_9 460
#define OBJECT_62_8 459
#define OBJECT_62_7 458
#define OBJECT_62_6 457
#define OBJECT_62_5 456
#define OBJECT_62_4 455
#define OBJECT_62_3 454
#define OBJECT_62_2 453
#define OBJECT_62_1 452
#define OBJECT_62_0 451
#define EXECUTE_CACHE_62_220 437
#define EXECUTE_CACHE_62_203 439
#define EXECUTE_CACHE_62_189 441
#define EXECUTE_CACHE_62_173 443
#define EXECUTE_CACHE_62_172 445
#define EXECUTE_CACHE_62_76 447
#define EXECUTE_CACHE_62_62 449
#define FREE_REFERENCES_LABEL_62_0 436
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd83;
  machine_word Wrd134;
  machine_word Wrd112;
  machine_word Wrd86;
  machine_word Wrd120;
  machine_word Wrd39;
  machine_word Wrd8;
  machine_word Wrd130;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd123;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd106;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd95;
  machine_word Wrd85;
  machine_word Wrd42;
  machine_word Wrd82;
  machine_word Wrd69;
  machine_word Wrd53;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd24;
  machine_word Wrd129;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd124;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd113;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd92;
  machine_word Wrd81;
  machine_word Wrd89;
  machine_word Wrd140;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd71;
  machine_word Wrd230;
  machine_word Wrd229;
  machine_word Wrd228;
  machine_word Wrd226;
  machine_word Wrd225;
  machine_word Wrd222;
  machine_word Wrd220;
  machine_word Wrd215;
  machine_word Wrd217;
  machine_word Wrd216;
  machine_word Wrd152;
  machine_word Wrd155;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd143;
  machine_word Wrd149;
  machine_word Wrd147;
  machine_word Wrd151;
  machine_word Wrd150;
  machine_word Wrd68;
  machine_word Wrd321;
  machine_word Wrd320;
  machine_word Wrd319;
  machine_word Wrd318;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd313;
  machine_word Wrd302;
  machine_word Wrd310;
  machine_word Wrd305;
  machine_word Wrd307;
  machine_word Wrd306;
  machine_word Wrd291;
  machine_word Wrd299;
  machine_word Wrd298;
  machine_word Wrd297;
  machine_word Wrd301;
  machine_word Wrd300;
  machine_word Wrd282;
  machine_word Wrd290;
  machine_word Wrd285;
  machine_word Wrd287;
  machine_word Wrd286;
  machine_word Wrd271;
  machine_word Wrd279;
  machine_word Wrd278;
  machine_word Wrd277;
  machine_word Wrd281;
  machine_word Wrd280;
  machine_word Wrd262;
  machine_word Wrd270;
  machine_word Wrd265;
  machine_word Wrd267;
  machine_word Wrd266;
  machine_word Wrd253;
  machine_word Wrd259;
  machine_word Wrd258;
  machine_word Wrd257;
  machine_word Wrd261;
  machine_word Wrd260;
  machine_word Wrd242;
  machine_word Wrd250;
  machine_word Wrd245;
  machine_word Wrd247;
  machine_word Wrd246;
  machine_word Wrd233;
  machine_word Wrd239;
  machine_word Wrd238;
  machine_word Wrd237;
  machine_word Wrd241;
  machine_word Wrd240;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd37;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd324;
  machine_word Wrd23;
  machine_word Wrd326;
  machine_word Wrd330;
  machine_word Wrd332;
  machine_word Wrd331;
  machine_word Wrd329;
  machine_word Wrd327;
  machine_word Wrd337;
  machine_word Wrd339;
  machine_word Wrd338;
  machine_word Wrd336;
  machine_word Wrd335;
  machine_word Wrd334;
  machine_word Wrd11;
  machine_word Wrd80;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd70;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd41;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd33;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd84;
  machine_word Wrd87;
  machine_word Wrd93;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd148;
  machine_word Wrd109;
  machine_word Wrd103;
  machine_word Wrd88;
  machine_word Wrd79;
  machine_word Wrd67;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd166;
  machine_word Wrd165;
  machine_word Wrd168;
  machine_word Wrd167;
  machine_word Wrd170;
  machine_word Wrd169;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd176;
  machine_word Wrd175;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd190;
  machine_word Wrd189;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd198;
  machine_word Wrd197;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd206;
  machine_word Wrd205;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd210;
  machine_word Wrd209;
  machine_word Wrd212;
  machine_word Wrd211;
  machine_word Wrd214;
  machine_word Wrd213;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto make_wt_tree_type_275;

    case 1:
      current_block = (Rpc - LABEL_62_61);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_62_59);
      goto node_find_12;

    case 3:
      current_block = (Rpc - LABEL_62_57);
      goto node_rank_30;

    case 4:
      current_block = (Rpc - LABEL_62_64);
      goto label_277;

    case 5:
      current_block = (Rpc - LABEL_62_55);
      goto node_add_48;

    case 6:
      current_block = (Rpc - LABEL_62_65);
      goto label_278;

    case 7:
      current_block = (Rpc - LABEL_62_66);
      goto label_279;

    case 8:
      current_block = (Rpc - LABEL_62_67);
      goto label_280;

    case 9:
      current_block = (Rpc - LABEL_62_68);
      goto label_281;

    case 10:
      current_block = (Rpc - LABEL_62_53);
      goto node_delete_59;

    case 11:
      current_block = (Rpc - LABEL_62_70);
      goto label_282;

    case 12:
      current_block = (Rpc - LABEL_62_71);
      goto label_283;

    case 13:
      current_block = (Rpc - LABEL_62_72);
      goto label_284;

    case 14:
      current_block = (Rpc - LABEL_62_73);
      goto label_285;

    case 15:
      current_block = (Rpc - LABEL_62_51);
      goto node_concat_67;

    case 16:
      current_block = (Rpc - LABEL_62_77);
      goto continuation_79;

    case 17:
      current_block = (Rpc - LABEL_62_78);
      goto continuation_81;

    case 18:
      current_block = (Rpc - LABEL_62_79);
      goto continuation_71;

    case 19:
      current_block = (Rpc - LABEL_62_80);
      goto continuation_73;

    case 20:
      current_block = (Rpc - LABEL_62_49);
      goto node_concat3_98;

    case 21:
      current_block = (Rpc - LABEL_62_81);
      goto label_286;

    case 22:
      current_block = (Rpc - LABEL_62_82);
      goto label_287;

    case 23:
      current_block = (Rpc - LABEL_62_83);
      goto label_294;

    case 24:
      current_block = (Rpc - LABEL_62_84);
      goto label_295;

    case 25:
      current_block = (Rpc - LABEL_62_85);
      goto label_296;

    case 26:
      current_block = (Rpc - LABEL_62_86);
      goto label_297;

    case 27:
      current_block = (Rpc - LABEL_62_88);
      goto label_290;

    case 28:
      current_block = (Rpc - LABEL_62_89);
      goto label_291;

    case 29:
      current_block = (Rpc - LABEL_62_90);
      goto label_292;

    case 30:
      current_block = (Rpc - LABEL_62_91);
      goto label_293;

    case 31:
      current_block = (Rpc - LABEL_62_93);
      goto label_288;

    case 32:
      current_block = (Rpc - LABEL_62_94);
      goto label_289;

    case 33:
      current_block = (Rpc - LABEL_62_47);
      goto node_split_lt_110;

    case 34:
      current_block = (Rpc - LABEL_62_96);
      goto label_298;

    case 35:
      current_block = (Rpc - LABEL_62_45);
      goto node_split_gt_122;

    case 36:
      current_block = (Rpc - LABEL_62_98);
      goto label_299;

    case 37:
      current_block = (Rpc - LABEL_62_43);
      goto node_union_135;

    case 38:
      current_block = (Rpc - LABEL_62_99);
      goto label_300;

    case 39:
      current_block = (Rpc - LABEL_62_100);
      goto label_301;

    case 40:
      current_block = (Rpc - LABEL_62_101);
      goto label_302;

    case 41:
      current_block = (Rpc - LABEL_62_102);
      goto label_303;

    case 42:
      current_block = (Rpc - LABEL_62_41);
      goto node_union_merge_154;

    case 43:
      current_block = (Rpc - LABEL_62_104);
      goto label_304;

    case 44:
      current_block = (Rpc - LABEL_62_105);
      goto label_305;

    case 45:
      current_block = (Rpc - LABEL_62_106);
      goto label_306;

    case 46:
      current_block = (Rpc - LABEL_62_107);
      goto label_307;

    case 47:
      current_block = (Rpc - LABEL_62_39);
      goto node_difference_167;

    case 48:
      current_block = (Rpc - LABEL_62_109);
      goto label_308;

    case 49:
      current_block = (Rpc - LABEL_62_110);
      goto label_309;

    case 50:
      current_block = (Rpc - LABEL_62_111);
      goto label_310;

    case 51:
      current_block = (Rpc - LABEL_62_37);
      goto node_intersection_183;

    case 52:
      current_block = (Rpc - LABEL_62_113);
      goto label_311;

    case 53:
      current_block = (Rpc - LABEL_62_114);
      goto label_312;

    case 54:
      current_block = (Rpc - LABEL_62_115);
      goto label_313;

    case 55:
      current_block = (Rpc - LABEL_62_116);
      goto label_314;

    case 56:
      current_block = (Rpc - LABEL_62_118);
      goto continuation_186;

    case 57:
      current_block = (Rpc - LABEL_62_119);
      goto continuation_188;

    case 58:
      current_block = (Rpc - LABEL_62_35);
      goto node_subsetP_208;

    case 59:
      current_block = (Rpc - LABEL_62_120);
      goto label_315;

    case 60:
      current_block = (Rpc - LABEL_62_121);
      goto label_316;

    case 61:
      current_block = (Rpc - LABEL_62_122);
      goto label_317;

    case 62:
      current_block = (Rpc - LABEL_62_123);
      goto label_318;

    case 63:
      current_block = (Rpc - LABEL_62_124);
      goto label_319;

    case 64:
      current_block = (Rpc - LABEL_62_126);
      goto label_320;

    case 65:
      current_block = (Rpc - LABEL_62_33);
      goto tree_map_add_404;

    case 66:
      current_block = (Rpc - LABEL_62_128);
      goto label_321;

    case 67:
      current_block = (Rpc - LABEL_62_31);
      goto tree_insertB_403;

    case 68:
      current_block = (Rpc - LABEL_62_130);
      goto label_322;

    case 69:
      current_block = (Rpc - LABEL_62_29);
      goto tree_delete_402;

    case 70:
      current_block = (Rpc - LABEL_62_132);
      goto label_323;

    case 71:
      current_block = (Rpc - LABEL_62_27);
      goto tree_deleteB_401;

    case 72:
      current_block = (Rpc - LABEL_62_134);
      goto label_324;

    case 73:
      current_block = (Rpc - LABEL_62_25);
      goto tree_split_lt_400;

    case 74:
      current_block = (Rpc - LABEL_62_136);
      goto label_325;

    case 75:
      current_block = (Rpc - LABEL_62_23);
      goto tree_split_gt_399;

    case 76:
      current_block = (Rpc - LABEL_62_138);
      goto label_326;

    case 77:
      current_block = (Rpc - LABEL_62_21);
      goto tree_union_398;

    case 78:
      current_block = (Rpc - LABEL_62_140);
      goto label_327;

    case 79:
      current_block = (Rpc - LABEL_62_141);
      goto label_328;

    case 80:
      current_block = (Rpc - LABEL_62_19);
      goto tree_union_merge_397;

    case 81:
      current_block = (Rpc - LABEL_62_143);
      goto label_329;

    case 82:
      current_block = (Rpc - LABEL_62_144);
      goto label_330;

    case 83:
      current_block = (Rpc - LABEL_62_17);
      goto tree_intersection_396;

    case 84:
      current_block = (Rpc - LABEL_62_146);
      goto label_331;

    case 85:
      current_block = (Rpc - LABEL_62_147);
      goto label_332;

    case 86:
      current_block = (Rpc - LABEL_62_15);
      goto tree_difference_395;

    case 87:
      current_block = (Rpc - LABEL_62_149);
      goto label_333;

    case 88:
      current_block = (Rpc - LABEL_62_150);
      goto label_334;

    case 89:
      current_block = (Rpc - LABEL_62_13);
      goto tree_subsetP_394;

    case 90:
      current_block = (Rpc - LABEL_62_151);
      goto label_335;

    case 91:
      current_block = (Rpc - LABEL_62_152);
      goto label_336;

    case 92:
      current_block = (Rpc - LABEL_62_11);
      goto alist__tree_393;

    case 93:
      current_block = (Rpc - LABEL_62_9);
      goto tree_get_392;

    case 94:
      current_block = (Rpc - LABEL_62_155);
      goto label_337;

    case 95:
      current_block = (Rpc - LABEL_62_7);
      goto tree_rank_391;

    case 96:
      current_block = (Rpc - LABEL_62_156);
      goto label_338;

    case 97:
      current_block = (Rpc - LABEL_62_5);
      goto tree_memberP_390;

    case 98:
      current_block = (Rpc - LABEL_62_158);
      goto label_339;

    case 99:
      current_block = (Rpc - LABEL_62_159);
      goto loop_11;

    case 100:
      current_block = (Rpc - LABEL_62_161);
      goto label_341;

    case 101:
      current_block = (Rpc - LABEL_62_163);
      goto label_340;

    case 102:
      current_block = (Rpc - LABEL_62_63);
      goto continuation_15;

    case 103:
      current_block = (Rpc - LABEL_62_165);
      goto label_343;

    case 104:
      current_block = (Rpc - LABEL_62_166);
      goto label_342;

    case 105:
      current_block = (Rpc - LABEL_62_69);
      goto continuation_36;

    case 106:
      current_block = (Rpc - LABEL_62_74);
      goto continuation_54;

    case 107:
      current_block = (Rpc - LABEL_62_75);
      goto continuation_62;

    case 108:
      current_block = (Rpc - LABEL_62_92);
      goto continuation_89;

    case 109:
      current_block = (Rpc - LABEL_62_87);
      goto continuation_95;

    case 110:
      current_block = (Rpc - LABEL_62_95);
      goto continuation_101;

    case 111:
      current_block = (Rpc - LABEL_62_175);
      goto label_345;

    case 112:
      current_block = (Rpc - LABEL_62_176);
      goto label_344;

    case 113:
      current_block = (Rpc - LABEL_62_97);
      goto continuation_113;

    case 114:
      current_block = (Rpc - LABEL_62_178);
      goto label_347;

    case 115:
      current_block = (Rpc - LABEL_62_179);
      goto label_346;

    case 116:
      current_block = (Rpc - LABEL_62_103);
      goto continuation_130;

    case 117:
      current_block = (Rpc - LABEL_62_108);
      goto continuation_142;

    case 118:
      current_block = (Rpc - LABEL_62_112);
      goto continuation_162;

    case 119:
      current_block = (Rpc - LABEL_62_117);
      goto continuation_175;

    case 120:
      current_block = (Rpc - LABEL_62_125);
      goto continuation_195;

    case 121:
      current_block = (Rpc - LABEL_62_185);
      goto label_349;

    case 122:
      current_block = (Rpc - LABEL_62_187);
      goto label_348;

    case 123:
      current_block = (Rpc - LABEL_62_127);
      goto continuation_211;

    case 124:
      current_block = (Rpc - LABEL_62_188);
      goto label_350;

    case 125:
      current_block = (Rpc - LABEL_62_129);
      goto continuation_214;

    case 126:
      current_block = (Rpc - LABEL_62_131);
      goto continuation_218;

    case 127:
      current_block = (Rpc - LABEL_62_190);
      goto label_351;

    case 128:
      current_block = (Rpc - LABEL_62_133);
      goto continuation_221;

    case 129:
      current_block = (Rpc - LABEL_62_135);
      goto continuation_225;

    case 130:
      current_block = (Rpc - LABEL_62_191);
      goto label_352;

    case 131:
      current_block = (Rpc - LABEL_62_137);
      goto continuation_229;

    case 132:
      current_block = (Rpc - LABEL_62_192);
      goto label_353;

    case 133:
      current_block = (Rpc - LABEL_62_139);
      goto continuation_234;

    case 134:
      current_block = (Rpc - LABEL_62_193);
      goto label_354;

    case 135:
      current_block = (Rpc - LABEL_62_142);
      goto continuation_239;

    case 136:
      current_block = (Rpc - LABEL_62_194);
      goto label_355;

    case 137:
      current_block = (Rpc - LABEL_62_145);
      goto continuation_244;

    case 138:
      current_block = (Rpc - LABEL_62_195);
      goto label_356;

    case 139:
      current_block = (Rpc - LABEL_62_148);
      goto continuation_249;

    case 140:
      current_block = (Rpc - LABEL_62_196);
      goto label_357;

    case 141:
      current_block = (Rpc - LABEL_62_197);
      goto loop_263;

    case 142:
      current_block = (Rpc - LABEL_62_199);
      goto label_358;

    case 143:
      current_block = (Rpc - LABEL_62_200);
      goto label_359;

    case 144:
      current_block = (Rpc - LABEL_62_201);
      goto label_360;

    case 145:
      current_block = (Rpc - LABEL_62_202);
      goto label_361;

    case 146:
      current_block = (Rpc - LABEL_62_153);
      goto continuation_254;

    case 147:
      current_block = (Rpc - LABEL_62_154);
      goto continuation_266;

    case 148:
      current_block = (Rpc - LABEL_62_157);
      goto continuation_272;

    case 149:
      current_block = (Rpc - LABEL_62_162);
      goto continuation_8;

    case 150:
      current_block = (Rpc - LABEL_62_204);
      goto label_363;

    case 151:
      current_block = (Rpc - LABEL_62_205);
      goto label_362;

    case 152:
      current_block = (Rpc - LABEL_62_160);
      goto continuation_4;

    case 153:
      current_block = (Rpc - LABEL_62_206);
      goto continuation_20;

    case 154:
      current_block = (Rpc - LABEL_62_207);
      goto continuation_25;

    case 155:
      current_block = (Rpc - LABEL_62_164);
      goto continuation_17;

    case 156:
      current_block = (Rpc - LABEL_62_208);
      goto label_368;

    case 157:
      current_block = (Rpc - LABEL_62_209);
      goto label_369;

    case 158:
      current_block = (Rpc - LABEL_62_210);
      goto label_370;

    case 159:
      current_block = (Rpc - LABEL_62_211);
      goto label_364;

    case 160:
      current_block = (Rpc - LABEL_62_212);
      goto label_365;

    case 161:
      current_block = (Rpc - LABEL_62_213);
      goto label_366;

    case 162:
      current_block = (Rpc - LABEL_62_214);
      goto label_367;

    case 163:
      current_block = (Rpc - LABEL_62_168);
      goto continuation_46;

    case 164:
      current_block = (Rpc - LABEL_62_215);
      goto continuation_39;

    case 165:
      current_block = (Rpc - LABEL_62_216);
      goto continuation_41;

    case 166:
      current_block = (Rpc - LABEL_62_167);
      goto continuation_37;

    case 167:
      current_block = (Rpc - LABEL_62_217);
      goto label_371;

    case 168:
      current_block = (Rpc - LABEL_62_218);
      goto label_372;

    case 169:
      current_block = (Rpc - LABEL_62_170);
      goto continuation_57;

    case 170:
      current_block = (Rpc - LABEL_62_169);
      goto continuation_55;

    case 171:
      current_block = (Rpc - LABEL_62_171);
      goto continuation_65;

    case 172:
      current_block = (Rpc - LABEL_62_222);
      goto label_373;

    case 173:
      current_block = (Rpc - LABEL_62_223);
      goto label_374;

    case 174:
      current_block = (Rpc - LABEL_62_174);
      goto continuation_103;

    case 175:
      current_block = (Rpc - LABEL_62_224);
      goto label_375;

    case 176:
      current_block = (Rpc - LABEL_62_226);
      goto label_376;

    case 177:
      current_block = (Rpc - LABEL_62_177);
      goto continuation_115;

    case 178:
      current_block = (Rpc - LABEL_62_227);
      goto label_377;

    case 179:
      current_block = (Rpc - LABEL_62_229);
      goto label_378;

    case 180:
      current_block = (Rpc - LABEL_62_180);
      goto continuation_129;

    case 181:
      current_block = (Rpc - LABEL_62_181);
      goto continuation_143;

    case 182:
      current_block = (Rpc - LABEL_62_182);
      goto continuation_161;

    case 183:
      current_block = (Rpc - LABEL_62_183);
      goto continuation_174;

    case 184:
      current_block = (Rpc - LABEL_62_186);
      goto continuation_205;

    case 185:
      current_block = (Rpc - LABEL_62_184);
      goto continuation_197;

    case 186:
      current_block = (Rpc - LABEL_62_236);
      goto label_380;

    case 187:
      current_block = (Rpc - LABEL_62_238);
      goto label_379;

    case 188:
      current_block = (Rpc - LABEL_62_198);
      goto continuation_262;

    case 189:
      current_block = (Rpc - LABEL_62_239);
      goto label_381;

    case 190:
      current_block = (Rpc - LABEL_62_219);
      goto continuation_45;

    case 191:
      current_block = (Rpc - LABEL_62_221);
      goto continuation_56;

    case 192:
      current_block = (Rpc - LABEL_62_225);
      goto continuation_108;

    case 193:
      current_block = (Rpc - LABEL_62_240);
      goto label_382;

    case 194:
      current_block = (Rpc - LABEL_62_241);
      goto label_383;

    case 195:
      current_block = (Rpc - LABEL_62_228);
      goto continuation_119;

    case 196:
      current_block = (Rpc - LABEL_62_242);
      goto label_384;

    case 197:
      current_block = (Rpc - LABEL_62_243);
      goto label_385;

    case 198:
      current_block = (Rpc - LABEL_62_230);
      goto continuation_132;

    case 199:
      current_block = (Rpc - LABEL_62_245);
      goto continuation_145;

    case 200:
      current_block = (Rpc - LABEL_62_231);
      goto continuation_144;

    case 201:
      current_block = (Rpc - LABEL_62_247);
      goto label_386;

    case 202:
      current_block = (Rpc - LABEL_62_232);
      goto continuation_164;

    case 203:
      current_block = (Rpc - LABEL_62_233);
      goto continuation_176;

    case 204:
      current_block = (Rpc - LABEL_62_234);
      goto continuation_206;

    case 205:
      current_block = (Rpc - LABEL_62_237);
      goto continuation_202;

    case 206:
      current_block = (Rpc - LABEL_62_235);
      goto continuation_199;

    case 207:
      current_block = (Rpc - LABEL_62_252);
      goto label_387;

    case 208:
      current_block = (Rpc - LABEL_62_244);
      goto continuation_131;

    case 209:
      current_block = (Rpc - LABEL_62_246);
      goto continuation_148;

    case 210:
      current_block = (Rpc - LABEL_62_248);
      goto continuation_163;

    case 211:
      current_block = (Rpc - LABEL_62_250);
      goto continuation_180;

    case 212:
      current_block = (Rpc - LABEL_62_249);
      goto continuation_178;

    case 213:
      current_block = (Rpc - LABEL_62_251);
      goto continuation_203;

    case 214:
      current_block = (Rpc - LABEL_62_253);
      goto continuation_147;

    case 215:
      current_block = (Rpc - LABEL_62_254);
      goto continuation_179;

    case 216:
      current_block = (Rpc - LABEL_62_255);
      goto continuation_177;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_wt_tree_type_389)
DEFLABEL (make_wt_tree_type_275)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd213.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_5])));
  Rhp += 1;
  (Wrd214.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd213.pObj)));
  (* (--Rsp)) = (Wrd214.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd211.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_7])));
  Rhp += 1;
  (Wrd212.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd211.pObj)));
  (* (--Rsp)) = (Wrd212.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd209.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_9])));
  Rhp += 1;
  (Wrd210.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd209.pObj)));
  (* (--Rsp)) = (Wrd210.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd207.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_11])));
  Rhp += 2;
  (Wrd208.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd207.pObj)));
  (* (--Rsp)) = (Wrd208.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd205.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_13])));
  Rhp += 1;
  (Wrd206.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd205.pObj)));
  (* (--Rsp)) = (Wrd206.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd203.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_15])));
  Rhp += 1;
  (Wrd204.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd203.pObj)));
  (* (--Rsp)) = (Wrd204.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd201.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_17])));
  Rhp += 1;
  (Wrd202.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd201.pObj)));
  (* (--Rsp)) = (Wrd202.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd199.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_19])));
  Rhp += 1;
  (Wrd200.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd199.pObj)));
  (* (--Rsp)) = (Wrd200.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd197.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_21])));
  Rhp += 1;
  (Wrd198.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd197.pObj)));
  (* (--Rsp)) = (Wrd198.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd195.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_24);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_23])));
  Rhp += 1;
  (Wrd196.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd195.pObj)));
  (* (--Rsp)) = (Wrd196.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd193.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_25])));
  Rhp += 1;
  (Wrd194.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd193.pObj)));
  (* (--Rsp)) = (Wrd194.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd191.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_28);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_27])));
  Rhp += 1;
  (Wrd192.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd191.pObj)));
  (* (--Rsp)) = (Wrd192.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd189.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_29])));
  Rhp += 1;
  (Wrd190.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd189.pObj)));
  (* (--Rsp)) = (Wrd190.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd187.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_31])));
  Rhp += 1;
  (Wrd188.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd187.pObj)));
  (* (--Rsp)) = (Wrd188.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd185.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_34);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_33])));
  Rhp += 1;
  (Wrd186.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd185.pObj)));
  (* (--Rsp)) = (Wrd186.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd183.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_35])));
  Rhp += 2;
  (Wrd184.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd183.pObj)));
  (* (--Rsp)) = (Wrd184.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd181.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_37])));
  Rhp += 5;
  (Wrd182.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd181.pObj)));
  (* (--Rsp)) = (Wrd182.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd179.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_39])));
  Rhp += 3;
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd179.pObj)));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd177.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_42);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_41])));
  Rhp += 4;
  (Wrd178.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd177.pObj)));
  (* (--Rsp)) = (Wrd178.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd175.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_44);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_43])));
  Rhp += 3;
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd175.pObj)));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd173.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_46);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_45])));
  Rhp += 2;
  (Wrd174.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd173.pObj)));
  (* (--Rsp)) = (Wrd174.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd171.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_48);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_47])));
  Rhp += 2;
  (Wrd172.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd171.pObj)));
  (* (--Rsp)) = (Wrd172.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd169.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_50);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_49])));
  Rhp += 1;
  (Wrd170.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd169.pObj)));
  (* (--Rsp)) = (Wrd170.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd167.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_52);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_51])));
  Rhp += 1;
  (Wrd168.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd167.pObj)));
  (* (--Rsp)) = (Wrd168.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd165.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_54);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_53])));
  Rhp += 1;
  (Wrd166.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd165.pObj)));
  (* (--Rsp)) = (Wrd166.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd163.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_56);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_55])));
  Rhp += 1;
  (Wrd164.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd163.pObj)));
  (* (--Rsp)) = (Wrd164.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd161.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_58);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_57])));
  Rhp += 1;
  (Wrd162.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd161.pObj)));
  (* (--Rsp)) = (Wrd162.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd159.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_60);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_59])));
  Rhp += 1;
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd159.pObj)));
  (* (--Rsp)) = (Wrd160.Obj);
  Wrd31 = Wrd159;
  (Wrd32.Obj) = (Rsp [29]);
  ((Wrd31.pObj) [2]) = (Wrd32.Obj);
  ((Wrd161.pObj) [2]) = (Wrd32.Obj);
  ((Wrd163.pObj) [2]) = (Wrd32.Obj);
  ((Wrd165.pObj) [2]) = (Wrd32.Obj);
  ((Wrd167.pObj) [2]) = (Wrd170.Obj);
  ((Wrd169.pObj) [2]) = (Wrd164.Obj);
  Wrd52 = Wrd171;
  ((Wrd52.pObj) [2]) = (Wrd32.Obj);
  ((Wrd52.pObj) [3]) = (Wrd170.Obj);
  Wrd58 = Wrd173;
  ((Wrd58.pObj) [2]) = (Wrd32.Obj);
  ((Wrd58.pObj) [3]) = (Wrd170.Obj);
  Wrd67 = Wrd175;
  ((Wrd67.pObj) [2]) = (Wrd174.Obj);
  ((Wrd67.pObj) [3]) = (Wrd172.Obj);
  ((Wrd67.pObj) [4]) = (Wrd170.Obj);
  Wrd79 = Wrd177;
  ((Wrd79.pObj) [2]) = (Wrd174.Obj);
  ((Wrd79.pObj) [3]) = (Wrd172.Obj);
  ((Wrd79.pObj) [4]) = (Wrd170.Obj);
  ((Wrd79.pObj) [5]) = (Wrd160.Obj);
  Wrd88 = Wrd179;
  ((Wrd88.pObj) [2]) = (Wrd174.Obj);
  ((Wrd88.pObj) [3]) = (Wrd172.Obj);
  ((Wrd88.pObj) [4]) = (Wrd168.Obj);
  Wrd103 = Wrd181;
  ((Wrd103.pObj) [2]) = (Wrd174.Obj);
  ((Wrd103.pObj) [3]) = (Wrd172.Obj);
  ((Wrd103.pObj) [4]) = (Wrd170.Obj);
  ((Wrd103.pObj) [5]) = (Wrd168.Obj);
  ((Wrd103.pObj) [6]) = (Wrd160.Obj);
  Wrd109 = Wrd183;
  ((Wrd109.pObj) [2]) = (Wrd32.Obj);
  ((Wrd109.pObj) [3]) = (Wrd160.Obj);
  ((Wrd185.pObj) [2]) = (Wrd164.Obj);
  ((Wrd187.pObj) [2]) = (Wrd164.Obj);
  ((Wrd189.pObj) [2]) = (Wrd166.Obj);
  ((Wrd191.pObj) [2]) = (Wrd166.Obj);
  ((Wrd193.pObj) [2]) = (Wrd172.Obj);
  ((Wrd195.pObj) [2]) = (Wrd174.Obj);
  ((Wrd197.pObj) [2]) = (Wrd176.Obj);
  ((Wrd199.pObj) [2]) = (Wrd178.Obj);
  ((Wrd201.pObj) [2]) = (Wrd182.Obj);
  ((Wrd203.pObj) [2]) = (Wrd180.Obj);
  ((Wrd205.pObj) [2]) = (Wrd184.Obj);
  Wrd148 = Wrd207;
  ((Wrd148.pObj) [2]) = (Wrd164.Obj);
  ((Wrd148.pObj) [3]) = (Wrd7.Obj);
  ((Wrd209.pObj) [2]) = (Wrd160.Obj);
  ((Wrd211.pObj) [2]) = (Wrd162.Obj);
  ((Wrd213.pObj) [2]) = (Wrd160.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_61]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd212.Obj);
  (* (--Rsp)) = (Wrd206.Obj);
  (* (--Rsp)) = (Wrd204.Obj);
  (* (--Rsp)) = (Wrd202.Obj);
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd198.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  (* (--Rsp)) = (Wrd194.Obj);
  (* (--Rsp)) = (Wrd210.Obj);
  (* (--Rsp)) = (Wrd214.Obj);
  (* (--Rsp)) = (Wrd192.Obj);
  (* (--Rsp)) = (Wrd190.Obj);
  (* (--Rsp)) = (Wrd188.Obj);
  (* (--Rsp)) = (Wrd186.Obj);
  (* (--Rsp)) = (Wrd208.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_62]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_62_61);
  (Wrd6.Obj) = (Rsp [28]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [30]));
  goto pop_return;

DEFLABEL (node_find_417)
DEFLABEL (node_find_12)
  INTERRUPT_CHECK (26, LABEL_62_59);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_11;

DEFLABEL (node_rank_416)
DEFLABEL (node_rank_30)
  INTERRUPT_CHECK (26, LABEL_62_57);
  (Wrd5.Obj) = (Rsp [2]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_62_0])))
    goto label_420;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_420)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_63]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_446;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_446;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_445)
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_62_63);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_423;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_422;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_422;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_421)
  (Rsp [2]) = (Wrd8.Obj);
  goto node_rank_30;

DEFLABEL (label_422)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_62_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_166]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_342)
  (Wrd8.Obj) = Rvl;
  goto label_421;

DEFLABEL (label_423)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_164]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_444;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd36.Lng))))
    goto label_444;
  (Wrd30.Obj) = ((Wrd34.pObj) [3]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_443)
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_62_164);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_434;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_207]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_433;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd19.Lng))))
    goto label_433;
  (Wrd11.Obj) = ((Wrd17.pObj) [2]);

DEFLABEL (label_432)
  if ((Wrd11.Obj) == (current_block [OBJECT_62_0]))
    goto label_431;
  (Wrd37.Obj) = (Rsp [3]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_430;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd36.Lng))))
    goto label_430;
  (Wrd28.Obj) = ((Wrd34.pObj) [2]);

DEFLABEL (label_429)
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_428;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [0]);
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd51.Lng))))
    goto label_428;
  (Wrd45.Obj) = ((Wrd49.pObj) [1]);

DEFLABEL (label_427)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_426)
  (Wrd59.Obj) = (Rsp [3]);
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd59.Obj));
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  (Wrd64.Lng) = ((Wrd60.Lng) + (Wrd61.Lng));
  (Wrd65.Lng) = ((Wrd64.Lng) + 1L);
  (Wrd63.Obj) = (LONG_TO_FIXNUM (Wrd65.Lng));
  (Rsp [3]) = (Wrd63.Obj);
  (Wrd75.Obj) = (Rsp [2]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if (! ((Wrd76.uLng) == 10))
    goto label_425;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd73.Obj) = ((Wrd72.pObj) [0]);
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd73.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd74.Lng))))
    goto label_425;
  (Wrd66.Obj) = ((Wrd72.pObj) [4]);

DEFLABEL (label_424)
  (Rsp [2]) = (Wrd66.Obj);
  goto node_rank_30;

DEFLABEL (label_425)
  (Wrd77.Obj) = (Rsp [2]);
  (Wrd78.Obj) = (current_block [OBJECT_62_4]);
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_214]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_367)
  (Wrd66.Obj) = Rvl;
  goto label_424;

DEFLABEL (label_428)
  (Wrd54.Obj) = (current_block [OBJECT_62_6]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_213]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_366)
  (Wrd45.Obj) = Rvl;
  goto label_427;

DEFLABEL (label_430)
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.Obj) = (current_block [OBJECT_62_3]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_212]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_365)
  (Wrd28.Obj) = Rvl;
  goto label_429;

DEFLABEL (label_431)
  (Wrd45.Obj) = (current_block [OBJECT_62_6]);
  goto label_427;

DEFLABEL (label_433)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_62_3]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_211]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_364)
  (Wrd11.Obj) = Rvl;
  goto label_432;

DEFLABEL (label_434)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_206]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd95.Obj) = (Rsp [3]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_442;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd94.Lng))))
    goto label_442;
  (Wrd86.Obj) = ((Wrd92.pObj) [2]);

DEFLABEL (label_441)
  if ((Wrd86.Obj) == (current_block [OBJECT_62_0]))
    goto label_440;
  (Wrd112.Obj) = (Rsp [3]);
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd112.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_439;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd110.Obj) = ((Wrd109.pObj) [0]);
  (Wrd111.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd111.Lng))))
    goto label_439;
  (Wrd103.Obj) = ((Wrd109.pObj) [2]);

DEFLABEL (label_438)
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_437;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd125.Obj) = ((Wrd124.pObj) [0]);
  (Wrd126.Lng) = (FIXNUM_TO_LONG (Wrd125.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd126.Lng))))
    goto label_437;
  (Wrd120.Obj) = ((Wrd124.pObj) [1]);

DEFLABEL (label_436)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_435)
  (Wrd134.Obj) = (Rsp [3]);
  (Wrd135.Lng) = (FIXNUM_TO_LONG (Wrd134.Obj));
  (Wrd136.Lng) = (FIXNUM_TO_LONG (Wrd120.Obj));
  (Wrd137.Lng) = ((Wrd135.Lng) + (Wrd136.Lng));
  Rvl = (LONG_TO_FIXNUM (Wrd137.Lng));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_437)
  (Wrd129.Obj) = (current_block [OBJECT_62_6]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_210]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_370)
  (Wrd120.Obj) = Rvl;
  goto label_436;

DEFLABEL (label_439)
  (Wrd114.Obj) = (Rsp [3]);
  (Wrd115.Obj) = (current_block [OBJECT_62_3]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_209]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_369)
  (Wrd103.Obj) = Rvl;
  goto label_438;

DEFLABEL (label_440)
  (Wrd120.Obj) = (current_block [OBJECT_62_6]);
  goto label_436;

DEFLABEL (label_442)
  (Wrd97.Obj) = (Rsp [3]);
  (Wrd98.Obj) = (current_block [OBJECT_62_3]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_208]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_368)
  (Wrd86.Obj) = Rvl;
  goto label_441;

DEFLABEL (label_444)
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.Obj) = (current_block [OBJECT_62_1]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_165]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_343)
  (* (--Rsp)) = Rvl;
  goto label_443;

DEFLABEL (label_446)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_62_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_64]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_277)
  (* (--Rsp)) = Rvl;
  goto label_445;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_62_207);
  (Wrd45.Obj) = Rvl;
  goto label_426;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_62_206);
  (Wrd120.Obj) = Rvl;
  goto label_435;

DEFLABEL (node_add_415)
DEFLABEL (node_add_48)
  INTERRUPT_CHECK (26, LABEL_62_55);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_447;
  (Wrd90.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd91.Obj) = (current_block [OBJECT_62_3]);
  (Wrd93.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd90.Obj);
  (* (Rhp++)) = (Wrd91.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd93.Obj);
  (Wrd87.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd84.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd84.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_447)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_465;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_465;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_464)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_463;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_463;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_462)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_461;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_461;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_460)
  (Wrd64.Obj) = (Rsp [4]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_459;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_459;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_458)
  Rdl = (& (Rsp [8]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_69]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [8]);
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [2]);
  (* (--Rsp)) = (Wrd80.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_62_69);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_448;
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_168]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd18.Obj);
  goto node_add_48;

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_62_168);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_448)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_167]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [8]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_62_167);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_449;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_219]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd17.Obj);
  goto node_add_48;

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_62_219);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_449)
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_216]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  if ((Wrd25.Obj) == (current_block [OBJECT_62_0]))
    goto label_457;
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_456;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd36.Lng))))
    goto label_456;
  (Wrd28.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_455)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_454)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_215]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [4]);
  if ((Wrd47.Obj) == (current_block [OBJECT_62_0]))
    goto label_453;
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd60.uLng) == 10))
    goto label_452;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [0]);
  (Wrd58.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd58.Lng))))
    goto label_452;
  (Wrd50.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_451)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_450)
  (Wrd66.Obj) = (* (Rsp++));
  (Wrd68.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  (Wrd72.Lng) = ((Wrd68.Lng) + (Wrd69.Lng));
  (Wrd73.Lng) = ((Wrd72.Lng) + 1L);
  (Wrd71.Obj) = (LONG_TO_FIXNUM (Wrd73.Lng));
  (Wrd82.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd83.Obj) = (Rsp [2]);
  (Wrd84.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd82.Obj);
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd83.Obj);
  (* (Rhp++)) = (Wrd84.Obj);
  (Wrd78.Obj) = (Rsp [3]);
  (Wrd79.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd78.Obj);
  (* (Rhp++)) = (Wrd79.Obj);
  (Wrd76.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd76.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_452)
  (Wrd61.Obj) = (Rsp [4]);
  (Wrd62.Obj) = (current_block [OBJECT_62_6]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_218]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_372)
  (Wrd50.Obj) = Rvl;
  goto label_451;

DEFLABEL (label_453)
  (Wrd50.Obj) = (current_block [OBJECT_62_6]);
  goto label_451;

DEFLABEL (label_456)
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.Obj) = (current_block [OBJECT_62_6]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_217]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_371)
  (Wrd28.Obj) = Rvl;
  goto label_455;

DEFLABEL (label_457)
  (Wrd87.Obj) = (current_block [OBJECT_62_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd87.Obj);
  goto label_454;

DEFLABEL (label_459)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.Obj) = (current_block [OBJECT_62_1]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_68]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_281)
  (* (--Rsp)) = Rvl;
  goto label_458;

DEFLABEL (label_461)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.Obj) = (current_block [OBJECT_62_5]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_67]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_280)
  (* (--Rsp)) = Rvl;
  goto label_460;

DEFLABEL (label_463)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.Obj) = (current_block [OBJECT_62_3]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_66]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_279)
  (* (--Rsp)) = Rvl;
  goto label_462;

DEFLABEL (label_465)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_62_4]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_65]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_278)
  (* (--Rsp)) = Rvl;
  goto label_464;

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_62_215);
  (Wrd50.Obj) = Rvl;
  goto label_450;

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_62_216);
  (* (--Rsp)) = Rvl;
  goto label_454;

DEFLABEL (node_delete_414)
DEFLABEL (node_delete_59)
  INTERRUPT_CHECK (26, LABEL_62_53);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_466;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_466)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_476;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_476;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_475)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_474;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_474;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_473)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_472;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_472;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_471)
  (Wrd64.Obj) = (Rsp [5]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_470;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_470;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_469)
  Rdl = (& (Rsp [7]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_74]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [8]);
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [2]);
  (* (--Rsp)) = (Wrd80.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_62_74);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_467;
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_170]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd17.Obj);
  goto node_delete_59;

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_62_170);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_467)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_169]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [8]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_62_169);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_468;
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_220]));

DEFLABEL (label_468)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_221]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_delete_59;

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_62_221);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_470)
  (Wrd66.Obj) = (Rsp [5]);
  (Wrd67.Obj) = (current_block [OBJECT_62_1]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_73]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_285)
  (* (--Rsp)) = Rvl;
  goto label_469;

DEFLABEL (label_472)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.Obj) = (current_block [OBJECT_62_5]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_72]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_284)
  (* (--Rsp)) = Rvl;
  goto label_471;

DEFLABEL (label_474)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.Obj) = (current_block [OBJECT_62_3]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_71]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_283)
  (* (--Rsp)) = Rvl;
  goto label_473;

DEFLABEL (label_476)
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (current_block [OBJECT_62_4]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_70]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_282)
  (* (--Rsp)) = Rvl;
  goto label_475;

DEFLABEL (node_concat_413)
DEFLABEL (node_concat_67)
  INTERRUPT_CHECK (26, LABEL_62_51);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_483;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_481;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_75]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_76]));

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_62_75);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_171]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_172]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_62_171);
  (Rsp [4]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_480;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd14.Lng))))
    goto label_480;
  (Wrd6.Obj) = ((Wrd12.pObj) [5]);

DEFLABEL (label_479)
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_478;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd30.Lng))))
    goto label_478;
  (Wrd22.Obj) = ((Wrd28.pObj) [3]);

DEFLABEL (label_477)
  (Rsp [1]) = (Wrd22.Obj);
  goto node_concat3_98;

DEFLABEL (label_478)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (current_block [OBJECT_62_1]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_223]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_374)
  (Wrd22.Obj) = Rvl;
  goto label_477;

DEFLABEL (label_480)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_5]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_222]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_373)
  (Wrd6.Obj) = Rvl;
  goto label_479;

DEFLABEL (label_481)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_482)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_483)
  Rvl = (Rsp [2]);
  goto label_482;

DEFLABEL (node_concat3_412)
DEFLABEL (node_concat3_98)
  INTERRUPT_CHECK (26, LABEL_62_49);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_520;
  (Wrd7.Obj) = (Rsp [4]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_518;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_80]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_517;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_516;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd23.Lng))))
    goto label_516;
  (Wrd15.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_515)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_514)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_79]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [5]);
  if ((Wrd34.Obj) == (current_block [OBJECT_62_0]))
    goto label_513;
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_512;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_512;
  (Wrd37.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_511)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_510)
  Rdl = (& (Rsp [7]));
  (Wrd55.Lng) = 5L;
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  (Wrd59.Lng) = ((Wrd55.Lng) * (Wrd57.Lng));
  (Wrd60.Obj) = (Rsp [1]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if ((Wrd59.Lng) < (Wrd61.Lng))
    goto label_501;
  (Wrd68.Lng) = ((Wrd55.Lng) * (Wrd61.Lng));
  if ((Wrd68.Lng) < (Wrd57.Lng))
    goto label_492;
  (Wrd71.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd73.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd74.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_78]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [4]);
  if ((Wrd78.Obj) == (current_block [OBJECT_62_0]))
    goto label_491;
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd91.uLng) == 10))
    goto label_490;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd88.Obj) = ((Wrd87.pObj) [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd89.Lng))))
    goto label_490;
  (Wrd81.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_489)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_488)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_77]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd100.Obj) = (Rsp [4]);
  if ((Wrd100.Obj) == (current_block [OBJECT_62_0]))
    goto label_487;
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_486;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd110.Obj) = ((Wrd109.pObj) [0]);
  (Wrd111.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd111.Lng))))
    goto label_486;
  (Wrd103.Obj) = ((Wrd109.pObj) [1]);

DEFLABEL (label_485)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_484)
  (Wrd119.Obj) = (* (Rsp++));
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd103.Obj));
  (Wrd122.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  (Wrd125.Lng) = ((Wrd121.Lng) + (Wrd122.Lng));
  (Wrd126.Lng) = ((Wrd125.Lng) + 1L);
  (Wrd124.Obj) = (LONG_TO_FIXNUM (Wrd126.Lng));
  (Wrd135.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd136.Obj) = (Rsp [2]);
  (Wrd137.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd135.Obj);
  (* (Rhp++)) = (Wrd124.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (* (Rhp++)) = (Wrd137.Obj);
  (Wrd131.Obj) = (Rsp [3]);
  (Wrd132.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd131.Obj);
  (* (Rhp++)) = (Wrd132.Obj);
  (Wrd129.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd129.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_486)
  (Wrd114.Obj) = (Rsp [4]);
  (Wrd115.Obj) = (current_block [OBJECT_62_6]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_94]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_289)
  (Wrd103.Obj) = Rvl;
  goto label_485;

DEFLABEL (label_487)
  (Wrd103.Obj) = (current_block [OBJECT_62_6]);
  goto label_485;

DEFLABEL (label_490)
  (Wrd92.Obj) = (Rsp [4]);
  (Wrd93.Obj) = (current_block [OBJECT_62_6]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_93]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_288)
  (Wrd81.Obj) = Rvl;
  goto label_489;

DEFLABEL (label_491)
  (Wrd140.Obj) = (current_block [OBJECT_62_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd140.Obj);
  goto label_488;

DEFLABEL (label_492)
  (Wrd150.Obj) = (Rsp [5]);
  (Wrd151.uLng) = (OBJECT_TYPE (Wrd150.Obj));
  if (! ((Wrd151.uLng) == 10))
    goto label_500;
  (Wrd147.pObj) = (OBJECT_ADDRESS (Wrd150.Obj));
  (Wrd148.Obj) = ((Wrd147.pObj) [0]);
  (Wrd149.Lng) = (FIXNUM_TO_LONG (Wrd148.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd149.Lng))))
    goto label_500;
  (Wrd143.Obj) = ((Wrd147.pObj) [5]);
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_499)
  (Wrd170.Obj) = (Rsp [6]);
  (Wrd171.uLng) = (OBJECT_TYPE (Wrd170.Obj));
  if (! ((Wrd171.uLng) == 10))
    goto label_498;
  (Wrd167.pObj) = (OBJECT_ADDRESS (Wrd170.Obj));
  (Wrd168.Obj) = ((Wrd167.pObj) [0]);
  (Wrd169.Lng) = (FIXNUM_TO_LONG (Wrd168.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd169.Lng))))
    goto label_498;
  (Wrd163.Obj) = ((Wrd167.pObj) [3]);
  (* (--Rsp)) = (Wrd163.Obj);

DEFLABEL (label_497)
  (Wrd190.Obj) = (Rsp [7]);
  (Wrd191.uLng) = (OBJECT_TYPE (Wrd190.Obj));
  if (! ((Wrd191.uLng) == 10))
    goto label_496;
  (Wrd187.pObj) = (OBJECT_ADDRESS (Wrd190.Obj));
  (Wrd188.Obj) = ((Wrd187.pObj) [0]);
  (Wrd189.Lng) = (FIXNUM_TO_LONG (Wrd188.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd189.Lng))))
    goto label_496;
  (Wrd181.Obj) = ((Wrd187.pObj) [2]);

DEFLABEL (label_495)
  (Rsp [2]) = (Wrd181.Obj);
  (Wrd210.Obj) = (Rsp [7]);
  (Wrd211.uLng) = (OBJECT_TYPE (Wrd210.Obj));
  if (! ((Wrd211.uLng) == 10))
    goto label_494;
  (Wrd207.pObj) = (OBJECT_ADDRESS (Wrd210.Obj));
  (Wrd208.Obj) = ((Wrd207.pObj) [0]);
  (Wrd209.Lng) = (FIXNUM_TO_LONG (Wrd208.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd209.Lng))))
    goto label_494;
  (Wrd201.Obj) = ((Wrd207.pObj) [4]);

DEFLABEL (label_493)
  (Rsp [3]) = (Wrd201.Obj);
  (Wrd222.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd222.Obj);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_92]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (Wrd226.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd226.Obj);
  (* (--Rsp)) = (Wrd201.Obj);
  (Wrd228.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd228.Obj);
  (Wrd229.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd229.Obj);
  (Wrd230.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd230.Obj);
  goto node_concat3_98;

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_62_92);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_494)
  (Wrd216.Obj) = (Rsp [7]);
  (Wrd217.Obj) = (current_block [OBJECT_62_4]);
  (Wrd215.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd215.Obj);
  (Wrd220.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_91]))));
  (* (--Rsp)) = (Wrd220.Obj);
  (* (--Rsp)) = (Wrd217.Obj);
  (* (--Rsp)) = (Wrd216.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_293)
  (Wrd212.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd212.Obj));
  (Wrd201.Obj) = Rvl;
  goto label_493;

DEFLABEL (label_496)
  (Wrd196.Obj) = (Rsp [7]);
  (Wrd197.Obj) = (current_block [OBJECT_62_3]);
  (Wrd195.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd200.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_90]))));
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd197.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_292)
  (Wrd192.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd192.Obj));
  (Wrd181.Obj) = Rvl;
  goto label_495;

DEFLABEL (label_498)
  (Wrd176.Obj) = (Rsp [6]);
  (Wrd177.Obj) = (current_block [OBJECT_62_1]);
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd175.Obj);
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_89]))));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd176.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_291)
  (Wrd172.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd172.Obj));
  (* (--Rsp)) = Rvl;
  goto label_497;

DEFLABEL (label_500)
  (Wrd156.Obj) = (Rsp [5]);
  (Wrd157.Obj) = (current_block [OBJECT_62_5]);
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd155.Obj);
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_88]))));
  (* (--Rsp)) = (Wrd160.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd156.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_290)
  (Wrd152.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd152.Obj));
  (* (--Rsp)) = Rvl;
  goto label_499;

DEFLABEL (label_501)
  (Wrd240.Obj) = (Rsp [6]);
  (Wrd241.uLng) = (OBJECT_TYPE (Wrd240.Obj));
  if (! ((Wrd241.uLng) == 10))
    goto label_509;
  (Wrd237.pObj) = (OBJECT_ADDRESS (Wrd240.Obj));
  (Wrd238.Obj) = ((Wrd237.pObj) [0]);
  (Wrd239.Lng) = (FIXNUM_TO_LONG (Wrd238.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd239.Lng))))
    goto label_509;
  (Wrd233.Obj) = ((Wrd237.pObj) [5]);
  (* (--Rsp)) = (Wrd233.Obj);

DEFLABEL (label_508)
  (Wrd260.Obj) = (Rsp [7]);
  (Wrd261.uLng) = (OBJECT_TYPE (Wrd260.Obj));
  if (! ((Wrd261.uLng) == 10))
    goto label_507;
  (Wrd257.pObj) = (OBJECT_ADDRESS (Wrd260.Obj));
  (Wrd258.Obj) = ((Wrd257.pObj) [0]);
  (Wrd259.Lng) = (FIXNUM_TO_LONG (Wrd258.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd259.Lng))))
    goto label_507;
  (Wrd253.Obj) = ((Wrd257.pObj) [3]);
  (* (--Rsp)) = (Wrd253.Obj);

DEFLABEL (label_506)
  (Wrd280.Obj) = (Rsp [8]);
  (Wrd281.uLng) = (OBJECT_TYPE (Wrd280.Obj));
  if (! ((Wrd281.uLng) == 10))
    goto label_505;
  (Wrd277.pObj) = (OBJECT_ADDRESS (Wrd280.Obj));
  (Wrd278.Obj) = ((Wrd277.pObj) [0]);
  (Wrd279.Lng) = (FIXNUM_TO_LONG (Wrd278.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd279.Lng))))
    goto label_505;
  (Wrd271.Obj) = ((Wrd277.pObj) [2]);

DEFLABEL (label_504)
  (Rsp [2]) = (Wrd271.Obj);
  (Wrd300.Obj) = (Rsp [8]);
  (Wrd301.uLng) = (OBJECT_TYPE (Wrd300.Obj));
  if (! ((Wrd301.uLng) == 10))
    goto label_503;
  (Wrd297.pObj) = (OBJECT_ADDRESS (Wrd300.Obj));
  (Wrd298.Obj) = ((Wrd297.pObj) [0]);
  (Wrd299.Lng) = (FIXNUM_TO_LONG (Wrd298.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd299.Lng))))
    goto label_503;
  (Wrd291.Obj) = ((Wrd297.pObj) [4]);

DEFLABEL (label_502)
  (Rsp [3]) = (Wrd291.Obj);
  (* (--Rsp)) = (Wrd291.Obj);
  (Wrd313.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd313.Obj);
  (Wrd316.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_87]))));
  (* (--Rsp)) = (Wrd316.Obj);
  (Wrd317.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd318.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd318.Obj);
  (Wrd319.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd319.Obj);
  (Wrd320.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd320.Obj);
  (Wrd321.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd321.Obj);
  goto node_concat3_98;

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_62_87);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_173]));

DEFLABEL (label_503)
  (Wrd306.Obj) = (Rsp [8]);
  (Wrd307.Obj) = (current_block [OBJECT_62_4]);
  (Wrd305.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd305.Obj);
  (Wrd310.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_86]))));
  (* (--Rsp)) = (Wrd310.Obj);
  (* (--Rsp)) = (Wrd307.Obj);
  (* (--Rsp)) = (Wrd306.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_297)
  (Wrd302.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd302.Obj));
  (Wrd291.Obj) = Rvl;
  goto label_502;

DEFLABEL (label_505)
  (Wrd286.Obj) = (Rsp [8]);
  (Wrd287.Obj) = (current_block [OBJECT_62_3]);
  (Wrd285.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd285.Obj);
  (Wrd290.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_85]))));
  (* (--Rsp)) = (Wrd290.Obj);
  (* (--Rsp)) = (Wrd287.Obj);
  (* (--Rsp)) = (Wrd286.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_296)
  (Wrd282.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd282.Obj));
  (Wrd271.Obj) = Rvl;
  goto label_504;

DEFLABEL (label_507)
  (Wrd266.Obj) = (Rsp [7]);
  (Wrd267.Obj) = (current_block [OBJECT_62_1]);
  (Wrd265.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd265.Obj);
  (Wrd270.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_84]))));
  (* (--Rsp)) = (Wrd270.Obj);
  (* (--Rsp)) = (Wrd267.Obj);
  (* (--Rsp)) = (Wrd266.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_295)
  (Wrd262.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd262.Obj));
  (* (--Rsp)) = Rvl;
  goto label_506;

DEFLABEL (label_509)
  (Wrd246.Obj) = (Rsp [6]);
  (Wrd247.Obj) = (current_block [OBJECT_62_5]);
  (Wrd245.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd245.Obj);
  (Wrd250.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_83]))));
  (* (--Rsp)) = (Wrd250.Obj);
  (* (--Rsp)) = (Wrd247.Obj);
  (* (--Rsp)) = (Wrd246.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_294)
  (Wrd242.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd242.Obj));
  (* (--Rsp)) = Rvl;
  goto label_508;

DEFLABEL (label_512)
  (Wrd48.Obj) = (Rsp [5]);
  (Wrd49.Obj) = (current_block [OBJECT_62_6]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_82]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_287)
  (Wrd37.Obj) = Rvl;
  goto label_511;

DEFLABEL (label_513)
  (Wrd324.Obj) = (current_block [OBJECT_62_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd324.Obj);
  goto label_510;

DEFLABEL (label_516)
  (Wrd26.Obj) = (Rsp [5]);
  (Wrd27.Obj) = (current_block [OBJECT_62_6]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_81]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_286)
  (Wrd15.Obj) = Rvl;
  goto label_515;

DEFLABEL (label_517)
  (Wrd326.Obj) = (current_block [OBJECT_62_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd326.Obj);
  goto label_514;

DEFLABEL (label_518)
  (Wrd327.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd327.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd329.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd329.Obj);
  (Wrd331.Obj) = (Rsp [0]);
  (Wrd332.pObj) = (OBJECT_ADDRESS (Wrd331.Obj));
  (Wrd330.Obj) = ((Wrd332.pObj) [2]);
  (Rsp [1]) = (Wrd330.Obj);

DEFLABEL (label_519)
  Rsp = (& (Rsp [1]));
  goto node_add_48;

DEFLABEL (label_520)
  (Wrd334.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd334.Obj);
  (Wrd335.Obj) = (Rsp [4]);
  (Wrd336.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd336.Obj);
  (Wrd338.Obj) = (Rsp [0]);
  (Wrd339.pObj) = (OBJECT_ADDRESS (Wrd338.Obj));
  (Wrd337.Obj) = ((Wrd339.pObj) [2]);
  (Rsp [1]) = (Wrd337.Obj);
  (Rsp [2]) = (Wrd335.Obj);
  goto label_519;

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_62_77);
  (Wrd103.Obj) = Rvl;
  goto label_484;

DEFLABEL (continuation_81)
  INTERRUPT_CHECK (27, LABEL_62_78);
  (* (--Rsp)) = Rvl;
  goto label_488;

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_62_79);
  (* (--Rsp)) = Rvl;
  goto label_510;

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_62_80);
  (* (--Rsp)) = Rvl;
  goto label_514;

DEFLABEL (node_split_lt_411)
DEFLABEL (node_split_lt_110)
  INTERRUPT_CHECK (26, LABEL_62_47);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_521;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_521)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_95]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_539;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_539;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_538)
  (Wrd26.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_62_95);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_524;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_523;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_523;
  (Wrd8.Obj) = ((Wrd14.pObj) [2]);

DEFLABEL (label_522)
  (Rsp [1]) = (Wrd8.Obj);
  goto node_split_lt_110;

DEFLABEL (label_523)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_62_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_176]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_344)
  (Wrd8.Obj) = Rvl;
  goto label_522;

DEFLABEL (label_524)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_174]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd37.Obj) = (Rsp [3]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_537;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd36.Lng))))
    goto label_537;
  (Wrd30.Obj) = ((Wrd34.pObj) [3]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_536)
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_62_174);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_533;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_532;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_532;
  (Wrd9.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_531)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_225]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd39.Obj) = (Rsp [5]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_530;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd38.Lng))))
    goto label_530;
  (Wrd32.Obj) = ((Wrd36.pObj) [4]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_529)
  (Wrd46.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd46.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_62_225);
  (Rsp [4]) = Rvl;
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_528;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd14.Lng))))
    goto label_528;
  (Wrd6.Obj) = ((Wrd12.pObj) [5]);

DEFLABEL (label_527)
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_526;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd30.Lng))))
    goto label_526;
  (Wrd22.Obj) = ((Wrd28.pObj) [2]);

DEFLABEL (label_525)
  (Rsp [3]) = (Wrd22.Obj);
  goto node_concat3_98;

DEFLABEL (label_526)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.Obj) = (current_block [OBJECT_62_3]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_241]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_383)
  (Wrd22.Obj) = Rvl;
  goto label_525;

DEFLABEL (label_528)
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.Obj) = (current_block [OBJECT_62_5]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_240]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_382)
  (Wrd6.Obj) = Rvl;
  goto label_527;

DEFLABEL (label_530)
  (Wrd41.Obj) = (Rsp [5]);
  (Wrd42.Obj) = (current_block [OBJECT_62_4]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_226]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_376)
  (* (--Rsp)) = Rvl;
  goto label_529;

DEFLABEL (label_532)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_62_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_224]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_375)
  (* (--Rsp)) = Rvl;
  goto label_531;

DEFLABEL (label_533)
  (Wrd47.Obj) = (current_block [OBJECT_62_3]);
  (Rsp [2]) = (Wrd47.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if ((Wrd59.uLng) == 10)
    goto label_535;

DEFLABEL (label_534)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_535)
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd57.Lng))))
    goto label_534;
  Rvl = ((Wrd55.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_537)
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.Obj) = (current_block [OBJECT_62_1]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_175]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_345)
  (* (--Rsp)) = Rvl;
  goto label_536;

DEFLABEL (label_539)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_62_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_96]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_298)
  (* (--Rsp)) = Rvl;
  goto label_538;

DEFLABEL (node_split_gt_410)
DEFLABEL (node_split_gt_122)
  INTERRUPT_CHECK (26, LABEL_62_45);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_540;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_540)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_97]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_558;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_558;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_557)
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_113)
  INTERRUPT_CHECK (27, LABEL_62_97);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_543;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_542;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_542;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_541)
  (Rsp [1]) = (Wrd8.Obj);
  goto node_split_gt_122;

DEFLABEL (label_542)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_62_4]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_179]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_346)
  (Wrd8.Obj) = Rvl;
  goto label_541;

DEFLABEL (label_543)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_177]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_556;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd35.Lng))))
    goto label_556;
  (Wrd29.Obj) = ((Wrd33.pObj) [3]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_555)
  (Wrd43.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_62_177);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_552;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_551;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_551;
  (Wrd9.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_550)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_228]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd39.Obj) = (Rsp [5]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_549;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd38.Lng))))
    goto label_549;
  (Wrd32.Obj) = ((Wrd36.pObj) [2]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_548)
  (Wrd46.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd46.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_119)
  INTERRUPT_CHECK (27, LABEL_62_228);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_547;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_547;
  (Wrd5.Obj) = ((Wrd11.pObj) [5]);

DEFLABEL (label_546)
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_545;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd29.Lng))))
    goto label_545;
  (Wrd21.Obj) = ((Wrd27.pObj) [4]);

DEFLABEL (label_544)
  (Rsp [5]) = (Wrd21.Obj);
  (Wrd37.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd37.Obj);
  goto node_concat3_98;

DEFLABEL (label_545)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (current_block [OBJECT_62_4]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_243]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_385)
  (Wrd21.Obj) = Rvl;
  goto label_544;

DEFLABEL (label_547)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_62_5]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_242]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_384)
  (Wrd5.Obj) = Rvl;
  goto label_546;

DEFLABEL (label_549)
  (Wrd41.Obj) = (Rsp [5]);
  (Wrd42.Obj) = (current_block [OBJECT_62_3]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_229]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_378)
  (* (--Rsp)) = Rvl;
  goto label_548;

DEFLABEL (label_551)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_62_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_227]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_377)
  (* (--Rsp)) = Rvl;
  goto label_550;

DEFLABEL (label_552)
  (Wrd47.Obj) = (current_block [OBJECT_62_4]);
  (Rsp [2]) = (Wrd47.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if ((Wrd59.uLng) == 10)
    goto label_554;

DEFLABEL (label_553)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_554)
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd57.Lng))))
    goto label_553;
  Rvl = ((Wrd55.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_556)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.Obj) = (current_block [OBJECT_62_1]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_178]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_347)
  (* (--Rsp)) = Rvl;
  goto label_555;

DEFLABEL (label_558)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_62_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_98]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_299)
  (* (--Rsp)) = Rvl;
  goto label_557;

DEFLABEL (node_union_409)
DEFLABEL (node_union_135)
  INTERRUPT_CHECK (26, LABEL_62_43);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_569;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_567;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_566;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_566;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_565)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_564;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_564;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_563)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_562;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_562;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_561)
  (Wrd66.Obj) = (Rsp [5]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_560;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_560;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_559)
  Rdl = (& (Rsp [7]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_103]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd80.Obj) = (Rsp [8]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [2]);
  (* (--Rsp)) = (Wrd82.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_130)
  INTERRUPT_CHECK (27, LABEL_62_103);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_180]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_129)
  INTERRUPT_CHECK (27, LABEL_62_180);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_230]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_union_135;

DEFLABEL (continuation_132)
  INTERRUPT_CHECK (27, LABEL_62_230);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_244]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_union_135;

DEFLABEL (continuation_131)
  INTERRUPT_CHECK (27, LABEL_62_244);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [10]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [5]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_98;

DEFLABEL (label_560)
  (Wrd68.Obj) = (Rsp [5]);
  (Wrd69.Obj) = (current_block [OBJECT_62_1]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_102]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_303)
  (* (--Rsp)) = Rvl;
  goto label_559;

DEFLABEL (label_562)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.Obj) = (current_block [OBJECT_62_5]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_101]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_302)
  (* (--Rsp)) = Rvl;
  goto label_561;

DEFLABEL (label_564)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_62_3]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_100]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_301)
  (* (--Rsp)) = Rvl;
  goto label_563;

DEFLABEL (label_566)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_62_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_99]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_300)
  (* (--Rsp)) = Rvl;
  goto label_565;

DEFLABEL (label_567)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_568)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_569)
  Rvl = (Rsp [2]);
  goto label_568;

DEFLABEL (node_union_merge_408)
DEFLABEL (node_union_merge_154)
  INTERRUPT_CHECK (26, LABEL_62_41);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_584;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_582;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_581;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_581;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_580)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_579;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_579;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_578)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_577;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_577;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_576)
  (Wrd66.Obj) = (Rsp [5]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_575;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_575;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_574)
  Rdl = (& (Rsp [8]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_108]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd80.Obj) = (Rsp [8]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [5]);
  (* (--Rsp)) = (Wrd82.Obj);
  goto node_find_12;

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_62_108);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_181]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_143)
  INTERRUPT_CHECK (27, LABEL_62_181);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_231]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [10]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_144)
  INTERRUPT_CHECK (27, LABEL_62_231);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_245]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_573;
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_572;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd22.Lng))))
    goto label_572;
  (Wrd16.Obj) = ((Wrd20.pObj) [5]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_571)
  (Wrd34.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [15]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (continuation_145)
  INTERRUPT_CHECK (27, LABEL_62_245);
  (Wrd50.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd50.Obj));
  (* (--Rsp)) = Rvl;

DEFLABEL (label_570)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_246]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [13]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [13]);
  (* (--Rsp)) = (Wrd49.Obj);
  goto node_union_merge_154;

DEFLABEL (continuation_148)
  INTERRUPT_CHECK (27, LABEL_62_246);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_253]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [14]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [14]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_union_merge_154;

DEFLABEL (continuation_147)
  INTERRUPT_CHECK (27, LABEL_62_253);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [12]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [5]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_98;

DEFLABEL (label_572)
  (Wrd29.Obj) = (Rsp [4]);
  (Wrd30.Obj) = (current_block [OBJECT_62_5]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_247]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_386)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_571;

DEFLABEL (label_573)
  (Wrd40.Obj) = (Rsp [6]);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_570;

DEFLABEL (label_575)
  (Wrd68.Obj) = (Rsp [5]);
  (Wrd69.Obj) = (current_block [OBJECT_62_1]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_107]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_307)
  (* (--Rsp)) = Rvl;
  goto label_574;

DEFLABEL (label_577)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.Obj) = (current_block [OBJECT_62_5]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_106]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_306)
  (* (--Rsp)) = Rvl;
  goto label_576;

DEFLABEL (label_579)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_62_3]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_105]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_305)
  (* (--Rsp)) = Rvl;
  goto label_578;

DEFLABEL (label_581)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_62_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_104]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_304)
  (* (--Rsp)) = Rvl;
  goto label_580;

DEFLABEL (label_582)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_583)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_584)
  Rvl = (Rsp [2]);
  goto label_583;

DEFLABEL (node_difference_407)
DEFLABEL (node_difference_167)
  INTERRUPT_CHECK (26, LABEL_62_39);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_593;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_591;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_590;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_590;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_589)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_588;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_588;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_587)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_586;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_586;
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_585)
  Rdl = (& (Rsp [6]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_112]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd62.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd64.Obj) = (Rsp [7]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [2]);
  (* (--Rsp)) = (Wrd66.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_62_112);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_182]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_161)
  INTERRUPT_CHECK (27, LABEL_62_182);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_232]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_difference_167;

DEFLABEL (continuation_164)
  INTERRUPT_CHECK (27, LABEL_62_232);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_248]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_difference_167;

DEFLABEL (continuation_163)
  INTERRUPT_CHECK (27, LABEL_62_248);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_67;

DEFLABEL (label_586)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.Obj) = (current_block [OBJECT_62_1]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_111]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_310)
  (* (--Rsp)) = Rvl;
  goto label_585;

DEFLABEL (label_588)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_62_3]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_110]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_309)
  (* (--Rsp)) = Rvl;
  goto label_587;

DEFLABEL (label_590)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_62_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_109]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_308)
  (* (--Rsp)) = Rvl;
  goto label_589;

DEFLABEL (label_591)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_592)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_593)
  Rvl = (Wrd6.Obj);
  goto label_592;

DEFLABEL (node_intersection_406)
DEFLABEL (node_intersection_183)
  INTERRUPT_CHECK (26, LABEL_62_37);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_595;

DEFLABEL (label_594)
  Rvl = (current_block [OBJECT_62_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_595)
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_594;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_606;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_606;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_605)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_604;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_604;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_603)
  (Wrd50.Obj) = (Rsp [4]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_602;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_602;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_601)
  (Wrd66.Obj) = (Rsp [5]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_600;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_600;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_599)
  Rdl = (& (Rsp [7]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_117]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd80.Obj) = (Rsp [8]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [2]);
  (* (--Rsp)) = (Wrd82.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_175)
  INTERRUPT_CHECK (27, LABEL_62_117);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_183]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_174)
  INTERRUPT_CHECK (27, LABEL_62_183);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_233]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [10]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_find_12;

DEFLABEL (continuation_176)
  INTERRUPT_CHECK (27, LABEL_62_233);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_597;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_250]))));
  (* (--Rsp)) = (Wrd13.Obj);
  goto label_596;

DEFLABEL (label_597)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_249]))));
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_596)
DEFLABEL (label_598)
  (Wrd22.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_intersection_183;

DEFLABEL (label_600)
  (Wrd68.Obj) = (Rsp [5]);
  (Wrd69.Obj) = (current_block [OBJECT_62_1]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_116]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_314)
  (* (--Rsp)) = Rvl;
  goto label_599;

DEFLABEL (label_602)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.Obj) = (current_block [OBJECT_62_5]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_115]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_313)
  (* (--Rsp)) = Rvl;
  goto label_601;

DEFLABEL (label_604)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_62_3]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_114]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_312)
  (* (--Rsp)) = Rvl;
  goto label_603;

DEFLABEL (label_606)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_62_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_113]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_311)
  (* (--Rsp)) = Rvl;
  goto label_605;

DEFLABEL (continuation_180)
  INTERRUPT_CHECK (27, LABEL_62_250);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_254]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_intersection_183;

DEFLABEL (continuation_179)
  INTERRUPT_CHECK (27, LABEL_62_254);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [10]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [5]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_98;

DEFLABEL (continuation_178)
  INTERRUPT_CHECK (27, LABEL_62_249);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_255]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_intersection_183;

DEFLABEL (continuation_177)
  INTERRUPT_CHECK (27, LABEL_62_255);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [8]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_67;

DEFLABEL (node_subsetP_405)
DEFLABEL (node_subsetP_208)
  INTERRUPT_CHECK (26, LABEL_62_35);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_638;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_119]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  if ((Wrd10.Obj) == (Wrd6.Obj))
    goto label_637;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_636;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_636;
  (Wrd13.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_635)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_634)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_118]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [3]);
  if ((Wrd32.Obj) == (current_block [OBJECT_62_0]))
    goto label_633;
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_632;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd43.Lng))))
    goto label_632;
  (Wrd35.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_631)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_630)
  (Wrd51.Obj) = (* (Rsp++));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if ((Wrd52.Lng) > (Wrd53.Lng))
    goto label_628;
  (Wrd63.Obj) = (Rsp [1]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_627;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd62.Lng))))
    goto label_627;
  (Wrd56.Obj) = ((Wrd60.pObj) [4]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_626)
  (Wrd79.Obj) = (Rsp [2]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd80.uLng) == 10))
    goto label_625;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd78.Lng))))
    goto label_625;
  (Wrd72.Obj) = ((Wrd76.pObj) [2]);
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_624)
  (Wrd95.Obj) = (Rsp [3]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_623;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd94.Lng))))
    goto label_623;
  (Wrd88.Obj) = ((Wrd92.pObj) [3]);
  (* (--Rsp)) = (Wrd88.Obj);

DEFLABEL (label_622)
  Rdl = (& (Rsp [6]));
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_125]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd116.Obj) = (Rsp [7]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if (! ((Wrd117.uLng) == 10))
    goto label_621;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd116.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd115.Lng))))
    goto label_621;
  (Wrd109.Obj) = ((Wrd113.pObj) [3]);
  (* (--Rsp)) = (Wrd109.Obj);

DEFLABEL (label_620)
  (Wrd127.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd127.Obj);
  (Wrd128.Obj) = (Rsp [7]);
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd130.Obj) = ((Wrd129.pObj) [2]);
  (* (--Rsp)) = (Wrd130.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_195)
  INTERRUPT_CHECK (27, LABEL_62_125);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_611;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_186]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [7]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_610;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_610;
  (Wrd16.Obj) = ((Wrd20.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_609)
  (Wrd34.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd35.Obj);
  goto node_subsetP_208;

DEFLABEL (continuation_205)
  INTERRUPT_CHECK (27, LABEL_62_186);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_607;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_607)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_234]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [7]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  goto node_find_12;

DEFLABEL (continuation_206)
  INTERRUPT_CHECK (27, LABEL_62_234);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_608;
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_208;

DEFLABEL (label_608)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_610)
  (Wrd29.Obj) = (Rsp [7]);
  (Wrd30.Obj) = (current_block [OBJECT_62_3]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_187]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_348)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_609;

DEFLABEL (label_611)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_184]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd51.Obj) = (Rsp [8]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_619;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd50.Lng))))
    goto label_619;
  (Wrd44.Obj) = ((Wrd48.pObj) [3]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_618)
  (Wrd62.Obj) = (Rsp [7]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [2]);
  (* (--Rsp)) = (Wrd64.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_197)
  INTERRUPT_CHECK (27, LABEL_62_184);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_615;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_237]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [7]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_614;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_614;
  (Wrd16.Obj) = ((Wrd20.pObj) [4]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_613)
  (Wrd34.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_612)
  (Wrd62.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd62.Obj);
  goto node_subsetP_208;

DEFLABEL (label_614)
  (Wrd29.Obj) = (Rsp [7]);
  (Wrd30.Obj) = (current_block [OBJECT_62_4]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_238]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_379)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_613;

DEFLABEL (label_615)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_235]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd50.Obj) = (Rsp [7]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_617;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd49.Lng))))
    goto label_617;
  (Wrd43.Obj) = ((Wrd47.pObj) [2]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_616)
  (Wrd61.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd61.Obj);
  goto label_612;

DEFLABEL (label_617)
  (Wrd56.Obj) = (Rsp [7]);
  (Wrd57.Obj) = (current_block [OBJECT_62_3]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_236]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_380)
  (Wrd52.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd52.Obj));
  (* (--Rsp)) = Rvl;
  goto label_616;

DEFLABEL (label_619)
  (Wrd57.Obj) = (Rsp [8]);
  (Wrd58.Obj) = (current_block [OBJECT_62_1]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_185]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_349)
  (Wrd53.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd53.Obj));
  (* (--Rsp)) = Rvl;
  goto label_618;

DEFLABEL (label_621)
  (Wrd122.Obj) = (Rsp [7]);
  (Wrd123.Obj) = (current_block [OBJECT_62_1]);
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_126]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_320)
  (Wrd118.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd118.Obj));
  (* (--Rsp)) = Rvl;
  goto label_620;

DEFLABEL (label_623)
  (Wrd97.Obj) = (Rsp [3]);
  (Wrd98.Obj) = (current_block [OBJECT_62_1]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_124]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_319)
  (* (--Rsp)) = Rvl;
  goto label_622;

DEFLABEL (label_625)
  (Wrd81.Obj) = (Rsp [2]);
  (Wrd82.Obj) = (current_block [OBJECT_62_3]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_123]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_318)
  (* (--Rsp)) = Rvl;
  goto label_624;

DEFLABEL (label_627)
  (Wrd65.Obj) = (Rsp [1]);
  (Wrd66.Obj) = (current_block [OBJECT_62_4]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_122]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_317)
  (* (--Rsp)) = Rvl;
  goto label_626;

DEFLABEL (label_628)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_629)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_632)
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.Obj) = (current_block [OBJECT_62_6]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_121]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_316)
  (Wrd35.Obj) = Rvl;
  goto label_631;

DEFLABEL (label_633)
  (Wrd35.Obj) = (current_block [OBJECT_62_6]);
  goto label_631;

DEFLABEL (label_636)
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.Obj) = (current_block [OBJECT_62_6]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_120]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_315)
  (Wrd13.Obj) = Rvl;
  goto label_635;

DEFLABEL (label_637)
  (Wrd136.Obj) = (current_block [OBJECT_62_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd136.Obj);
  goto label_634;

DEFLABEL (label_638)
  Rvl = (current_block [OBJECT_62_7]);
  goto label_629;

DEFLABEL (continuation_202)
  INTERRUPT_CHECK (27, LABEL_62_237);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_639;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_639)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_251]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [7]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  goto node_find_12;

DEFLABEL (continuation_203)
  INTERRUPT_CHECK (27, LABEL_62_251);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_640;
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_208;

DEFLABEL (label_640)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (continuation_199)
  INTERRUPT_CHECK (27, LABEL_62_235);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_641;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_641)
  (Wrd18.Obj) = (Rsp [5]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_643;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_643;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_642)
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_208;

DEFLABEL (label_643)
  (Wrd24.Obj) = (Rsp [5]);
  (Wrd25.Obj) = (current_block [OBJECT_62_4]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_252]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_387)
  (Wrd20.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd20.Obj));
  (* (--Rsp)) = Rvl;
  goto label_642;

DEFLABEL (continuation_186)
  INTERRUPT_CHECK (27, LABEL_62_118);
  (Wrd35.Obj) = Rvl;
  goto label_630;

DEFLABEL (continuation_188)
  INTERRUPT_CHECK (27, LABEL_62_119);
  (* (--Rsp)) = Rvl;
  goto label_634;

DEFLABEL (tree_map_add_404)
  CLOSURE_HEADER (LABEL_62_33);

DEFLABEL (tree_map_add_212)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_127]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_647;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_647;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_646)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  goto node_add_48;

DEFLABEL (continuation_211)
  INTERRUPT_CHECK (27, LABEL_62_127);
  (Rsp [3]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_645;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_645;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_644)
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_645)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_188]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_350)
  (Wrd6.Obj) = Rvl;
  goto label_644;

DEFLABEL (label_647)
  (Wrd21.Obj) = (Rsp [4]);
  (Wrd22.Obj) = (current_block [OBJECT_62_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_128]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_321)
  (* (--Rsp)) = Rvl;
  goto label_646;

DEFLABEL (tree_insertB_403)
  CLOSURE_HEADER (LABEL_62_31);

DEFLABEL (tree_insertB_215)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_129]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_651;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_651;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_650)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  goto node_add_48;

DEFLABEL (continuation_214)
  INTERRUPT_CHECK (27, LABEL_62_129);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_62_1]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_649;

DEFLABEL (label_648)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_10]), 3);

DEFLABEL (label_649)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_648;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_62_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_651)
  (Wrd21.Obj) = (Rsp [4]);
  (Wrd22.Obj) = (current_block [OBJECT_62_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_130]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_322)
  (* (--Rsp)) = Rvl;
  goto label_650;

DEFLABEL (tree_delete_402)
  CLOSURE_HEADER (LABEL_62_29);

DEFLABEL (tree_delete_219)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_131]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_655;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_655;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_654)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_delete_59;

DEFLABEL (continuation_218)
  INTERRUPT_CHECK (27, LABEL_62_131);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_653;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_653;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_652)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_653)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_190]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_351)
  (Wrd6.Obj) = Rvl;
  goto label_652;

DEFLABEL (label_655)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_132]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_323)
  (* (--Rsp)) = Rvl;
  goto label_654;

DEFLABEL (tree_deleteB_401)
  CLOSURE_HEADER (LABEL_62_27);

DEFLABEL (tree_deleteB_222)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_133]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_659;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_659;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_658)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_delete_59;

DEFLABEL (continuation_221)
  INTERRUPT_CHECK (27, LABEL_62_133);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_62_1]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd20.uLng) == 62)
    goto label_657;

DEFLABEL (label_656)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_10]), 3);

DEFLABEL (label_657)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_656;
  ((Wrd16.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_62_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_659)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_134]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_324)
  (* (--Rsp)) = Rvl;
  goto label_658;

DEFLABEL (tree_split_lt_400)
  CLOSURE_HEADER (LABEL_62_25);

DEFLABEL (tree_split_lt_226)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_135]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_663;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_663;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_662)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_split_lt_110;

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_62_135);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_661;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_661;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_660)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_661)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_191]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_352)
  (Wrd6.Obj) = Rvl;
  goto label_660;

DEFLABEL (label_663)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_62_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_136]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_325)
  (* (--Rsp)) = Rvl;
  goto label_662;

DEFLABEL (tree_split_gt_399)
  CLOSURE_HEADER (LABEL_62_23);

DEFLABEL (tree_split_gt_230)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_137]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_667;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_667;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_666)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_split_gt_122;

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_62_137);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_665;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_665;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_664)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_665)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_192]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_353)
  (Wrd6.Obj) = Rvl;
  goto label_664;

DEFLABEL (label_667)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_62_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_138]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_326)
  (* (--Rsp)) = Rvl;
  goto label_666;

DEFLABEL (tree_union_398)
  CLOSURE_HEADER (LABEL_62_21);

DEFLABEL (tree_union_235)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_139]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_673;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_673;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_672)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_671;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_671;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_670)
  (Wrd40.Obj) = (Rsp [3]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  goto node_union_135;

DEFLABEL (continuation_234)
  INTERRUPT_CHECK (27, LABEL_62_139);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_669;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_669;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_668)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_669)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_193]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_354)
  (Wrd6.Obj) = Rvl;
  goto label_668;

DEFLABEL (label_671)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_62_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_141]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_328)
  (* (--Rsp)) = Rvl;
  goto label_670;

DEFLABEL (label_673)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_140]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_327)
  (* (--Rsp)) = Rvl;
  goto label_672;

DEFLABEL (tree_union_merge_397)
  CLOSURE_HEADER (LABEL_62_19);

DEFLABEL (tree_union_merge_240)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_142]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_679;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_679;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_678)
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 62))
    goto label_677;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd33.Lng))))
    goto label_677;
  (Wrd27.Obj) = ((Wrd31.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_676)
  (Wrd41.Obj) = (Rsp [4]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [2]);
  (* (--Rsp)) = (Wrd43.Obj);
  goto node_union_merge_154;

DEFLABEL (continuation_239)
  INTERRUPT_CHECK (27, LABEL_62_142);
  (Rsp [3]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_675;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_675;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_674)
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_675)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_194]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_355)
  (Wrd6.Obj) = Rvl;
  goto label_674;

DEFLABEL (label_677)
  (Wrd36.Obj) = (Rsp [4]);
  (Wrd37.Obj) = (current_block [OBJECT_62_1]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_144]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_330)
  (* (--Rsp)) = Rvl;
  goto label_676;

DEFLABEL (label_679)
  (Wrd20.Obj) = (Rsp [4]);
  (Wrd21.Obj) = (current_block [OBJECT_62_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_143]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_329)
  (* (--Rsp)) = Rvl;
  goto label_678;

DEFLABEL (tree_intersection_396)
  CLOSURE_HEADER (LABEL_62_17);

DEFLABEL (tree_intersection_245)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_145]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_685;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_685;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_684)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_683;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_683;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_682)
  (Wrd40.Obj) = (Rsp [3]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  goto node_intersection_183;

DEFLABEL (continuation_244)
  INTERRUPT_CHECK (27, LABEL_62_145);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_681;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_681;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_680)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_681)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_195]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_356)
  (Wrd6.Obj) = Rvl;
  goto label_680;

DEFLABEL (label_683)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_62_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_147]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_332)
  (* (--Rsp)) = Rvl;
  goto label_682;

DEFLABEL (label_685)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_146]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_331)
  (* (--Rsp)) = Rvl;
  goto label_684;

DEFLABEL (tree_difference_395)
  CLOSURE_HEADER (LABEL_62_15);

DEFLABEL (tree_difference_250)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_148]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_691;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_691;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_690)
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_689;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_689;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_688)
  (Wrd40.Obj) = (Rsp [3]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  goto node_difference_167;

DEFLABEL (continuation_249)
  INTERRUPT_CHECK (27, LABEL_62_148);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_687;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_687;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_686)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (label_687)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_62_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_196]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_357)
  (Wrd6.Obj) = Rvl;
  goto label_686;

DEFLABEL (label_689)
  (Wrd35.Obj) = (Rsp [3]);
  (Wrd36.Obj) = (current_block [OBJECT_62_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_150]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_334)
  (* (--Rsp)) = Rvl;
  goto label_688;

DEFLABEL (label_691)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_149]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_333)
  (* (--Rsp)) = Rvl;
  goto label_690;

DEFLABEL (tree_subsetP_394)
  CLOSURE_HEADER (LABEL_62_13);

DEFLABEL (tree_subsetP_253)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_695;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_695;
  (Wrd8.Obj) = ((Wrd14.pObj) [3]);

DEFLABEL (label_694)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_693;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_693;
  (Wrd24.Obj) = ((Wrd30.pObj) [3]);

DEFLABEL (label_692)
  (Rsp [2]) = (Wrd24.Obj);
  goto node_subsetP_208;

DEFLABEL (label_693)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_62_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_152]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_336)
  (Wrd24.Obj) = Rvl;
  goto label_692;

DEFLABEL (label_695)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_151]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_335)
  (Wrd8.Obj) = Rvl;
  goto label_694;

DEFLABEL (alist__tree_393)
  CLOSURE_HEADER (LABEL_62_11);

DEFLABEL (alist__tree_264)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_153]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_62_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_263;

DEFLABEL (continuation_254)
  INTERRUPT_CHECK (27, LABEL_62_153);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_696)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd10.pObj) [0]);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_189]));

DEFLABEL (tree_get_392)
  CLOSURE_HEADER (LABEL_62_9);

DEFLABEL (tree_get_268)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_154]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_701;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_701;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_700)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_find_12;

DEFLABEL (continuation_266)
  INTERRUPT_CHECK (27, LABEL_62_154);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_697;
  Rvl = (Rsp [4]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_697)
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_62_5]);
  (Rsp [4]) = (Wrd8.Obj);
  Rsp = (& (Rsp [3]));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_699;

DEFLABEL (label_698)
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_699)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_698;
  Rvl = ((Wrd16.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_701)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_155]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_337)
  (* (--Rsp)) = Rvl;
  goto label_700;

DEFLABEL (tree_rank_391)
  CLOSURE_HEADER (LABEL_62_7);

DEFLABEL (tree_rank_270)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_703;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_703;
  (Wrd9.Obj) = ((Wrd15.pObj) [3]);

DEFLABEL (label_702)
  (Rsp [2]) = (Wrd9.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_62_6]);
  (Rsp [3]) = (Wrd25.Obj);
  goto node_rank_30;

DEFLABEL (label_703)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_62_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_156]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_338)
  (Wrd9.Obj) = Rvl;
  goto label_702;

DEFLABEL (tree_memberP_390)
  CLOSURE_HEADER (LABEL_62_5);

DEFLABEL (tree_memberP_273)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_157]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_708;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_708;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_707)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto node_find_12;

DEFLABEL (continuation_272)
  INTERRUPT_CHECK (27, LABEL_62_157);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_705;
  Rvl = (current_block [OBJECT_62_7]);
  goto label_704;

DEFLABEL (label_705)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_704)
DEFLABEL (label_706)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_708)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_62_1]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_158]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_8]), 2);

DEFLABEL (label_339)
  (* (--Rsp)) = Rvl;
  goto label_707;

DEFLABEL (loop_418)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_62_159);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_62_0]))
    goto label_716;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_162]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_715;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_715;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_714)
  (Wrd26.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_62_162);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_711;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_710;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_710;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_709)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_11;

DEFLABEL (label_710)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_62_3]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_205]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_362)
  (Wrd7.Obj) = Rvl;
  goto label_709;

DEFLABEL (label_711)
  (Wrd23.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd23.Obj);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_713;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd32.Lng))))
    goto label_713;
  (Wrd24.Obj) = ((Wrd30.pObj) [4]);

DEFLABEL (label_712)
  (Rsp [0]) = (Wrd24.Obj);
  goto loop_11;

DEFLABEL (label_713)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_62_4]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_204]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_363)
  (Wrd24.Obj) = Rvl;
  goto label_712;

DEFLABEL (label_715)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_62_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_163]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_340)
  (* (--Rsp)) = Rvl;
  goto label_714;

DEFLABEL (label_716)
  (Wrd31.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd31.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_717;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_717)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_160]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_722;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd46.Lng))))
    goto label_722;
  (Wrd40.Obj) = ((Wrd44.pObj) [3]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_721)
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [2]);
  (* (--Rsp)) = (Wrd56.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_62_160);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_719;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_718;

DEFLABEL (label_719)
  Rvl = (Rsp [0]);

DEFLABEL (label_718)
DEFLABEL (label_720)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_722)
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (current_block [OBJECT_62_1]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_161]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_2]), 2);

DEFLABEL (label_341)
  (* (--Rsp)) = Rvl;
  goto label_721;

DEFLABEL (loop_419)
DEFLABEL (loop_263)
  INTERRUPT_CHECK (26, LABEL_62_197);
  (Wrd11.Obj) = (Rsp [0]);
  if ((Wrd11.Obj) == (current_block [OBJECT_62_11]))
    goto label_734;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_723;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_62_14]);
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_62_15]);
  (Rsp [2]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_203]));

DEFLABEL (label_723)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_198]))));
  (* (--Rsp)) = (Wrd20.Obj);
  if (! ((Wrd14.uLng) == 1))
    goto label_733;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_732)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_731;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_730)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_729;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_728)
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_727;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_726)
  (Wrd53.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [7]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [2]);
  (* (--Rsp)) = (Wrd56.Obj);
  goto node_add_48;

DEFLABEL (continuation_262)
  INTERRUPT_CHECK (27, LABEL_62_198);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_725;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_724)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_263;

DEFLABEL (label_725)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_239]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_13]), 1);

DEFLABEL (label_381)
  (Wrd6.Obj) = Rvl;
  goto label_724;

DEFLABEL (label_727)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_202]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_12]), 1);

DEFLABEL (label_361)
  (* (--Rsp)) = Rvl;
  goto label_726;

DEFLABEL (label_729)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_201]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_12]), 1);

DEFLABEL (label_360)
  (Wrd37.Obj) = Rvl;
  goto label_728;

DEFLABEL (label_731)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_200]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_13]), 1);

DEFLABEL (label_359)
  (* (--Rsp)) = Rvl;
  goto label_730;

DEFLABEL (label_733)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_199]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_12]), 1);

DEFLABEL (label_358)
  (Wrd21.Obj) = Rvl;
  goto label_732;

DEFLABEL (label_734)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto label_696;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define ENVIRONMENT_LABEL_63_3 9
#define DEBUGGING_LABEL_63_2 8
#define OBJECT_63_0 7
#define EXECUTE_CACHE_63_5 5
#define FREE_REFERENCES_LABEL_63_0 4
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto guarantee_tree_report_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_tree_report_3)
DEFLABEL (guarantee_tree_report_0)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_63_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define LABEL_64_5 5
#define ENVIRONMENT_LABEL_64_3 13
#define DEBUGGING_LABEL_64_2 12
#define OBJECT_64_0 11
#define EXECUTE_CACHE_64_7 7
#define EXECUTE_CACHE_64_6 9
#define FREE_REFERENCES_LABEL_64_0 6
#define NUMBER_OF_LINKER_SECTIONS_64_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto guarantee_tree_1;

    case 1:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_tree_4)
DEFLABEL (guarantee_tree_1)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_64_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_5 5
#define ENVIRONMENT_LABEL_65_3 14
#define DEBUGGING_LABEL_65_2 13
#define OBJECT_65_1 12
#define OBJECT_65_0 11
#define EXECUTE_CACHE_65_7 7
#define EXECUTE_CACHE_65_6 9
#define FREE_REFERENCES_LABEL_65_0 6
#define NUMBER_OF_LINKER_SECTIONS_65_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto guarantee_tree_type_1;

    case 1:
      current_block = (Rpc - LABEL_65_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_tree_type_4)
DEFLABEL (guarantee_tree_type_1)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_65_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_65_0]);
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define LABEL_66_7 5
#define LABEL_66_5 7
#define LABEL_66_10 9
#define LABEL_66_9 11
#define LABEL_66_11 13
#define LABEL_66_12 15
#define ENVIRONMENT_LABEL_66_3 31
#define DEBUGGING_LABEL_66_2 30
#define OBJECT_66_6 29
#define OBJECT_66_5 28
#define OBJECT_66_4 27
#define OBJECT_66_3 26
#define OBJECT_66_2 25
#define OBJECT_66_1 24
#define OBJECT_66_0 23
#define EXECUTE_CACHE_66_13 17
#define EXECUTE_CACHE_66_8 19
#define EXECUTE_CACHE_66_6 21
#define FREE_REFERENCES_LABEL_66_0 16
#define NUMBER_OF_LINKER_SECTIONS_66_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd30;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto guarantee_compatible_trees_report_6;

    case 1:
      current_block = (Rpc - LABEL_66_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_66_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_66_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_66_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_66_11);
      goto label_8;

    case 6:
      current_block = (Rpc - LABEL_66_12);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_compatible_trees_report_11)
DEFLABEL (guarantee_compatible_trees_report_6)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_66_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;

DEFLABEL (label_17)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_66_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_10]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_66_10);

DEFLABEL (label_16)
  (Wrd7.Obj) = (current_block [OBJECT_66_0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_66_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_66_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_66_3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_66_4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 62))
    goto label_15;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_15;
  (Wrd14.Obj) = ((Wrd20.pObj) [2]);

DEFLABEL (label_14)
  (Rsp [7]) = (Wrd14.Obj);
  (Wrd39.Obj) = (Rsp [8]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_13;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd38.Lng))))
    goto label_13;
  (Wrd30.Obj) = ((Wrd36.pObj) [2]);

DEFLABEL (label_12)
  (Rsp [9]) = (Wrd30.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_66_3]);
  (Rsp [8]) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_13]));

DEFLABEL (label_13)
  (Wrd41.Obj) = (Rsp [8]);
  (Wrd42.Obj) = (current_block [OBJECT_66_5]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_12]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_6]), 2);

DEFLABEL (label_9)
  (Wrd30.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.Obj) = (current_block [OBJECT_66_5]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_11]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_6]), 2);

DEFLABEL (label_8)
  (Wrd14.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_66_7);
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_5 5
#define LABEL_67_8 7
#define LABEL_67_10 9
#define LABEL_67_11 11
#define LABEL_67_13 13
#define LABEL_67_7 15
#define LABEL_67_16 17
#define LABEL_67_12 19
#define LABEL_67_18 21
#define LABEL_67_9 23
#define LABEL_67_20 25
#define LABEL_67_15 27
#define LABEL_67_21 29
#define LABEL_67_22 31
#define LABEL_67_24 33
#define LABEL_67_17 35
#define LABEL_67_25 37
#define LABEL_67_26 39
#define LABEL_67_27 41
#define LABEL_67_19 43
#define LABEL_67_28 45
#define LABEL_67_29 47
#define ENVIRONMENT_LABEL_67_3 64
#define DEBUGGING_LABEL_67_2 63
#define OBJECT_67_7 62
#define OBJECT_67_6 61
#define OBJECT_67_5 60
#define OBJECT_67_4 59
#define OBJECT_67_3 58
#define OBJECT_67_2 57
#define OBJECT_67_1 56
#define OBJECT_67_0 55
#define EXECUTE_CACHE_67_23 49
#define EXECUTE_CACHE_67_14 51
#define EXECUTE_CACHE_67_6 53
#define FREE_REFERENCES_LABEL_67_0 48
#define NUMBER_OF_LINKER_SECTIONS_67_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd40;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd48;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto guarantee_compatible_trees_23;

    case 1:
      current_block = (Rpc - LABEL_67_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_67_8);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_67_10);
      goto label_25;

    case 4:
      current_block = (Rpc - LABEL_67_11);
      goto label_26;

    case 5:
      current_block = (Rpc - LABEL_67_13);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_67_7);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_67_16);
      goto continuation_18;

    case 8:
      current_block = (Rpc - LABEL_67_12);
      goto continuation_17;

    case 9:
      current_block = (Rpc - LABEL_67_18);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_67_9);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_67_20);
      goto continuation_4;

    case 12:
      current_block = (Rpc - LABEL_67_15);
      goto continuation_3;

    case 13:
      current_block = (Rpc - LABEL_67_21);
      goto label_27;

    case 14:
      current_block = (Rpc - LABEL_67_22);
      goto label_28;

    case 15:
      current_block = (Rpc - LABEL_67_24);
      goto continuation_20;

    case 16:
      current_block = (Rpc - LABEL_67_17);
      goto continuation_19;

    case 17:
      current_block = (Rpc - LABEL_67_25);
      goto label_29;

    case 18:
      current_block = (Rpc - LABEL_67_26);
      goto label_30;

    case 19:
      current_block = (Rpc - LABEL_67_27);
      goto continuation_11;

    case 20:
      current_block = (Rpc - LABEL_67_19);
      goto continuation_10;

    case 21:
      current_block = (Rpc - LABEL_67_28);
      goto label_31;

    case 22:
      current_block = (Rpc - LABEL_67_29);
      goto label_32;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_compatible_trees_34)
DEFLABEL (guarantee_compatible_trees_23)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_67_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_67_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_40;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_40;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_39)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_38;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_38;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_37)
  (Wrd39.Obj) = (* (Rsp++));
  if (! ((Wrd23.Obj) == (Wrd39.Obj)))
    goto label_35;
  Rvl = (current_block [OBJECT_67_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_12]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_36)
  (Wrd49.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (label_38)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_67_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_11]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_26)
  (Wrd23.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_67_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_10]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_41)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_9]))));
  (* (--Rsp)) = (Wrd48.Obj);
  goto label_36;

DEFLABEL (label_42)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_67_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;

DEFLABEL (label_48)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_67_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_47;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_20]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_67_20);

DEFLABEL (label_47)
  (Wrd7.Obj) = (current_block [OBJECT_67_3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_67_5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_67_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_67_7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 62))
    goto label_46;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_46;
  (Wrd14.Obj) = ((Wrd20.pObj) [2]);

DEFLABEL (label_45)
  (Rsp [7]) = (Wrd14.Obj);
  (Wrd39.Obj) = (Rsp [8]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_44;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd38.Lng))))
    goto label_44;
  (Wrd30.Obj) = ((Wrd36.pObj) [2]);

DEFLABEL (label_43)
  (Rsp [9]) = (Wrd30.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_67_6]);
  (Rsp [8]) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (label_44)
  (Wrd41.Obj) = (Rsp [8]);
  (Wrd42.Obj) = (current_block [OBJECT_67_0]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_22]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_28)
  (Wrd30.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.Obj) = (current_block [OBJECT_67_0]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_21]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_27)
  (Wrd14.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_49)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_13]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_67_13);
  goto label_48;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_67_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_56;

DEFLABEL (label_55)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_67_17);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_54;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_24]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_67_24);

DEFLABEL (label_54)
  (Wrd7.Obj) = (current_block [OBJECT_67_3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_67_5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_67_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_67_7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 62))
    goto label_53;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_53;
  (Wrd14.Obj) = ((Wrd20.pObj) [2]);

DEFLABEL (label_52)
  (Rsp [7]) = (Wrd14.Obj);
  (Wrd39.Obj) = (Rsp [8]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_51;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd38.Lng))))
    goto label_51;
  (Wrd30.Obj) = ((Wrd36.pObj) [2]);

DEFLABEL (label_50)
  (Rsp [9]) = (Wrd30.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_67_6]);
  (Rsp [8]) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (label_51)
  (Wrd41.Obj) = (Rsp [8]);
  (Wrd42.Obj) = (current_block [OBJECT_67_0]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_26]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_30)
  (Wrd30.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.Obj) = (current_block [OBJECT_67_0]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_25]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_29)
  (Wrd14.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_56)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_67_16);
  goto label_55;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_67_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_63;

DEFLABEL (label_62)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_67_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_61;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_27]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_67_27);

DEFLABEL (label_61)
  (Wrd7.Obj) = (current_block [OBJECT_67_3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_67_5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_67_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_67_7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 62))
    goto label_60;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_60;
  (Wrd14.Obj) = ((Wrd20.pObj) [2]);

DEFLABEL (label_59)
  (Rsp [7]) = (Wrd14.Obj);
  (Wrd39.Obj) = (Rsp [8]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 62))
    goto label_58;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd38.Lng))))
    goto label_58;
  (Wrd30.Obj) = ((Wrd36.pObj) [2]);

DEFLABEL (label_57)
  (Rsp [9]) = (Wrd30.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_67_6]);
  (Rsp [8]) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_23]));

DEFLABEL (label_58)
  (Wrd41.Obj) = (Rsp [8]);
  (Wrd42.Obj) = (current_block [OBJECT_67_0]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_29]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_32)
  (Wrd30.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.Obj) = (current_block [OBJECT_67_0]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_28]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_1]), 2);

DEFLABEL (label_31)
  (Wrd14.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_67_18);
  goto label_62;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define ENVIRONMENT_LABEL_68_3 9
#define DEBUGGING_LABEL_68_2 8
#define OBJECT_68_0 7
#define EXECUTE_CACHE_68_5 5
#define FREE_REFERENCES_LABEL_68_0 4
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto make_wt_tree_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_wt_tree_3)
DEFLABEL (make_wt_tree_0)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_68_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_4 3
#define LABEL_69_7 5
#define LABEL_69_5 7
#define ENVIRONMENT_LABEL_69_3 20
#define DEBUGGING_LABEL_69_2 19
#define OBJECT_69_3 18
#define OBJECT_69_2 17
#define OBJECT_69_1 16
#define OBJECT_69_0 15
#define EXECUTE_CACHE_69_9 9
#define EXECUTE_CACHE_69_8 11
#define EXECUTE_CACHE_69_6 13
#define FREE_REFERENCES_LABEL_69_0 8
#define NUMBER_OF_LINKER_SECTIONS_69_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_4);
      goto singleton_wt_tree_3;

    case 1:
      current_block = (Rpc - LABEL_69_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (singleton_wt_tree_6)
DEFLABEL (singleton_wt_tree_3)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_69_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;

DEFLABEL (label_7)
  (Wrd14.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd15.Obj) = (current_block [OBJECT_69_2]);
  (Wrd16.Obj) = (current_block [OBJECT_69_3]);
  (Wrd17.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-6]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_9]));

DEFLABEL (label_8)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_69_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_69_1]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_69_7);
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_7 5
#define LABEL_70_5 7
#define LABEL_70_9 9
#define ENVIRONMENT_LABEL_70_3 20
#define DEBUGGING_LABEL_70_2 19
#define OBJECT_70_3 18
#define OBJECT_70_2 17
#define OBJECT_70_1 16
#define OBJECT_70_0 15
#define EXECUTE_CACHE_70_8 11
#define EXECUTE_CACHE_70_6 13
#define FREE_REFERENCES_LABEL_70_0 10
#define NUMBER_OF_LINKER_SECTIONS_70_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto alist__wt_tree_3;

    case 1:
      current_block = (Rpc - LABEL_70_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_70_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_70_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist__wt_tree_7)
DEFLABEL (alist__wt_tree_3)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_70_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_70_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_70_1]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_70_7);

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_9;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_9)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_70_2]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_3]), 2);

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define LABEL_71_7 5
#define LABEL_71_5 7
#define LABEL_71_9 9
#define ENVIRONMENT_LABEL_71_3 21
#define DEBUGGING_LABEL_71_2 20
#define OBJECT_71_4 19
#define OBJECT_71_3 18
#define OBJECT_71_2 17
#define OBJECT_71_1 16
#define OBJECT_71_0 15
#define EXECUTE_CACHE_71_8 11
#define EXECUTE_CACHE_71_6 13
#define FREE_REFERENCES_LABEL_71_0 10
#define NUMBER_OF_LINKER_SECTIONS_71_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto wt_tree_emptyP_3;

    case 1:
      current_block = (Rpc - LABEL_71_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_71_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_71_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_emptyP_7)
DEFLABEL (wt_tree_emptyP_3)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_71_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_71_7);

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_12;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_12;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_11)
  if ((Wrd7.Obj) == (current_block [OBJECT_71_3]))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_8;

DEFLABEL (label_9)
  Rvl = (current_block [OBJECT_71_4]);

DEFLABEL (label_8)
DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_71_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_2]), 2);

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_7 5
#define LABEL_72_5 7
#define LABEL_72_9 9
#define LABEL_72_10 11
#define ENVIRONMENT_LABEL_72_3 24
#define DEBUGGING_LABEL_72_2 23
#define OBJECT_72_5 22
#define OBJECT_72_4 21
#define OBJECT_72_3 20
#define OBJECT_72_2 19
#define OBJECT_72_1 18
#define OBJECT_72_0 17
#define EXECUTE_CACHE_72_8 13
#define EXECUTE_CACHE_72_6 15
#define FREE_REFERENCES_LABEL_72_0 12
#define NUMBER_OF_LINKER_SECTIONS_72_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto wt_tree_size_5;

    case 1:
      current_block = (Rpc - LABEL_72_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_72_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_72_10);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_size_10)
DEFLABEL (wt_tree_size_5)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_7]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (current_block [OBJECT_72_0]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_72_7);

DEFLABEL (label_18)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_17;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_17;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_16)
  if (! ((Wrd7.Obj) == (current_block [OBJECT_72_3])))
    goto label_11;
  Rvl = (current_block [OBJECT_72_4]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_15;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_15;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_14)
  (Wrd40.Obj) = (current_block [OBJECT_72_4]);
  (Rsp [1]) = (Wrd40.Obj);
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 10)
    goto label_13;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_5]), 2);

DEFLABEL (label_13)
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd50.Lng))))
    goto label_12;
  Rvl = ((Wrd48.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_72_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_10]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_2]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_72_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_2]), 2);

DEFLABEL (label_7)
  (Wrd7.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_7 5
#define LABEL_73_5 7
#define LABEL_73_9 9
#define LABEL_73_10 11
#define ENVIRONMENT_LABEL_73_3 22
#define DEBUGGING_LABEL_73_2 21
#define OBJECT_73_3 20
#define OBJECT_73_2 19
#define OBJECT_73_1 18
#define OBJECT_73_0 17
#define EXECUTE_CACHE_73_8 13
#define EXECUTE_CACHE_73_6 15
#define FREE_REFERENCES_LABEL_73_0 12
#define NUMBER_OF_LINKER_SECTIONS_73_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto wt_tree_add_4;

    case 1:
      current_block = (Rpc - LABEL_73_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_73_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_73_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_add_9)
DEFLABEL (wt_tree_add_4)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_73_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_73_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [4]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_73_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_73_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_7 5
#define LABEL_74_5 7
#define LABEL_74_9 9
#define LABEL_74_10 11
#define ENVIRONMENT_LABEL_74_3 22
#define DEBUGGING_LABEL_74_2 21
#define OBJECT_74_3 20
#define OBJECT_74_2 19
#define OBJECT_74_1 18
#define OBJECT_74_0 17
#define EXECUTE_CACHE_74_8 13
#define EXECUTE_CACHE_74_6 15
#define FREE_REFERENCES_LABEL_74_0 12
#define NUMBER_OF_LINKER_SECTIONS_74_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto wt_tree_delete_4;

    case 1:
      current_block = (Rpc - LABEL_74_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_74_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_74_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_74_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_delete_9)
DEFLABEL (wt_tree_delete_4)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_74_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_74_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_74_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [6]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_74_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_74_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define LABEL_75_7 5
#define LABEL_75_5 7
#define LABEL_75_9 9
#define LABEL_75_10 11
#define ENVIRONMENT_LABEL_75_3 22
#define DEBUGGING_LABEL_75_2 21
#define OBJECT_75_3 20
#define OBJECT_75_2 19
#define OBJECT_75_1 18
#define OBJECT_75_0 17
#define EXECUTE_CACHE_75_8 13
#define EXECUTE_CACHE_75_6 15
#define FREE_REFERENCES_LABEL_75_0 12
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto wt_tree_addB_4;

    case 1:
      current_block = (Rpc - LABEL_75_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_75_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_75_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_75_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_addB_9)
DEFLABEL (wt_tree_addB_4)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_75_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_75_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_75_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [5]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_75_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_75_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define LABEL_76_7 5
#define LABEL_76_5 7
#define LABEL_76_9 9
#define LABEL_76_10 11
#define ENVIRONMENT_LABEL_76_3 22
#define DEBUGGING_LABEL_76_2 21
#define OBJECT_76_3 20
#define OBJECT_76_2 19
#define OBJECT_76_1 18
#define OBJECT_76_0 17
#define EXECUTE_CACHE_76_8 13
#define EXECUTE_CACHE_76_6 15
#define FREE_REFERENCES_LABEL_76_0 12
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto wt_tree_deleteB_4;

    case 1:
      current_block = (Rpc - LABEL_76_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_76_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_76_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_76_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_deleteB_9)
DEFLABEL (wt_tree_deleteB_4)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_76_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_76_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_76_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [7]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_76_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_76_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define LABEL_77_7 5
#define LABEL_77_5 7
#define LABEL_77_9 9
#define LABEL_77_10 11
#define ENVIRONMENT_LABEL_77_3 22
#define DEBUGGING_LABEL_77_2 21
#define OBJECT_77_3 20
#define OBJECT_77_2 19
#define OBJECT_77_1 18
#define OBJECT_77_0 17
#define EXECUTE_CACHE_77_8 13
#define EXECUTE_CACHE_77_6 15
#define FREE_REFERENCES_LABEL_77_0 12
#define NUMBER_OF_LINKER_SECTIONS_77_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto wt_tree_memberP_4;

    case 1:
      current_block = (Rpc - LABEL_77_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_77_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_77_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_77_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_memberP_9)
DEFLABEL (wt_tree_memberP_4)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_77_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_77_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_77_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [8]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_77_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_77_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_77_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_77_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_7 5
#define LABEL_78_5 7
#define LABEL_78_9 9
#define LABEL_78_10 11
#define ENVIRONMENT_LABEL_78_3 22
#define DEBUGGING_LABEL_78_2 21
#define OBJECT_78_3 20
#define OBJECT_78_2 19
#define OBJECT_78_1 18
#define OBJECT_78_0 17
#define EXECUTE_CACHE_78_8 13
#define EXECUTE_CACHE_78_6 15
#define FREE_REFERENCES_LABEL_78_0 12
#define NUMBER_OF_LINKER_SECTIONS_78_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto wt_tree_lookup_4;

    case 1:
      current_block = (Rpc - LABEL_78_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_78_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_78_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_78_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_lookup_9)
DEFLABEL (wt_tree_lookup_4)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_78_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_78_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_78_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [9]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_78_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_78_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_78_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_78_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define LABEL_79_7 5
#define LABEL_79_5 7
#define LABEL_79_9 9
#define LABEL_79_10 11
#define ENVIRONMENT_LABEL_79_3 22
#define DEBUGGING_LABEL_79_2 21
#define OBJECT_79_3 20
#define OBJECT_79_2 19
#define OBJECT_79_1 18
#define OBJECT_79_0 17
#define EXECUTE_CACHE_79_8 13
#define EXECUTE_CACHE_79_6 15
#define FREE_REFERENCES_LABEL_79_0 12
#define NUMBER_OF_LINKER_SECTIONS_79_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto wt_tree_split__4;

    case 1:
      current_block = (Rpc - LABEL_79_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_79_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_79_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_79_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_split__9)
DEFLABEL (wt_tree_split__4)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_79_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_79_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_79_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [10]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_79_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_79_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define LABEL_80_7 5
#define LABEL_80_5 7
#define LABEL_80_9 9
#define LABEL_80_10 11
#define ENVIRONMENT_LABEL_80_3 22
#define DEBUGGING_LABEL_80_2 21
#define OBJECT_80_3 20
#define OBJECT_80_2 19
#define OBJECT_80_1 18
#define OBJECT_80_0 17
#define EXECUTE_CACHE_80_8 13
#define EXECUTE_CACHE_80_6 15
#define FREE_REFERENCES_LABEL_80_0 12
#define NUMBER_OF_LINKER_SECTIONS_80_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto wt_tree_split__4;

    case 1:
      current_block = (Rpc - LABEL_80_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_80_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_80_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_80_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_split__9)
DEFLABEL (wt_tree_split__4)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_80_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_80_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_80_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [11]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_80_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_80_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define LABEL_81_5 5
#define LABEL_81_9 7
#define LABEL_81_8 9
#define LABEL_81_11 11
#define LABEL_81_12 13
#define LABEL_81_13 15
#define LABEL_81_14 17
#define LABEL_81_16 19
#define LABEL_81_7 21
#define LABEL_81_19 23
#define LABEL_81_15 25
#define LABEL_81_21 27
#define LABEL_81_10 29
#define LABEL_81_23 31
#define LABEL_81_18 33
#define LABEL_81_24 35
#define LABEL_81_25 37
#define LABEL_81_27 39
#define LABEL_81_20 41
#define LABEL_81_28 43
#define LABEL_81_29 45
#define LABEL_81_30 47
#define LABEL_81_22 49
#define LABEL_81_31 51
#define LABEL_81_32 53
#define ENVIRONMENT_LABEL_81_3 71
#define DEBUGGING_LABEL_81_2 70
#define OBJECT_81_8 69
#define OBJECT_81_7 68
#define OBJECT_81_6 67
#define OBJECT_81_5 66
#define OBJECT_81_4 65
#define OBJECT_81_3 64
#define OBJECT_81_2 63
#define OBJECT_81_1 62
#define OBJECT_81_0 61
#define EXECUTE_CACHE_81_26 55
#define EXECUTE_CACHE_81_17 57
#define EXECUTE_CACHE_81_6 59
#define FREE_REFERENCES_LABEL_81_0 54
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd76;
  machine_word Wrd42;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd75;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto wt_tree_union_26;

    case 1:
      current_block = (Rpc - LABEL_81_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_81_9);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_81_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_81_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_81_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_81_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_81_14);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_81_16);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_81_7);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_81_19);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_81_15);
      goto continuation_18;

    case 12:
      current_block = (Rpc - LABEL_81_21);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_81_10);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_81_23);
      goto continuation_4;

    case 15:
      current_block = (Rpc - LABEL_81_18);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_81_24);
      goto label_32;

    case 17:
      current_block = (Rpc - LABEL_81_25);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_81_27);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_81_20);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_81_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_81_29);
      goto label_35;

    case 22:
      current_block = (Rpc - LABEL_81_30);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_81_22);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_81_31);
      goto label_36;

    case 25:
      current_block = (Rpc - LABEL_81_32);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_union_39)
DEFLABEL (wt_tree_union_26)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_81_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_81_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_49;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_49;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_48)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_47;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_47;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_46)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_41;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_15]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_40)
  (Wrd76.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (label_41)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_45;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_45;
  (Wrd44.Obj) = ((Wrd50.pObj) [2]);

DEFLABEL (label_44)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd67.uLng) == 62))
    goto label_43;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd66.Lng))))
    goto label_43;
  (Wrd61.Obj) = ((Wrd64.pObj) [12]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_42)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_43)
  (Wrd69.Obj) = (current_block [OBJECT_81_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_81_0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_13]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_30)
  (Wrd44.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_81_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_81_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_10]))));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_40;

DEFLABEL (label_51)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_81_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_58;

DEFLABEL (label_57)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_81_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_81_23);

DEFLABEL (label_56)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_55;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_55;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_54)
  (Wrd26.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_53;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_53;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_52)
  (Wrd43.Obj) = (current_block [OBJECT_81_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_81_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_81_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_81_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_26]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_81_9);
  goto label_41;

DEFLABEL (label_53)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_81_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_81_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_81_16);
  goto label_57;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_81_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_81_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_27]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_81_27);

DEFLABEL (label_63)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_62;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_62;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_60;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_60;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd43.Obj) = (current_block [OBJECT_81_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_81_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_81_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_81_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_26]));

DEFLABEL (label_60)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_81_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_29]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_81_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_28]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_81_19);
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_81_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;

DEFLABEL (label_71)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_6]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_81_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_81_30);

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_69;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_69;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_68)
  (Wrd26.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_67;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_67;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_66)
  (Wrd43.Obj) = (current_block [OBJECT_81_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_81_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_81_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_81_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_81_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_26]));

DEFLABEL (label_67)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_81_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_81_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_81_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_81_21);
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_5 5
#define LABEL_82_9 7
#define LABEL_82_8 9
#define LABEL_82_11 11
#define LABEL_82_12 13
#define LABEL_82_13 15
#define LABEL_82_14 17
#define LABEL_82_16 19
#define LABEL_82_7 21
#define LABEL_82_19 23
#define LABEL_82_15 25
#define LABEL_82_21 27
#define LABEL_82_10 29
#define LABEL_82_23 31
#define LABEL_82_18 33
#define LABEL_82_24 35
#define LABEL_82_25 37
#define LABEL_82_27 39
#define LABEL_82_20 41
#define LABEL_82_28 43
#define LABEL_82_29 45
#define LABEL_82_30 47
#define LABEL_82_22 49
#define LABEL_82_31 51
#define LABEL_82_32 53
#define ENVIRONMENT_LABEL_82_3 71
#define DEBUGGING_LABEL_82_2 70
#define OBJECT_82_8 69
#define OBJECT_82_7 68
#define OBJECT_82_6 67
#define OBJECT_82_5 66
#define OBJECT_82_4 65
#define OBJECT_82_3 64
#define OBJECT_82_2 63
#define OBJECT_82_1 62
#define OBJECT_82_0 61
#define EXECUTE_CACHE_82_26 55
#define EXECUTE_CACHE_82_17 57
#define EXECUTE_CACHE_82_6 59
#define FREE_REFERENCES_LABEL_82_0 54
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd76;
  machine_word Wrd42;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd75;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto wt_tree_union_merge_26;

    case 1:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_82_9);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_82_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_82_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_82_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_82_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_82_14);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_82_16);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_82_7);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_82_19);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_82_15);
      goto continuation_18;

    case 12:
      current_block = (Rpc - LABEL_82_21);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_82_10);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_82_23);
      goto continuation_4;

    case 15:
      current_block = (Rpc - LABEL_82_18);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_82_24);
      goto label_32;

    case 17:
      current_block = (Rpc - LABEL_82_25);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_82_27);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_82_20);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_82_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_82_29);
      goto label_35;

    case 22:
      current_block = (Rpc - LABEL_82_30);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_82_22);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_82_31);
      goto label_36;

    case 25:
      current_block = (Rpc - LABEL_82_32);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_union_merge_39)
DEFLABEL (wt_tree_union_merge_26)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_82_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_49;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_49;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_48)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_47;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_47;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_46)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_41;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_15]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_40)
  (Wrd76.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (label_41)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_45;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_45;
  (Wrd44.Obj) = ((Wrd50.pObj) [2]);

DEFLABEL (label_44)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd67.uLng) == 62))
    goto label_43;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd66.Lng))))
    goto label_43;
  (Wrd61.Obj) = ((Wrd64.pObj) [13]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_42)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_43)
  (Wrd69.Obj) = (current_block [OBJECT_82_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_82_0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_13]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_30)
  (Wrd44.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_82_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_82_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_10]))));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_40;

DEFLABEL (label_51)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_82_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_58;

DEFLABEL (label_57)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_82_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_82_23);

DEFLABEL (label_56)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_55;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_55;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_54)
  (Wrd26.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_53;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_53;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_52)
  (Wrd43.Obj) = (current_block [OBJECT_82_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_82_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_82_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_82_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_26]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_82_9);
  goto label_41;

DEFLABEL (label_53)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_82_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_82_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_82_16);
  goto label_57;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_82_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_82_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_27]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_82_27);

DEFLABEL (label_63)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_62;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_62;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_60;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_60;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd43.Obj) = (current_block [OBJECT_82_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_82_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_82_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_82_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_26]));

DEFLABEL (label_60)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_82_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_29]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_82_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_28]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_82_19);
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_82_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;

DEFLABEL (label_71)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_82_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_82_30);

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_69;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_69;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_68)
  (Wrd26.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_67;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_67;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_66)
  (Wrd43.Obj) = (current_block [OBJECT_82_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_82_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_82_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_82_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_82_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_26]));

DEFLABEL (label_67)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_82_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_82_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_82_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_82_21);
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define LABEL_83_5 5
#define LABEL_83_9 7
#define LABEL_83_8 9
#define LABEL_83_11 11
#define LABEL_83_12 13
#define LABEL_83_13 15
#define LABEL_83_14 17
#define LABEL_83_16 19
#define LABEL_83_7 21
#define LABEL_83_19 23
#define LABEL_83_15 25
#define LABEL_83_21 27
#define LABEL_83_10 29
#define LABEL_83_23 31
#define LABEL_83_18 33
#define LABEL_83_24 35
#define LABEL_83_25 37
#define LABEL_83_27 39
#define LABEL_83_20 41
#define LABEL_83_28 43
#define LABEL_83_29 45
#define LABEL_83_30 47
#define LABEL_83_22 49
#define LABEL_83_31 51
#define LABEL_83_32 53
#define ENVIRONMENT_LABEL_83_3 71
#define DEBUGGING_LABEL_83_2 70
#define OBJECT_83_8 69
#define OBJECT_83_7 68
#define OBJECT_83_6 67
#define OBJECT_83_5 66
#define OBJECT_83_4 65
#define OBJECT_83_3 64
#define OBJECT_83_2 63
#define OBJECT_83_1 62
#define OBJECT_83_0 61
#define EXECUTE_CACHE_83_26 55
#define EXECUTE_CACHE_83_17 57
#define EXECUTE_CACHE_83_6 59
#define FREE_REFERENCES_LABEL_83_0 54
#define NUMBER_OF_LINKER_SECTIONS_83_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd76;
  machine_word Wrd42;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd75;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto wt_tree_intersection_26;

    case 1:
      current_block = (Rpc - LABEL_83_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_83_9);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_83_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_83_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_83_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_83_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_83_14);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_83_16);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_83_7);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_83_19);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_83_15);
      goto continuation_18;

    case 12:
      current_block = (Rpc - LABEL_83_21);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_83_10);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_83_23);
      goto continuation_4;

    case 15:
      current_block = (Rpc - LABEL_83_18);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_83_24);
      goto label_32;

    case 17:
      current_block = (Rpc - LABEL_83_25);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_83_27);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_83_20);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_83_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_83_29);
      goto label_35;

    case 22:
      current_block = (Rpc - LABEL_83_30);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_83_22);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_83_31);
      goto label_36;

    case 25:
      current_block = (Rpc - LABEL_83_32);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_intersection_39)
DEFLABEL (wt_tree_intersection_26)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_83_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_83_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_49;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_49;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_48)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_47;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_47;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_46)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_41;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_15]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_40)
  (Wrd76.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (label_41)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_45;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_45;
  (Wrd44.Obj) = ((Wrd50.pObj) [2]);

DEFLABEL (label_44)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd67.uLng) == 62))
    goto label_43;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 13L) < ((unsigned long) (Wrd66.Lng))))
    goto label_43;
  (Wrd61.Obj) = ((Wrd64.pObj) [14]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_42)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_43)
  (Wrd69.Obj) = (current_block [OBJECT_83_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_83_0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_13]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_30)
  (Wrd44.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_83_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_83_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_10]))));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_40;

DEFLABEL (label_51)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_83_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_58;

DEFLABEL (label_57)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_83_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_83_23);

DEFLABEL (label_56)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_55;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_55;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_54)
  (Wrd26.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_53;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_53;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_52)
  (Wrd43.Obj) = (current_block [OBJECT_83_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_83_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_83_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_83_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_26]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_83_9);
  goto label_41;

DEFLABEL (label_53)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_83_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_83_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_83_16);
  goto label_57;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_83_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_83_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_27]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_83_27);

DEFLABEL (label_63)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_62;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_62;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_60;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_60;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd43.Obj) = (current_block [OBJECT_83_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_83_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_83_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_83_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_26]));

DEFLABEL (label_60)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_83_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_29]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_83_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_28]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_83_19);
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_83_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;

DEFLABEL (label_71)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_83_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_83_30);

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_69;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_69;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_68)
  (Wrd26.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_67;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_67;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_66)
  (Wrd43.Obj) = (current_block [OBJECT_83_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_83_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_83_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_83_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_83_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_26]));

DEFLABEL (label_67)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_83_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_83_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_83_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_83_21);
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define LABEL_84_5 5
#define LABEL_84_9 7
#define LABEL_84_8 9
#define LABEL_84_11 11
#define LABEL_84_12 13
#define LABEL_84_13 15
#define LABEL_84_14 17
#define LABEL_84_16 19
#define LABEL_84_7 21
#define LABEL_84_19 23
#define LABEL_84_15 25
#define LABEL_84_21 27
#define LABEL_84_10 29
#define LABEL_84_23 31
#define LABEL_84_18 33
#define LABEL_84_24 35
#define LABEL_84_25 37
#define LABEL_84_27 39
#define LABEL_84_20 41
#define LABEL_84_28 43
#define LABEL_84_29 45
#define LABEL_84_30 47
#define LABEL_84_22 49
#define LABEL_84_31 51
#define LABEL_84_32 53
#define ENVIRONMENT_LABEL_84_3 71
#define DEBUGGING_LABEL_84_2 70
#define OBJECT_84_8 69
#define OBJECT_84_7 68
#define OBJECT_84_6 67
#define OBJECT_84_5 66
#define OBJECT_84_4 65
#define OBJECT_84_3 64
#define OBJECT_84_2 63
#define OBJECT_84_1 62
#define OBJECT_84_0 61
#define EXECUTE_CACHE_84_26 55
#define EXECUTE_CACHE_84_17 57
#define EXECUTE_CACHE_84_6 59
#define FREE_REFERENCES_LABEL_84_0 54
#define NUMBER_OF_LINKER_SECTIONS_84_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd76;
  machine_word Wrd42;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd75;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto wt_tree_difference_26;

    case 1:
      current_block = (Rpc - LABEL_84_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_84_9);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_84_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_84_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_84_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_84_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_84_14);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_84_16);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_84_7);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_84_19);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_84_15);
      goto continuation_18;

    case 12:
      current_block = (Rpc - LABEL_84_21);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_84_10);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_84_23);
      goto continuation_4;

    case 15:
      current_block = (Rpc - LABEL_84_18);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_84_24);
      goto label_32;

    case 17:
      current_block = (Rpc - LABEL_84_25);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_84_27);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_84_20);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_84_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_84_29);
      goto label_35;

    case 22:
      current_block = (Rpc - LABEL_84_30);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_84_22);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_84_31);
      goto label_36;

    case 25:
      current_block = (Rpc - LABEL_84_32);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_difference_39)
DEFLABEL (wt_tree_difference_26)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_84_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_84_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_49;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_49;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_48)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_47;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_47;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_46)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_41;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_15]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_40)
  (Wrd76.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (label_41)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_45;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_45;
  (Wrd44.Obj) = ((Wrd50.pObj) [2]);

DEFLABEL (label_44)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd67.uLng) == 62))
    goto label_43;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd66.Lng))))
    goto label_43;
  (Wrd61.Obj) = ((Wrd64.pObj) [15]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_42)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_43)
  (Wrd69.Obj) = (current_block [OBJECT_84_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_84_0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_13]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_30)
  (Wrd44.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_84_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_84_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_10]))));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_40;

DEFLABEL (label_51)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_84_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_58;

DEFLABEL (label_57)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_84_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_84_23);

DEFLABEL (label_56)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_55;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_55;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_54)
  (Wrd26.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_53;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_53;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_52)
  (Wrd43.Obj) = (current_block [OBJECT_84_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_84_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_84_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_84_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_26]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_84_9);
  goto label_41;

DEFLABEL (label_53)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_84_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_84_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_84_16);
  goto label_57;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_84_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_84_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_27]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_84_27);

DEFLABEL (label_63)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_62;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_62;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_60;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_60;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd43.Obj) = (current_block [OBJECT_84_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_84_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_84_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_84_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_26]));

DEFLABEL (label_60)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_84_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_29]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_84_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_28]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_84_19);
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_84_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;

DEFLABEL (label_71)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_84_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_84_30);

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_69;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_69;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_68)
  (Wrd26.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_67;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_67;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_66)
  (Wrd43.Obj) = (current_block [OBJECT_84_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_84_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_84_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_84_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_84_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_26]));

DEFLABEL (label_67)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_84_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_84_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_84_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_84_21);
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define LABEL_85_5 5
#define LABEL_85_9 7
#define LABEL_85_8 9
#define LABEL_85_11 11
#define LABEL_85_12 13
#define LABEL_85_13 15
#define LABEL_85_14 17
#define LABEL_85_16 19
#define LABEL_85_7 21
#define LABEL_85_19 23
#define LABEL_85_15 25
#define LABEL_85_21 27
#define LABEL_85_10 29
#define LABEL_85_23 31
#define LABEL_85_18 33
#define LABEL_85_24 35
#define LABEL_85_25 37
#define LABEL_85_27 39
#define LABEL_85_20 41
#define LABEL_85_28 43
#define LABEL_85_29 45
#define LABEL_85_30 47
#define LABEL_85_22 49
#define LABEL_85_31 51
#define LABEL_85_32 53
#define ENVIRONMENT_LABEL_85_3 71
#define DEBUGGING_LABEL_85_2 70
#define OBJECT_85_8 69
#define OBJECT_85_7 68
#define OBJECT_85_6 67
#define OBJECT_85_5 66
#define OBJECT_85_4 65
#define OBJECT_85_3 64
#define OBJECT_85_2 63
#define OBJECT_85_1 62
#define OBJECT_85_0 61
#define EXECUTE_CACHE_85_26 55
#define EXECUTE_CACHE_85_17 57
#define EXECUTE_CACHE_85_6 59
#define FREE_REFERENCES_LABEL_85_0 54
#define NUMBER_OF_LINKER_SECTIONS_85_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd76;
  machine_word Wrd42;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd75;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto wt_tree_subsetP_26;

    case 1:
      current_block = (Rpc - LABEL_85_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_85_9);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_85_8);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_85_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_85_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_85_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_85_14);
      goto label_31;

    case 8:
      current_block = (Rpc - LABEL_85_16);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_85_7);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_85_19);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_85_15);
      goto continuation_18;

    case 12:
      current_block = (Rpc - LABEL_85_21);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_85_10);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_85_23);
      goto continuation_4;

    case 15:
      current_block = (Rpc - LABEL_85_18);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_85_24);
      goto label_32;

    case 17:
      current_block = (Rpc - LABEL_85_25);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_85_27);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_85_20);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_85_28);
      goto label_34;

    case 21:
      current_block = (Rpc - LABEL_85_29);
      goto label_35;

    case 22:
      current_block = (Rpc - LABEL_85_30);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_85_22);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_85_31);
      goto label_36;

    case 25:
      current_block = (Rpc - LABEL_85_32);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_subsetP_39)
DEFLABEL (wt_tree_subsetP_26)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_85_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_85_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_49;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_49;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_48)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 62))
    goto label_47;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_47;
  (Wrd23.Obj) = ((Wrd29.pObj) [2]);

DEFLABEL (label_46)
  (Wrd39.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd39.Obj))
    goto label_41;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_15]))));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_40)
  (Wrd76.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd76.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (label_41)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_45;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_45;
  (Wrd44.Obj) = ((Wrd50.pObj) [2]);

DEFLABEL (label_44)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd67.uLng) == 62))
    goto label_43;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) 15L) < ((unsigned long) (Wrd66.Lng))))
    goto label_43;
  (Wrd61.Obj) = ((Wrd64.pObj) [16]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_42)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_43)
  (Wrd69.Obj) = (current_block [OBJECT_85_2]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_85_0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_13]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_30)
  (Wrd44.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_85_0]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_85_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_10]))));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_40;

DEFLABEL (label_51)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_85_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_58;

DEFLABEL (label_57)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_85_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_85_23);

DEFLABEL (label_56)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_55;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_55;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_54)
  (Wrd26.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_53;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_53;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_52)
  (Wrd43.Obj) = (current_block [OBJECT_85_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_85_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_85_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_85_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_26]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_85_9);
  goto label_41;

DEFLABEL (label_53)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_85_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_85_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_85_16);
  goto label_57;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_85_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;

DEFLABEL (label_64)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_85_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_27]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_85_27);

DEFLABEL (label_63)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_62;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_62;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_60;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_60;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd43.Obj) = (current_block [OBJECT_85_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_85_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_85_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_85_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_26]));

DEFLABEL (label_60)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_85_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_29]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_85_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_28]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_85_19);
  goto label_64;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_85_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;

DEFLABEL (label_71)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_6]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_85_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd54.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_85_30);

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_69;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_69;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_68)
  (Wrd26.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 62))
    goto label_67;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_67;
  (Wrd29.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_66)
  (Wrd43.Obj) = (current_block [OBJECT_85_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_85_6]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_85_7]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (current_block [OBJECT_85_4]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_85_8]);
  (* (--Rsp)) = (Wrd49.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_26]));

DEFLABEL (label_67)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_85_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_85_0]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_85_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_85_21);
  goto label_71;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_4 3
#define LABEL_86_5 5
#define ENVIRONMENT_LABEL_86_3 10
#define DEBUGGING_LABEL_86_2 9
#define EXECUTE_CACHE_86_6 7
#define FREE_REFERENCES_LABEL_86_0 6
#define NUMBER_OF_LINKER_SECTIONS_86_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_4);
      goto wt_tree_set_equalP_1;

    case 1:
      current_block = (Rpc - LABEL_86_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_set_equalP_4)
DEFLABEL (wt_tree_set_equalP_1)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_86_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_6]));

DEFLABEL (label_5)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define LABEL_87_7 5
#define LABEL_87_5 7
#define LABEL_87_9 9
#define ENVIRONMENT_LABEL_87_3 21
#define DEBUGGING_LABEL_87_2 20
#define OBJECT_87_2 19
#define OBJECT_87_1 18
#define OBJECT_87_0 17
#define EXECUTE_CACHE_87_10 11
#define EXECUTE_CACHE_87_8 13
#define EXECUTE_CACHE_87_6 15
#define FREE_REFERENCES_LABEL_87_0 10
#define NUMBER_OF_LINKER_SECTIONS_87_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto wt_tree_fold_3;

    case 1:
      current_block = (Rpc - LABEL_87_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_87_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_87_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_fold_7)
DEFLABEL (wt_tree_fold_3)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_87_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_87_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_87_7);

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_9;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_10]));

DEFLABEL (label_9)
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (current_block [OBJECT_87_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_2]), 2);

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define LABEL_88_7 5
#define LABEL_88_5 7
#define LABEL_88_9 9
#define ENVIRONMENT_LABEL_88_3 21
#define DEBUGGING_LABEL_88_2 20
#define OBJECT_88_2 19
#define OBJECT_88_1 18
#define OBJECT_88_0 17
#define EXECUTE_CACHE_88_10 11
#define EXECUTE_CACHE_88_8 13
#define EXECUTE_CACHE_88_6 15
#define FREE_REFERENCES_LABEL_88_0 10
#define NUMBER_OF_LINKER_SECTIONS_88_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto wt_tree_for_each_3;

    case 1:
      current_block = (Rpc - LABEL_88_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_88_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_88_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_for_each_7)
DEFLABEL (wt_tree_for_each_3)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_88_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_88_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_88_7);

DEFLABEL (label_10)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_9;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_8)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_10]));

DEFLABEL (label_9)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_88_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 2);

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define LABEL_89_7 5
#define LABEL_89_5 7
#define LABEL_89_10 9
#define LABEL_89_9 11
#define ENVIRONMENT_LABEL_89_3 24
#define DEBUGGING_LABEL_89_2 23
#define OBJECT_89_3 22
#define OBJECT_89_2 21
#define OBJECT_89_1 20
#define OBJECT_89_0 19
#define EXECUTE_CACHE_89_11 13
#define EXECUTE_CACHE_89_8 15
#define EXECUTE_CACHE_89_6 17
#define FREE_REFERENCES_LABEL_89_0 12
#define NUMBER_OF_LINKER_SECTIONS_89_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto wt_tree_index_5;

    case 1:
      current_block = (Rpc - LABEL_89_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_89_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_89_10);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_89_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_index_9)
DEFLABEL (wt_tree_index_5)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_89_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_89_7);

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_14;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_14;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_89_9);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if (! ((Wrd6.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_10;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_89_1]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd21.uLng) == 10)
    goto label_12;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_3]), 2);

DEFLABEL (label_12)
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_11;
  Rvl = ((Wrd17.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_89_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_4 3
#define LABEL_90_7 5
#define LABEL_90_5 7
#define LABEL_90_10 9
#define LABEL_90_9 11
#define ENVIRONMENT_LABEL_90_3 25
#define DEBUGGING_LABEL_90_2 24
#define OBJECT_90_4 23
#define OBJECT_90_3 22
#define OBJECT_90_2 21
#define OBJECT_90_1 20
#define OBJECT_90_0 19
#define EXECUTE_CACHE_90_11 13
#define EXECUTE_CACHE_90_8 15
#define EXECUTE_CACHE_90_6 17
#define FREE_REFERENCES_LABEL_90_0 12
#define NUMBER_OF_LINKER_SECTIONS_90_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_4);
      goto wt_tree_index_datum_5;

    case 1:
      current_block = (Rpc - LABEL_90_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_90_10);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_90_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_index_datum_9)
DEFLABEL (wt_tree_index_datum_5)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_90_0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_90_7);

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_14;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_14;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_90_9);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if (! ((Wrd6.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_10;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_90_3]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd21.uLng) == 10)
    goto label_12;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_4]), 2);

DEFLABEL (label_12)
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd19.Lng))))
    goto label_11;
  Rvl = ((Wrd17.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_90_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define LABEL_91_7 5
#define LABEL_91_5 7
#define LABEL_91_10 9
#define LABEL_91_9 11
#define LABEL_91_12 13
#define LABEL_91_13 15
#define ENVIRONMENT_LABEL_91_3 29
#define DEBUGGING_LABEL_91_2 28
#define OBJECT_91_4 27
#define OBJECT_91_3 26
#define OBJECT_91_2 25
#define OBJECT_91_1 24
#define OBJECT_91_0 23
#define EXECUTE_CACHE_91_11 17
#define EXECUTE_CACHE_91_8 19
#define EXECUTE_CACHE_91_6 21
#define FREE_REFERENCES_LABEL_91_0 16
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd24;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto wt_tree_index_pair_7;

    case 1:
      current_block = (Rpc - LABEL_91_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_91_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_91_10);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_91_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_91_12);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_91_13);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_index_pair_13)
DEFLABEL (wt_tree_index_pair_7)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_91_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_91_0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_91_7);

DEFLABEL (label_22)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_21;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_21;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_20)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_91_9);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_18;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_18;
  (Wrd10.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_17)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_16;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_16;
  (Wrd24.Obj) = ((Wrd30.pObj) [3]);

DEFLABEL (label_15)
  (Wrd40.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));

DEFLABEL (label_14)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_91_1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_13]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_4]), 2);

DEFLABEL (label_11)
  (Wrd24.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_91_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_4]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_14;

DEFLABEL (label_21)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_91_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_2]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_7 5
#define LABEL_92_5 7
#define LABEL_92_9 9
#define LABEL_92_10 11
#define ENVIRONMENT_LABEL_92_3 22
#define DEBUGGING_LABEL_92_2 21
#define OBJECT_92_3 20
#define OBJECT_92_2 19
#define OBJECT_92_1 18
#define OBJECT_92_0 17
#define EXECUTE_CACHE_92_8 13
#define EXECUTE_CACHE_92_6 15
#define FREE_REFERENCES_LABEL_92_0 12
#define NUMBER_OF_LINKER_SECTIONS_92_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto wt_tree_rank_4;

    case 1:
      current_block = (Rpc - LABEL_92_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_92_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_92_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_92_10);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_rank_9)
DEFLABEL (wt_tree_rank_4)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_92_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_92_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_92_7);

DEFLABEL (label_14)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_13;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_13;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_12)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd30.uLng) == 62))
    goto label_11;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 16L) < ((unsigned long) (Wrd29.Lng))))
    goto label_11;
  (Wrd24.Obj) = ((Wrd27.pObj) [17]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_10)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_11)
  (Wrd32.Obj) = (current_block [OBJECT_92_3]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_92_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_2]), 2);

DEFLABEL (label_6)
  (Wrd7.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_7 5
#define LABEL_93_5 7
#define LABEL_93_10 9
#define LABEL_93_9 11
#define ENVIRONMENT_LABEL_93_3 24
#define DEBUGGING_LABEL_93_2 23
#define OBJECT_93_3 22
#define OBJECT_93_2 21
#define OBJECT_93_1 20
#define OBJECT_93_0 19
#define EXECUTE_CACHE_93_11 13
#define EXECUTE_CACHE_93_8 15
#define EXECUTE_CACHE_93_6 17
#define FREE_REFERENCES_LABEL_93_0 12
#define NUMBER_OF_LINKER_SECTIONS_93_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto wt_tree_min_4;

    case 1:
      current_block = (Rpc - LABEL_93_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_93_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_93_10);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_93_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_min_8)
DEFLABEL (wt_tree_min_4)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_93_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_93_0]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_93_7);

DEFLABEL (label_13)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_12;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_12;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_93_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_93_1]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_10;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_3]), 2);

DEFLABEL (label_10)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  Rvl = ((Wrd13.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_93_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_2]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_7 5
#define LABEL_94_5 7
#define LABEL_94_10 9
#define LABEL_94_9 11
#define ENVIRONMENT_LABEL_94_3 25
#define DEBUGGING_LABEL_94_2 24
#define OBJECT_94_4 23
#define OBJECT_94_3 22
#define OBJECT_94_2 21
#define OBJECT_94_1 20
#define OBJECT_94_0 19
#define EXECUTE_CACHE_94_11 13
#define EXECUTE_CACHE_94_8 15
#define EXECUTE_CACHE_94_6 17
#define FREE_REFERENCES_LABEL_94_0 12
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto wt_tree_min_datum_4;

    case 1:
      current_block = (Rpc - LABEL_94_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_94_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_94_10);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_94_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_min_datum_8)
DEFLABEL (wt_tree_min_datum_4)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_94_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_94_0]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_94_7);

DEFLABEL (label_13)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_12;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_12;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_94_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_94_3]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 10)
    goto label_10;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_4]), 2);

DEFLABEL (label_10)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd15.Lng))))
    goto label_9;
  Rvl = ((Wrd13.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_94_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_2]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_7 5
#define LABEL_95_5 7
#define LABEL_95_10 9
#define LABEL_95_9 11
#define LABEL_95_12 13
#define LABEL_95_13 15
#define ENVIRONMENT_LABEL_95_3 29
#define DEBUGGING_LABEL_95_2 28
#define OBJECT_95_4 27
#define OBJECT_95_3 26
#define OBJECT_95_2 25
#define OBJECT_95_1 24
#define OBJECT_95_0 23
#define EXECUTE_CACHE_95_11 17
#define EXECUTE_CACHE_95_8 19
#define EXECUTE_CACHE_95_6 21
#define FREE_REFERENCES_LABEL_95_0 16
#define NUMBER_OF_LINKER_SECTIONS_95_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto wt_tree_min_pair_7;

    case 1:
      current_block = (Rpc - LABEL_95_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_95_10);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_95_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_95_12);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_95_13);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_min_pair_13)
DEFLABEL (wt_tree_min_pair_7)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_95_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_20;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_95_0]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_95_7);

DEFLABEL (label_20)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_19;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_19;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_18)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_95_9);
  (Rsp [0]) = Rvl;
  (Wrd16.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd16.uLng) == 10))
    goto label_17;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd14.Lng))))
    goto label_17;
  (Wrd8.Obj) = ((Wrd12.pObj) [5]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_16)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_15;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd30.Lng))))
    goto label_15;
  (Wrd22.Obj) = ((Wrd28.pObj) [3]);

DEFLABEL (label_14)
  (Wrd38.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd41.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd41.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (current_block [OBJECT_95_1]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_13]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_4]), 2);

DEFLABEL (label_11)
  (Wrd22.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_95_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_4]), 2);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_95_1]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_2]), 2);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_7 5
#define LABEL_96_5 7
#define LABEL_96_9 9
#define LABEL_96_11 11
#define LABEL_96_10 13
#define ENVIRONMENT_LABEL_96_3 28
#define DEBUGGING_LABEL_96_2 27
#define OBJECT_96_3 26
#define OBJECT_96_2 25
#define OBJECT_96_1 24
#define OBJECT_96_0 23
#define EXECUTE_CACHE_96_13 15
#define EXECUTE_CACHE_96_12 17
#define EXECUTE_CACHE_96_8 19
#define EXECUTE_CACHE_96_6 21
#define FREE_REFERENCES_LABEL_96_0 14
#define NUMBER_OF_LINKER_SECTIONS_96_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd28;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto wt_tree_delete_min_5;

    case 1:
      current_block = (Rpc - LABEL_96_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_96_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_96_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_96_11);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_96_10);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_delete_min_10)
DEFLABEL (wt_tree_delete_min_5)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_96_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_7]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_96_0]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_96_7);

DEFLABEL (label_15)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_14;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_14;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_13)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 62))
    goto label_12;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_12;
  (Wrd28.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_96_10);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_13]));

DEFLABEL (label_12)
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.Obj) = (current_block [OBJECT_96_3]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_11]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_2]), 2);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_96_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_2]), 2);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define LABEL_97_7 5
#define LABEL_97_5 7
#define LABEL_97_10 9
#define LABEL_97_9 11
#define ENVIRONMENT_LABEL_97_3 25
#define DEBUGGING_LABEL_97_2 24
#define OBJECT_97_4 23
#define OBJECT_97_3 22
#define OBJECT_97_2 21
#define OBJECT_97_1 20
#define OBJECT_97_0 19
#define EXECUTE_CACHE_97_11 13
#define EXECUTE_CACHE_97_8 15
#define EXECUTE_CACHE_97_6 17
#define FREE_REFERENCES_LABEL_97_0 12
#define NUMBER_OF_LINKER_SECTIONS_97_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
wttree_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto wt_tree_delete_minB_4;

    case 1:
      current_block = (Rpc - LABEL_97_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_97_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_97_10);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_97_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wt_tree_delete_minB_8)
DEFLABEL (wt_tree_delete_minB_4)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_97_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_7]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_97_0]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_97_7);

DEFLABEL (label_13)
  (Wrd7.Obj) = (current_block [OBJECT_97_1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd22.uLng) == 62))
    goto label_12;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_12;
  (Wrd14.Obj) = ((Wrd18.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_97_9);
  (Rsp [2]) = Rvl;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_10;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_4]), 3);

DEFLABEL (label_10)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_9;
  ((Wrd14.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_97_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd23.Obj) = (Rsp [3]);
  (Wrd24.Obj) = (current_block [OBJECT_97_1]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_10]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_2]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_10 5
#define LABEL_5 7
#define LABEL_6 9
#define LABEL_8 11
#define LABEL_9 13
#define LABEL_13 15
#define LABEL_19 17
#define LABEL_15 19
#define TAG_16 8
#define LABEL_17 21
#define LABEL_18 23
#define LABEL_20 25
#define LABEL_26 27
#define LABEL_21 29
#define LABEL_22 31
#define TAG_23 14
#define LABEL_27 33
#define LABEL_24 35
#define LABEL_25 37
#define LABEL_28 39
#define LABEL_33 41
#define LABEL_29 43
#define TAG_30 20
#define LABEL_31 45
#define LABEL_32 47
#define LABEL_34 49
#define LABEL_39 51
#define LABEL_35 53
#define TAG_36 25
#define LABEL_41 55
#define LABEL_37 57
#define LABEL_38 59
#define LABEL_42 61
#define LABEL_79 63
#define LABEL_45 65
#define LABEL_46 67
#define LABEL_80 69
#define LABEL_47 71
#define LABEL_81 73
#define LABEL_82 75
#define LABEL_48 77
#define LABEL_84 79
#define LABEL_85 81
#define LABEL_49 83
#define LABEL_87 85
#define LABEL_88 87
#define LABEL_50 89
#define LABEL_90 91
#define LABEL_91 93
#define LABEL_51 95
#define LABEL_93 97
#define LABEL_94 99
#define LABEL_52 101
#define LABEL_96 103
#define LABEL_53 105
#define LABEL_98 107
#define LABEL_54 109
#define LABEL_100 111
#define LABEL_55 113
#define LABEL_102 115
#define LABEL_56 117
#define LABEL_104 119
#define LABEL_57 121
#define LABEL_106 123
#define LABEL_58 125
#define LABEL_108 127
#define LABEL_59 129
#define LABEL_110 131
#define LABEL_60 133
#define LABEL_43 135
#define TAG_44 66
#define LABEL_64 137
#define LABEL_65 139
#define LABEL_112 141
#define LABEL_66 143
#define LABEL_113 145
#define LABEL_114 147
#define LABEL_67 149
#define LABEL_116 151
#define LABEL_117 153
#define LABEL_68 155
#define LABEL_119 157
#define LABEL_120 159
#define LABEL_69 161
#define LABEL_122 163
#define LABEL_123 165
#define LABEL_70 167
#define LABEL_125 169
#define LABEL_126 171
#define LABEL_71 173
#define LABEL_128 175
#define LABEL_72 177
#define LABEL_130 179
#define LABEL_73 181
#define LABEL_132 183
#define LABEL_74 185
#define LABEL_134 187
#define LABEL_75 189
#define LABEL_136 191
#define LABEL_76 193
#define LABEL_138 195
#define LABEL_77 197
#define LABEL_140 199
#define LABEL_78 201
#define LABEL_142 203
#define LABEL_62 205
#define TAG_63 101
#define LABEL_144 207
#define LABEL_145 209
#define LABEL_146 211
#define LABEL_147 213
#define LABEL_148 215
#define LABEL_149 217
#define LABEL_150 219
#define LABEL_151 221
#define LABEL_152 223
#define LABEL_153 225
#define LABEL_154 227
#define LABEL_155 229
#define LABEL_156 231
#define LABEL_157 233
#define LABEL_158 235
#define LABEL_159 237
#define LABEL_160 239
#define LABEL_161 241
#define LABEL_162 243
#define LABEL_163 245
#define LABEL_164 247
#define LABEL_165 249
#define LABEL_166 251
#define LABEL_167 253
#define LABEL_168 255
#define LABEL_169 257
#define LABEL_170 259
#define LABEL_172 261
#define LABEL_174 263
#define LABEL_176 265
#define LABEL_83 267
#define LABEL_177 269
#define LABEL_179 271
#define LABEL_180 273
#define LABEL_181 275
#define LABEL_182 277
#define LABEL_86 279
#define LABEL_184 281
#define LABEL_185 283
#define LABEL_186 285
#define LABEL_187 287
#define LABEL_188 289
#define LABEL_189 291
#define LABEL_89 293
#define LABEL_191 295
#define LABEL_192 297
#define LABEL_193 299
#define LABEL_194 301
#define LABEL_195 303
#define LABEL_196 305
#define LABEL_92 307
#define LABEL_198 309
#define LABEL_199 311
#define LABEL_200 313
#define LABEL_201 315
#define LABEL_202 317
#define LABEL_203 319
#define LABEL_95 321
#define LABEL_205 323
#define LABEL_206 325
#define LABEL_207 327
#define LABEL_208 329
#define LABEL_209 331
#define LABEL_210 333
#define LABEL_211 335
#define LABEL_212 337
#define LABEL_213 339
#define LABEL_215 341
#define LABEL_216 343
#define LABEL_97 345
#define LABEL_217 347
#define LABEL_218 349
#define LABEL_219 351
#define LABEL_220 353
#define LABEL_221 355
#define LABEL_222 357
#define LABEL_223 359
#define LABEL_224 361
#define LABEL_226 363
#define LABEL_227 365
#define LABEL_99 367
#define LABEL_228 369
#define LABEL_101 371
#define LABEL_103 373
#define LABEL_229 375
#define LABEL_230 377
#define LABEL_231 379
#define LABEL_232 381
#define LABEL_233 383
#define LABEL_234 385
#define LABEL_235 387
#define LABEL_105 389
#define LABEL_239 391
#define LABEL_107 393
#define LABEL_240 395
#define LABEL_241 397
#define LABEL_242 399
#define LABEL_243 401
#define LABEL_244 403
#define LABEL_245 405
#define LABEL_246 407
#define LABEL_247 409
#define LABEL_248 411
#define LABEL_249 413
#define LABEL_250 415
#define LABEL_109 417
#define LABEL_253 419
#define LABEL_254 421
#define LABEL_256 423
#define LABEL_257 425
#define LABEL_258 427
#define LABEL_259 429
#define LABEL_111 431
#define LABEL_261 433
#define LABEL_263 435
#define LABEL_265 437
#define LABEL_266 439
#define LABEL_267 441
#define LABEL_268 443
#define LABEL_269 445
#define LABEL_270 447
#define LABEL_271 449
#define LABEL_272 451
#define LABEL_274 453
#define LABEL_115 455
#define LABEL_275 457
#define LABEL_276 459
#define LABEL_277 461
#define LABEL_278 463
#define LABEL_279 465
#define LABEL_118 467
#define LABEL_281 469
#define LABEL_282 471
#define LABEL_283 473
#define LABEL_284 475
#define LABEL_285 477
#define LABEL_286 479
#define LABEL_121 481
#define LABEL_288 483
#define LABEL_289 485
#define LABEL_290 487
#define LABEL_291 489
#define LABEL_292 491
#define LABEL_293 493
#define LABEL_124 495
#define LABEL_295 497
#define LABEL_296 499
#define LABEL_297 501
#define LABEL_298 503
#define LABEL_299 505
#define LABEL_300 507
#define LABEL_127 509
#define LABEL_302 511
#define LABEL_303 513
#define LABEL_305 515
#define LABEL_129 517
#define LABEL_306 519
#define LABEL_307 521
#define LABEL_309 523
#define LABEL_131 525
#define LABEL_310 527
#define LABEL_133 529
#define LABEL_135 531
#define LABEL_311 533
#define LABEL_312 535
#define LABEL_313 537
#define LABEL_314 539
#define LABEL_315 541
#define LABEL_137 543
#define LABEL_317 545
#define LABEL_139 547
#define LABEL_318 549
#define LABEL_319 551
#define LABEL_320 553
#define LABEL_321 555
#define LABEL_322 557
#define LABEL_141 559
#define LABEL_324 561
#define LABEL_325 563
#define LABEL_327 565
#define LABEL_328 567
#define LABEL_329 569
#define LABEL_330 571
#define LABEL_143 573
#define LABEL_171 575
#define LABEL_331 577
#define LABEL_173 579
#define LABEL_175 581
#define LABEL_183 583
#define LABEL_190 585
#define LABEL_197 587
#define LABEL_204 589
#define LABEL_214 591
#define LABEL_225 593
#define LABEL_338 595
#define LABEL_339 597
#define LABEL_340 599
#define LABEL_341 601
#define LABEL_342 603
#define LABEL_343 605
#define LABEL_344 607
#define LABEL_345 609
#define LABEL_237 611
#define LABEL_238 613
#define LABEL_251 615
#define LABEL_252 617
#define LABEL_255 619
#define LABEL_347 621
#define LABEL_262 623
#define LABEL_349 625
#define LABEL_350 627
#define LABEL_273 629
#define LABEL_352 631
#define LABEL_354 633
#define LABEL_280 635
#define LABEL_287 637
#define LABEL_294 639
#define LABEL_301 641
#define LABEL_304 643
#define LABEL_360 645
#define LABEL_361 647
#define LABEL_308 649
#define LABEL_363 651
#define LABEL_364 653
#define LABEL_365 655
#define LABEL_367 657
#define LABEL_369 659
#define LABEL_316 661
#define LABEL_323 663
#define LABEL_326 665
#define LABEL_374 667
#define LABEL_332 669
#define LABEL_333 671
#define LABEL_334 673
#define LABEL_335 675
#define LABEL_336 677
#define LABEL_337 679
#define LABEL_379 681
#define LABEL_380 683
#define LABEL_381 685
#define LABEL_382 687
#define LABEL_383 689
#define LABEL_384 691
#define LABEL_385 693
#define LABEL_386 695
#define LABEL_387 697
#define LABEL_388 699
#define LABEL_389 701
#define LABEL_391 703
#define LABEL_392 705
#define LABEL_393 707
#define LABEL_394 709
#define LABEL_396 711
#define LABEL_397 713
#define LABEL_398 715
#define LABEL_399 717
#define LABEL_348 719
#define LABEL_400 721
#define LABEL_401 723
#define LABEL_402 725
#define LABEL_403 727
#define LABEL_404 729
#define LABEL_405 731
#define LABEL_406 733
#define LABEL_353 735
#define LABEL_351 737
#define LABEL_409 739
#define LABEL_411 741
#define LABEL_355 743
#define LABEL_356 745
#define LABEL_357 747
#define LABEL_358 749
#define LABEL_359 751
#define LABEL_416 753
#define LABEL_417 755
#define LABEL_418 757
#define LABEL_420 759
#define LABEL_362 761
#define LABEL_421 763
#define LABEL_422 765
#define LABEL_424 767
#define LABEL_368 769
#define LABEL_425 771
#define LABEL_426 773
#define LABEL_366 775
#define LABEL_371 777
#define LABEL_370 779
#define LABEL_373 781
#define LABEL_428 783
#define LABEL_429 785
#define LABEL_372 787
#define LABEL_430 789
#define LABEL_431 791
#define LABEL_375 793
#define LABEL_376 795
#define LABEL_436 797
#define LABEL_377 799
#define LABEL_438 801
#define LABEL_378 803
#define LABEL_395 805
#define LABEL_390 807
#define LABEL_407 809
#define LABEL_410 811
#define LABEL_408 813
#define LABEL_441 815
#define LABEL_412 817
#define LABEL_413 819
#define LABEL_445 821
#define LABEL_414 823
#define LABEL_447 825
#define LABEL_415 827
#define LABEL_419 829
#define LABEL_423 831
#define LABEL_449 833
#define LABEL_427 835
#define LABEL_432 837
#define LABEL_433 839
#define LABEL_435 841
#define LABEL_434 843
#define LABEL_437 845
#define LABEL_439 847
#define LABEL_440 849
#define LABEL_442 851
#define LABEL_444 853
#define LABEL_443 855
#define LABEL_446 857
#define LABEL_448 859
#define LABEL_456 861
#define LABEL_457 863
#define LABEL_458 865
#define LABEL_459 867
#define LABEL_460 869
#define LABEL_461 871
#define LABEL_462 873
#define LABEL_463 875
#define LABEL_464 877
#define LABEL_465 879
#define LABEL_466 881
#define LABEL_468 883
#define LABEL_469 885
#define LABEL_470 887
#define LABEL_471 889
#define LABEL_473 891
#define LABEL_474 893
#define LABEL_475 895
#define LABEL_450 897
#define LABEL_451 899
#define LABEL_452 901
#define LABEL_478 903
#define LABEL_453 905
#define LABEL_454 907
#define LABEL_455 909
#define LABEL_472 911
#define LABEL_467 913
#define LABEL_476 915
#define LABEL_480 917
#define LABEL_481 919
#define LABEL_479 921
#define LABEL_484 923
#define LABEL_485 925
#define LABEL_482 927
#define LABEL_486 929
#define LABEL_487 931
#define LABEL_488 933
#define LABEL_489 935
#define ENVIRONMENT_LABEL_3 1027
#define DEBUGGING_LABEL_2 1026
#define PURIFICATION_ROOT 1025
#define OBJECT_55 1024
#define OBJECT_54 1023
#define OBJECT_53 1022
#define OBJECT_52 1021
#define OBJECT_51 1020
#define OBJECT_50 1019
#define OBJECT_49 1018
#define OBJECT_48 1017
#define OBJECT_47 1016
#define OBJECT_46 1015
#define OBJECT_45 1014
#define OBJECT_44 1013
#define OBJECT_43 1012
#define OBJECT_42 1011
#define OBJECT_41 1010
#define OBJECT_40 1009
#define OBJECT_39 1008
#define OBJECT_38 1007
#define OBJECT_37 1006
#define OBJECT_36 1005
#define OBJECT_35 1004
#define OBJECT_34 1003
#define OBJECT_33 1002
#define OBJECT_32 1001
#define OBJECT_31 1000
#define OBJECT_30 999
#define OBJECT_29 998
#define OBJECT_28 997
#define OBJECT_27 996
#define OBJECT_26 995
#define OBJECT_25 994
#define OBJECT_24 993
#define OBJECT_23 992
#define OBJECT_22 991
#define OBJECT_21 990
#define OBJECT_20 989
#define OBJECT_19 988
#define OBJECT_18 987
#define OBJECT_17 986
#define OBJECT_16 985
#define OBJECT_15 984
#define OBJECT_14 983
#define OBJECT_13 982
#define OBJECT_12 981
#define OBJECT_11 980
#define OBJECT_10 979
#define OBJECT_9 978
#define OBJECT_8 977
#define OBJECT_7 976
#define OBJECT_6 975
#define OBJECT_5 974
#define OBJECT_4 973
#define OBJECT_3 972
#define OBJECT_2 971
#define OBJECT_1 970
#define OBJECT_0 969
#define EXECUTE_CACHE_483 937
#define EXECUTE_CACHE_477 939
#define EXECUTE_CACHE_346 941
#define EXECUTE_CACHE_264 943
#define EXECUTE_CACHE_260 945
#define EXECUTE_CACHE_236 947
#define EXECUTE_CACHE_178 949
#define EXECUTE_CACHE_61 951
#define EXECUTE_CACHE_40 953
#define EXECUTE_CACHE_7 955
#define FREE_REFERENCE_3 958
#define FREE_REFERENCE_2 959
#define FREE_REFERENCE_1 960
#define FREE_REFERENCE_0 961
#define GLOBAL_EXECUTE_CACHE_14 963
#define GLOBAL_EXECUTE_CACHE_12 965
#define GLOBAL_EXECUTE_CACHE_11 967
#define FREE_REFERENCES_LABEL_0 936
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
wttree_so_4251645db0305c5b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd73;
  machine_word Wrd229;
  machine_word Wrd228;
  machine_word Wrd197;
  machine_word Wrd148;
  machine_word Wrd147;
  machine_word Wrd319;
  machine_word Wrd318;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd315;
  machine_word Wrd312;
  machine_word Wrd301;
  machine_word Wrd309;
  machine_word Wrd304;
  machine_word Wrd306;
  machine_word Wrd305;
  machine_word Wrd290;
  machine_word Wrd298;
  machine_word Wrd297;
  machine_word Wrd296;
  machine_word Wrd300;
  machine_word Wrd299;
  machine_word Wrd281;
  machine_word Wrd289;
  machine_word Wrd284;
  machine_word Wrd286;
  machine_word Wrd285;
  machine_word Wrd278;
  machine_word Wrd277;
  machine_word Wrd276;
  machine_word Wrd280;
  machine_word Wrd279;
  machine_word Wrd261;
  machine_word Wrd269;
  machine_word Wrd264;
  machine_word Wrd265;
  machine_word Wrd258;
  machine_word Wrd257;
  machine_word Wrd260;
  machine_word Wrd259;
  machine_word Wrd241;
  machine_word Wrd249;
  machine_word Wrd232;
  machine_word Wrd238;
  machine_word Wrd237;
  machine_word Wrd240;
  machine_word Wrd322;
  machine_word Wrd324;
  machine_word Wrd327;
  machine_word Wrd325;
  machine_word Wrd331;
  machine_word Wrd330;
  machine_word Wrd329;
  machine_word Wrd102;
  machine_word Wrd86;
  machine_word Wrd188;
  machine_word Wrd189;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd164;
  machine_word Wrd151;
  machine_word Wrd180;
  machine_word Wrd215;
  machine_word Wrd119;
  machine_word Wrd75;
  machine_word Wrd70;
  machine_word Wrd130;
  machine_word Wrd165;
  machine_word Wrd150;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd143;
  machine_word Wrd132;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd105;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd90;
  machine_word Wrd91;
  machine_word Wrd74;
  machine_word Wrd68;
  machine_word Wrd58;
  machine_word Wrd205;
  machine_word Wrd256;
  machine_word Wrd251;
  machine_word Wrd253;
  machine_word Wrd252;
  machine_word Wrd239;
  machine_word Wrd245;
  machine_word Wrd244;
  machine_word Wrd243;
  machine_word Wrd247;
  machine_word Wrd246;
  machine_word Wrd236;
  machine_word Wrd233;
  machine_word Wrd231;
  machine_word Wrd222;
  machine_word Wrd230;
  machine_word Wrd225;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd219;
  machine_word Wrd218;
  machine_word Wrd217;
  machine_word Wrd221;
  machine_word Wrd220;
  machine_word Wrd204;
  machine_word Wrd200;
  machine_word Wrd187;
  machine_word Wrd176;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd171;
  machine_word Wrd166;
  machine_word Wrd162;
  machine_word Wrd149;
  machine_word Wrd145;
  machine_word Wrd142;
  machine_word Wrd131;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd109;
  machine_word Wrd114;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd103;
  machine_word Wrd88;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd85;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd56;
  machine_word Wrd64;
  machine_word Wrd263;
  machine_word Wrd266;
  machine_word Wrd270;
  machine_word Wrd216;
  machine_word Wrd213;
  machine_word Wrd212;
  machine_word Wrd201;
  machine_word Wrd209;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd211;
  machine_word Wrd210;
  machine_word Wrd199;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd184;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd190;
  machine_word Wrd194;
  machine_word Wrd193;
  machine_word Wrd181;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd175;
  machine_word Wrd172;
  machine_word Wrd169;
  machine_word Wrd168;
  machine_word Wrd167;
  machine_word Wrd170;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd146;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd129;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd128;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd113;
  machine_word Wrd104;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd89;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd87;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd72;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd71;
  machine_word Wrd59;
  machine_word Wrd67;
  machine_word Wrd65;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd106;
  machine_word Wrd163;
  machine_word Wrd45;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_10);
      goto label_609;

    case 2:
      current_block = (Rpc - LABEL_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_9);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_19);
      goto label_610;

    case 8:
      current_block = (Rpc - LABEL_15);
      goto Z__make_tree_type_840;

    case 9:
      current_block = (Rpc - LABEL_17);
      goto continuation_15;

    case 10:
      current_block = (Rpc - LABEL_18);
      goto continuation_9;

    case 11:
      current_block = (Rpc - LABEL_20);
      goto continuation_19;

    case 12:
      current_block = (Rpc - LABEL_26);
      goto label_611;

    case 13:
      current_block = (Rpc - LABEL_21);
      goto continuation_18;

    case 14:
      current_block = (Rpc - LABEL_22);
      goto tree_typeP_841;

    case 15:
      current_block = (Rpc - LABEL_27);
      goto label_612;

    case 16:
      current_block = (Rpc - LABEL_24);
      goto continuation_24;

    case 17:
      current_block = (Rpc - LABEL_25);
      goto continuation_20;

    case 18:
      current_block = (Rpc - LABEL_28);
      goto continuation_25;

    case 19:
      current_block = (Rpc - LABEL_33);
      goto label_613;

    case 20:
      current_block = (Rpc - LABEL_29);
      goto Z__make_wt_tree_842;

    case 21:
      current_block = (Rpc - LABEL_31);
      goto continuation_32;

    case 22:
      current_block = (Rpc - LABEL_32);
      goto continuation_26;

    case 23:
      current_block = (Rpc - LABEL_34);
      goto continuation_33;

    case 24:
      current_block = (Rpc - LABEL_39);
      goto label_614;

    case 25:
      current_block = (Rpc - LABEL_35);
      goto wt_treeP_843;

    case 26:
      current_block = (Rpc - LABEL_41);
      goto label_615;

    case 27:
      current_block = (Rpc - LABEL_37);
      goto continuation_35;

    case 28:
      current_block = (Rpc - LABEL_38);
      goto continuation_34;

    case 29:
      current_block = (Rpc - LABEL_42);
      goto continuation_329;

    case 30:
      current_block = (Rpc - LABEL_79);
      goto label_616;

    case 31:
      current_block = (Rpc - LABEL_45);
      goto continuation_38;

    case 32:
      current_block = (Rpc - LABEL_46);
      goto tree_rank_323;

    case 33:
      current_block = (Rpc - LABEL_80);
      goto label_617;

    case 34:
      current_block = (Rpc - LABEL_47);
      goto tree_subsetP_306;

    case 35:
      current_block = (Rpc - LABEL_81);
      goto label_618;

    case 36:
      current_block = (Rpc - LABEL_82);
      goto label_619;

    case 37:
      current_block = (Rpc - LABEL_48);
      goto tree_difference_303;

    case 38:
      current_block = (Rpc - LABEL_84);
      goto label_620;

    case 39:
      current_block = (Rpc - LABEL_85);
      goto label_621;

    case 40:
      current_block = (Rpc - LABEL_49);
      goto tree_intersection_298;

    case 41:
      current_block = (Rpc - LABEL_87);
      goto label_622;

    case 42:
      current_block = (Rpc - LABEL_88);
      goto label_623;

    case 43:
      current_block = (Rpc - LABEL_50);
      goto tree_union_merge_293;

    case 44:
      current_block = (Rpc - LABEL_90);
      goto label_624;

    case 45:
      current_block = (Rpc - LABEL_91);
      goto label_625;

    case 46:
      current_block = (Rpc - LABEL_51);
      goto tree_union_288;

    case 47:
      current_block = (Rpc - LABEL_93);
      goto label_626;

    case 48:
      current_block = (Rpc - LABEL_94);
      goto label_627;

    case 49:
      current_block = (Rpc - LABEL_52);
      goto tree_split_gt_283;

    case 50:
      current_block = (Rpc - LABEL_96);
      goto label_628;

    case 51:
      current_block = (Rpc - LABEL_53);
      goto tree_split_lt_279;

    case 52:
      current_block = (Rpc - LABEL_98);
      goto label_629;

    case 53:
      current_block = (Rpc - LABEL_54);
      goto tree_get_321;

    case 54:
      current_block = (Rpc - LABEL_100);
      goto label_630;

    case 55:
      current_block = (Rpc - LABEL_55);
      goto tree_memberP_326;

    case 56:
      current_block = (Rpc - LABEL_102);
      goto label_631;

    case 57:
      current_block = (Rpc - LABEL_56);
      goto tree_deleteB_275;

    case 58:
      current_block = (Rpc - LABEL_104);
      goto label_632;

    case 59:
      current_block = (Rpc - LABEL_57);
      goto tree_delete_272;

    case 60:
      current_block = (Rpc - LABEL_106);
      goto label_633;

    case 61:
      current_block = (Rpc - LABEL_58);
      goto tree_insertB_268;

    case 62:
      current_block = (Rpc - LABEL_108);
      goto label_634;

    case 63:
      current_block = (Rpc - LABEL_59);
      goto tree_map_add_265;

    case 64:
      current_block = (Rpc - LABEL_110);
      goto label_635;

    case 65:
      current_block = (Rpc - LABEL_60);
      goto lambda_37;

    case 66:
      current_block = (Rpc - LABEL_43);
      goto alist__tree_844;

    case 67:
      current_block = (Rpc - LABEL_64);
      goto continuation_331;

    case 68:
      current_block = (Rpc - LABEL_65);
      goto tree_rank_601;

    case 69:
      current_block = (Rpc - LABEL_112);
      goto label_636;

    case 70:
      current_block = (Rpc - LABEL_66);
      goto tree_subsetP_584;

    case 71:
      current_block = (Rpc - LABEL_113);
      goto label_637;

    case 72:
      current_block = (Rpc - LABEL_114);
      goto label_638;

    case 73:
      current_block = (Rpc - LABEL_67);
      goto tree_difference_581;

    case 74:
      current_block = (Rpc - LABEL_116);
      goto label_639;

    case 75:
      current_block = (Rpc - LABEL_117);
      goto label_640;

    case 76:
      current_block = (Rpc - LABEL_68);
      goto tree_intersection_576;

    case 77:
      current_block = (Rpc - LABEL_119);
      goto label_641;

    case 78:
      current_block = (Rpc - LABEL_120);
      goto label_642;

    case 79:
      current_block = (Rpc - LABEL_69);
      goto tree_union_merge_571;

    case 80:
      current_block = (Rpc - LABEL_122);
      goto label_643;

    case 81:
      current_block = (Rpc - LABEL_123);
      goto label_644;

    case 82:
      current_block = (Rpc - LABEL_70);
      goto tree_union_566;

    case 83:
      current_block = (Rpc - LABEL_125);
      goto label_645;

    case 84:
      current_block = (Rpc - LABEL_126);
      goto label_646;

    case 85:
      current_block = (Rpc - LABEL_71);
      goto tree_split_gt_561;

    case 86:
      current_block = (Rpc - LABEL_128);
      goto label_647;

    case 87:
      current_block = (Rpc - LABEL_72);
      goto tree_split_lt_557;

    case 88:
      current_block = (Rpc - LABEL_130);
      goto label_648;

    case 89:
      current_block = (Rpc - LABEL_73);
      goto tree_get_599;

    case 90:
      current_block = (Rpc - LABEL_132);
      goto label_649;

    case 91:
      current_block = (Rpc - LABEL_74);
      goto tree_memberP_604;

    case 92:
      current_block = (Rpc - LABEL_134);
      goto label_650;

    case 93:
      current_block = (Rpc - LABEL_75);
      goto tree_deleteB_553;

    case 94:
      current_block = (Rpc - LABEL_136);
      goto label_651;

    case 95:
      current_block = (Rpc - LABEL_76);
      goto tree_delete_550;

    case 96:
      current_block = (Rpc - LABEL_138);
      goto label_652;

    case 97:
      current_block = (Rpc - LABEL_77);
      goto tree_insertB_546;

    case 98:
      current_block = (Rpc - LABEL_140);
      goto label_653;

    case 99:
      current_block = (Rpc - LABEL_78);
      goto tree_map_add_543;

    case 100:
      current_block = (Rpc - LABEL_142);
      goto label_654;

    case 101:
      current_block = (Rpc - LABEL_62);
      goto alist__tree_845;

    case 102:
      current_block = (Rpc - LABEL_144);
      goto continuation_68;

    case 103:
      current_block = (Rpc - LABEL_145);
      goto continuation_63;

    case 104:
      current_block = (Rpc - LABEL_146);
      goto continuation_59;

    case 105:
      current_block = (Rpc - LABEL_147);
      goto continuation_56;

    case 106:
      current_block = (Rpc - LABEL_148);
      goto node_rank_73;

    case 107:
      current_block = (Rpc - LABEL_149);
      goto label_655;

    case 108:
      current_block = (Rpc - LABEL_150);
      goto label_656;

    case 109:
      current_block = (Rpc - LABEL_151);
      goto label_657;

    case 110:
      current_block = (Rpc - LABEL_152);
      goto label_658;

    case 111:
      current_block = (Rpc - LABEL_153);
      goto label_659;

    case 112:
      current_block = (Rpc - LABEL_154);
      goto label_660;

    case 113:
      current_block = (Rpc - LABEL_155);
      goto label_661;

    case 114:
      current_block = (Rpc - LABEL_156);
      goto label_662;

    case 115:
      current_block = (Rpc - LABEL_157);
      goto label_663;

    case 116:
      current_block = (Rpc - LABEL_158);
      goto label_664;

    case 117:
      current_block = (Rpc - LABEL_159);
      goto continuation_249;

    case 118:
      current_block = (Rpc - LABEL_160);
      goto continuation_246;

    case 119:
      current_block = (Rpc - LABEL_161);
      goto continuation_237;

    case 120:
      current_block = (Rpc - LABEL_162);
      goto continuation_239;

    case 121:
      current_block = (Rpc - LABEL_163);
      goto node_subsetP_261;

    case 122:
      current_block = (Rpc - LABEL_164);
      goto label_665;

    case 123:
      current_block = (Rpc - LABEL_165);
      goto label_666;

    case 124:
      current_block = (Rpc - LABEL_166);
      goto label_667;

    case 125:
      current_block = (Rpc - LABEL_167);
      goto label_668;

    case 126:
      current_block = (Rpc - LABEL_168);
      goto label_669;

    case 127:
      current_block = (Rpc - LABEL_169);
      goto label_670;

    case 128:
      current_block = (Rpc - LABEL_170);
      goto label_671;

    case 129:
      current_block = (Rpc - LABEL_172);
      goto label_672;

    case 130:
      current_block = (Rpc - LABEL_174);
      goto label_673;

    case 131:
      current_block = (Rpc - LABEL_176);
      goto label_674;

    case 132:
      current_block = (Rpc - LABEL_83);
      goto continuation_302;

    case 133:
      current_block = (Rpc - LABEL_177);
      goto label_675;

    case 134:
      current_block = (Rpc - LABEL_179);
      goto node_difference_218;

    case 135:
      current_block = (Rpc - LABEL_180);
      goto label_676;

    case 136:
      current_block = (Rpc - LABEL_181);
      goto label_677;

    case 137:
      current_block = (Rpc - LABEL_182);
      goto label_678;

    case 138:
      current_block = (Rpc - LABEL_86);
      goto continuation_297;

    case 139:
      current_block = (Rpc - LABEL_184);
      goto label_679;

    case 140:
      current_block = (Rpc - LABEL_185);
      goto node_intersection_234;

    case 141:
      current_block = (Rpc - LABEL_186);
      goto label_680;

    case 142:
      current_block = (Rpc - LABEL_187);
      goto label_681;

    case 143:
      current_block = (Rpc - LABEL_188);
      goto label_682;

    case 144:
      current_block = (Rpc - LABEL_189);
      goto label_683;

    case 145:
      current_block = (Rpc - LABEL_89);
      goto continuation_292;

    case 146:
      current_block = (Rpc - LABEL_191);
      goto label_684;

    case 147:
      current_block = (Rpc - LABEL_192);
      goto node_union_merge_205;

    case 148:
      current_block = (Rpc - LABEL_193);
      goto label_685;

    case 149:
      current_block = (Rpc - LABEL_194);
      goto label_686;

    case 150:
      current_block = (Rpc - LABEL_195);
      goto label_687;

    case 151:
      current_block = (Rpc - LABEL_196);
      goto label_688;

    case 152:
      current_block = (Rpc - LABEL_92);
      goto continuation_287;

    case 153:
      current_block = (Rpc - LABEL_198);
      goto label_689;

    case 154:
      current_block = (Rpc - LABEL_199);
      goto node_union_186;

    case 155:
      current_block = (Rpc - LABEL_200);
      goto label_690;

    case 156:
      current_block = (Rpc - LABEL_201);
      goto label_691;

    case 157:
      current_block = (Rpc - LABEL_202);
      goto label_692;

    case 158:
      current_block = (Rpc - LABEL_203);
      goto label_693;

    case 159:
      current_block = (Rpc - LABEL_95);
      goto continuation_282;

    case 160:
      current_block = (Rpc - LABEL_205);
      goto label_694;

    case 161:
      current_block = (Rpc - LABEL_206);
      goto continuation_165;

    case 162:
      current_block = (Rpc - LABEL_207);
      goto continuation_162;

    case 163:
      current_block = (Rpc - LABEL_208);
      goto node_split_gt_173;

    case 164:
      current_block = (Rpc - LABEL_209);
      goto label_695;

    case 165:
      current_block = (Rpc - LABEL_210);
      goto label_696;

    case 166:
      current_block = (Rpc - LABEL_211);
      goto label_697;

    case 167:
      current_block = (Rpc - LABEL_212);
      goto label_698;

    case 168:
      current_block = (Rpc - LABEL_213);
      goto label_699;

    case 169:
      current_block = (Rpc - LABEL_215);
      goto label_700;

    case 170:
      current_block = (Rpc - LABEL_216);
      goto label_701;

    case 171:
      current_block = (Rpc - LABEL_97);
      goto continuation_278;

    case 172:
      current_block = (Rpc - LABEL_217);
      goto label_702;

    case 173:
      current_block = (Rpc - LABEL_218);
      goto continuation_151;

    case 174:
      current_block = (Rpc - LABEL_219);
      goto continuation_148;

    case 175:
      current_block = (Rpc - LABEL_220);
      goto node_split_lt_159;

    case 176:
      current_block = (Rpc - LABEL_221);
      goto label_703;

    case 177:
      current_block = (Rpc - LABEL_222);
      goto label_704;

    case 178:
      current_block = (Rpc - LABEL_223);
      goto label_705;

    case 179:
      current_block = (Rpc - LABEL_224);
      goto label_706;

    case 180:
      current_block = (Rpc - LABEL_226);
      goto label_707;

    case 181:
      current_block = (Rpc - LABEL_227);
      goto label_708;

    case 182:
      current_block = (Rpc - LABEL_99);
      goto continuation_319;

    case 183:
      current_block = (Rpc - LABEL_228);
      goto node_find_53;

    case 184:
      current_block = (Rpc - LABEL_101);
      goto continuation_325;

    case 185:
      current_block = (Rpc - LABEL_103);
      goto continuation_274;

    case 186:
      current_block = (Rpc - LABEL_229);
      goto continuation_101;

    case 187:
      current_block = (Rpc - LABEL_230);
      goto continuation_99;

    case 188:
      current_block = (Rpc - LABEL_231);
      goto node_delete_106;

    case 189:
      current_block = (Rpc - LABEL_232);
      goto label_709;

    case 190:
      current_block = (Rpc - LABEL_233);
      goto label_710;

    case 191:
      current_block = (Rpc - LABEL_234);
      goto label_711;

    case 192:
      current_block = (Rpc - LABEL_235);
      goto label_712;

    case 193:
      current_block = (Rpc - LABEL_105);
      goto continuation_271;

    case 194:
      current_block = (Rpc - LABEL_239);
      goto label_713;

    case 195:
      current_block = (Rpc - LABEL_107);
      goto continuation_267;

    case 196:
      current_block = (Rpc - LABEL_240);
      goto continuation_84;

    case 197:
      current_block = (Rpc - LABEL_241);
      goto continuation_86;

    case 198:
      current_block = (Rpc - LABEL_242);
      goto continuation_81;

    case 199:
      current_block = (Rpc - LABEL_243);
      goto continuation_79;

    case 200:
      current_block = (Rpc - LABEL_244);
      goto node_add_93;

    case 201:
      current_block = (Rpc - LABEL_245);
      goto label_714;

    case 202:
      current_block = (Rpc - LABEL_246);
      goto label_715;

    case 203:
      current_block = (Rpc - LABEL_247);
      goto label_716;

    case 204:
      current_block = (Rpc - LABEL_248);
      goto label_717;

    case 205:
      current_block = (Rpc - LABEL_249);
      goto label_718;

    case 206:
      current_block = (Rpc - LABEL_250);
      goto label_719;

    case 207:
      current_block = (Rpc - LABEL_109);
      goto continuation_264;

    case 208:
      current_block = (Rpc - LABEL_253);
      goto label_720;

    case 209:
      current_block = (Rpc - LABEL_254);
      goto loop_316;

    case 210:
      current_block = (Rpc - LABEL_256);
      goto label_721;

    case 211:
      current_block = (Rpc - LABEL_257);
      goto label_722;

    case 212:
      current_block = (Rpc - LABEL_258);
      goto label_723;

    case 213:
      current_block = (Rpc - LABEL_259);
      goto label_724;

    case 214:
      current_block = (Rpc - LABEL_111);
      goto continuation_307;

    case 215:
      current_block = (Rpc - LABEL_261);
      goto node_rank_361;

    case 216:
      current_block = (Rpc - LABEL_263);
      goto label_725;

    case 217:
      current_block = (Rpc - LABEL_265);
      goto continuation_517;

    case 218:
      current_block = (Rpc - LABEL_266);
      goto continuation_519;

    case 219:
      current_block = (Rpc - LABEL_267);
      goto node_subsetP_539;

    case 220:
      current_block = (Rpc - LABEL_268);
      goto label_726;

    case 221:
      current_block = (Rpc - LABEL_269);
      goto label_727;

    case 222:
      current_block = (Rpc - LABEL_270);
      goto label_728;

    case 223:
      current_block = (Rpc - LABEL_271);
      goto label_729;

    case 224:
      current_block = (Rpc - LABEL_272);
      goto label_730;

    case 225:
      current_block = (Rpc - LABEL_274);
      goto label_731;

    case 226:
      current_block = (Rpc - LABEL_115);
      goto continuation_580;

    case 227:
      current_block = (Rpc - LABEL_275);
      goto label_732;

    case 228:
      current_block = (Rpc - LABEL_276);
      goto node_difference_498;

    case 229:
      current_block = (Rpc - LABEL_277);
      goto label_733;

    case 230:
      current_block = (Rpc - LABEL_278);
      goto label_734;

    case 231:
      current_block = (Rpc - LABEL_279);
      goto label_735;

    case 232:
      current_block = (Rpc - LABEL_118);
      goto continuation_575;

    case 233:
      current_block = (Rpc - LABEL_281);
      goto label_736;

    case 234:
      current_block = (Rpc - LABEL_282);
      goto node_intersection_514;

    case 235:
      current_block = (Rpc - LABEL_283);
      goto label_737;

    case 236:
      current_block = (Rpc - LABEL_284);
      goto label_738;

    case 237:
      current_block = (Rpc - LABEL_285);
      goto label_739;

    case 238:
      current_block = (Rpc - LABEL_286);
      goto label_740;

    case 239:
      current_block = (Rpc - LABEL_121);
      goto continuation_570;

    case 240:
      current_block = (Rpc - LABEL_288);
      goto label_741;

    case 241:
      current_block = (Rpc - LABEL_289);
      goto node_union_merge_485;

    case 242:
      current_block = (Rpc - LABEL_290);
      goto label_742;

    case 243:
      current_block = (Rpc - LABEL_291);
      goto label_743;

    case 244:
      current_block = (Rpc - LABEL_292);
      goto label_744;

    case 245:
      current_block = (Rpc - LABEL_293);
      goto label_745;

    case 246:
      current_block = (Rpc - LABEL_124);
      goto continuation_565;

    case 247:
      current_block = (Rpc - LABEL_295);
      goto label_746;

    case 248:
      current_block = (Rpc - LABEL_296);
      goto node_union_466;

    case 249:
      current_block = (Rpc - LABEL_297);
      goto label_747;

    case 250:
      current_block = (Rpc - LABEL_298);
      goto label_748;

    case 251:
      current_block = (Rpc - LABEL_299);
      goto label_749;

    case 252:
      current_block = (Rpc - LABEL_300);
      goto label_750;

    case 253:
      current_block = (Rpc - LABEL_127);
      goto continuation_560;

    case 254:
      current_block = (Rpc - LABEL_302);
      goto label_751;

    case 255:
      current_block = (Rpc - LABEL_303);
      goto node_split_gt_453;

    case 256:
      current_block = (Rpc - LABEL_305);
      goto label_752;

    case 257:
      current_block = (Rpc - LABEL_129);
      goto continuation_556;

    case 258:
      current_block = (Rpc - LABEL_306);
      goto label_753;

    case 259:
      current_block = (Rpc - LABEL_307);
      goto node_split_lt_441;

    case 260:
      current_block = (Rpc - LABEL_309);
      goto label_754;

    case 261:
      current_block = (Rpc - LABEL_131);
      goto continuation_597;

    case 262:
      current_block = (Rpc - LABEL_310);
      goto node_find_343;

    case 263:
      current_block = (Rpc - LABEL_133);
      goto continuation_603;

    case 264:
      current_block = (Rpc - LABEL_135);
      goto continuation_552;

    case 265:
      current_block = (Rpc - LABEL_311);
      goto node_delete_390;

    case 266:
      current_block = (Rpc - LABEL_312);
      goto label_755;

    case 267:
      current_block = (Rpc - LABEL_313);
      goto label_756;

    case 268:
      current_block = (Rpc - LABEL_314);
      goto label_757;

    case 269:
      current_block = (Rpc - LABEL_315);
      goto label_758;

    case 270:
      current_block = (Rpc - LABEL_137);
      goto continuation_549;

    case 271:
      current_block = (Rpc - LABEL_317);
      goto label_759;

    case 272:
      current_block = (Rpc - LABEL_139);
      goto continuation_545;

    case 273:
      current_block = (Rpc - LABEL_318);
      goto node_add_379;

    case 274:
      current_block = (Rpc - LABEL_319);
      goto label_760;

    case 275:
      current_block = (Rpc - LABEL_320);
      goto label_761;

    case 276:
      current_block = (Rpc - LABEL_321);
      goto label_762;

    case 277:
      current_block = (Rpc - LABEL_322);
      goto label_763;

    case 278:
      current_block = (Rpc - LABEL_141);
      goto continuation_542;

    case 279:
      current_block = (Rpc - LABEL_324);
      goto label_764;

    case 280:
      current_block = (Rpc - LABEL_325);
      goto loop_594;

    case 281:
      current_block = (Rpc - LABEL_327);
      goto label_765;

    case 282:
      current_block = (Rpc - LABEL_328);
      goto label_766;

    case 283:
      current_block = (Rpc - LABEL_329);
      goto label_767;

    case 284:
      current_block = (Rpc - LABEL_330);
      goto label_768;

    case 285:
      current_block = (Rpc - LABEL_143);
      goto continuation_585;

    case 286:
      current_block = (Rpc - LABEL_171);
      goto continuation_252;

    case 287:
      current_block = (Rpc - LABEL_331);
      goto label_769;

    case 288:
      current_block = (Rpc - LABEL_173);
      goto continuation_255;

    case 289:
      current_block = (Rpc - LABEL_175);
      goto continuation_258;

    case 290:
      current_block = (Rpc - LABEL_183);
      goto continuation_213;

    case 291:
      current_block = (Rpc - LABEL_190);
      goto continuation_226;

    case 292:
      current_block = (Rpc - LABEL_197);
      goto continuation_193;

    case 293:
      current_block = (Rpc - LABEL_204);
      goto continuation_181;

    case 294:
      current_block = (Rpc - LABEL_214);
      goto continuation_170;

    case 295:
      current_block = (Rpc - LABEL_225);
      goto continuation_157;

    case 296:
      current_block = (Rpc - LABEL_338);
      goto label_770;

    case 297:
      current_block = (Rpc - LABEL_339);
      goto continuation_43;

    case 298:
      current_block = (Rpc - LABEL_340);
      goto continuation_48;

    case 299:
      current_block = (Rpc - LABEL_341);
      goto loop_52;

    case 300:
      current_block = (Rpc - LABEL_342);
      goto label_774;

    case 301:
      current_block = (Rpc - LABEL_343);
      goto label_771;

    case 302:
      current_block = (Rpc - LABEL_344);
      goto label_772;

    case 303:
      current_block = (Rpc - LABEL_345);
      goto label_773;

    case 304:
      current_block = (Rpc - LABEL_237);
      goto continuation_103;

    case 305:
      current_block = (Rpc - LABEL_238);
      goto continuation_104;

    case 306:
      current_block = (Rpc - LABEL_251);
      goto continuation_90;

    case 307:
      current_block = (Rpc - LABEL_252);
      goto continuation_91;

    case 308:
      current_block = (Rpc - LABEL_255);
      goto continuation_315;

    case 309:
      current_block = (Rpc - LABEL_347);
      goto label_775;

    case 310:
      current_block = (Rpc - LABEL_262);
      goto continuation_346;

    case 311:
      current_block = (Rpc - LABEL_349);
      goto label_777;

    case 312:
      current_block = (Rpc - LABEL_350);
      goto label_776;

    case 313:
      current_block = (Rpc - LABEL_273);
      goto continuation_526;

    case 314:
      current_block = (Rpc - LABEL_352);
      goto label_779;

    case 315:
      current_block = (Rpc - LABEL_354);
      goto label_778;

    case 316:
      current_block = (Rpc - LABEL_280);
      goto continuation_493;

    case 317:
      current_block = (Rpc - LABEL_287);
      goto continuation_506;

    case 318:
      current_block = (Rpc - LABEL_294);
      goto continuation_473;

    case 319:
      current_block = (Rpc - LABEL_301);
      goto continuation_461;

    case 320:
      current_block = (Rpc - LABEL_304);
      goto continuation_444;

    case 321:
      current_block = (Rpc - LABEL_360);
      goto label_781;

    case 322:
      current_block = (Rpc - LABEL_361);
      goto label_780;

    case 323:
      current_block = (Rpc - LABEL_308);
      goto continuation_432;

    case 324:
      current_block = (Rpc - LABEL_363);
      goto label_783;

    case 325:
      current_block = (Rpc - LABEL_364);
      goto label_782;

    case 326:
      current_block = (Rpc - LABEL_365);
      goto loop_342;

    case 327:
      current_block = (Rpc - LABEL_367);
      goto label_785;

    case 328:
      current_block = (Rpc - LABEL_369);
      goto label_784;

    case 329:
      current_block = (Rpc - LABEL_316);
      goto continuation_385;

    case 330:
      current_block = (Rpc - LABEL_323);
      goto continuation_367;

    case 331:
      current_block = (Rpc - LABEL_326);
      goto continuation_593;

    case 332:
      current_block = (Rpc - LABEL_374);
      goto label_786;

    case 333:
      current_block = (Rpc - LABEL_332);
      goto continuation_256;

    case 334:
      current_block = (Rpc - LABEL_333);
      goto continuation_259;

    case 335:
      current_block = (Rpc - LABEL_334);
      goto continuation_212;

    case 336:
      current_block = (Rpc - LABEL_335);
      goto continuation_225;

    case 337:
      current_block = (Rpc - LABEL_336);
      goto continuation_194;

    case 338:
      current_block = (Rpc - LABEL_337);
      goto continuation_180;

    case 339:
      current_block = (Rpc - LABEL_379);
      goto continuation_126;

    case 340:
      current_block = (Rpc - LABEL_380);
      goto continuation_128;

    case 341:
      current_block = (Rpc - LABEL_381);
      goto continuation_118;

    case 342:
      current_block = (Rpc - LABEL_382);
      goto continuation_120;

    case 343:
      current_block = (Rpc - LABEL_383);
      goto node_concat3_145;

    case 344:
      current_block = (Rpc - LABEL_384);
      goto label_787;

    case 345:
      current_block = (Rpc - LABEL_385);
      goto label_788;

    case 346:
      current_block = (Rpc - LABEL_386);
      goto label_795;

    case 347:
      current_block = (Rpc - LABEL_387);
      goto label_796;

    case 348:
      current_block = (Rpc - LABEL_388);
      goto label_797;

    case 349:
      current_block = (Rpc - LABEL_389);
      goto label_798;

    case 350:
      current_block = (Rpc - LABEL_391);
      goto label_791;

    case 351:
      current_block = (Rpc - LABEL_392);
      goto label_792;

    case 352:
      current_block = (Rpc - LABEL_393);
      goto label_793;

    case 353:
      current_block = (Rpc - LABEL_394);
      goto label_794;

    case 354:
      current_block = (Rpc - LABEL_396);
      goto label_789;

    case 355:
      current_block = (Rpc - LABEL_397);
      goto label_790;

    case 356:
      current_block = (Rpc - LABEL_398);
      goto continuation_351;

    case 357:
      current_block = (Rpc - LABEL_399);
      goto continuation_356;

    case 358:
      current_block = (Rpc - LABEL_348);
      goto continuation_348;

    case 359:
      current_block = (Rpc - LABEL_400);
      goto label_803;

    case 360:
      current_block = (Rpc - LABEL_401);
      goto label_804;

    case 361:
      current_block = (Rpc - LABEL_402);
      goto label_805;

    case 362:
      current_block = (Rpc - LABEL_403);
      goto label_799;

    case 363:
      current_block = (Rpc - LABEL_404);
      goto label_800;

    case 364:
      current_block = (Rpc - LABEL_405);
      goto label_801;

    case 365:
      current_block = (Rpc - LABEL_406);
      goto label_802;

    case 366:
      current_block = (Rpc - LABEL_353);
      goto continuation_536;

    case 367:
      current_block = (Rpc - LABEL_351);
      goto continuation_528;

    case 368:
      current_block = (Rpc - LABEL_409);
      goto label_807;

    case 369:
      current_block = (Rpc - LABEL_411);
      goto label_806;

    case 370:
      current_block = (Rpc - LABEL_355);
      goto continuation_492;

    case 371:
      current_block = (Rpc - LABEL_356);
      goto continuation_505;

    case 372:
      current_block = (Rpc - LABEL_357);
      goto continuation_474;

    case 373:
      current_block = (Rpc - LABEL_358);
      goto continuation_460;

    case 374:
      current_block = (Rpc - LABEL_359);
      goto continuation_446;

    case 375:
      current_block = (Rpc - LABEL_416);
      goto label_808;

    case 376:
      current_block = (Rpc - LABEL_417);
      goto label_809;

    case 377:
      current_block = (Rpc - LABEL_418);
      goto label_810;

    case 378:
      current_block = (Rpc - LABEL_420);
      goto label_811;

    case 379:
      current_block = (Rpc - LABEL_362);
      goto continuation_434;

    case 380:
      current_block = (Rpc - LABEL_421);
      goto label_812;

    case 381:
      current_block = (Rpc - LABEL_422);
      goto label_813;

    case 382:
      current_block = (Rpc - LABEL_424);
      goto label_814;

    case 383:
      current_block = (Rpc - LABEL_368);
      goto continuation_339;

    case 384:
      current_block = (Rpc - LABEL_425);
      goto label_816;

    case 385:
      current_block = (Rpc - LABEL_426);
      goto label_815;

    case 386:
      current_block = (Rpc - LABEL_366);
      goto continuation_335;

    case 387:
      current_block = (Rpc - LABEL_371);
      goto continuation_388;

    case 388:
      current_block = (Rpc - LABEL_370);
      goto continuation_386;

    case 389:
      current_block = (Rpc - LABEL_373);
      goto continuation_377;

    case 390:
      current_block = (Rpc - LABEL_428);
      goto continuation_370;

    case 391:
      current_block = (Rpc - LABEL_429);
      goto continuation_372;

    case 392:
      current_block = (Rpc - LABEL_372);
      goto continuation_368;

    case 393:
      current_block = (Rpc - LABEL_430);
      goto label_817;

    case 394:
      current_block = (Rpc - LABEL_431);
      goto label_818;

    case 395:
      current_block = (Rpc - LABEL_375);
      goto continuation_215;

    case 396:
      current_block = (Rpc - LABEL_376);
      goto continuation_227;

    case 397:
      current_block = (Rpc - LABEL_436);
      goto continuation_196;

    case 398:
      current_block = (Rpc - LABEL_377);
      goto continuation_195;

    case 399:
      current_block = (Rpc - LABEL_438);
      goto label_819;

    case 400:
      current_block = (Rpc - LABEL_378);
      goto continuation_183;

    case 401:
      current_block = (Rpc - LABEL_395);
      goto continuation_136;

    case 402:
      current_block = (Rpc - LABEL_390);
      goto continuation_142;

    case 403:
      current_block = (Rpc - LABEL_407);
      goto continuation_537;

    case 404:
      current_block = (Rpc - LABEL_410);
      goto continuation_533;

    case 405:
      current_block = (Rpc - LABEL_408);
      goto continuation_530;

    case 406:
      current_block = (Rpc - LABEL_441);
      goto label_820;

    case 407:
      current_block = (Rpc - LABEL_412);
      goto continuation_495;

    case 408:
      current_block = (Rpc - LABEL_413);
      goto continuation_507;

    case 409:
      current_block = (Rpc - LABEL_445);
      goto continuation_476;

    case 410:
      current_block = (Rpc - LABEL_414);
      goto continuation_475;

    case 411:
      current_block = (Rpc - LABEL_447);
      goto label_821;

    case 412:
      current_block = (Rpc - LABEL_415);
      goto continuation_463;

    case 413:
      current_block = (Rpc - LABEL_419);
      goto continuation_450;

    case 414:
      current_block = (Rpc - LABEL_423);
      goto continuation_439;

    case 415:
      current_block = (Rpc - LABEL_449);
      goto label_822;

    case 416:
      current_block = (Rpc - LABEL_427);
      goto continuation_387;

    case 417:
      current_block = (Rpc - LABEL_432);
      goto continuation_376;

    case 418:
      current_block = (Rpc - LABEL_433);
      goto continuation_214;

    case 419:
      current_block = (Rpc - LABEL_435);
      goto continuation_231;

    case 420:
      current_block = (Rpc - LABEL_434);
      goto continuation_229;

    case 421:
      current_block = (Rpc - LABEL_437);
      goto continuation_199;

    case 422:
      current_block = (Rpc - LABEL_439);
      goto continuation_182;

    case 423:
      current_block = (Rpc - LABEL_440);
      goto continuation_534;

    case 424:
      current_block = (Rpc - LABEL_442);
      goto continuation_494;

    case 425:
      current_block = (Rpc - LABEL_444);
      goto continuation_511;

    case 426:
      current_block = (Rpc - LABEL_443);
      goto continuation_509;

    case 427:
      current_block = (Rpc - LABEL_446);
      goto continuation_479;

    case 428:
      current_block = (Rpc - LABEL_448);
      goto continuation_462;

    case 429:
      current_block = (Rpc - LABEL_456);
      goto continuation_410;

    case 430:
      current_block = (Rpc - LABEL_457);
      goto continuation_412;

    case 431:
      current_block = (Rpc - LABEL_458);
      goto continuation_402;

    case 432:
      current_block = (Rpc - LABEL_459);
      goto continuation_404;

    case 433:
      current_block = (Rpc - LABEL_460);
      goto node_concat3_429;

    case 434:
      current_block = (Rpc - LABEL_461);
      goto label_823;

    case 435:
      current_block = (Rpc - LABEL_462);
      goto label_824;

    case 436:
      current_block = (Rpc - LABEL_463);
      goto label_831;

    case 437:
      current_block = (Rpc - LABEL_464);
      goto label_832;

    case 438:
      current_block = (Rpc - LABEL_465);
      goto label_833;

    case 439:
      current_block = (Rpc - LABEL_466);
      goto label_834;

    case 440:
      current_block = (Rpc - LABEL_468);
      goto label_827;

    case 441:
      current_block = (Rpc - LABEL_469);
      goto label_828;

    case 442:
      current_block = (Rpc - LABEL_470);
      goto label_829;

    case 443:
      current_block = (Rpc - LABEL_471);
      goto label_830;

    case 444:
      current_block = (Rpc - LABEL_473);
      goto label_825;

    case 445:
      current_block = (Rpc - LABEL_474);
      goto label_826;

    case 446:
      current_block = (Rpc - LABEL_475);
      goto node_concat_114;

    case 447:
      current_block = (Rpc - LABEL_450);
      goto continuation_230;

    case 448:
      current_block = (Rpc - LABEL_451);
      goto continuation_228;

    case 449:
      current_block = (Rpc - LABEL_452);
      goto continuation_198;

    case 450:
      current_block = (Rpc - LABEL_478);
      goto node_concat_398;

    case 451:
      current_block = (Rpc - LABEL_453);
      goto continuation_510;

    case 452:
      current_block = (Rpc - LABEL_454);
      goto continuation_508;

    case 453:
      current_block = (Rpc - LABEL_455);
      goto continuation_478;

    case 454:
      current_block = (Rpc - LABEL_472);
      goto continuation_420;

    case 455:
      current_block = (Rpc - LABEL_467);
      goto continuation_426;

    case 456:
      current_block = (Rpc - LABEL_476);
      goto continuation_109;

    case 457:
      current_block = (Rpc - LABEL_480);
      goto label_835;

    case 458:
      current_block = (Rpc - LABEL_481);
      goto label_836;

    case 459:
      current_block = (Rpc - LABEL_479);
      goto continuation_393;

    case 460:
      current_block = (Rpc - LABEL_484);
      goto label_837;

    case 461:
      current_block = (Rpc - LABEL_485);
      goto label_838;

    case 462:
      current_block = (Rpc - LABEL_482);
      goto continuation_112;

    case 463:
      current_block = (Rpc - LABEL_486);
      goto continuation_396;

    case 464:
      current_block = (Rpc - LABEL_487);
      goto label_906;

    case 465:
      current_block = (Rpc - LABEL_488);
      goto label_907;

    case 466:
      current_block = (Rpc - LABEL_489);
      goto expression_608;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_608)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_488])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_907)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_906)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 97)
      goto label_905;
    blocks = (current_block [OBJECT_55]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_487])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_905)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_919;
  Wrd11 = Wrd15;

DEFLABEL (label_918)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_9);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x1111, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_15])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_917;
  Wrd11 = Wrd15;

DEFLABEL (label_916)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_18);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_22])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (current_block [OBJECT_23]);
  (Wrd16.Obj) = (current_block [OBJECT_24]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_25]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_12]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_21);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_915;
  Wrd11 = Wrd15;

DEFLABEL (label_914)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_25);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_29])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_913;
  Wrd11 = Wrd15;

DEFLABEL (label_912)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_32);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_35])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_911;
  Wrd11 = Wrd15;

DEFLABEL (label_910)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_38);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd9.pObj) = (& (Rhp [-1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd51.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_44);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_43])));
  Rhp += 1;
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd51.pObj)));
  (* (--Rsp)) = (Wrd52.Obj);
  ((Wrd51.pObj) [2]) = (Wrd10.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60]))));
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  (Wrd9.Obj) = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (continuation_329)
  INTERRUPT_CHECK (27, LABEL_42);
  (Wrd5.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd8.pObj) = (& (Rhp [-1]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd54.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62])));
  Rhp += 1;
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd54.pObj)));
  (* (--Rsp)) = (Wrd55.Obj);
  ((Wrd54.pObj) [2]) = (Wrd9.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd46.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd49.Obj) = ((Wrd46.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_909;
  Wrd45 = Wrd49;

DEFLABEL (label_908)
  (* (--Rsp)) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61]));

DEFLABEL (continuation_331)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  (Wrd9.Obj) = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (Rsp [2]) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17]), 3);

DEFLABEL (label_909)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79])), (Wrd46.pObj));

DEFLABEL (label_616)
  (Wrd45.Obj) = Rvl;
  goto label_908;

DEFLABEL (label_911)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_39])), (Wrd12.pObj));

DEFLABEL (label_614)
  (Wrd11.Obj) = Rvl;
  goto label_910;

DEFLABEL (label_913)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33])), (Wrd12.pObj));

DEFLABEL (label_613)
  (Wrd11.Obj) = Rvl;
  goto label_912;

DEFLABEL (label_915)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26])), (Wrd12.pObj));

DEFLABEL (label_611)
  (Wrd11.Obj) = Rvl;
  goto label_914;

DEFLABEL (label_917)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19])), (Wrd12.pObj));

DEFLABEL (label_610)
  (Wrd11.Obj) = Rvl;
  goto label_916;

DEFLABEL (label_919)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10])), (Wrd12.pObj));

DEFLABEL (label_609)
  (Wrd11.Obj) = Rvl;
  goto label_918;

DEFLABEL (Z__make_tree_type_840)
  CLOSURE_HEADER (LABEL_15);

DEFLABEL (Z__make_tree_type_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd25.Obj) = (MAKE_OBJECT (0, 17));
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (Rsp [4]);
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd15.Obj) = (Rsp [7]);
  (Wrd16.Obj) = (Rsp [8]);
  (Wrd17.Obj) = (Rsp [9]);
  (Wrd18.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd11.Obj) = (Rsp [11]);
  (Wrd12.Obj) = (Rsp [12]);
  (Wrd13.Obj) = (Rsp [13]);
  (Wrd14.Obj) = (Rsp [14]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd9.Obj) = (Rsp [15]);
  (Wrd10.Obj) = (Rsp [16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-18]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [17]));
  goto pop_return;

DEFLABEL (tree_typeP_841)
  CLOSURE_HEADER (LABEL_22);

DEFLABEL (tree_typeP_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_922;

DEFLABEL (label_921)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_920)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_922)
  if (! ((Wrd6.uLng) == 62))
    goto label_924;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_924;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_923)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_921;
  Rvl = (current_block [OBJECT_32]);
  goto label_920;

DEFLABEL (label_924)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_30]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_612)
  (Wrd9.Obj) = Rvl;
  goto label_923;

DEFLABEL (Z__make_wt_tree_842)
  CLOSURE_HEADER (LABEL_29);

DEFLABEL (Z__make_wt_tree_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd7.pObj) = (& (Rhp [-4]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (wt_treeP_843)
  CLOSURE_HEADER (LABEL_35);

DEFLABEL (wt_treeP_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_927;

DEFLABEL (label_926)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_925)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_927)
  if (! ((Wrd6.uLng) == 62))
    goto label_929;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_929;
  (Wrd9.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_928)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  if (! ((Wrd9.Obj) == (Wrd28.Obj)))
    goto label_926;
  Rvl = (current_block [OBJECT_32]);
  goto label_925;

DEFLABEL (label_929)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_30]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_615)
  (Wrd9.Obj) = Rvl;
  goto label_928;

DEFLABEL (tree_rank_846)
DEFLABEL (tree_rank_323)
  INTERRUPT_CHECK (26, LABEL_46);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_931;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd14.Lng))))
    goto label_931;
  (Wrd6.Obj) = ((Wrd12.pObj) [3]);

DEFLABEL (label_930)
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_30]);
  (Rsp [2]) = (Wrd22.Obj);
  goto node_rank_73;

DEFLABEL (label_931)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_42]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_617)
  (Wrd6.Obj) = Rvl;
  goto label_930;

DEFLABEL (tree_subsetP_847)
DEFLABEL (tree_subsetP_306)
  INTERRUPT_CHECK (26, LABEL_47);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_935;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_935;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_934)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_933;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_933;
  (Wrd21.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_932)
  (Rsp [1]) = (Wrd21.Obj);
  goto node_subsetP_261;

DEFLABEL (label_933)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_42]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_619)
  (Wrd21.Obj) = Rvl;
  goto label_932;

DEFLABEL (label_935)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_42]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_618)
  (Wrd5.Obj) = Rvl;
  goto label_934;

DEFLABEL (tree_difference_848)
DEFLABEL (tree_difference_303)
  INTERRUPT_CHECK (26, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_941;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_941;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_940)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_939;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_939;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_938)
  goto node_difference_218;

DEFLABEL (continuation_302)
  INTERRUPT_CHECK (27, LABEL_83);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_937;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_937;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_936)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_937)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_675)
  (Wrd6.Obj) = Rvl;
  goto label_936;

DEFLABEL (label_939)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_621)
  (* (--Rsp)) = Rvl;
  goto label_938;

DEFLABEL (label_941)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_620)
  (* (--Rsp)) = Rvl;
  goto label_940;

DEFLABEL (tree_intersection_849)
DEFLABEL (tree_intersection_298)
  INTERRUPT_CHECK (26, LABEL_49);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_947;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_947;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_946)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_945;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_945;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_944)
  goto node_intersection_234;

DEFLABEL (continuation_297)
  INTERRUPT_CHECK (27, LABEL_86);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_943;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_943;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_942)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_943)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_679)
  (Wrd6.Obj) = Rvl;
  goto label_942;

DEFLABEL (label_945)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_623)
  (* (--Rsp)) = Rvl;
  goto label_944;

DEFLABEL (label_947)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_622)
  (* (--Rsp)) = Rvl;
  goto label_946;

DEFLABEL (tree_union_merge_850)
DEFLABEL (tree_union_merge_293)
  INTERRUPT_CHECK (26, LABEL_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_953;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_953;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_952)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 62))
    goto label_951;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd33.Lng))))
    goto label_951;
  (Wrd27.Obj) = ((Wrd31.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_950)
  goto node_union_merge_205;

DEFLABEL (continuation_292)
  INTERRUPT_CHECK (27, LABEL_89);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_949;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_949;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_948)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_949)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_191]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_684)
  (Wrd6.Obj) = Rvl;
  goto label_948;

DEFLABEL (label_951)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_42]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_625)
  (* (--Rsp)) = Rvl;
  goto label_950;

DEFLABEL (label_953)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_624)
  (* (--Rsp)) = Rvl;
  goto label_952;

DEFLABEL (tree_union_851)
DEFLABEL (tree_union_288)
  INTERRUPT_CHECK (26, LABEL_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_959;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_959;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_958)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_957;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_957;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_956)
  goto node_union_186;

DEFLABEL (continuation_287)
  INTERRUPT_CHECK (27, LABEL_92);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_955;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_955;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_954)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_955)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_689)
  (Wrd6.Obj) = Rvl;
  goto label_954;

DEFLABEL (label_957)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_627)
  (* (--Rsp)) = Rvl;
  goto label_956;

DEFLABEL (label_959)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_626)
  (* (--Rsp)) = Rvl;
  goto label_958;

DEFLABEL (tree_split_gt_852)
DEFLABEL (tree_split_gt_283)
  INTERRUPT_CHECK (26, LABEL_52);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_963;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_963;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_962)
  goto node_split_gt_173;

DEFLABEL (continuation_282)
  INTERRUPT_CHECK (27, LABEL_95);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_961;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_961;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_960)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_961)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_205]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_694)
  (Wrd6.Obj) = Rvl;
  goto label_960;

DEFLABEL (label_963)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_628)
  (* (--Rsp)) = Rvl;
  goto label_962;

DEFLABEL (tree_split_lt_853)
DEFLABEL (tree_split_lt_279)
  INTERRUPT_CHECK (26, LABEL_53);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_967;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_967;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_966)
  goto node_split_lt_159;

DEFLABEL (continuation_278)
  INTERRUPT_CHECK (27, LABEL_97);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_965;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_965;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_964)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_965)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_217]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_702)
  (Wrd6.Obj) = Rvl;
  goto label_964;

DEFLABEL (label_967)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_629)
  (* (--Rsp)) = Rvl;
  goto label_966;

DEFLABEL (tree_get_854)
DEFLABEL (tree_get_321)
  INTERRUPT_CHECK (26, LABEL_54);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_972;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_972;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_971)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_find_53;

DEFLABEL (continuation_319)
  INTERRUPT_CHECK (27, LABEL_99);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_968;
  Rvl = (Rsp [3]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_968)
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_48]);
  (Rsp [3]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_970;

DEFLABEL (label_969)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_970)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_969;
  Rvl = ((Wrd16.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_972)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_630)
  (* (--Rsp)) = Rvl;
  goto label_971;

DEFLABEL (tree_memberP_855)
DEFLABEL (tree_memberP_326)
  INTERRUPT_CHECK (26, LABEL_55);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_977;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_977;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_976)
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_find_53;

DEFLABEL (continuation_325)
  INTERRUPT_CHECK (27, LABEL_101);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_974;
  Rvl = (current_block [OBJECT_32]);
  goto label_973;

DEFLABEL (label_974)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_973)
DEFLABEL (label_975)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_977)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_631)
  (* (--Rsp)) = Rvl;
  goto label_976;

DEFLABEL (tree_deleteB_856)
DEFLABEL (tree_deleteB_275)
  INTERRUPT_CHECK (26, LABEL_56);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_981;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_981;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_980)
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  goto node_delete_106;

DEFLABEL (continuation_274)
  INTERRUPT_CHECK (27, LABEL_103);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_42]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_979;

DEFLABEL (label_978)
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 3);

DEFLABEL (label_979)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_978;
  ((Wrd15.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_49]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_981)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_632)
  (* (--Rsp)) = Rvl;
  goto label_980;

DEFLABEL (tree_delete_857)
DEFLABEL (tree_delete_272)
  INTERRUPT_CHECK (26, LABEL_57);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_985;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_985;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_984)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_delete_106;

DEFLABEL (continuation_271)
  INTERRUPT_CHECK (27, LABEL_105);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_983;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_983;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_982)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_983)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_713)
  (Wrd6.Obj) = Rvl;
  goto label_982;

DEFLABEL (label_985)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_633)
  (* (--Rsp)) = Rvl;
  goto label_984;

DEFLABEL (tree_insertB_858)
DEFLABEL (tree_insertB_268)
  INTERRUPT_CHECK (26, LABEL_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_989;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_989;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_988)
  goto node_add_93;

DEFLABEL (continuation_267)
  INTERRUPT_CHECK (27, LABEL_107);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_42]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_987;

DEFLABEL (label_986)
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 3);

DEFLABEL (label_987)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_986;
  ((Wrd15.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_49]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_989)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_634)
  (* (--Rsp)) = Rvl;
  goto label_988;

DEFLABEL (tree_map_add_859)
DEFLABEL (tree_map_add_265)
  INTERRUPT_CHECK (26, LABEL_59);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_993;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_993;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_992)
  goto node_add_93;

DEFLABEL (continuation_264)
  INTERRUPT_CHECK (27, LABEL_109);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_991;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_991;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_990)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_991)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_720)
  (Wrd6.Obj) = Rvl;
  goto label_990;

DEFLABEL (label_993)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_635)
  (* (--Rsp)) = Rvl;
  goto label_992;

DEFLABEL (lambda_860)
DEFLABEL (lambda_37)
  INTERRUPT_CHECK (26, LABEL_60);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd7.uLng) == 26)
    goto label_995;

DEFLABEL (label_994)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_995)
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 26))
    goto label_994;
  (Wrd11.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
  if ((Wrd11.Lng) < (Wrd13.Lng))
    goto label_997;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_996;

DEFLABEL (label_997)
  Rvl = (current_block [OBJECT_32]);

DEFLABEL (label_996)
DEFLABEL (label_998)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (alist__tree_844)
  CLOSURE_HEADER (LABEL_43);

DEFLABEL (alist__tree_317)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_316;

DEFLABEL (continuation_307)
  INTERRUPT_CHECK (27, LABEL_111);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_999)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd10.pObj) [0]);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (tree_rank_861)
DEFLABEL (tree_rank_601)
  INTERRUPT_CHECK (26, LABEL_65);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1001;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1001;
  (Wrd6.Obj) = ((Wrd12.pObj) [3]);

DEFLABEL (label_1000)
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_30]);
  (Rsp [2]) = (Wrd22.Obj);
  goto node_rank_361;

DEFLABEL (label_1001)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_42]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_636)
  (Wrd6.Obj) = Rvl;
  goto label_1000;

DEFLABEL (tree_subsetP_862)
DEFLABEL (tree_subsetP_584)
  INTERRUPT_CHECK (26, LABEL_66);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_1005;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_1005;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_1004)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 62))
    goto label_1003;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_1003;
  (Wrd21.Obj) = ((Wrd27.pObj) [3]);

DEFLABEL (label_1002)
  (Rsp [1]) = (Wrd21.Obj);
  goto node_subsetP_539;

DEFLABEL (label_1003)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_42]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_638)
  (Wrd21.Obj) = Rvl;
  goto label_1002;

DEFLABEL (label_1005)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_42]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_637)
  (Wrd5.Obj) = Rvl;
  goto label_1004;

DEFLABEL (tree_difference_863)
DEFLABEL (tree_difference_581)
  INTERRUPT_CHECK (26, LABEL_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1011;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1011;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1010)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_1009;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_1009;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_1008)
  goto node_difference_498;

DEFLABEL (continuation_580)
  INTERRUPT_CHECK (27, LABEL_115);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1007;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1007;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1006)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1007)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_275]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_732)
  (Wrd6.Obj) = Rvl;
  goto label_1006;

DEFLABEL (label_1009)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_640)
  (* (--Rsp)) = Rvl;
  goto label_1008;

DEFLABEL (label_1011)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_639)
  (* (--Rsp)) = Rvl;
  goto label_1010;

DEFLABEL (tree_intersection_864)
DEFLABEL (tree_intersection_576)
  INTERRUPT_CHECK (26, LABEL_68);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1017;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1017;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1016)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_1015;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_1015;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_1014)
  goto node_intersection_514;

DEFLABEL (continuation_575)
  INTERRUPT_CHECK (27, LABEL_118);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1013;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1013;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1012)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1013)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_281]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_736)
  (Wrd6.Obj) = Rvl;
  goto label_1012;

DEFLABEL (label_1015)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_642)
  (* (--Rsp)) = Rvl;
  goto label_1014;

DEFLABEL (label_1017)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_641)
  (* (--Rsp)) = Rvl;
  goto label_1016;

DEFLABEL (tree_union_merge_865)
DEFLABEL (tree_union_merge_571)
  INTERRUPT_CHECK (26, LABEL_69);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_1023;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1023;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1022)
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 62))
    goto label_1021;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1021;
  (Wrd27.Obj) = ((Wrd31.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1020)
  goto node_union_merge_485;

DEFLABEL (continuation_570)
  INTERRUPT_CHECK (27, LABEL_121);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1019;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1019;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1018)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1019)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_288]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_741)
  (Wrd6.Obj) = Rvl;
  goto label_1018;

DEFLABEL (label_1021)
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.Obj) = (current_block [OBJECT_42]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_644)
  (* (--Rsp)) = Rvl;
  goto label_1020;

DEFLABEL (label_1023)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_643)
  (* (--Rsp)) = Rvl;
  goto label_1022;

DEFLABEL (tree_union_866)
DEFLABEL (tree_union_566)
  INTERRUPT_CHECK (26, LABEL_70);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1029;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1029;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1028)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_1027;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd32.Lng))))
    goto label_1027;
  (Wrd26.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_1026)
  goto node_union_466;

DEFLABEL (continuation_565)
  INTERRUPT_CHECK (27, LABEL_124);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1025;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1025;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1024)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1025)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_295]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_746)
  (Wrd6.Obj) = Rvl;
  goto label_1024;

DEFLABEL (label_1027)
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (current_block [OBJECT_42]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_646)
  (* (--Rsp)) = Rvl;
  goto label_1026;

DEFLABEL (label_1029)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_645)
  (* (--Rsp)) = Rvl;
  goto label_1028;

DEFLABEL (tree_split_gt_867)
DEFLABEL (tree_split_gt_561)
  INTERRUPT_CHECK (26, LABEL_71);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_1033;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1033;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1032)
  goto node_split_gt_453;

DEFLABEL (continuation_560)
  INTERRUPT_CHECK (27, LABEL_127);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1031;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1031;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1030)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1031)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_302]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_751)
  (Wrd6.Obj) = Rvl;
  goto label_1030;

DEFLABEL (label_1033)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_647)
  (* (--Rsp)) = Rvl;
  goto label_1032;

DEFLABEL (tree_split_lt_868)
DEFLABEL (tree_split_lt_557)
  INTERRUPT_CHECK (26, LABEL_72);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_1037;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1037;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1036)
  goto node_split_lt_441;

DEFLABEL (continuation_556)
  INTERRUPT_CHECK (27, LABEL_129);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1035;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1035;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1034)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1035)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_306]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_753)
  (Wrd6.Obj) = Rvl;
  goto label_1034;

DEFLABEL (label_1037)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_648)
  (* (--Rsp)) = Rvl;
  goto label_1036;

DEFLABEL (tree_get_869)
DEFLABEL (tree_get_599)
  INTERRUPT_CHECK (26, LABEL_73);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1042;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1042;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1041)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_find_343;

DEFLABEL (continuation_597)
  INTERRUPT_CHECK (27, LABEL_131);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1038;
  Rvl = (Rsp [3]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_1038)
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_48]);
  (Rsp [3]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 10)
    goto label_1040;

DEFLABEL (label_1039)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_1040)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1039;
  Rvl = ((Wrd16.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1042)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_649)
  (* (--Rsp)) = Rvl;
  goto label_1041;

DEFLABEL (tree_memberP_870)
DEFLABEL (tree_memberP_604)
  INTERRUPT_CHECK (26, LABEL_74);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1047;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1047;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1046)
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_find_343;

DEFLABEL (continuation_603)
  INTERRUPT_CHECK (27, LABEL_133);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1044;
  Rvl = (current_block [OBJECT_32]);
  goto label_1043;

DEFLABEL (label_1044)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_1043)
DEFLABEL (label_1045)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1047)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_650)
  (* (--Rsp)) = Rvl;
  goto label_1046;

DEFLABEL (tree_deleteB_871)
DEFLABEL (tree_deleteB_553)
  INTERRUPT_CHECK (26, LABEL_75);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd19.uLng) == 62))
    goto label_1051;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1051;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1050)
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  goto node_delete_390;

DEFLABEL (continuation_552)
  INTERRUPT_CHECK (27, LABEL_135);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_42]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_1049;

DEFLABEL (label_1048)
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 3);

DEFLABEL (label_1049)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1048;
  ((Wrd15.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_49]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1051)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_42]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_136]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_651)
  (* (--Rsp)) = Rvl;
  goto label_1050;

DEFLABEL (tree_delete_872)
DEFLABEL (tree_delete_550)
  INTERRUPT_CHECK (26, LABEL_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 62))
    goto label_1055;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_1055;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_1054)
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto node_delete_390;

DEFLABEL (continuation_549)
  INTERRUPT_CHECK (27, LABEL_137);
  (Rsp [1]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1053;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1053;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1052)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1053)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_317]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_759)
  (Wrd6.Obj) = Rvl;
  goto label_1052;

DEFLABEL (label_1055)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_42]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_652)
  (* (--Rsp)) = Rvl;
  goto label_1054;

DEFLABEL (tree_insertB_873)
DEFLABEL (tree_insertB_546)
  INTERRUPT_CHECK (26, LABEL_77);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_1059;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1059;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1058)
  goto node_add_379;

DEFLABEL (continuation_545)
  INTERRUPT_CHECK (27, LABEL_139);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_42]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_1057;

DEFLABEL (label_1056)
  INVOKE_PRIMITIVE ((current_block [OBJECT_50]), 3);

DEFLABEL (label_1057)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1056;
  ((Wrd15.pObj) [3]) = Rvl;
  Rvl = (current_block [OBJECT_49]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1059)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_653)
  (* (--Rsp)) = Rvl;
  goto label_1058;

DEFLABEL (tree_map_add_874)
DEFLABEL (tree_map_add_543)
  INTERRUPT_CHECK (26, LABEL_78);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_1063;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1063;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1062)
  goto node_add_379;

DEFLABEL (continuation_542)
  INTERRUPT_CHECK (27, LABEL_141);
  (Rsp [2]) = Rvl;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_1061;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1061;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1060)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (label_1061)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_324]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_764)
  (Wrd6.Obj) = Rvl;
  goto label_1060;

DEFLABEL (label_1063)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31]), 2);

DEFLABEL (label_654)
  (* (--Rsp)) = Rvl;
  goto label_1062;

DEFLABEL (alist__tree_845)
  CLOSURE_HEADER (LABEL_62);

DEFLABEL (alist__tree_595)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_594;

DEFLABEL (continuation_585)
  INTERRUPT_CHECK (27, LABEL_143);
  (Wrd5.Obj) = Rvl;

DEFLABEL (label_1064)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd10.pObj) [0]);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178]));

DEFLABEL (node_rank_875)
DEFLABEL (node_rank_73)
  INTERRUPT_CHECK (26, LABEL_148);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_43]))
    goto label_1102;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1101;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1101;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1100)
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_1066;

DEFLABEL (label_1065)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1066)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 26))
    goto label_1065;
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if ((Wrd34.Lng) < (Wrd36.Lng))
    goto label_1068;
  (Wrd28.Obj) = (current_block [OBJECT_45]);
  goto label_1067;

DEFLABEL (label_1068)
  (Wrd28.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1067)
DEFLABEL (label_1099)
  Rsp = (& (Rsp [3]));
  if ((Wrd28.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1072;

DEFLABEL (label_1071)
  (Wrd210.Obj) = (Rsp [1]);
  (Wrd211.uLng) = (OBJECT_TYPE (Wrd210.Obj));
  if (! ((Wrd211.uLng) == 10))
    goto label_1070;
  (Wrd207.pObj) = (OBJECT_ADDRESS (Wrd210.Obj));
  (Wrd208.Obj) = ((Wrd207.pObj) [0]);
  (Wrd209.Lng) = (FIXNUM_TO_LONG (Wrd208.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd209.Lng))))
    goto label_1070;
  (Wrd201.Obj) = ((Wrd207.pObj) [2]);

DEFLABEL (label_1069)
  (Rsp [1]) = (Wrd201.Obj);
  goto node_rank_73;

DEFLABEL (label_1070)
  (Wrd212.Obj) = (Rsp [1]);
  (Wrd213.Obj) = (current_block [OBJECT_46]);
  (Wrd216.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158]))));
  (* (--Rsp)) = (Wrd216.Obj);
  (* (--Rsp)) = (Wrd213.Obj);
  (* (--Rsp)) = (Wrd212.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_664)
  (Wrd201.Obj) = Rvl;
  goto label_1069;

DEFLABEL (label_1072)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_1098;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd50.Lng))))
    goto label_1098;
  (Wrd44.Obj) = ((Wrd48.pObj) [3]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_1097)
  (Wrd60.Obj) = (Rsp [0]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd61.uLng) == 26))
    goto label_1065;
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 26))
    goto label_1065;
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if ((Wrd65.Lng) < (Wrd67.Lng))
    goto label_1074;
  (Wrd59.Obj) = (current_block [OBJECT_45]);
  goto label_1073;

DEFLABEL (label_1074)
  (Wrd59.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1073)
DEFLABEL (label_1096)
  Rsp = (& (Rsp [3]));
  if ((Wrd59.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1086;

DEFLABEL (label_1085)
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (Wrd138.Obj) = (Rsp [2]);
  (Wrd139.uLng) = (OBJECT_TYPE (Wrd138.Obj));
  if (! ((Wrd139.uLng) == 10))
    goto label_1084;
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd138.Obj));
  (Wrd136.Obj) = ((Wrd135.pObj) [0]);
  (Wrd137.Lng) = (FIXNUM_TO_LONG (Wrd136.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd137.Lng))))
    goto label_1084;
  (Wrd129.Obj) = ((Wrd135.pObj) [2]);

DEFLABEL (label_1083)
  if ((Wrd129.Obj) == (current_block [OBJECT_43]))
    goto label_1082;
  (Wrd155.Obj) = (Rsp [2]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if (! ((Wrd156.uLng) == 10))
    goto label_1081;
  (Wrd152.pObj) = (OBJECT_ADDRESS (Wrd155.Obj));
  (Wrd153.Obj) = ((Wrd152.pObj) [0]);
  (Wrd154.Lng) = (FIXNUM_TO_LONG (Wrd153.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd154.Lng))))
    goto label_1081;
  (Wrd146.Obj) = ((Wrd152.pObj) [2]);

DEFLABEL (label_1080)
  (Wrd170.uLng) = (OBJECT_TYPE (Wrd146.Obj));
  if (! ((Wrd170.uLng) == 10))
    goto label_1079;
  (Wrd167.pObj) = (OBJECT_ADDRESS (Wrd146.Obj));
  (Wrd168.Obj) = ((Wrd167.pObj) [0]);
  (Wrd169.Lng) = (FIXNUM_TO_LONG (Wrd168.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd169.Lng))))
    goto label_1079;
  (Wrd163.Obj) = ((Wrd167.pObj) [1]);

DEFLABEL (label_1078)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1077)
  (Wrd177.Obj) = (Rsp [2]);
  (Wrd178.Lng) = (FIXNUM_TO_LONG (Wrd177.Obj));
  (Wrd179.Lng) = (FIXNUM_TO_LONG (Wrd163.Obj));
  (Wrd182.Lng) = ((Wrd178.Lng) + (Wrd179.Lng));
  (Wrd183.Lng) = ((Wrd182.Lng) + 1L);
  (Wrd181.Obj) = (LONG_TO_FIXNUM (Wrd183.Lng));
  (Rsp [2]) = (Wrd181.Obj);
  (Wrd193.Obj) = (Rsp [1]);
  (Wrd194.uLng) = (OBJECT_TYPE (Wrd193.Obj));
  if (! ((Wrd194.uLng) == 10))
    goto label_1076;
  (Wrd190.pObj) = (OBJECT_ADDRESS (Wrd193.Obj));
  (Wrd191.Obj) = ((Wrd190.pObj) [0]);
  (Wrd192.Lng) = (FIXNUM_TO_LONG (Wrd191.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd192.Lng))))
    goto label_1076;
  (Wrd184.Obj) = ((Wrd190.pObj) [4]);

DEFLABEL (label_1075)
  (Rsp [1]) = (Wrd184.Obj);
  goto node_rank_73;

DEFLABEL (label_1076)
  (Wrd195.Obj) = (Rsp [1]);
  (Wrd196.Obj) = (current_block [OBJECT_47]);
  (Wrd199.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157]))));
  (* (--Rsp)) = (Wrd199.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  (* (--Rsp)) = (Wrd195.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_663)
  (Wrd184.Obj) = Rvl;
  goto label_1075;

DEFLABEL (label_1079)
  (Wrd172.Obj) = (current_block [OBJECT_30]);
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156]))));
  (* (--Rsp)) = (Wrd175.Obj);
  (* (--Rsp)) = (Wrd172.Obj);
  (* (--Rsp)) = (Wrd146.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_662)
  (Wrd163.Obj) = Rvl;
  goto label_1078;

DEFLABEL (label_1081)
  (Wrd157.Obj) = (Rsp [2]);
  (Wrd158.Obj) = (current_block [OBJECT_46]);
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_155]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_661)
  (Wrd146.Obj) = Rvl;
  goto label_1080;

DEFLABEL (label_1082)
  (Wrd163.Obj) = (current_block [OBJECT_30]);
  goto label_1078;

DEFLABEL (label_1084)
  (Wrd140.Obj) = (Rsp [2]);
  (Wrd141.Obj) = (current_block [OBJECT_46]);
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154]))));
  (* (--Rsp)) = (Wrd144.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd140.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_660)
  (Wrd129.Obj) = Rvl;
  goto label_1083;

DEFLABEL (label_1086)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd81.Obj) = (Rsp [2]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 10))
    goto label_1095;
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd80.Lng))))
    goto label_1095;
  (Wrd72.Obj) = ((Wrd78.pObj) [2]);

DEFLABEL (label_1094)
  if ((Wrd72.Obj) == (current_block [OBJECT_43]))
    goto label_1093;
  (Wrd98.Obj) = (Rsp [2]);
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if (! ((Wrd99.uLng) == 10))
    goto label_1092;
  (Wrd95.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd96.Obj) = ((Wrd95.pObj) [0]);
  (Wrd97.Lng) = (FIXNUM_TO_LONG (Wrd96.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd97.Lng))))
    goto label_1092;
  (Wrd89.Obj) = ((Wrd95.pObj) [2]);

DEFLABEL (label_1091)
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_1090;
  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd111.Obj) = ((Wrd110.pObj) [0]);
  (Wrd112.Lng) = (FIXNUM_TO_LONG (Wrd111.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd112.Lng))))
    goto label_1090;
  (Wrd106.Obj) = ((Wrd110.pObj) [1]);

DEFLABEL (label_1089)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1088)
  (Wrd120.Obj) = (Rsp [2]);
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd120.Obj));
  (Wrd122.Lng) = (FIXNUM_TO_LONG (Wrd106.Obj));
  (Wrd123.Lng) = ((Wrd121.Lng) + (Wrd122.Lng));
  Rvl = (LONG_TO_FIXNUM (Wrd123.Lng));

DEFLABEL (label_1087)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1090)
  (Wrd115.Obj) = (current_block [OBJECT_30]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_659)
  (Wrd106.Obj) = Rvl;
  goto label_1089;

DEFLABEL (label_1092)
  (Wrd100.Obj) = (Rsp [2]);
  (Wrd101.Obj) = (current_block [OBJECT_46]);
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_658)
  (Wrd89.Obj) = Rvl;
  goto label_1091;

DEFLABEL (label_1093)
  (Wrd106.Obj) = (current_block [OBJECT_30]);
  goto label_1089;

DEFLABEL (label_1095)
  (Wrd83.Obj) = (Rsp [2]);
  (Wrd84.Obj) = (current_block [OBJECT_46]);
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_657)
  (Wrd72.Obj) = Rvl;
  goto label_1094;

DEFLABEL (label_1098)
  (Wrd53.Obj) = (Rsp [3]);
  (Wrd54.Obj) = (current_block [OBJECT_42]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_656)
  (* (--Rsp)) = Rvl;
  goto label_1097;

DEFLABEL (label_1101)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_655)
  (* (--Rsp)) = Rvl;
  goto label_1100;

DEFLABEL (label_1102)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_1087;

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_144);
  (Wrd163.Obj) = Rvl;
  goto label_1077;

DEFLABEL (continuation_63)
  INTERRUPT_CHECK (27, LABEL_145);
  (Wrd106.Obj) = Rvl;
  goto label_1088;

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_146);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1086;
  goto label_1085;

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_147);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1072;
  goto label_1071;

DEFLABEL (node_subsetP_876)
DEFLABEL (node_subsetP_261)
  INTERRUPT_CHECK (26, LABEL_163);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1143;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  if ((Wrd10.Obj) == (Wrd6.Obj))
    goto label_1142;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_1141;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_1141;
  (Wrd13.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_1140)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_1139)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  if ((Wrd32.Obj) == (current_block [OBJECT_43]))
    goto label_1138;
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_1137;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd43.Lng))))
    goto label_1137;
  (Wrd35.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_1136)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1135)
  (Wrd51.Obj) = (* (Rsp++));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if ((Wrd52.Lng) > (Wrd53.Lng))
    goto label_1133;
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_1132;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd62.Lng))))
    goto label_1132;
  (Wrd56.Obj) = ((Wrd60.pObj) [4]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_1131)
  (Wrd79.Obj) = (Rsp [1]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd80.uLng) == 10))
    goto label_1130;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd78.Lng))))
    goto label_1130;
  (Wrd72.Obj) = ((Wrd76.pObj) [2]);
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_1129)
  (Wrd95.Obj) = (Rsp [2]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_1128;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd94.Lng))))
    goto label_1128;
  (Wrd88.Obj) = ((Wrd92.pObj) [3]);
  (* (--Rsp)) = (Wrd88.Obj);

DEFLABEL (label_1127)
  Rdl = (& (Rsp [5]));
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd116.Obj) = (Rsp [6]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if (! ((Wrd117.uLng) == 10))
    goto label_1126;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd116.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd115.Lng))))
    goto label_1126;
  (Wrd109.Obj) = ((Wrd113.pObj) [3]);
  (* (--Rsp)) = (Wrd109.Obj);

DEFLABEL (label_1125)
  (Wrd127.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd127.Obj);
  (Wrd133.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd133.uLng) == 26)
    goto label_1104;

DEFLABEL (label_1103)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1104)
  (Wrd134.Obj) = (Rsp [1]);
  (Wrd135.uLng) = (OBJECT_TYPE (Wrd134.Obj));
  if (! ((Wrd135.uLng) == 26))
    goto label_1103;
  (Wrd137.Lng) = (FIXNUM_TO_LONG (Wrd127.Obj));
  (Wrd139.Lng) = (FIXNUM_TO_LONG (Wrd134.Obj));
  if ((Wrd137.Lng) < (Wrd139.Lng))
    goto label_1106;
  (Wrd131.Obj) = (current_block [OBJECT_45]);
  goto label_1105;

DEFLABEL (label_1106)
  (Wrd131.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1105)
DEFLABEL (label_1124)
  Rsp = (& (Rsp [3]));
  (Wrd128.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd128.Obj));
  if ((Wrd131.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1111;

DEFLABEL (label_1110)
  (Wrd233.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd233.Obj);
  (Wrd236.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_175]))));
  (* (--Rsp)) = (Wrd236.Obj);
  (Wrd246.Obj) = (Rsp [6]);
  (Wrd247.uLng) = (OBJECT_TYPE (Wrd246.Obj));
  if (! ((Wrd247.uLng) == 10))
    goto label_1108;
  (Wrd243.pObj) = (OBJECT_ADDRESS (Wrd246.Obj));
  (Wrd244.Obj) = ((Wrd243.pObj) [0]);
  (Wrd245.Lng) = (FIXNUM_TO_LONG (Wrd244.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd245.Lng))))
    goto label_1108;
  (Wrd239.Obj) = ((Wrd243.pObj) [2]);
  (* (--Rsp)) = (Wrd239.Obj);

DEFLABEL (label_1107)
  (Wrd205.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd205.Obj);
  goto node_subsetP_261;

DEFLABEL (label_1108)
  (Wrd252.Obj) = (Rsp [6]);
  (Wrd253.Obj) = (current_block [OBJECT_46]);
  (Wrd251.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd251.Obj);
  (Wrd256.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_176]))));
  (* (--Rsp)) = (Wrd256.Obj);
  (* (--Rsp)) = (Wrd253.Obj);
  (* (--Rsp)) = (Wrd252.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_674)
DEFLABEL (label_1109)
  (Wrd196.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd196.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1107;

DEFLABEL (label_1111)
  (Wrd142.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd142.Obj);
  (Wrd145.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159]))));
  (* (--Rsp)) = (Wrd145.Obj);
  (Wrd146.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd146.Obj);
  (Wrd156.Obj) = (Rsp [7]);
  (Wrd157.uLng) = (OBJECT_TYPE (Wrd156.Obj));
  if (! ((Wrd157.uLng) == 10))
    goto label_1123;
  (Wrd153.pObj) = (OBJECT_ADDRESS (Wrd156.Obj));
  (Wrd154.Obj) = ((Wrd153.pObj) [0]);
  (Wrd155.Lng) = (FIXNUM_TO_LONG (Wrd154.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd155.Lng))))
    goto label_1123;
  (Wrd149.Obj) = ((Wrd153.pObj) [3]);
  (* (--Rsp)) = (Wrd149.Obj);

DEFLABEL (label_1122)
  (Wrd171.Obj) = (Rsp [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if (! ((Wrd172.uLng) == 26))
    goto label_1103;
  (Wrd173.Obj) = (Rsp [1]);
  (Wrd174.uLng) = (OBJECT_TYPE (Wrd173.Obj));
  if (! ((Wrd174.uLng) == 26))
    goto label_1103;
  (Wrd176.Lng) = (FIXNUM_TO_LONG (Wrd171.Obj));
  (Wrd178.Lng) = (FIXNUM_TO_LONG (Wrd173.Obj));
  if ((Wrd176.Lng) < (Wrd178.Lng))
    goto label_1113;
  (Wrd170.Obj) = (current_block [OBJECT_45]);
  goto label_1112;

DEFLABEL (label_1113)
  (Wrd170.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1112)
DEFLABEL (label_1121)
  Rsp = (& (Rsp [3]));
  (Wrd167.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd167.Obj));
  if ((Wrd170.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1119;

DEFLABEL (label_1118)
  (Wrd207.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd207.Obj);
  (Wrd210.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173]))));
  (* (--Rsp)) = (Wrd210.Obj);
  (Wrd220.Obj) = (Rsp [6]);
  (Wrd221.uLng) = (OBJECT_TYPE (Wrd220.Obj));
  if (! ((Wrd221.uLng) == 10))
    goto label_1117;
  (Wrd217.pObj) = (OBJECT_ADDRESS (Wrd220.Obj));
  (Wrd218.Obj) = ((Wrd217.pObj) [0]);
  (Wrd219.Lng) = (FIXNUM_TO_LONG (Wrd218.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd219.Lng))))
    goto label_1117;
  (Wrd213.Obj) = ((Wrd217.pObj) [4]);
  (* (--Rsp)) = (Wrd213.Obj);

DEFLABEL (label_1116)
  (Wrd231.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd231.Obj);
  goto node_subsetP_261;

DEFLABEL (continuation_255)
  INTERRUPT_CHECK (27, LABEL_173);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1114;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1114)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_332]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_find_53;

DEFLABEL (continuation_256)
  INTERRUPT_CHECK (27, LABEL_332);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1115;
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_261;

DEFLABEL (label_1115)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1117)
  (Wrd226.Obj) = (Rsp [6]);
  (Wrd227.Obj) = (current_block [OBJECT_47]);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd225.Obj);
  (Wrd230.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174]))));
  (* (--Rsp)) = (Wrd230.Obj);
  (* (--Rsp)) = (Wrd227.Obj);
  (* (--Rsp)) = (Wrd226.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_673)
  (Wrd222.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd222.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1116;

DEFLABEL (label_1119)
  (Wrd181.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd181.Obj);
  (Wrd184.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171]))));
  (* (--Rsp)) = (Wrd184.Obj);
  (Wrd194.Obj) = (Rsp [6]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if (! ((Wrd195.uLng) == 10))
    goto label_1120;
  (Wrd191.pObj) = (OBJECT_ADDRESS (Wrd194.Obj));
  (Wrd192.Obj) = ((Wrd191.pObj) [0]);
  (Wrd193.Lng) = (FIXNUM_TO_LONG (Wrd192.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd193.Lng))))
    goto label_1120;
  (Wrd187.Obj) = ((Wrd191.pObj) [2]);
  (* (--Rsp)) = (Wrd187.Obj);
  goto label_1107;

DEFLABEL (label_1120)
  (Wrd200.Obj) = (Rsp [6]);
  (Wrd201.Obj) = (current_block [OBJECT_46]);
  (Wrd199.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd199.Obj);
  (Wrd204.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172]))));
  (* (--Rsp)) = (Wrd204.Obj);
  (* (--Rsp)) = (Wrd201.Obj);
  (* (--Rsp)) = (Wrd200.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_672)
  goto label_1109;

DEFLABEL (label_1123)
  (Wrd162.Obj) = (Rsp [7]);
  (Wrd163.Obj) = (current_block [OBJECT_42]);
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd161.Obj);
  (Wrd166.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170]))));
  (* (--Rsp)) = (Wrd166.Obj);
  (* (--Rsp)) = (Wrd163.Obj);
  (* (--Rsp)) = (Wrd162.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_671)
  (Wrd158.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd158.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1122;

DEFLABEL (label_1126)
  (Wrd122.Obj) = (Rsp [6]);
  (Wrd123.Obj) = (current_block [OBJECT_42]);
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_670)
  (Wrd118.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd118.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1125;

DEFLABEL (label_1128)
  (Wrd97.Obj) = (Rsp [2]);
  (Wrd98.Obj) = (current_block [OBJECT_42]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_669)
  (* (--Rsp)) = Rvl;
  goto label_1127;

DEFLABEL (label_1130)
  (Wrd81.Obj) = (Rsp [1]);
  (Wrd82.Obj) = (current_block [OBJECT_46]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_668)
  (* (--Rsp)) = Rvl;
  goto label_1129;

DEFLABEL (label_1132)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.Obj) = (current_block [OBJECT_47]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_667)
  (* (--Rsp)) = Rvl;
  goto label_1131;

DEFLABEL (label_1133)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_1134)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1137)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.Obj) = (current_block [OBJECT_30]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_666)
  (Wrd35.Obj) = Rvl;
  goto label_1136;

DEFLABEL (label_1138)
  (Wrd35.Obj) = (current_block [OBJECT_30]);
  goto label_1136;

DEFLABEL (label_1141)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_30]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_665)
  (Wrd13.Obj) = Rvl;
  goto label_1140;

DEFLABEL (label_1142)
  (Wrd263.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd263.Obj);
  goto label_1139;

DEFLABEL (label_1143)
  Rvl = (current_block [OBJECT_32]);
  goto label_1134;

DEFLABEL (continuation_258)
  INTERRUPT_CHECK (27, LABEL_175);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1144;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1144)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_333]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_find_53;

DEFLABEL (continuation_259)
  INTERRUPT_CHECK (27, LABEL_333);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1145;
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_261;

DEFLABEL (label_1145)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (continuation_252)
  INTERRUPT_CHECK (27, LABEL_171);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1146;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1146)
  (Wrd18.Obj) = (Rsp [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1148;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1148;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1147)
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_261;

DEFLABEL (label_1148)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_47]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_331]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_769)
  (Wrd20.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd20.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1147;

DEFLABEL (continuation_249)
  INTERRUPT_CHECK (27, LABEL_159);
  (Wrd270.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd270.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1119;
  goto label_1118;

DEFLABEL (continuation_246)
  INTERRUPT_CHECK (27, LABEL_160);
  (Wrd266.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd266.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1111;
  goto label_1110;

DEFLABEL (continuation_237)
  INTERRUPT_CHECK (27, LABEL_161);
  (Wrd35.Obj) = Rvl;
  goto label_1135;

DEFLABEL (continuation_239)
  INTERRUPT_CHECK (27, LABEL_162);
  (* (--Rsp)) = Rvl;
  goto label_1139;

DEFLABEL (node_difference_877)
DEFLABEL (node_difference_218)
  INTERRUPT_CHECK (26, LABEL_179);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1157;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1155;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1154;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1154;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1153)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1152;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1152;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1151)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1150;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1150;
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1149)
  Rdl = (& (Rsp [5]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd62.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd63.Obj);
  goto node_split_gt_173;

DEFLABEL (continuation_213)
  INTERRUPT_CHECK (27, LABEL_183);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_334]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_159;

DEFLABEL (continuation_212)
  INTERRUPT_CHECK (27, LABEL_334);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_375]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_difference_218;

DEFLABEL (continuation_215)
  INTERRUPT_CHECK (27, LABEL_375);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_433]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_difference_218;

DEFLABEL (continuation_214)
  INTERRUPT_CHECK (27, LABEL_433);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_114;

DEFLABEL (label_1150)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_42]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_182]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_678)
  (* (--Rsp)) = Rvl;
  goto label_1149;

DEFLABEL (label_1152)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_181]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_677)
  (* (--Rsp)) = Rvl;
  goto label_1151;

DEFLABEL (label_1154)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_676)
  (* (--Rsp)) = Rvl;
  goto label_1153;

DEFLABEL (label_1155)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1156)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1157)
  Rvl = (Wrd6.Obj);
  goto label_1156;

DEFLABEL (node_intersection_878)
DEFLABEL (node_intersection_234)
  INTERRUPT_CHECK (26, LABEL_185);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1159;

DEFLABEL (label_1158)
  Rvl = (current_block [OBJECT_43]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1159)
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1158;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1170;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1170;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1169)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1168;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1168;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1167)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1166;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1166;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1165)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1164;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1164;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1163)
  Rdl = (& (Rsp [6]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_190]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_split_gt_173;

DEFLABEL (continuation_226)
  INTERRUPT_CHECK (27, LABEL_190);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_335]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_159;

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_335);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_376]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_find_53;

DEFLABEL (continuation_227)
  INTERRUPT_CHECK (27, LABEL_376);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1161;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_435]))));
  (* (--Rsp)) = (Wrd13.Obj);
  goto label_1160;

DEFLABEL (label_1161)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_434]))));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_1160)
DEFLABEL (label_1162)
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto node_intersection_234;

DEFLABEL (label_1164)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_683)
  (* (--Rsp)) = Rvl;
  goto label_1163;

DEFLABEL (label_1166)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_682)
  (* (--Rsp)) = Rvl;
  goto label_1165;

DEFLABEL (label_1168)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_187]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_681)
  (* (--Rsp)) = Rvl;
  goto label_1167;

DEFLABEL (label_1170)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_186]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_680)
  (* (--Rsp)) = Rvl;
  goto label_1169;

DEFLABEL (continuation_231)
  INTERRUPT_CHECK (27, LABEL_435);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_450]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_intersection_234;

DEFLABEL (continuation_230)
  INTERRUPT_CHECK (27, LABEL_450);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_145;

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_434);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_451]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_intersection_234;

DEFLABEL (continuation_228)
  INTERRUPT_CHECK (27, LABEL_451);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_114;

DEFLABEL (node_union_merge_879)
DEFLABEL (node_union_merge_205)
  INTERRUPT_CHECK (26, LABEL_192);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1185;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1183;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1182;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1182;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1181)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1180;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1180;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1179)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1178;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1178;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1177)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1176;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1176;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1175)
  Rdl = (& (Rsp [7]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_197]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_find_53;

DEFLABEL (continuation_193)
  INTERRUPT_CHECK (27, LABEL_197);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_336]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_159;

DEFLABEL (continuation_194)
  INTERRUPT_CHECK (27, LABEL_336);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_377]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_gt_173;

DEFLABEL (continuation_195)
  INTERRUPT_CHECK (27, LABEL_377);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_436]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1174;
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_1173;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd22.Lng))))
    goto label_1173;
  (Wrd16.Obj) = ((Wrd20.pObj) [5]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_1172)
  (Wrd34.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [14]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (continuation_196)
  INTERRUPT_CHECK (27, LABEL_436);
  (Wrd49.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd49.Obj));
  (* (--Rsp)) = Rvl;

DEFLABEL (label_1171)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_437]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [12]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd48.Obj);
  goto node_union_merge_205;

DEFLABEL (continuation_199)
  INTERRUPT_CHECK (27, LABEL_437);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_452]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [13]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_union_merge_205;

DEFLABEL (continuation_198)
  INTERRUPT_CHECK (27, LABEL_452);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_145;

DEFLABEL (label_1173)
  (Wrd29.Obj) = (Rsp [4]);
  (Wrd30.Obj) = (current_block [OBJECT_48]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_438]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_819)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1172;

DEFLABEL (label_1174)
  (Wrd40.Obj) = (Rsp [6]);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_1171;

DEFLABEL (label_1176)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_196]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_688)
  (* (--Rsp)) = Rvl;
  goto label_1175;

DEFLABEL (label_1178)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_195]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_687)
  (* (--Rsp)) = Rvl;
  goto label_1177;

DEFLABEL (label_1180)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_686)
  (* (--Rsp)) = Rvl;
  goto label_1179;

DEFLABEL (label_1182)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_685)
  (* (--Rsp)) = Rvl;
  goto label_1181;

DEFLABEL (label_1183)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1184)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1185)
  Rvl = (Rsp [1]);
  goto label_1184;

DEFLABEL (node_union_880)
DEFLABEL (node_union_186)
  INTERRUPT_CHECK (26, LABEL_199);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1196;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1194;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1193;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1193;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1192)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1191;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1191;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1190)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1189;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1189;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1188)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1187;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1187;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1186)
  Rdl = (& (Rsp [6]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_204]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_split_gt_173;

DEFLABEL (continuation_181)
  INTERRUPT_CHECK (27, LABEL_204);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_337]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_159;

DEFLABEL (continuation_180)
  INTERRUPT_CHECK (27, LABEL_337);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_378]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_union_186;

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_378);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_439]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_union_186;

DEFLABEL (continuation_182)
  INTERRUPT_CHECK (27, LABEL_439);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_145;

DEFLABEL (label_1187)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_203]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_693)
  (* (--Rsp)) = Rvl;
  goto label_1186;

DEFLABEL (label_1189)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_202]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_692)
  (* (--Rsp)) = Rvl;
  goto label_1188;

DEFLABEL (label_1191)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_201]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_691)
  (* (--Rsp)) = Rvl;
  goto label_1190;

DEFLABEL (label_1193)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_200]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_690)
  (* (--Rsp)) = Rvl;
  goto label_1192;

DEFLABEL (label_1194)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1195)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1196)
  Rvl = (Rsp [1]);
  goto label_1195;

DEFLABEL (node_split_gt_881)
DEFLABEL (node_split_gt_173)
  INTERRUPT_CHECK (26, LABEL_208);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1226;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_207]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_1225;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_1225;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_1224)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_1198;

DEFLABEL (label_1197)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1198)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 26))
    goto label_1197;
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if ((Wrd34.Lng) < (Wrd36.Lng))
    goto label_1200;
  (Wrd28.Obj) = (current_block [OBJECT_45]);
  goto label_1199;

DEFLABEL (label_1200)
  (Wrd28.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1199)
DEFLABEL (label_1223)
  Rsp = (& (Rsp [3]));
  if ((Wrd28.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1205;

DEFLABEL (label_1204)
  (Wrd159.Obj) = (Rsp [0]);
  (Wrd160.uLng) = (OBJECT_TYPE (Wrd159.Obj));
  if (! ((Wrd160.uLng) == 10))
    goto label_1203;
  (Wrd156.pObj) = (OBJECT_ADDRESS (Wrd159.Obj));
  (Wrd157.Obj) = ((Wrd156.pObj) [0]);
  (Wrd158.Lng) = (FIXNUM_TO_LONG (Wrd157.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd158.Lng))))
    goto label_1203;
  (Wrd150.Obj) = ((Wrd156.pObj) [4]);

DEFLABEL (label_1202)
  (Rsp [0]) = (Wrd150.Obj);

DEFLABEL (label_1201)
  goto node_split_gt_173;

DEFLABEL (label_1203)
  (Wrd161.Obj) = (Rsp [0]);
  (Wrd162.Obj) = (current_block [OBJECT_47]);
  (Wrd165.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_216]))));
  (* (--Rsp)) = (Wrd165.Obj);
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd161.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_701)
  (Wrd150.Obj) = Rvl;
  goto label_1202;

DEFLABEL (label_1205)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_206]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd50.Obj) = (Rsp [1]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1222;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1222;
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1221)
  (Wrd57.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd61.uLng) == 26))
    goto label_1197;
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 26))
    goto label_1197;
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if ((Wrd65.Lng) < (Wrd67.Lng))
    goto label_1207;
  (Wrd59.Obj) = (current_block [OBJECT_45]);
  goto label_1206;

DEFLABEL (label_1207)
  (Wrd59.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1206)
DEFLABEL (label_1220)
  Rsp = (& (Rsp [3]));
  if ((Wrd59.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1216;

DEFLABEL (label_1215)
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 10))
    goto label_1214;
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd89.Obj) = ((Wrd88.pObj) [0]);
  (Wrd90.Lng) = (FIXNUM_TO_LONG (Wrd89.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd90.Lng))))
    goto label_1214;
  (Wrd84.Obj) = ((Wrd88.pObj) [5]);
  (* (--Rsp)) = (Wrd84.Obj);

DEFLABEL (label_1213)
  (Wrd107.Obj) = (Rsp [1]);
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if (! ((Wrd108.uLng) == 10))
    goto label_1212;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [0]);
  (Wrd106.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd106.Lng))))
    goto label_1212;
  (Wrd100.Obj) = ((Wrd104.pObj) [3]);
  (* (--Rsp)) = (Wrd100.Obj);

DEFLABEL (label_1211)
  (Wrd123.Obj) = (Rsp [2]);
  (Wrd124.uLng) = (OBJECT_TYPE (Wrd123.Obj));
  if (! ((Wrd124.uLng) == 10))
    goto label_1210;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd121.Obj) = ((Wrd120.pObj) [0]);
  (Wrd122.Lng) = (FIXNUM_TO_LONG (Wrd121.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd122.Lng))))
    goto label_1210;
  (Wrd116.Obj) = ((Wrd120.pObj) [4]);
  (* (--Rsp)) = (Wrd116.Obj);

DEFLABEL (label_1209)
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_214]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (Wrd133.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd133.Obj);
  (Wrd143.Obj) = (Rsp [5]);
  (Wrd144.uLng) = (OBJECT_TYPE (Wrd143.Obj));
  if (! ((Wrd144.uLng) == 10))
    goto label_1208;
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd143.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (Wrd142.Lng) = (FIXNUM_TO_LONG (Wrd141.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd142.Lng))))
    goto label_1208;
  (Wrd136.Obj) = ((Wrd140.pObj) [2]);
  (* (--Rsp)) = (Wrd136.Obj);
  goto label_1201;

DEFLABEL (label_1208)
  (Wrd145.Obj) = (Rsp [5]);
  (Wrd146.Obj) = (current_block [OBJECT_46]);
  (Wrd149.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_215]))));
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd146.Obj);
  (* (--Rsp)) = (Wrd145.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_700)
  (* (--Rsp)) = Rvl;
  goto label_1201;

DEFLABEL (label_1210)
  (Wrd125.Obj) = (Rsp [2]);
  (Wrd126.Obj) = (current_block [OBJECT_47]);
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_213]))));
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd125.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_699)
  (* (--Rsp)) = Rvl;
  goto label_1209;

DEFLABEL (label_1212)
  (Wrd109.Obj) = (Rsp [1]);
  (Wrd110.Obj) = (current_block [OBJECT_42]);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_212]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_698)
  (* (--Rsp)) = Rvl;
  goto label_1211;

DEFLABEL (label_1214)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.Obj) = (current_block [OBJECT_48]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_211]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_697)
  (* (--Rsp)) = Rvl;
  goto label_1213;

DEFLABEL (label_1216)
  (Wrd69.Obj) = (current_block [OBJECT_47]);
  (Rsp [1]) = (Wrd69.Obj);
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 10)
    goto label_1218;

DEFLABEL (label_1217)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_1218)
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [0]);
  (Wrd79.Lng) = (FIXNUM_TO_LONG (Wrd78.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd79.Lng))))
    goto label_1217;
  Rvl = ((Wrd77.pObj) [4]);

DEFLABEL (label_1219)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1222)
  (Wrd52.Obj) = (Rsp [1]);
  (Wrd53.Obj) = (current_block [OBJECT_42]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_210]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_696)
  (* (--Rsp)) = Rvl;
  goto label_1221;

DEFLABEL (label_1225)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_42]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_209]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_695)
  (* (--Rsp)) = Rvl;
  goto label_1224;

DEFLABEL (label_1226)
  Rvl = (Wrd6.Obj);
  goto label_1219;

DEFLABEL (continuation_170)
  INTERRUPT_CHECK (27, LABEL_214);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd6.Obj);
  goto node_concat3_145;

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_206);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1216;
  goto label_1215;

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_207);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1205;
  goto label_1204;

DEFLABEL (node_split_lt_882)
DEFLABEL (node_split_lt_159)
  INTERRUPT_CHECK (26, LABEL_220);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1254;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_219]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1253;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1253;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1252)
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_1228;

DEFLABEL (label_1227)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1228)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 26))
    goto label_1227;
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if ((Wrd34.Lng) < (Wrd36.Lng))
    goto label_1230;
  (Wrd28.Obj) = (current_block [OBJECT_45]);
  goto label_1229;

DEFLABEL (label_1230)
  (Wrd28.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1229)
DEFLABEL (label_1251)
  Rsp = (& (Rsp [3]));
  if ((Wrd28.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1235;

DEFLABEL (label_1234)
  (Wrd143.Obj) = (Rsp [0]);
  (Wrd144.uLng) = (OBJECT_TYPE (Wrd143.Obj));
  if (! ((Wrd144.uLng) == 10))
    goto label_1233;
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd143.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (Wrd142.Lng) = (FIXNUM_TO_LONG (Wrd141.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd142.Lng))))
    goto label_1233;
  (Wrd134.Obj) = ((Wrd140.pObj) [2]);

DEFLABEL (label_1232)
  (Rsp [0]) = (Wrd134.Obj);

DEFLABEL (label_1231)
  goto node_split_lt_159;

DEFLABEL (label_1233)
  (Wrd145.Obj) = (Rsp [0]);
  (Wrd146.Obj) = (current_block [OBJECT_46]);
  (Wrd149.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227]))));
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd146.Obj);
  (* (--Rsp)) = (Wrd145.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_708)
  (Wrd134.Obj) = Rvl;
  goto label_1232;

DEFLABEL (label_1235)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_218]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_1250;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd50.Lng))))
    goto label_1250;
  (Wrd44.Obj) = ((Wrd48.pObj) [3]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_1249)
  (Wrd60.Obj) = (Rsp [0]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd61.uLng) == 26))
    goto label_1227;
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 26))
    goto label_1227;
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if ((Wrd65.Lng) < (Wrd67.Lng))
    goto label_1237;
  (Wrd59.Obj) = (current_block [OBJECT_45]);
  goto label_1236;

DEFLABEL (label_1237)
  (Wrd59.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1236)
DEFLABEL (label_1248)
  Rsp = (& (Rsp [3]));
  if ((Wrd59.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1244;

DEFLABEL (label_1243)
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 10))
    goto label_1242;
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd89.Obj) = ((Wrd88.pObj) [0]);
  (Wrd90.Lng) = (FIXNUM_TO_LONG (Wrd89.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd90.Lng))))
    goto label_1242;
  (Wrd84.Obj) = ((Wrd88.pObj) [5]);
  (* (--Rsp)) = (Wrd84.Obj);

DEFLABEL (label_1241)
  (Wrd107.Obj) = (Rsp [1]);
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if (! ((Wrd108.uLng) == 10))
    goto label_1240;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [0]);
  (Wrd106.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd106.Lng))))
    goto label_1240;
  (Wrd100.Obj) = ((Wrd104.pObj) [3]);
  (* (--Rsp)) = (Wrd100.Obj);

DEFLABEL (label_1239)
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_225]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (Wrd117.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd117.Obj);
  (Wrd127.Obj) = (Rsp [4]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd128.uLng) == 10))
    goto label_1238;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd125.Obj) = ((Wrd124.pObj) [0]);
  (Wrd126.Lng) = (FIXNUM_TO_LONG (Wrd125.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd126.Lng))))
    goto label_1238;
  (Wrd120.Obj) = ((Wrd124.pObj) [4]);
  (* (--Rsp)) = (Wrd120.Obj);
  goto label_1231;

DEFLABEL (label_1238)
  (Wrd129.Obj) = (Rsp [4]);
  (Wrd130.Obj) = (current_block [OBJECT_47]);
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_707)
  (* (--Rsp)) = Rvl;
  goto label_1231;

DEFLABEL (label_1240)
  (Wrd109.Obj) = (Rsp [1]);
  (Wrd110.Obj) = (current_block [OBJECT_42]);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_224]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_706)
  (* (--Rsp)) = Rvl;
  goto label_1239;

DEFLABEL (label_1242)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.Obj) = (current_block [OBJECT_48]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_223]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_705)
  (* (--Rsp)) = Rvl;
  goto label_1241;

DEFLABEL (label_1244)
  (Wrd69.Obj) = (current_block [OBJECT_46]);
  (Rsp [1]) = (Wrd69.Obj);
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 10)
    goto label_1246;

DEFLABEL (label_1245)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_1246)
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [0]);
  (Wrd79.Lng) = (FIXNUM_TO_LONG (Wrd78.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd79.Lng))))
    goto label_1245;
  Rvl = ((Wrd77.pObj) [2]);

DEFLABEL (label_1247)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1250)
  (Wrd53.Obj) = (Rsp [2]);
  (Wrd54.Obj) = (current_block [OBJECT_42]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_222]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_704)
  (* (--Rsp)) = Rvl;
  goto label_1249;

DEFLABEL (label_1253)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_221]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_703)
  (* (--Rsp)) = Rvl;
  goto label_1252;

DEFLABEL (label_1254)
  Rvl = (Wrd6.Obj);
  goto label_1247;

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_225);
  (Rsp [3]) = Rvl;
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_1256;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1256;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1255)
  (Rsp [2]) = (Wrd6.Obj);
  goto node_concat3_145;

DEFLABEL (label_1256)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_338]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_770)
  (Wrd6.Obj) = Rvl;
  goto label_1255;

DEFLABEL (continuation_151)
  INTERRUPT_CHECK (27, LABEL_218);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1244;
  goto label_1243;

DEFLABEL (continuation_148)
  INTERRUPT_CHECK (27, LABEL_219);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1235;
  goto label_1234;

DEFLABEL (node_find_883)
DEFLABEL (node_find_53)
  INTERRUPT_CHECK (26, LABEL_228);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_52;

DEFLABEL (node_delete_884)
DEFLABEL (node_delete_106)
  INTERRUPT_CHECK (26, LABEL_231);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1257;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1257)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1277;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1277;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1276)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1275;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1275;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1274)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1273;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1273;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_1272)
  (Wrd64.Obj) = (Rsp [4]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_1271;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_1271;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_1270)
  Rdl = (& (Rsp [6]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_230]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd83.uLng) == 26)
    goto label_1259;

DEFLABEL (label_1258)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1259)
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd85.uLng) == 26))
    goto label_1258;
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if ((Wrd87.Lng) < (Wrd89.Lng))
    goto label_1261;
  (Wrd81.Obj) = (current_block [OBJECT_45]);
  goto label_1260;

DEFLABEL (label_1261)
  (Wrd81.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1260)
DEFLABEL (label_1269)
  Rsp = (& (Rsp [3]));
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  if ((Wrd81.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1263;

DEFLABEL (label_1262)
  (Wrd120.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd120.Obj);
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd122.Obj);
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (Wrd126.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd127.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd127.Obj);
  goto node_delete_106;

DEFLABEL (continuation_104)
  INTERRUPT_CHECK (27, LABEL_238);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1263)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_229]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd96.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd97.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd103.uLng) == 26))
    goto label_1258;
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd96.Obj));
  if (! ((Wrd105.uLng) == 26))
    goto label_1258;
  (Wrd107.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd96.Obj));
  if ((Wrd107.Lng) < (Wrd109.Lng))
    goto label_1265;
  (Wrd101.Obj) = (current_block [OBJECT_45]);
  goto label_1264;

DEFLABEL (label_1265)
  (Wrd101.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1264)
DEFLABEL (label_1268)
  Rsp = (& (Rsp [3]));
  (Wrd98.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd98.Obj));
  if (! ((Wrd101.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_1267;

DEFLABEL (label_1266)
  (Wrd111.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd111.Obj);
  (Wrd112.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_236]));

DEFLABEL (label_1267)
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_237]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (Wrd118.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd118.Obj);
  (Wrd119.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd119.Obj);
  goto node_delete_106;

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_237);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1271)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.Obj) = (current_block [OBJECT_42]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_235]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_712)
  (* (--Rsp)) = Rvl;
  goto label_1270;

DEFLABEL (label_1273)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.Obj) = (current_block [OBJECT_48]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_234]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_711)
  (* (--Rsp)) = Rvl;
  goto label_1272;

DEFLABEL (label_1275)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.Obj) = (current_block [OBJECT_46]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_233]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_710)
  (* (--Rsp)) = Rvl;
  goto label_1274;

DEFLABEL (label_1277)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_47]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_709)
  (* (--Rsp)) = Rvl;
  goto label_1276;

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_229);
  (Wrd135.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd135.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1266;
  goto label_1267;

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_230);
  (Wrd131.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd131.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1263;
  goto label_1262;

DEFLABEL (node_add_885)
DEFLABEL (node_add_93)
  INTERRUPT_CHECK (26, LABEL_244);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1278;
  (Wrd207.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd208.Obj) = (current_block [OBJECT_46]);
  (Wrd210.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd207.Obj);
  (* (Rhp++)) = (Wrd208.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd210.Obj);
  (Wrd204.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd204.Obj);
  (Wrd201.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd201.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1278)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1307;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1307;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1306)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1305;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1305;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1304)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1303;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1303;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_1302)
  (Wrd64.Obj) = (Rsp [3]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_1301;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_1301;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_1300)
  Rdl = (& (Rsp [7]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_243]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd83.uLng) == 26)
    goto label_1280;

DEFLABEL (label_1279)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1280)
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd85.uLng) == 26))
    goto label_1279;
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if ((Wrd87.Lng) < (Wrd89.Lng))
    goto label_1282;
  (Wrd81.Obj) = (current_block [OBJECT_45]);
  goto label_1281;

DEFLABEL (label_1282)
  (Wrd81.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1281)
DEFLABEL (label_1299)
  Rsp = (& (Rsp [3]));
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  if ((Wrd81.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1285;

DEFLABEL (label_1284)
  (Wrd189.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd189.Obj);
  (Wrd191.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd191.Obj);
  (Wrd194.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_252]))));
  (* (--Rsp)) = (Wrd194.Obj);
  (Wrd195.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd196.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd196.Obj);

DEFLABEL (label_1283)
  (Wrd188.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd188.Obj);
  goto node_add_93;

DEFLABEL (label_1285)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_242]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd96.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd97.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd103.uLng) == 26))
    goto label_1279;
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd96.Obj));
  if (! ((Wrd105.uLng) == 26))
    goto label_1279;
  (Wrd107.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd96.Obj));
  if ((Wrd107.Lng) < (Wrd109.Lng))
    goto label_1287;
  (Wrd101.Obj) = (current_block [OBJECT_45]);
  goto label_1286;

DEFLABEL (label_1287)
  (Wrd101.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1286)
DEFLABEL (label_1298)
  Rsp = (& (Rsp [3]));
  (Wrd98.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd98.Obj));
  if ((Wrd101.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1289;

DEFLABEL (label_1288)
  (Wrd182.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd182.Obj);
  (Wrd185.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_251]))));
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd186.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd186.Obj);
  (Wrd187.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd187.Obj);
  goto label_1283;

DEFLABEL (label_1289)
  (Wrd111.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd111.Obj);
  (Wrd112.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd112.Obj);
  (Wrd113.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd113.Obj);
  (Wrd114.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd114.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_241]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (Wrd118.Obj) = (Rsp [4]);
  if ((Wrd118.Obj) == (current_block [OBJECT_43]))
    goto label_1297;
  (Wrd131.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if (! ((Wrd131.uLng) == 10))
    goto label_1296;
  (Wrd127.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd128.Obj) = ((Wrd127.pObj) [0]);
  (Wrd129.Lng) = (FIXNUM_TO_LONG (Wrd128.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd129.Lng))))
    goto label_1296;
  (Wrd121.Obj) = ((Wrd127.pObj) [1]);

DEFLABEL (label_1295)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd121.Obj);

DEFLABEL (label_1294)
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_240]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (Wrd140.Obj) = (Rsp [4]);
  if ((Wrd140.Obj) == (current_block [OBJECT_43]))
    goto label_1293;
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd140.Obj));
  if (! ((Wrd153.uLng) == 10))
    goto label_1292;
  (Wrd149.pObj) = (OBJECT_ADDRESS (Wrd140.Obj));
  (Wrd150.Obj) = ((Wrd149.pObj) [0]);
  (Wrd151.Lng) = (FIXNUM_TO_LONG (Wrd150.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd151.Lng))))
    goto label_1292;
  (Wrd143.Obj) = ((Wrd149.pObj) [1]);

DEFLABEL (label_1291)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1290)
  (Wrd159.Obj) = (* (Rsp++));
  (Wrd161.Lng) = (FIXNUM_TO_LONG (Wrd143.Obj));
  (Wrd162.Lng) = (FIXNUM_TO_LONG (Wrd159.Obj));
  (Wrd165.Lng) = ((Wrd161.Lng) + (Wrd162.Lng));
  (Wrd166.Lng) = ((Wrd165.Lng) + 1L);
  (Wrd164.Obj) = (LONG_TO_FIXNUM (Wrd166.Lng));
  (Wrd175.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd176.Obj) = (Rsp [2]);
  (Wrd177.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd175.Obj);
  (* (Rhp++)) = (Wrd164.Obj);
  (* (Rhp++)) = (Wrd176.Obj);
  (* (Rhp++)) = (Wrd177.Obj);
  (Wrd171.Obj) = (Rsp [3]);
  (Wrd172.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd171.Obj);
  (* (Rhp++)) = (Wrd172.Obj);
  (Wrd169.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd169.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_1292)
  (Wrd154.Obj) = (Rsp [4]);
  (Wrd155.Obj) = (current_block [OBJECT_30]);
  (Wrd158.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_250]))));
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd154.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_719)
  (Wrd143.Obj) = Rvl;
  goto label_1291;

DEFLABEL (label_1293)
  (Wrd143.Obj) = (current_block [OBJECT_30]);
  goto label_1291;

DEFLABEL (label_1296)
  (Wrd132.Obj) = (Rsp [4]);
  (Wrd133.Obj) = (current_block [OBJECT_30]);
  (Wrd136.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_249]))));
  (* (--Rsp)) = (Wrd136.Obj);
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd132.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_718)
  (Wrd121.Obj) = Rvl;
  goto label_1295;

DEFLABEL (label_1297)
  (Wrd180.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd180.Obj);
  goto label_1294;

DEFLABEL (label_1301)
  (Wrd66.Obj) = (Rsp [3]);
  (Wrd67.Obj) = (current_block [OBJECT_42]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_248]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_717)
  (* (--Rsp)) = Rvl;
  goto label_1300;

DEFLABEL (label_1303)
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.Obj) = (current_block [OBJECT_48]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_247]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_716)
  (* (--Rsp)) = Rvl;
  goto label_1302;

DEFLABEL (label_1305)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_46]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_246]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_715)
  (* (--Rsp)) = Rvl;
  goto label_1304;

DEFLABEL (label_1307)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_47]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_245]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_714)
  (* (--Rsp)) = Rvl;
  goto label_1306;

DEFLABEL (continuation_91)
  INTERRUPT_CHECK (27, LABEL_252);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_251);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_240);
  (Wrd143.Obj) = Rvl;
  goto label_1290;

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_241);
  (* (--Rsp)) = Rvl;
  goto label_1294;

DEFLABEL (continuation_81)
  INTERRUPT_CHECK (27, LABEL_242);
  (Wrd215.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd215.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1289;
  goto label_1288;

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_243);
  (Wrd211.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd211.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1285;
  goto label_1284;

DEFLABEL (loop_886)
DEFLABEL (loop_316)
  INTERRUPT_CHECK (26, LABEL_254);
  (Wrd11.Obj) = (Rsp [0]);
  if ((Wrd11.Obj) == (current_block [OBJECT_24]))
    goto label_1319;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_1308;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_53]);
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_54]);
  (Rsp [2]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_260]));

DEFLABEL (label_1308)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255]))));
  (* (--Rsp)) = (Wrd20.Obj);
  if (! ((Wrd14.uLng) == 1))
    goto label_1318;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_1317)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_1316;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_1315)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_1314;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_1313)
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_1312;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_1311)
  (Wrd53.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd53.Obj);
  goto node_add_93;

DEFLABEL (continuation_315)
  INTERRUPT_CHECK (27, LABEL_255);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_1310;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_1309)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_316;

DEFLABEL (label_1310)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_347]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52]), 1);

DEFLABEL (label_775)
  (Wrd6.Obj) = Rvl;
  goto label_1309;

DEFLABEL (label_1312)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_259]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_724)
  (* (--Rsp)) = Rvl;
  goto label_1311;

DEFLABEL (label_1314)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_258]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_723)
  (Wrd37.Obj) = Rvl;
  goto label_1313;

DEFLABEL (label_1316)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_257]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52]), 1);

DEFLABEL (label_722)
  (* (--Rsp)) = Rvl;
  goto label_1315;

DEFLABEL (label_1318)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_256]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_721)
  (Wrd21.Obj) = Rvl;
  goto label_1317;

DEFLABEL (label_1319)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto label_999;

DEFLABEL (node_rank_887)
DEFLABEL (node_rank_361)
  INTERRUPT_CHECK (26, LABEL_261);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_43])))
    goto label_1320;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1320)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1346;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1346;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1345)
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_346)
  INTERRUPT_CHECK (27, LABEL_262);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1323;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1322;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1322;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_1321)
  (Rsp [1]) = (Wrd7.Obj);
  goto node_rank_361;

DEFLABEL (label_1322)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_46]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_350]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_776)
  (Wrd7.Obj) = Rvl;
  goto label_1321;

DEFLABEL (label_1323)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_348]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_1344;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd35.Lng))))
    goto label_1344;
  (Wrd29.Obj) = ((Wrd33.pObj) [3]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_1343)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_348)
  INTERRUPT_CHECK (27, LABEL_348);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1334;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_399]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1333;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1333;
  (Wrd10.Obj) = ((Wrd16.pObj) [2]);

DEFLABEL (label_1332)
  if ((Wrd10.Obj) == (current_block [OBJECT_43]))
    goto label_1331;
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_1330;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd35.Lng))))
    goto label_1330;
  (Wrd27.Obj) = ((Wrd33.pObj) [2]);

DEFLABEL (label_1329)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1328;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd50.Lng))))
    goto label_1328;
  (Wrd44.Obj) = ((Wrd48.pObj) [1]);

DEFLABEL (label_1327)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1326)
  (Wrd58.Obj) = (Rsp [2]);
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  (Wrd63.Lng) = ((Wrd59.Lng) + (Wrd60.Lng));
  (Wrd64.Lng) = ((Wrd63.Lng) + 1L);
  (Wrd62.Obj) = (LONG_TO_FIXNUM (Wrd64.Lng));
  (Rsp [2]) = (Wrd62.Obj);
  (Wrd74.Obj) = (Rsp [1]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 10))
    goto label_1325;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd72.Obj) = ((Wrd71.pObj) [0]);
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd72.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd73.Lng))))
    goto label_1325;
  (Wrd65.Obj) = ((Wrd71.pObj) [4]);

DEFLABEL (label_1324)
  (Rsp [1]) = (Wrd65.Obj);
  goto node_rank_361;

DEFLABEL (label_1325)
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd77.Obj) = (current_block [OBJECT_47]);
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_406]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_802)
  (Wrd65.Obj) = Rvl;
  goto label_1324;

DEFLABEL (label_1328)
  (Wrd53.Obj) = (current_block [OBJECT_30]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_405]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_801)
  (Wrd44.Obj) = Rvl;
  goto label_1327;

DEFLABEL (label_1330)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.Obj) = (current_block [OBJECT_46]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_404]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_800)
  (Wrd27.Obj) = Rvl;
  goto label_1329;

DEFLABEL (label_1331)
  (Wrd44.Obj) = (current_block [OBJECT_30]);
  goto label_1327;

DEFLABEL (label_1333)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_46]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_403]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_799)
  (Wrd10.Obj) = Rvl;
  goto label_1332;

DEFLABEL (label_1334)
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_398]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (Wrd94.Obj) = (Rsp [2]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_1342;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_1342;
  (Wrd85.Obj) = ((Wrd91.pObj) [2]);

DEFLABEL (label_1341)
  if ((Wrd85.Obj) == (current_block [OBJECT_43]))
    goto label_1340;
  (Wrd111.Obj) = (Rsp [2]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 10))
    goto label_1339;
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd109.Obj) = ((Wrd108.pObj) [0]);
  (Wrd110.Lng) = (FIXNUM_TO_LONG (Wrd109.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd110.Lng))))
    goto label_1339;
  (Wrd102.Obj) = ((Wrd108.pObj) [2]);

DEFLABEL (label_1338)
  (Wrd126.uLng) = (OBJECT_TYPE (Wrd102.Obj));
  if (! ((Wrd126.uLng) == 10))
    goto label_1337;
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd102.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [0]);
  (Wrd125.Lng) = (FIXNUM_TO_LONG (Wrd124.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd125.Lng))))
    goto label_1337;
  (Wrd119.Obj) = ((Wrd123.pObj) [1]);

DEFLABEL (label_1336)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1335)
  (Wrd133.Obj) = (Rsp [2]);
  (Wrd134.Lng) = (FIXNUM_TO_LONG (Wrd133.Obj));
  (Wrd135.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  (Wrd136.Lng) = ((Wrd134.Lng) + (Wrd135.Lng));
  Rvl = (LONG_TO_FIXNUM (Wrd136.Lng));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1337)
  (Wrd128.Obj) = (current_block [OBJECT_30]);
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_402]))));
  (* (--Rsp)) = (Wrd131.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_805)
  (Wrd119.Obj) = Rvl;
  goto label_1336;

DEFLABEL (label_1339)
  (Wrd113.Obj) = (Rsp [2]);
  (Wrd114.Obj) = (current_block [OBJECT_46]);
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_401]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_804)
  (Wrd102.Obj) = Rvl;
  goto label_1338;

DEFLABEL (label_1340)
  (Wrd119.Obj) = (current_block [OBJECT_30]);
  goto label_1336;

DEFLABEL (label_1342)
  (Wrd96.Obj) = (Rsp [2]);
  (Wrd97.Obj) = (current_block [OBJECT_46]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_400]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_803)
  (Wrd85.Obj) = Rvl;
  goto label_1341;

DEFLABEL (label_1344)
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (current_block [OBJECT_42]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_349]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_777)
  (* (--Rsp)) = Rvl;
  goto label_1343;

DEFLABEL (label_1346)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_263]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_725)
  (* (--Rsp)) = Rvl;
  goto label_1345;

DEFLABEL (continuation_356)
  INTERRUPT_CHECK (27, LABEL_399);
  (Wrd44.Obj) = Rvl;
  goto label_1326;

DEFLABEL (continuation_351)
  INTERRUPT_CHECK (27, LABEL_398);
  (Wrd119.Obj) = Rvl;
  goto label_1335;

DEFLABEL (node_subsetP_888)
DEFLABEL (node_subsetP_539)
  INTERRUPT_CHECK (26, LABEL_267);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1382;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_266]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  if ((Wrd10.Obj) == (Wrd6.Obj))
    goto label_1381;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_1380;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_1380;
  (Wrd13.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_1379)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_1378)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_265]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  if ((Wrd32.Obj) == (current_block [OBJECT_43]))
    goto label_1377;
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_1376;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd43.Lng))))
    goto label_1376;
  (Wrd35.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_1375)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1374)
  (Wrd51.Obj) = (* (Rsp++));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if ((Wrd52.Lng) > (Wrd53.Lng))
    goto label_1372;
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_1371;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd62.Lng))))
    goto label_1371;
  (Wrd56.Obj) = ((Wrd60.pObj) [4]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_1370)
  (Wrd79.Obj) = (Rsp [1]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd80.uLng) == 10))
    goto label_1369;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd78.Lng))))
    goto label_1369;
  (Wrd72.Obj) = ((Wrd76.pObj) [2]);
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_1368)
  (Wrd95.Obj) = (Rsp [2]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_1367;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd94.Lng))))
    goto label_1367;
  (Wrd88.Obj) = ((Wrd92.pObj) [3]);
  (* (--Rsp)) = (Wrd88.Obj);

DEFLABEL (label_1366)
  Rdl = (& (Rsp [5]));
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd103.Obj);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_273]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd116.Obj) = (Rsp [6]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if (! ((Wrd117.uLng) == 10))
    goto label_1365;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd116.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd115.Lng))))
    goto label_1365;
  (Wrd109.Obj) = ((Wrd113.pObj) [3]);
  (* (--Rsp)) = (Wrd109.Obj);

DEFLABEL (label_1364)
  (Wrd127.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd127.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_526)
  INTERRUPT_CHECK (27, LABEL_273);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1351;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_353]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [6]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_1350;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_1350;
  (Wrd16.Obj) = ((Wrd20.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_1349)
  (Wrd34.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto node_subsetP_539;

DEFLABEL (continuation_536)
  INTERRUPT_CHECK (27, LABEL_353);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1347;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1347)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_407]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_find_343;

DEFLABEL (continuation_537)
  INTERRUPT_CHECK (27, LABEL_407);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1348;
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_539;

DEFLABEL (label_1348)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1350)
  (Wrd29.Obj) = (Rsp [6]);
  (Wrd30.Obj) = (current_block [OBJECT_46]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_354]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_778)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1349;

DEFLABEL (label_1351)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_351]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd50.Obj) = (Rsp [7]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1363;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1363;
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1362)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_528)
  INTERRUPT_CHECK (27, LABEL_351);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1356;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_410]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [6]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_1355;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_1355;
  (Wrd16.Obj) = ((Wrd20.pObj) [4]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_1354)
  (Wrd34.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto node_subsetP_539;

DEFLABEL (continuation_533)
  INTERRUPT_CHECK (27, LABEL_410);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1352;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1352)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_440]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_find_343;

DEFLABEL (continuation_534)
  INTERRUPT_CHECK (27, LABEL_440);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1353;
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_539;

DEFLABEL (label_1353)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1355)
  (Wrd29.Obj) = (Rsp [6]);
  (Wrd30.Obj) = (current_block [OBJECT_47]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_411]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_806)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1354;

DEFLABEL (label_1356)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_408]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd49.Obj) = (Rsp [6]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_1361;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd48.Lng))))
    goto label_1361;
  (Wrd42.Obj) = ((Wrd46.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_1360)
  (Wrd60.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd60.Obj);
  goto node_subsetP_539;

DEFLABEL (continuation_530)
  INTERRUPT_CHECK (27, LABEL_408);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1357;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_1357)
  (Wrd18.Obj) = (Rsp [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1359;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1359;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1358)
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_subsetP_539;

DEFLABEL (label_1359)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_47]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_441]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_820)
  (Wrd20.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd20.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1358;

DEFLABEL (label_1361)
  (Wrd55.Obj) = (Rsp [6]);
  (Wrd56.Obj) = (current_block [OBJECT_46]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_409]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_807)
  (Wrd51.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd51.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1360;

DEFLABEL (label_1363)
  (Wrd56.Obj) = (Rsp [7]);
  (Wrd57.Obj) = (current_block [OBJECT_42]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_352]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_779)
  (Wrd52.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd52.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1362;

DEFLABEL (label_1365)
  (Wrd122.Obj) = (Rsp [6]);
  (Wrd123.Obj) = (current_block [OBJECT_42]);
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_274]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_731)
  (Wrd118.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd118.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1364;

DEFLABEL (label_1367)
  (Wrd97.Obj) = (Rsp [2]);
  (Wrd98.Obj) = (current_block [OBJECT_42]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_272]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_730)
  (* (--Rsp)) = Rvl;
  goto label_1366;

DEFLABEL (label_1369)
  (Wrd81.Obj) = (Rsp [1]);
  (Wrd82.Obj) = (current_block [OBJECT_46]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_271]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_729)
  (* (--Rsp)) = Rvl;
  goto label_1368;

DEFLABEL (label_1371)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.Obj) = (current_block [OBJECT_47]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_270]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_728)
  (* (--Rsp)) = Rvl;
  goto label_1370;

DEFLABEL (label_1372)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_1373)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1376)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.Obj) = (current_block [OBJECT_30]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_269]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_727)
  (Wrd35.Obj) = Rvl;
  goto label_1375;

DEFLABEL (label_1377)
  (Wrd35.Obj) = (current_block [OBJECT_30]);
  goto label_1375;

DEFLABEL (label_1380)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_30]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_268]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_726)
  (Wrd13.Obj) = Rvl;
  goto label_1379;

DEFLABEL (label_1381)
  (Wrd133.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd133.Obj);
  goto label_1378;

DEFLABEL (label_1382)
  Rvl = (current_block [OBJECT_32]);
  goto label_1373;

DEFLABEL (continuation_517)
  INTERRUPT_CHECK (27, LABEL_265);
  (Wrd35.Obj) = Rvl;
  goto label_1374;

DEFLABEL (continuation_519)
  INTERRUPT_CHECK (27, LABEL_266);
  (* (--Rsp)) = Rvl;
  goto label_1378;

DEFLABEL (node_difference_889)
DEFLABEL (node_difference_498)
  INTERRUPT_CHECK (26, LABEL_276);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1391;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1389;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1388;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1388;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1387)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1386;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1386;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1385)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1384;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1384;
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1383)
  Rdl = (& (Rsp [5]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_280]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd62.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd63.Obj);
  goto node_split_gt_453;

DEFLABEL (continuation_493)
  INTERRUPT_CHECK (27, LABEL_280);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_355]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_441;

DEFLABEL (continuation_492)
  INTERRUPT_CHECK (27, LABEL_355);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_412]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_difference_498;

DEFLABEL (continuation_495)
  INTERRUPT_CHECK (27, LABEL_412);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_442]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_difference_498;

DEFLABEL (continuation_494)
  INTERRUPT_CHECK (27, LABEL_442);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_398;

DEFLABEL (label_1384)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_42]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_279]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_735)
  (* (--Rsp)) = Rvl;
  goto label_1383;

DEFLABEL (label_1386)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_278]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_734)
  (* (--Rsp)) = Rvl;
  goto label_1385;

DEFLABEL (label_1388)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_277]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_733)
  (* (--Rsp)) = Rvl;
  goto label_1387;

DEFLABEL (label_1389)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1390)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1391)
  Rvl = (Wrd6.Obj);
  goto label_1390;

DEFLABEL (node_intersection_890)
DEFLABEL (node_intersection_514)
  INTERRUPT_CHECK (26, LABEL_282);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1393;

DEFLABEL (label_1392)
  Rvl = (current_block [OBJECT_43]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1393)
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1392;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1404;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1404;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1403)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1402;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1402;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1401)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1400;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1400;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1399)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1398;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1398;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1397)
  Rdl = (& (Rsp [6]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_287]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_split_gt_453;

DEFLABEL (continuation_506)
  INTERRUPT_CHECK (27, LABEL_287);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_356]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_441;

DEFLABEL (continuation_505)
  INTERRUPT_CHECK (27, LABEL_356);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_413]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_find_343;

DEFLABEL (continuation_507)
  INTERRUPT_CHECK (27, LABEL_413);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1395;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_444]))));
  (* (--Rsp)) = (Wrd13.Obj);
  goto label_1394;

DEFLABEL (label_1395)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_443]))));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_1394)
DEFLABEL (label_1396)
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto node_intersection_514;

DEFLABEL (label_1398)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_286]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_740)
  (* (--Rsp)) = Rvl;
  goto label_1397;

DEFLABEL (label_1400)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_285]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_739)
  (* (--Rsp)) = Rvl;
  goto label_1399;

DEFLABEL (label_1402)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_284]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_738)
  (* (--Rsp)) = Rvl;
  goto label_1401;

DEFLABEL (label_1404)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_283]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_737)
  (* (--Rsp)) = Rvl;
  goto label_1403;

DEFLABEL (continuation_511)
  INTERRUPT_CHECK (27, LABEL_444);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_453]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_intersection_514;

DEFLABEL (continuation_510)
  INTERRUPT_CHECK (27, LABEL_453);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_429;

DEFLABEL (continuation_509)
  INTERRUPT_CHECK (27, LABEL_443);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_454]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_intersection_514;

DEFLABEL (continuation_508)
  INTERRUPT_CHECK (27, LABEL_454);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto node_concat_398;

DEFLABEL (node_union_merge_891)
DEFLABEL (node_union_merge_485)
  INTERRUPT_CHECK (26, LABEL_289);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1419;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1417;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1416;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1416;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1415)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1414;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1414;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1413)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1412;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1412;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1411)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1410;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1410;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1409)
  Rdl = (& (Rsp [7]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_294]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_find_343;

DEFLABEL (continuation_473)
  INTERRUPT_CHECK (27, LABEL_294);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_357]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_441;

DEFLABEL (continuation_474)
  INTERRUPT_CHECK (27, LABEL_357);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_414]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_gt_453;

DEFLABEL (continuation_475)
  INTERRUPT_CHECK (27, LABEL_414);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_445]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  if ((Wrd12.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1408;
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_1407;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd22.Lng))))
    goto label_1407;
  (Wrd16.Obj) = ((Wrd20.pObj) [5]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_1406)
  (Wrd34.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [14]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (continuation_476)
  INTERRUPT_CHECK (27, LABEL_445);
  (Wrd49.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd49.Obj));
  (* (--Rsp)) = Rvl;

DEFLABEL (label_1405)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_446]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [12]);
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd48.Obj);
  goto node_union_merge_485;

DEFLABEL (continuation_479)
  INTERRUPT_CHECK (27, LABEL_446);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_455]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [13]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto node_union_merge_485;

DEFLABEL (continuation_478)
  INTERRUPT_CHECK (27, LABEL_455);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_429;

DEFLABEL (label_1407)
  (Wrd29.Obj) = (Rsp [4]);
  (Wrd30.Obj) = (current_block [OBJECT_48]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_447]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_821)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1406;

DEFLABEL (label_1408)
  (Wrd40.Obj) = (Rsp [6]);
  Rsp = (& (Rsp [1]));
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_1405;

DEFLABEL (label_1410)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_293]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_745)
  (* (--Rsp)) = Rvl;
  goto label_1409;

DEFLABEL (label_1412)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_292]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_744)
  (* (--Rsp)) = Rvl;
  goto label_1411;

DEFLABEL (label_1414)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_291]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_743)
  (* (--Rsp)) = Rvl;
  goto label_1413;

DEFLABEL (label_1416)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_290]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_742)
  (* (--Rsp)) = Rvl;
  goto label_1415;

DEFLABEL (label_1417)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1418)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1419)
  Rvl = (Rsp [1]);
  goto label_1418;

DEFLABEL (node_union_892)
DEFLABEL (node_union_466)
  INTERRUPT_CHECK (26, LABEL_296);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1430;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1428;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1427;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1427;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_1426)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_1425;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd33.Lng))))
    goto label_1425;
  (Wrd27.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1424)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 10))
    goto label_1423;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd49.Lng))))
    goto label_1423;
  (Wrd43.Obj) = ((Wrd47.pObj) [5]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_1422)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd67.uLng) == 10))
    goto label_1421;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (Wrd65.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd65.Lng))))
    goto label_1421;
  (Wrd59.Obj) = ((Wrd63.pObj) [3]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_1420)
  Rdl = (& (Rsp [6]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_301]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto node_split_gt_453;

DEFLABEL (continuation_461)
  INTERRUPT_CHECK (27, LABEL_301);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_358]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_split_lt_441;

DEFLABEL (continuation_460)
  INTERRUPT_CHECK (27, LABEL_358);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_415]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_union_466;

DEFLABEL (continuation_463)
  INTERRUPT_CHECK (27, LABEL_415);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_448]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  goto node_union_466;

DEFLABEL (continuation_462)
  INTERRUPT_CHECK (27, LABEL_448);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  goto node_concat3_429;

DEFLABEL (label_1421)
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.Obj) = (current_block [OBJECT_42]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_300]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_750)
  (* (--Rsp)) = Rvl;
  goto label_1420;

DEFLABEL (label_1423)
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.Obj) = (current_block [OBJECT_48]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_299]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_749)
  (* (--Rsp)) = Rvl;
  goto label_1422;

DEFLABEL (label_1425)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (current_block [OBJECT_46]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_298]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_748)
  (* (--Rsp)) = Rvl;
  goto label_1424;

DEFLABEL (label_1427)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_47]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_297]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_747)
  (* (--Rsp)) = Rvl;
  goto label_1426;

DEFLABEL (label_1428)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1429)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1430)
  Rvl = (Rsp [1]);
  goto label_1429;

DEFLABEL (node_split_gt_893)
DEFLABEL (node_split_gt_453)
  INTERRUPT_CHECK (26, LABEL_303);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1431;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1431)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_304]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_1449;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_1449;
  (Wrd13.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_1448)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_444)
  INTERRUPT_CHECK (27, LABEL_304);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1434;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1433;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1433;
  (Wrd7.Obj) = ((Wrd13.pObj) [4]);

DEFLABEL (label_1432)
  (Rsp [0]) = (Wrd7.Obj);
  goto node_split_gt_453;

DEFLABEL (label_1433)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_47]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_361]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_780)
  (Wrd7.Obj) = Rvl;
  goto label_1432;

DEFLABEL (label_1434)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_359]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_1447;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd34.Lng))))
    goto label_1447;
  (Wrd28.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_1446)
  (Wrd42.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_446)
  INTERRUPT_CHECK (27, LABEL_359);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1443;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1442;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1442;
  (Wrd9.Obj) = ((Wrd13.pObj) [5]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1441)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1440;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1440;
  (Wrd25.Obj) = ((Wrd29.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1439)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1438;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1438;
  (Wrd41.Obj) = ((Wrd45.pObj) [4]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_1437)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_419]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd68.Obj) = (Rsp [5]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_1436;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd67.Lng))))
    goto label_1436;
  (Wrd61.Obj) = ((Wrd65.pObj) [2]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_1435)
  goto node_split_gt_453;

DEFLABEL (continuation_450)
  INTERRUPT_CHECK (27, LABEL_419);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd6.Obj);
  goto node_concat3_429;

DEFLABEL (label_1436)
  (Wrd70.Obj) = (Rsp [5]);
  (Wrd71.Obj) = (current_block [OBJECT_46]);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_420]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_811)
  (* (--Rsp)) = Rvl;
  goto label_1435;

DEFLABEL (label_1438)
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.Obj) = (current_block [OBJECT_47]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_418]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_810)
  (* (--Rsp)) = Rvl;
  goto label_1437;

DEFLABEL (label_1440)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_42]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_417]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_809)
  (* (--Rsp)) = Rvl;
  goto label_1439;

DEFLABEL (label_1442)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_48]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_416]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_808)
  (* (--Rsp)) = Rvl;
  goto label_1441;

DEFLABEL (label_1443)
  (Wrd75.Obj) = (current_block [OBJECT_47]);
  (Rsp [1]) = (Wrd75.Obj);
  (Wrd86.Obj) = (Rsp [0]);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if ((Wrd87.uLng) == 10)
    goto label_1445;

DEFLABEL (label_1444)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_1445)
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd84.Obj) = ((Wrd83.pObj) [0]);
  (Wrd85.Lng) = (FIXNUM_TO_LONG (Wrd84.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd85.Lng))))
    goto label_1444;
  Rvl = ((Wrd83.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1447)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (current_block [OBJECT_42]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_360]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_781)
  (* (--Rsp)) = Rvl;
  goto label_1446;

DEFLABEL (label_1449)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_42]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_305]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_752)
  (* (--Rsp)) = Rvl;
  goto label_1448;

DEFLABEL (node_split_lt_894)
DEFLABEL (node_split_lt_441)
  INTERRUPT_CHECK (26, LABEL_307);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1450;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1450)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_308]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1468;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1468;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1467)
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_432)
  INTERRUPT_CHECK (27, LABEL_308);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1453;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1452;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1452;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_1451)
  (Rsp [0]) = (Wrd7.Obj);
  goto node_split_lt_441;

DEFLABEL (label_1452)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_46]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_364]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_782)
  (Wrd7.Obj) = Rvl;
  goto label_1451;

DEFLABEL (label_1453)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_362]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_1466;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd35.Lng))))
    goto label_1466;
  (Wrd29.Obj) = ((Wrd33.pObj) [3]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_1465)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_434)
  INTERRUPT_CHECK (27, LABEL_362);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1462;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1461;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1461;
  (Wrd9.Obj) = ((Wrd13.pObj) [5]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1460)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1459;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1459;
  (Wrd25.Obj) = ((Wrd29.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1458)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_423]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 10))
    goto label_1457;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [0]);
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd51.Lng))))
    goto label_1457;
  (Wrd45.Obj) = ((Wrd49.pObj) [4]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_1456)
  goto node_split_lt_441;

DEFLABEL (continuation_439)
  INTERRUPT_CHECK (27, LABEL_423);
  (Rsp [3]) = Rvl;
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_1455;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd14.Lng))))
    goto label_1455;
  (Wrd6.Obj) = ((Wrd12.pObj) [2]);

DEFLABEL (label_1454)
  (Rsp [2]) = (Wrd6.Obj);
  goto node_concat3_429;

DEFLABEL (label_1455)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.Obj) = (current_block [OBJECT_46]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_449]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_822)
  (Wrd6.Obj) = Rvl;
  goto label_1454;

DEFLABEL (label_1457)
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.Obj) = (current_block [OBJECT_47]);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_424]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_814)
  (* (--Rsp)) = Rvl;
  goto label_1456;

DEFLABEL (label_1459)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_42]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_422]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_813)
  (* (--Rsp)) = Rvl;
  goto label_1458;

DEFLABEL (label_1461)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_48]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_421]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_812)
  (* (--Rsp)) = Rvl;
  goto label_1460;

DEFLABEL (label_1462)
  (Wrd59.Obj) = (current_block [OBJECT_46]);
  (Rsp [1]) = (Wrd59.Obj);
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 10)
    goto label_1464;

DEFLABEL (label_1463)
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_1464)
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd69.Lng))))
    goto label_1463;
  Rvl = ((Wrd67.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1466)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.Obj) = (current_block [OBJECT_42]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_363]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_783)
  (* (--Rsp)) = Rvl;
  goto label_1465;

DEFLABEL (label_1468)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_309]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_754)
  (* (--Rsp)) = Rvl;
  goto label_1467;

DEFLABEL (node_find_895)
DEFLABEL (node_find_343)
  INTERRUPT_CHECK (26, LABEL_310);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_342;

DEFLABEL (node_delete_896)
DEFLABEL (node_delete_390)
  INTERRUPT_CHECK (26, LABEL_311);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1469;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1469)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1479;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1479;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1478)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1477;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1477;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1476)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1475;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1475;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_1474)
  (Wrd64.Obj) = (Rsp [4]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_1473;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_1473;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_1472)
  Rdl = (& (Rsp [6]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_316]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_385)
  INTERRUPT_CHECK (27, LABEL_316);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1470;
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_371]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_delete_390;

DEFLABEL (continuation_388)
  INTERRUPT_CHECK (27, LABEL_371);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1470)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_370]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_386)
  INTERRUPT_CHECK (27, LABEL_370);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1471;
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_236]));

DEFLABEL (label_1471)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_427]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd15.Obj);
  goto node_delete_390;

DEFLABEL (continuation_387)
  INTERRUPT_CHECK (27, LABEL_427);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1473)
  (Wrd66.Obj) = (Rsp [4]);
  (Wrd67.Obj) = (current_block [OBJECT_42]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_315]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_758)
  (* (--Rsp)) = Rvl;
  goto label_1472;

DEFLABEL (label_1475)
  (Wrd50.Obj) = (Rsp [3]);
  (Wrd51.Obj) = (current_block [OBJECT_48]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_314]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_757)
  (* (--Rsp)) = Rvl;
  goto label_1474;

DEFLABEL (label_1477)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.Obj) = (current_block [OBJECT_46]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_313]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_756)
  (* (--Rsp)) = Rvl;
  goto label_1476;

DEFLABEL (label_1479)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_47]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_312]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_755)
  (* (--Rsp)) = Rvl;
  goto label_1478;

DEFLABEL (node_add_897)
DEFLABEL (node_add_379)
  INTERRUPT_CHECK (26, LABEL_318);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_1480;
  (Wrd87.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd88.Obj) = (current_block [OBJECT_46]);
  (Wrd90.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd87.Obj);
  (* (Rhp++)) = (Wrd88.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd90.Obj);
  (Wrd84.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd84.Obj);
  (Wrd81.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd81.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1480)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1498;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1498;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_1497)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_1496;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd31.Lng))))
    goto label_1496;
  (Wrd25.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_1495)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1494;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1494;
  (Wrd41.Obj) = ((Wrd45.pObj) [5]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_1493)
  (Wrd64.Obj) = (Rsp [3]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_1492;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd63.Lng))))
    goto label_1492;
  (Wrd57.Obj) = ((Wrd61.pObj) [3]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_1491)
  Rdl = (& (Rsp [7]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_323]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  (Wrd77.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_367)
  INTERRUPT_CHECK (27, LABEL_323);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1481;
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_373]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd17.Obj);
  goto node_add_379;

DEFLABEL (continuation_377)
  INTERRUPT_CHECK (27, LABEL_373);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1481)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_372]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (continuation_368)
  INTERRUPT_CHECK (27, LABEL_372);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1482;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_432]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto node_add_379;

DEFLABEL (continuation_376)
  INTERRUPT_CHECK (27, LABEL_432);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1482)
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_429]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  if ((Wrd24.Obj) == (current_block [OBJECT_43]))
    goto label_1490;
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_1489;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd35.Lng))))
    goto label_1489;
  (Wrd27.Obj) = ((Wrd33.pObj) [1]);

DEFLABEL (label_1488)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_1487)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_428]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (Rsp [4]);
  if ((Wrd46.Obj) == (current_block [OBJECT_43]))
    goto label_1486;
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd59.uLng) == 10))
    goto label_1485;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd57.Lng))))
    goto label_1485;
  (Wrd49.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_1484)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1483)
  (Wrd65.Obj) = (* (Rsp++));
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  (Wrd68.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  (Wrd71.Lng) = ((Wrd67.Lng) + (Wrd68.Lng));
  (Wrd72.Lng) = ((Wrd71.Lng) + 1L);
  (Wrd70.Obj) = (LONG_TO_FIXNUM (Wrd72.Lng));
  (Wrd81.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd82.Obj) = (Rsp [2]);
  (Wrd83.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd81.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd82.Obj);
  (* (Rhp++)) = (Wrd83.Obj);
  (Wrd77.Obj) = (Rsp [3]);
  (Wrd78.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd77.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd75.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd75.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_1485)
  (Wrd60.Obj) = (Rsp [4]);
  (Wrd61.Obj) = (current_block [OBJECT_30]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_431]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_818)
  (Wrd49.Obj) = Rvl;
  goto label_1484;

DEFLABEL (label_1486)
  (Wrd49.Obj) = (current_block [OBJECT_30]);
  goto label_1484;

DEFLABEL (label_1489)
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.Obj) = (current_block [OBJECT_30]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_430]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_817)
  (Wrd27.Obj) = Rvl;
  goto label_1488;

DEFLABEL (label_1490)
  (Wrd86.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd86.Obj);
  goto label_1487;

DEFLABEL (label_1492)
  (Wrd66.Obj) = (Rsp [3]);
  (Wrd67.Obj) = (current_block [OBJECT_42]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_322]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_763)
  (* (--Rsp)) = Rvl;
  goto label_1491;

DEFLABEL (label_1494)
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.Obj) = (current_block [OBJECT_48]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_321]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_762)
  (* (--Rsp)) = Rvl;
  goto label_1493;

DEFLABEL (label_1496)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (current_block [OBJECT_46]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_320]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_761)
  (* (--Rsp)) = Rvl;
  goto label_1495;

DEFLABEL (label_1498)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_47]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_319]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_760)
  (* (--Rsp)) = Rvl;
  goto label_1497;

DEFLABEL (continuation_370)
  INTERRUPT_CHECK (27, LABEL_428);
  (Wrd49.Obj) = Rvl;
  goto label_1483;

DEFLABEL (continuation_372)
  INTERRUPT_CHECK (27, LABEL_429);
  (* (--Rsp)) = Rvl;
  goto label_1487;

DEFLABEL (loop_898)
DEFLABEL (loop_594)
  INTERRUPT_CHECK (26, LABEL_325);
  (Wrd11.Obj) = (Rsp [0]);
  if ((Wrd11.Obj) == (current_block [OBJECT_24]))
    goto label_1510;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_1499;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_53]);
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_54]);
  (Rsp [2]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_260]));

DEFLABEL (label_1499)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_326]))));
  (* (--Rsp)) = (Wrd20.Obj);
  if (! ((Wrd14.uLng) == 1))
    goto label_1509;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_1508)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_1507;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_1506)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_1505;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_1504)
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_1503;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_1502)
  (Wrd53.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd53.Obj);
  goto node_add_379;

DEFLABEL (continuation_593)
  INTERRUPT_CHECK (27, LABEL_326);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_1501;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_1500)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_594;

DEFLABEL (label_1501)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_374]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52]), 1);

DEFLABEL (label_786)
  (Wrd6.Obj) = Rvl;
  goto label_1500;

DEFLABEL (label_1503)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_330]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_768)
  (* (--Rsp)) = Rvl;
  goto label_1502;

DEFLABEL (label_1505)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_329]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_767)
  (Wrd37.Obj) = Rvl;
  goto label_1504;

DEFLABEL (label_1507)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_328]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52]), 1);

DEFLABEL (label_766)
  (* (--Rsp)) = Rvl;
  goto label_1506;

DEFLABEL (label_1509)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_327]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51]), 1);

DEFLABEL (label_765)
  (Wrd21.Obj) = Rvl;
  goto label_1508;

DEFLABEL (label_1510)
  (Wrd5.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto label_1064;

DEFLABEL (loop_899)
DEFLABEL (loop_52)
  INTERRUPT_CHECK (26, LABEL_341);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_43]))
    goto label_1524;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_340]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1523;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1523;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1522)
  (Wrd26.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_1512;

DEFLABEL (label_1511)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_1512)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 26))
    goto label_1511;
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if ((Wrd34.Lng) < (Wrd36.Lng))
    goto label_1514;
  (Wrd28.Obj) = (current_block [OBJECT_45]);
  goto label_1513;

DEFLABEL (label_1514)
  (Wrd28.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1513)
DEFLABEL (label_1521)
  Rsp = (& (Rsp [3]));
  if ((Wrd28.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1518;

DEFLABEL (label_1517)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_1516;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd63.Lng))))
    goto label_1516;
  (Wrd55.Obj) = ((Wrd61.pObj) [2]);

DEFLABEL (label_1515)
  (Rsp [0]) = (Wrd55.Obj);
  goto loop_52;

DEFLABEL (label_1516)
  (Wrd66.Obj) = (Rsp [0]);
  (Wrd67.Obj) = (current_block [OBJECT_46]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_345]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_773)
  (Wrd55.Obj) = Rvl;
  goto label_1515;

DEFLABEL (label_1518)
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd38.Obj);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_1520;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd47.Lng))))
    goto label_1520;
  (Wrd39.Obj) = ((Wrd45.pObj) [4]);

DEFLABEL (label_1519)
  (Rsp [0]) = (Wrd39.Obj);
  goto loop_52;

DEFLABEL (label_1520)
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd51.Obj) = (current_block [OBJECT_47]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_344]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_772)
  (Wrd39.Obj) = Rvl;
  goto label_1519;

DEFLABEL (label_1523)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_343]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_771)
  (* (--Rsp)) = Rvl;
  goto label_1522;

DEFLABEL (label_1524)
  (Wrd72.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd72.Obj);
  if ((Wrd72.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1529;
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_339]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd89.uLng) == 10))
    goto label_1533;
  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  (Wrd86.Obj) = ((Wrd85.pObj) [0]);
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd86.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd87.Lng))))
    goto label_1533;
  (Wrd81.Obj) = ((Wrd85.pObj) [3]);
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_1532)
  (Wrd97.Obj) = (Rsp [0]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd98.uLng) == 26))
    goto label_1511;
  (Wrd99.Obj) = (Rsp [1]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd100.uLng) == 26))
    goto label_1511;
  (Wrd102.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  (Wrd104.Lng) = (FIXNUM_TO_LONG (Wrd99.Obj));
  if ((Wrd102.Lng) < (Wrd104.Lng))
    goto label_1526;
  (Wrd96.Obj) = (current_block [OBJECT_45]);
  goto label_1525;

DEFLABEL (label_1526)
  (Wrd96.Obj) = (current_block [OBJECT_32]);

DEFLABEL (label_1525)
DEFLABEL (label_1531)
  Rsp = (& (Rsp [3]));
  if ((Wrd96.Obj) == ((SCHEME_OBJECT) 0))
    goto label_1528;

DEFLABEL (label_1529)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_1527;

DEFLABEL (label_1528)
  Rvl = (Rsp [0]);

DEFLABEL (label_1527)
DEFLABEL (label_1530)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1533)
  (Wrd90.Obj) = (Rsp [2]);
  (Wrd91.Obj) = (current_block [OBJECT_42]);
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_342]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_774)
  (* (--Rsp)) = Rvl;
  goto label_1532;

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_340);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1518;
  goto label_1517;

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_339);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1528;
  goto label_1529;

DEFLABEL (loop_900)
DEFLABEL (loop_342)
  INTERRUPT_CHECK (26, LABEL_365);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_43]))
    goto label_1537;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_368]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_1536;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_1536;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1535)
  (Wrd26.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_1534)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_264]));

DEFLABEL (label_1536)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_42]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_369]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_784)
  (* (--Rsp)) = Rvl;
  goto label_1535;

DEFLABEL (label_1537)
  (Wrd28.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd28.Obj);
  if (! ((Wrd28.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_1538;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1538)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_366]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_1539;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd43.Lng))))
    goto label_1539;
  (Wrd37.Obj) = ((Wrd41.pObj) [3]);
  (* (--Rsp)) = (Wrd37.Obj);
  goto label_1534;

DEFLABEL (label_1539)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.Obj) = (current_block [OBJECT_42]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_367]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_785)
  (* (--Rsp)) = Rvl;
  goto label_1534;

DEFLABEL (continuation_339)
  INTERRUPT_CHECK (27, LABEL_368);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1542;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_1541;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_1541;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_1540)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_342;

DEFLABEL (label_1541)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_46]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_426]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_815)
  (Wrd7.Obj) = Rvl;
  goto label_1540;

DEFLABEL (label_1542)
  (Wrd23.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd23.Obj);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_1544;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd32.Lng))))
    goto label_1544;
  (Wrd24.Obj) = ((Wrd30.pObj) [4]);

DEFLABEL (label_1543)
  (Rsp [0]) = (Wrd24.Obj);
  goto loop_342;

DEFLABEL (label_1544)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_47]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_425]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_816)
  (Wrd24.Obj) = Rvl;
  goto label_1543;

DEFLABEL (continuation_335)
  INTERRUPT_CHECK (27, LABEL_366);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1546;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_1545;

DEFLABEL (label_1546)
  Rvl = (Rsp [0]);

DEFLABEL (label_1545)
DEFLABEL (label_1547)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (node_concat3_901)
DEFLABEL (node_concat3_145)
  INTERRUPT_CHECK (26, LABEL_383);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1584;
  (Wrd7.Obj) = (Rsp [3]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1582;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_382]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1581;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_1580;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd23.Lng))))
    goto label_1580;
  (Wrd15.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_1579)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_1578)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_381]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  if ((Wrd34.Obj) == (current_block [OBJECT_43]))
    goto label_1577;
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_1576;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_1576;
  (Wrd37.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_1575)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_1574)
  Rdl = (& (Rsp [6]));
  (Wrd55.Lng) = 5L;
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  (Wrd59.Lng) = ((Wrd55.Lng) * (Wrd57.Lng));
  (Wrd60.Obj) = (Rsp [1]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if ((Wrd59.Lng) < (Wrd61.Lng))
    goto label_1565;
  (Wrd68.Lng) = ((Wrd55.Lng) * (Wrd61.Lng));
  if ((Wrd68.Lng) < (Wrd57.Lng))
    goto label_1556;
  (Wrd71.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd73.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd74.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_380]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [4]);
  if ((Wrd78.Obj) == (current_block [OBJECT_43]))
    goto label_1555;
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd91.uLng) == 10))
    goto label_1554;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd88.Obj) = ((Wrd87.pObj) [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd89.Lng))))
    goto label_1554;
  (Wrd81.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_1553)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_1552)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_379]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd100.Obj) = (Rsp [4]);
  if ((Wrd100.Obj) == (current_block [OBJECT_43]))
    goto label_1551;
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_1550;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd110.Obj) = ((Wrd109.pObj) [0]);
  (Wrd111.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd111.Lng))))
    goto label_1550;
  (Wrd103.Obj) = ((Wrd109.pObj) [1]);

DEFLABEL (label_1549)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1548)
  (Wrd119.Obj) = (* (Rsp++));
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd103.Obj));
  (Wrd122.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  (Wrd125.Lng) = ((Wrd121.Lng) + (Wrd122.Lng));
  (Wrd126.Lng) = ((Wrd125.Lng) + 1L);
  (Wrd124.Obj) = (LONG_TO_FIXNUM (Wrd126.Lng));
  (Wrd135.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd136.Obj) = (Rsp [2]);
  (Wrd137.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd135.Obj);
  (* (Rhp++)) = (Wrd124.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (* (Rhp++)) = (Wrd137.Obj);
  (Wrd131.Obj) = (Rsp [3]);
  (Wrd132.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd131.Obj);
  (* (Rhp++)) = (Wrd132.Obj);
  (Wrd129.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd129.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_1550)
  (Wrd114.Obj) = (Rsp [4]);
  (Wrd115.Obj) = (current_block [OBJECT_30]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_397]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_790)
  (Wrd103.Obj) = Rvl;
  goto label_1549;

DEFLABEL (label_1551)
  (Wrd103.Obj) = (current_block [OBJECT_30]);
  goto label_1549;

DEFLABEL (label_1554)
  (Wrd92.Obj) = (Rsp [4]);
  (Wrd93.Obj) = (current_block [OBJECT_30]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_396]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_789)
  (Wrd81.Obj) = Rvl;
  goto label_1553;

DEFLABEL (label_1555)
  (Wrd140.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd140.Obj);
  goto label_1552;

DEFLABEL (label_1556)
  (Wrd150.Obj) = (Rsp [4]);
  (Wrd151.uLng) = (OBJECT_TYPE (Wrd150.Obj));
  if (! ((Wrd151.uLng) == 10))
    goto label_1564;
  (Wrd147.pObj) = (OBJECT_ADDRESS (Wrd150.Obj));
  (Wrd148.Obj) = ((Wrd147.pObj) [0]);
  (Wrd149.Lng) = (FIXNUM_TO_LONG (Wrd148.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd149.Lng))))
    goto label_1564;
  (Wrd143.Obj) = ((Wrd147.pObj) [5]);
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_1563)
  (Wrd170.Obj) = (Rsp [5]);
  (Wrd171.uLng) = (OBJECT_TYPE (Wrd170.Obj));
  if (! ((Wrd171.uLng) == 10))
    goto label_1562;
  (Wrd167.pObj) = (OBJECT_ADDRESS (Wrd170.Obj));
  (Wrd168.Obj) = ((Wrd167.pObj) [0]);
  (Wrd169.Lng) = (FIXNUM_TO_LONG (Wrd168.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd169.Lng))))
    goto label_1562;
  (Wrd163.Obj) = ((Wrd167.pObj) [3]);
  (* (--Rsp)) = (Wrd163.Obj);

DEFLABEL (label_1561)
  (Wrd190.Obj) = (Rsp [6]);
  (Wrd191.uLng) = (OBJECT_TYPE (Wrd190.Obj));
  if (! ((Wrd191.uLng) == 10))
    goto label_1560;
  (Wrd187.pObj) = (OBJECT_ADDRESS (Wrd190.Obj));
  (Wrd188.Obj) = ((Wrd187.pObj) [0]);
  (Wrd189.Lng) = (FIXNUM_TO_LONG (Wrd188.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd189.Lng))))
    goto label_1560;
  (Wrd181.Obj) = ((Wrd187.pObj) [2]);

DEFLABEL (label_1559)
  (Rsp [2]) = (Wrd181.Obj);
  (Wrd210.Obj) = (Rsp [6]);
  (Wrd211.uLng) = (OBJECT_TYPE (Wrd210.Obj));
  if (! ((Wrd211.uLng) == 10))
    goto label_1558;
  (Wrd207.pObj) = (OBJECT_ADDRESS (Wrd210.Obj));
  (Wrd208.Obj) = ((Wrd207.pObj) [0]);
  (Wrd209.Lng) = (FIXNUM_TO_LONG (Wrd208.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd209.Lng))))
    goto label_1558;
  (Wrd201.Obj) = ((Wrd207.pObj) [4]);

DEFLABEL (label_1557)
  (Rsp [3]) = (Wrd201.Obj);
  (Wrd222.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd222.Obj);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_395]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (Wrd226.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd226.Obj);
  (* (--Rsp)) = (Wrd201.Obj);
  (Wrd228.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd228.Obj);
  (Wrd229.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd229.Obj);
  goto node_concat3_145;

DEFLABEL (continuation_136)
  INTERRUPT_CHECK (27, LABEL_395);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1558)
  (Wrd216.Obj) = (Rsp [6]);
  (Wrd217.Obj) = (current_block [OBJECT_47]);
  (Wrd215.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd215.Obj);
  (Wrd220.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_394]))));
  (* (--Rsp)) = (Wrd220.Obj);
  (* (--Rsp)) = (Wrd217.Obj);
  (* (--Rsp)) = (Wrd216.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_794)
  (Wrd212.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd212.Obj));
  (Wrd201.Obj) = Rvl;
  goto label_1557;

DEFLABEL (label_1560)
  (Wrd196.Obj) = (Rsp [6]);
  (Wrd197.Obj) = (current_block [OBJECT_46]);
  (Wrd195.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd200.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_393]))));
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd197.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_793)
  (Wrd192.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd192.Obj));
  (Wrd181.Obj) = Rvl;
  goto label_1559;

DEFLABEL (label_1562)
  (Wrd176.Obj) = (Rsp [5]);
  (Wrd177.Obj) = (current_block [OBJECT_42]);
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd175.Obj);
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_392]))));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd176.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_792)
  (Wrd172.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd172.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1561;

DEFLABEL (label_1564)
  (Wrd156.Obj) = (Rsp [4]);
  (Wrd157.Obj) = (current_block [OBJECT_48]);
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd155.Obj);
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_391]))));
  (* (--Rsp)) = (Wrd160.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd156.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_791)
  (Wrd152.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd152.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1563;

DEFLABEL (label_1565)
  (Wrd239.Obj) = (Rsp [5]);
  (Wrd240.uLng) = (OBJECT_TYPE (Wrd239.Obj));
  if (! ((Wrd240.uLng) == 10))
    goto label_1573;
  (Wrd236.pObj) = (OBJECT_ADDRESS (Wrd239.Obj));
  (Wrd237.Obj) = ((Wrd236.pObj) [0]);
  (Wrd238.Lng) = (FIXNUM_TO_LONG (Wrd237.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd238.Lng))))
    goto label_1573;
  (Wrd232.Obj) = ((Wrd236.pObj) [5]);
  (* (--Rsp)) = (Wrd232.Obj);

DEFLABEL (label_1572)
  (Wrd259.Obj) = (Rsp [6]);
  (Wrd260.uLng) = (OBJECT_TYPE (Wrd259.Obj));
  if (! ((Wrd260.uLng) == 10))
    goto label_1571;
  (Wrd256.pObj) = (OBJECT_ADDRESS (Wrd259.Obj));
  (Wrd257.Obj) = ((Wrd256.pObj) [0]);
  (Wrd258.Lng) = (FIXNUM_TO_LONG (Wrd257.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd258.Lng))))
    goto label_1571;
  (Wrd252.Obj) = ((Wrd256.pObj) [3]);
  (* (--Rsp)) = (Wrd252.Obj);

DEFLABEL (label_1570)
  (Wrd279.Obj) = (Rsp [7]);
  (Wrd280.uLng) = (OBJECT_TYPE (Wrd279.Obj));
  if (! ((Wrd280.uLng) == 10))
    goto label_1569;
  (Wrd276.pObj) = (OBJECT_ADDRESS (Wrd279.Obj));
  (Wrd277.Obj) = ((Wrd276.pObj) [0]);
  (Wrd278.Lng) = (FIXNUM_TO_LONG (Wrd277.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd278.Lng))))
    goto label_1569;
  (Wrd270.Obj) = ((Wrd276.pObj) [2]);

DEFLABEL (label_1568)
  (Rsp [2]) = (Wrd270.Obj);
  (Wrd299.Obj) = (Rsp [7]);
  (Wrd300.uLng) = (OBJECT_TYPE (Wrd299.Obj));
  if (! ((Wrd300.uLng) == 10))
    goto label_1567;
  (Wrd296.pObj) = (OBJECT_ADDRESS (Wrd299.Obj));
  (Wrd297.Obj) = ((Wrd296.pObj) [0]);
  (Wrd298.Lng) = (FIXNUM_TO_LONG (Wrd297.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd298.Lng))))
    goto label_1567;
  (Wrd290.Obj) = ((Wrd296.pObj) [4]);

DEFLABEL (label_1566)
  (Rsp [3]) = (Wrd290.Obj);
  (* (--Rsp)) = (Wrd290.Obj);
  (Wrd312.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd312.Obj);
  (Wrd315.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_390]))));
  (* (--Rsp)) = (Wrd315.Obj);
  (Wrd316.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd316.Obj);
  (Wrd317.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd318.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd318.Obj);
  (Wrd319.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd319.Obj);
  goto node_concat3_145;

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_390);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1567)
  (Wrd305.Obj) = (Rsp [7]);
  (Wrd306.Obj) = (current_block [OBJECT_47]);
  (Wrd304.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd304.Obj);
  (Wrd309.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_389]))));
  (* (--Rsp)) = (Wrd309.Obj);
  (* (--Rsp)) = (Wrd306.Obj);
  (* (--Rsp)) = (Wrd305.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_798)
  (Wrd301.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd301.Obj));
  (Wrd290.Obj) = Rvl;
  goto label_1566;

DEFLABEL (label_1569)
  (Wrd285.Obj) = (Rsp [7]);
  (Wrd286.Obj) = (current_block [OBJECT_46]);
  (Wrd284.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd284.Obj);
  (Wrd289.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_388]))));
  (* (--Rsp)) = (Wrd289.Obj);
  (* (--Rsp)) = (Wrd286.Obj);
  (* (--Rsp)) = (Wrd285.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_797)
  (Wrd281.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd281.Obj));
  (Wrd270.Obj) = Rvl;
  goto label_1568;

DEFLABEL (label_1571)
  (Wrd265.Obj) = (Rsp [6]);
  (Wrd266.Obj) = (current_block [OBJECT_42]);
  (Wrd264.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd264.Obj);
  (Wrd269.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_387]))));
  (* (--Rsp)) = (Wrd269.Obj);
  (* (--Rsp)) = (Wrd266.Obj);
  (* (--Rsp)) = (Wrd265.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_796)
  (Wrd261.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd261.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1570;

DEFLABEL (label_1573)
  (Wrd245.Obj) = (Rsp [5]);
  (Wrd246.Obj) = (current_block [OBJECT_48]);
  (Wrd244.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd244.Obj);
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_386]))));
  (* (--Rsp)) = (Wrd249.Obj);
  (* (--Rsp)) = (Wrd246.Obj);
  (* (--Rsp)) = (Wrd245.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_795)
  (Wrd241.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd241.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1572;

DEFLABEL (label_1576)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.Obj) = (current_block [OBJECT_30]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_385]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_788)
  (Wrd37.Obj) = Rvl;
  goto label_1575;

DEFLABEL (label_1577)
  (Wrd322.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd322.Obj);
  goto label_1574;

DEFLABEL (label_1580)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.Obj) = (current_block [OBJECT_30]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_384]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_787)
  (Wrd15.Obj) = Rvl;
  goto label_1579;

DEFLABEL (label_1581)
  (Wrd324.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd324.Obj);
  goto label_1578;

DEFLABEL (label_1582)
  (Wrd325.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd325.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd327.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd327.Obj);

DEFLABEL (label_1583)
  Rsp = (& (Rsp [1]));
  goto node_add_93;

DEFLABEL (label_1584)
  (Wrd329.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd329.Obj);
  (Wrd330.Obj) = (Rsp [1]);
  (Wrd331.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd331.Obj);
  (Rsp [3]) = (Wrd330.Obj);
  goto label_1583;

DEFLABEL (continuation_126)
  INTERRUPT_CHECK (27, LABEL_379);
  (Wrd103.Obj) = Rvl;
  goto label_1548;

DEFLABEL (continuation_128)
  INTERRUPT_CHECK (27, LABEL_380);
  (* (--Rsp)) = Rvl;
  goto label_1552;

DEFLABEL (continuation_118)
  INTERRUPT_CHECK (27, LABEL_381);
  (* (--Rsp)) = Rvl;
  goto label_1574;

DEFLABEL (continuation_120)
  INTERRUPT_CHECK (27, LABEL_382);
  (* (--Rsp)) = Rvl;
  goto label_1578;

DEFLABEL (node_concat3_902)
DEFLABEL (node_concat3_429)
  INTERRUPT_CHECK (26, LABEL_460);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1621;
  (Wrd7.Obj) = (Rsp [3]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1619;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_459]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1618;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_1617;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd23.Lng))))
    goto label_1617;
  (Wrd15.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_1616)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_1615)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_458]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  if ((Wrd34.Obj) == (current_block [OBJECT_43]))
    goto label_1614;
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_1613;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_1613;
  (Wrd37.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_1612)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_1611)
  Rdl = (& (Rsp [6]));
  (Wrd55.Lng) = 5L;
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  (Wrd59.Lng) = ((Wrd55.Lng) * (Wrd57.Lng));
  (Wrd60.Obj) = (Rsp [1]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if ((Wrd59.Lng) < (Wrd61.Lng))
    goto label_1602;
  (Wrd68.Lng) = ((Wrd55.Lng) * (Wrd61.Lng));
  if ((Wrd68.Lng) < (Wrd57.Lng))
    goto label_1593;
  (Wrd71.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd73.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd74.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_457]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd78.Obj) = (Rsp [4]);
  if ((Wrd78.Obj) == (current_block [OBJECT_43]))
    goto label_1592;
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd91.uLng) == 10))
    goto label_1591;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd88.Obj) = ((Wrd87.pObj) [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd89.Lng))))
    goto label_1591;
  (Wrd81.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_1590)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_1589)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_456]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd100.Obj) = (Rsp [4]);
  if ((Wrd100.Obj) == (current_block [OBJECT_43]))
    goto label_1588;
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd113.uLng) == 10))
    goto label_1587;
  (Wrd109.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd110.Obj) = ((Wrd109.pObj) [0]);
  (Wrd111.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd111.Lng))))
    goto label_1587;
  (Wrd103.Obj) = ((Wrd109.pObj) [1]);

DEFLABEL (label_1586)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_1585)
  (Wrd119.Obj) = (* (Rsp++));
  (Wrd121.Lng) = (FIXNUM_TO_LONG (Wrd103.Obj));
  (Wrd122.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  (Wrd125.Lng) = ((Wrd121.Lng) + (Wrd122.Lng));
  (Wrd126.Lng) = ((Wrd125.Lng) + 1L);
  (Wrd124.Obj) = (LONG_TO_FIXNUM (Wrd126.Lng));
  (Wrd135.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd136.Obj) = (Rsp [2]);
  (Wrd137.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd135.Obj);
  (* (Rhp++)) = (Wrd124.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (* (Rhp++)) = (Wrd137.Obj);
  (Wrd131.Obj) = (Rsp [3]);
  (Wrd132.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd131.Obj);
  (* (Rhp++)) = (Wrd132.Obj);
  (Wrd129.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd129.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_1587)
  (Wrd114.Obj) = (Rsp [4]);
  (Wrd115.Obj) = (current_block [OBJECT_30]);
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_474]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_826)
  (Wrd103.Obj) = Rvl;
  goto label_1586;

DEFLABEL (label_1588)
  (Wrd103.Obj) = (current_block [OBJECT_30]);
  goto label_1586;

DEFLABEL (label_1591)
  (Wrd92.Obj) = (Rsp [4]);
  (Wrd93.Obj) = (current_block [OBJECT_30]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_473]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_825)
  (Wrd81.Obj) = Rvl;
  goto label_1590;

DEFLABEL (label_1592)
  (Wrd140.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd140.Obj);
  goto label_1589;

DEFLABEL (label_1593)
  (Wrd150.Obj) = (Rsp [4]);
  (Wrd151.uLng) = (OBJECT_TYPE (Wrd150.Obj));
  if (! ((Wrd151.uLng) == 10))
    goto label_1601;
  (Wrd147.pObj) = (OBJECT_ADDRESS (Wrd150.Obj));
  (Wrd148.Obj) = ((Wrd147.pObj) [0]);
  (Wrd149.Lng) = (FIXNUM_TO_LONG (Wrd148.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd149.Lng))))
    goto label_1601;
  (Wrd143.Obj) = ((Wrd147.pObj) [5]);
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_1600)
  (Wrd170.Obj) = (Rsp [5]);
  (Wrd171.uLng) = (OBJECT_TYPE (Wrd170.Obj));
  if (! ((Wrd171.uLng) == 10))
    goto label_1599;
  (Wrd167.pObj) = (OBJECT_ADDRESS (Wrd170.Obj));
  (Wrd168.Obj) = ((Wrd167.pObj) [0]);
  (Wrd169.Lng) = (FIXNUM_TO_LONG (Wrd168.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd169.Lng))))
    goto label_1599;
  (Wrd163.Obj) = ((Wrd167.pObj) [3]);
  (* (--Rsp)) = (Wrd163.Obj);

DEFLABEL (label_1598)
  (Wrd190.Obj) = (Rsp [6]);
  (Wrd191.uLng) = (OBJECT_TYPE (Wrd190.Obj));
  if (! ((Wrd191.uLng) == 10))
    goto label_1597;
  (Wrd187.pObj) = (OBJECT_ADDRESS (Wrd190.Obj));
  (Wrd188.Obj) = ((Wrd187.pObj) [0]);
  (Wrd189.Lng) = (FIXNUM_TO_LONG (Wrd188.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd189.Lng))))
    goto label_1597;
  (Wrd181.Obj) = ((Wrd187.pObj) [2]);

DEFLABEL (label_1596)
  (Rsp [2]) = (Wrd181.Obj);
  (Wrd210.Obj) = (Rsp [6]);
  (Wrd211.uLng) = (OBJECT_TYPE (Wrd210.Obj));
  if (! ((Wrd211.uLng) == 10))
    goto label_1595;
  (Wrd207.pObj) = (OBJECT_ADDRESS (Wrd210.Obj));
  (Wrd208.Obj) = ((Wrd207.pObj) [0]);
  (Wrd209.Lng) = (FIXNUM_TO_LONG (Wrd208.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd209.Lng))))
    goto label_1595;
  (Wrd201.Obj) = ((Wrd207.pObj) [4]);

DEFLABEL (label_1594)
  (Rsp [3]) = (Wrd201.Obj);
  (Wrd222.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd222.Obj);
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_472]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (Wrd226.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd226.Obj);
  (* (--Rsp)) = (Wrd201.Obj);
  (Wrd228.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd228.Obj);
  (Wrd229.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd229.Obj);
  goto node_concat3_429;

DEFLABEL (continuation_420)
  INTERRUPT_CHECK (27, LABEL_472);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1595)
  (Wrd216.Obj) = (Rsp [6]);
  (Wrd217.Obj) = (current_block [OBJECT_47]);
  (Wrd215.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd215.Obj);
  (Wrd220.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_471]))));
  (* (--Rsp)) = (Wrd220.Obj);
  (* (--Rsp)) = (Wrd217.Obj);
  (* (--Rsp)) = (Wrd216.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_830)
  (Wrd212.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd212.Obj));
  (Wrd201.Obj) = Rvl;
  goto label_1594;

DEFLABEL (label_1597)
  (Wrd196.Obj) = (Rsp [6]);
  (Wrd197.Obj) = (current_block [OBJECT_46]);
  (Wrd195.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd200.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_470]))));
  (* (--Rsp)) = (Wrd200.Obj);
  (* (--Rsp)) = (Wrd197.Obj);
  (* (--Rsp)) = (Wrd196.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_829)
  (Wrd192.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd192.Obj));
  (Wrd181.Obj) = Rvl;
  goto label_1596;

DEFLABEL (label_1599)
  (Wrd176.Obj) = (Rsp [5]);
  (Wrd177.Obj) = (current_block [OBJECT_42]);
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd175.Obj);
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_469]))));
  (* (--Rsp)) = (Wrd180.Obj);
  (* (--Rsp)) = (Wrd177.Obj);
  (* (--Rsp)) = (Wrd176.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_828)
  (Wrd172.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd172.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1598;

DEFLABEL (label_1601)
  (Wrd156.Obj) = (Rsp [4]);
  (Wrd157.Obj) = (current_block [OBJECT_48]);
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd155.Obj);
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_468]))));
  (* (--Rsp)) = (Wrd160.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd156.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_827)
  (Wrd152.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd152.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1600;

DEFLABEL (label_1602)
  (Wrd239.Obj) = (Rsp [5]);
  (Wrd240.uLng) = (OBJECT_TYPE (Wrd239.Obj));
  if (! ((Wrd240.uLng) == 10))
    goto label_1610;
  (Wrd236.pObj) = (OBJECT_ADDRESS (Wrd239.Obj));
  (Wrd237.Obj) = ((Wrd236.pObj) [0]);
  (Wrd238.Lng) = (FIXNUM_TO_LONG (Wrd237.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd238.Lng))))
    goto label_1610;
  (Wrd232.Obj) = ((Wrd236.pObj) [5]);
  (* (--Rsp)) = (Wrd232.Obj);

DEFLABEL (label_1609)
  (Wrd259.Obj) = (Rsp [6]);
  (Wrd260.uLng) = (OBJECT_TYPE (Wrd259.Obj));
  if (! ((Wrd260.uLng) == 10))
    goto label_1608;
  (Wrd256.pObj) = (OBJECT_ADDRESS (Wrd259.Obj));
  (Wrd257.Obj) = ((Wrd256.pObj) [0]);
  (Wrd258.Lng) = (FIXNUM_TO_LONG (Wrd257.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd258.Lng))))
    goto label_1608;
  (Wrd252.Obj) = ((Wrd256.pObj) [3]);
  (* (--Rsp)) = (Wrd252.Obj);

DEFLABEL (label_1607)
  (Wrd279.Obj) = (Rsp [7]);
  (Wrd280.uLng) = (OBJECT_TYPE (Wrd279.Obj));
  if (! ((Wrd280.uLng) == 10))
    goto label_1606;
  (Wrd276.pObj) = (OBJECT_ADDRESS (Wrd279.Obj));
  (Wrd277.Obj) = ((Wrd276.pObj) [0]);
  (Wrd278.Lng) = (FIXNUM_TO_LONG (Wrd277.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd278.Lng))))
    goto label_1606;
  (Wrd270.Obj) = ((Wrd276.pObj) [2]);

DEFLABEL (label_1605)
  (Rsp [2]) = (Wrd270.Obj);
  (Wrd299.Obj) = (Rsp [7]);
  (Wrd300.uLng) = (OBJECT_TYPE (Wrd299.Obj));
  if (! ((Wrd300.uLng) == 10))
    goto label_1604;
  (Wrd296.pObj) = (OBJECT_ADDRESS (Wrd299.Obj));
  (Wrd297.Obj) = ((Wrd296.pObj) [0]);
  (Wrd298.Lng) = (FIXNUM_TO_LONG (Wrd297.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd298.Lng))))
    goto label_1604;
  (Wrd290.Obj) = ((Wrd296.pObj) [4]);

DEFLABEL (label_1603)
  (Rsp [3]) = (Wrd290.Obj);
  (* (--Rsp)) = (Wrd290.Obj);
  (Wrd312.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd312.Obj);
  (Wrd315.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_467]))));
  (* (--Rsp)) = (Wrd315.Obj);
  (Wrd316.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd316.Obj);
  (Wrd317.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd318.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd318.Obj);
  (Wrd319.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd319.Obj);
  goto node_concat3_429;

DEFLABEL (continuation_426)
  INTERRUPT_CHECK (27, LABEL_467);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [4]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_346]));

DEFLABEL (label_1604)
  (Wrd305.Obj) = (Rsp [7]);
  (Wrd306.Obj) = (current_block [OBJECT_47]);
  (Wrd304.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd304.Obj);
  (Wrd309.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_466]))));
  (* (--Rsp)) = (Wrd309.Obj);
  (* (--Rsp)) = (Wrd306.Obj);
  (* (--Rsp)) = (Wrd305.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_834)
  (Wrd301.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd301.Obj));
  (Wrd290.Obj) = Rvl;
  goto label_1603;

DEFLABEL (label_1606)
  (Wrd285.Obj) = (Rsp [7]);
  (Wrd286.Obj) = (current_block [OBJECT_46]);
  (Wrd284.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd284.Obj);
  (Wrd289.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_465]))));
  (* (--Rsp)) = (Wrd289.Obj);
  (* (--Rsp)) = (Wrd286.Obj);
  (* (--Rsp)) = (Wrd285.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_833)
  (Wrd281.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd281.Obj));
  (Wrd270.Obj) = Rvl;
  goto label_1605;

DEFLABEL (label_1608)
  (Wrd265.Obj) = (Rsp [6]);
  (Wrd266.Obj) = (current_block [OBJECT_42]);
  (Wrd264.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd264.Obj);
  (Wrd269.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_464]))));
  (* (--Rsp)) = (Wrd269.Obj);
  (* (--Rsp)) = (Wrd266.Obj);
  (* (--Rsp)) = (Wrd265.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_832)
  (Wrd261.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd261.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1607;

DEFLABEL (label_1610)
  (Wrd245.Obj) = (Rsp [5]);
  (Wrd246.Obj) = (current_block [OBJECT_48]);
  (Wrd244.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd244.Obj);
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_463]))));
  (* (--Rsp)) = (Wrd249.Obj);
  (* (--Rsp)) = (Wrd246.Obj);
  (* (--Rsp)) = (Wrd245.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_831)
  (Wrd241.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd241.Obj));
  (* (--Rsp)) = Rvl;
  goto label_1609;

DEFLABEL (label_1613)
  (Wrd48.Obj) = (Rsp [4]);
  (Wrd49.Obj) = (current_block [OBJECT_30]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_462]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_824)
  (Wrd37.Obj) = Rvl;
  goto label_1612;

DEFLABEL (label_1614)
  (Wrd322.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd322.Obj);
  goto label_1611;

DEFLABEL (label_1617)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.Obj) = (current_block [OBJECT_30]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_461]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_823)
  (Wrd15.Obj) = Rvl;
  goto label_1616;

DEFLABEL (label_1618)
  (Wrd324.Obj) = (current_block [OBJECT_30]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd324.Obj);
  goto label_1615;

DEFLABEL (label_1619)
  (Wrd325.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd325.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd327.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd327.Obj);

DEFLABEL (label_1620)
  Rsp = (& (Rsp [1]));
  goto node_add_379;

DEFLABEL (label_1621)
  (Wrd329.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd329.Obj);
  (Wrd330.Obj) = (Rsp [1]);
  (Wrd331.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd331.Obj);
  (Rsp [3]) = (Wrd330.Obj);
  goto label_1620;

DEFLABEL (continuation_410)
  INTERRUPT_CHECK (27, LABEL_456);
  (Wrd103.Obj) = Rvl;
  goto label_1585;

DEFLABEL (continuation_412)
  INTERRUPT_CHECK (27, LABEL_457);
  (* (--Rsp)) = Rvl;
  goto label_1589;

DEFLABEL (continuation_402)
  INTERRUPT_CHECK (27, LABEL_458);
  (* (--Rsp)) = Rvl;
  goto label_1611;

DEFLABEL (continuation_404)
  INTERRUPT_CHECK (27, LABEL_459);
  (* (--Rsp)) = Rvl;
  goto label_1615;

DEFLABEL (node_concat_903)
DEFLABEL (node_concat_114)
  INTERRUPT_CHECK (26, LABEL_475);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1628;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1626;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_476]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_477]));

DEFLABEL (continuation_109)
  INTERRUPT_CHECK (27, LABEL_476);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_1625;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_1625;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_1624)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_1623;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd29.Lng))))
    goto label_1623;
  (Wrd21.Obj) = ((Wrd27.pObj) [5]);

DEFLABEL (label_1622)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_482]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_483]));

DEFLABEL (continuation_112)
  INTERRUPT_CHECK (27, LABEL_482);
  (Rsp [3]) = Rvl;
  goto node_concat3_145;

DEFLABEL (label_1623)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_48]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_481]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_836)
  (Wrd21.Obj) = Rvl;
  goto label_1622;

DEFLABEL (label_1625)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_42]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_480]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_835)
  (* (--Rsp)) = Rvl;
  goto label_1624;

DEFLABEL (label_1626)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1627)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1628)
  Rvl = (Rsp [1]);
  goto label_1627;

DEFLABEL (node_concat_904)
DEFLABEL (node_concat_398)
  INTERRUPT_CHECK (26, LABEL_478);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (current_block [OBJECT_43]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_1635;
  (Wrd7.Obj) = (Rsp [1]);
  if ((Wrd7.Obj) == (Wrd6.Obj))
    goto label_1633;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_479]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_477]));

DEFLABEL (continuation_393)
  INTERRUPT_CHECK (27, LABEL_479);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_1632;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_1632;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_1631)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_1630;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd29.Lng))))
    goto label_1630;
  (Wrd21.Obj) = ((Wrd27.pObj) [5]);

DEFLABEL (label_1629)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_486]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_483]));

DEFLABEL (continuation_396)
  INTERRUPT_CHECK (27, LABEL_486);
  (Rsp [3]) = Rvl;
  goto node_concat3_429;

DEFLABEL (label_1630)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_48]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_485]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_838)
  (Wrd21.Obj) = Rvl;
  goto label_1629;

DEFLABEL (label_1632)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_42]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_484]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44]), 2);

DEFLABEL (label_837)
  (* (--Rsp)) = Rvl;
  goto label_1631;

DEFLABEL (label_1633)
  Rvl = (Wrd5.Obj);

DEFLABEL (label_1634)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1635)
  Rvl = (Rsp [1]);
  goto label_1634;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_wttree_so_4251645db0305c5b [97] =
  {
    { "wttree_so_code_1", 1, wttree_so_code_1 },
    { "wttree_so_code_2", 1, wttree_so_code_2 },
    { "wttree_so_code_3", 1, wttree_so_code_3 },
    { "wttree_so_code_4", 1, wttree_so_code_4 },
    { "wttree_so_code_5", 1, wttree_so_code_5 },
    { "wttree_so_code_6", 1, wttree_so_code_6 },
    { "wttree_so_code_7", 1, wttree_so_code_7 },
    { "wttree_so_code_8", 1, wttree_so_code_8 },
    { "wttree_so_code_9", 1, wttree_so_code_9 },
    { "wttree_so_code_10", 1, wttree_so_code_10 },
    { "wttree_so_code_11", 1, wttree_so_code_11 },
    { "wttree_so_code_12", 1, wttree_so_code_12 },
    { "wttree_so_code_13", 1, wttree_so_code_13 },
    { "wttree_so_code_14", 1, wttree_so_code_14 },
    { "wttree_so_code_15", 1, wttree_so_code_15 },
    { "wttree_so_code_16", 1, wttree_so_code_16 },
    { "wttree_so_code_17", 1, wttree_so_code_17 },
    { "wttree_so_code_18", 1, wttree_so_code_18 },
    { "wttree_so_code_19", 1, wttree_so_code_19 },
    { "wttree_so_code_20", 1, wttree_so_code_20 },
    { "wttree_so_code_21", 1, wttree_so_code_21 },
    { "wttree_so_code_22", 1, wttree_so_code_22 },
    { "wttree_so_code_23", 1, wttree_so_code_23 },
    { "wttree_so_code_24", 1, wttree_so_code_24 },
    { "wttree_so_code_25", 1, wttree_so_code_25 },
    { "wttree_so_code_26", 1, wttree_so_code_26 },
    { "wttree_so_code_27", 1, wttree_so_code_27 },
    { "wttree_so_code_28", 1, wttree_so_code_28 },
    { "wttree_so_code_29", 1, wttree_so_code_29 },
    { "wttree_so_code_30", 1, wttree_so_code_30 },
    { "wttree_so_code_31", 1, wttree_so_code_31 },
    { "wttree_so_code_32", 1, wttree_so_code_32 },
    { "wttree_so_code_33", 1, wttree_so_code_33 },
    { "wttree_so_code_34", 1, wttree_so_code_34 },
    { "wttree_so_code_35", 1, wttree_so_code_35 },
    { "wttree_so_code_36", 1, wttree_so_code_36 },
    { "wttree_so_code_37", 1, wttree_so_code_37 },
    { "wttree_so_code_38", 1, wttree_so_code_38 },
    { "wttree_so_code_39", 1, wttree_so_code_39 },
    { "wttree_so_code_40", 1, wttree_so_code_40 },
    { "wttree_so_code_41", 1, wttree_so_code_41 },
    { "wttree_so_code_42", 1, wttree_so_code_42 },
    { "wttree_so_code_43", 1, wttree_so_code_43 },
    { "wttree_so_code_44", 1, wttree_so_code_44 },
    { "wttree_so_code_45", 1, wttree_so_code_45 },
    { "wttree_so_code_46", 1, wttree_so_code_46 },
    { "wttree_so_code_47", 5, wttree_so_code_47 },
    { "wttree_so_code_48", 5, wttree_so_code_48 },
    { "wttree_so_code_49", 13, wttree_so_code_49 },
    { "wttree_so_code_50", 21, wttree_so_code_50 },
    { "wttree_so_code_51", 13, wttree_so_code_51 },
    { "wttree_so_code_52", 21, wttree_so_code_52 },
    { "wttree_so_code_53", 26, wttree_so_code_53 },
    { "wttree_so_code_54", 3, wttree_so_code_54 },
    { "wttree_so_code_55", 7, wttree_so_code_55 },
    { "wttree_so_code_56", 5, wttree_so_code_56 },
    { "wttree_so_code_57", 8, wttree_so_code_57 },
    { "wttree_so_code_58", 7, wttree_so_code_58 },
    { "wttree_so_code_59", 6, wttree_so_code_59 },
    { "wttree_so_code_60", 12, wttree_so_code_60 },
    { "wttree_so_code_61", 1, wttree_so_code_61 },
    { "wttree_so_code_62", 217, wttree_so_code_62 },
    { "wttree_so_code_63", 1, wttree_so_code_63 },
    { "wttree_so_code_64", 2, wttree_so_code_64 },
    { "wttree_so_code_65", 2, wttree_so_code_65 },
    { "wttree_so_code_66", 7, wttree_so_code_66 },
    { "wttree_so_code_67", 23, wttree_so_code_67 },
    { "wttree_so_code_68", 1, wttree_so_code_68 },
    { "wttree_so_code_69", 3, wttree_so_code_69 },
    { "wttree_so_code_70", 4, wttree_so_code_70 },
    { "wttree_so_code_71", 4, wttree_so_code_71 },
    { "wttree_so_code_72", 5, wttree_so_code_72 },
    { "wttree_so_code_73", 5, wttree_so_code_73 },
    { "wttree_so_code_74", 5, wttree_so_code_74 },
    { "wttree_so_code_75", 5, wttree_so_code_75 },
    { "wttree_so_code_76", 5, wttree_so_code_76 },
    { "wttree_so_code_77", 5, wttree_so_code_77 },
    { "wttree_so_code_78", 5, wttree_so_code_78 },
    { "wttree_so_code_79", 5, wttree_so_code_79 },
    { "wttree_so_code_80", 5, wttree_so_code_80 },
    { "wttree_so_code_81", 26, wttree_so_code_81 },
    { "wttree_so_code_82", 26, wttree_so_code_82 },
    { "wttree_so_code_83", 26, wttree_so_code_83 },
    { "wttree_so_code_84", 26, wttree_so_code_84 },
    { "wttree_so_code_85", 26, wttree_so_code_85 },
    { "wttree_so_code_86", 2, wttree_so_code_86 },
    { "wttree_so_code_87", 4, wttree_so_code_87 },
    { "wttree_so_code_88", 4, wttree_so_code_88 },
    { "wttree_so_code_89", 5, wttree_so_code_89 },
    { "wttree_so_code_90", 5, wttree_so_code_90 },
    { "wttree_so_code_91", 7, wttree_so_code_91 },
    { "wttree_so_code_92", 5, wttree_so_code_92 },
    { "wttree_so_code_93", 5, wttree_so_code_93 },
    { "wttree_so_code_94", 5, wttree_so_code_94 },
    { "wttree_so_code_95", 7, wttree_so_code_95 },
    { "wttree_so_code_96", 6, wttree_so_code_96 },
    { "wttree_so_code_97", 5, wttree_so_code_97 }
  };

int
decl_wttree_so_4251645db0305c5b (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_wttree_so_4251645db0305c5b);
  return (0);
}

DECLARE_COMPILED_CODE ("wttree.so", 467, decl_wttree_so_4251645db0305c5b, wttree_so_4251645db0305c5b)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_wttree_so_data_4251645db0305c5b [14571] =
  "\x84\x08\x9a\x01\xa2\x20\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29"
  "\x21\x9c\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0"
  "\x83\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c"
  "\x2b\xbc\x1d\xb0\x85\x88\x22\x29\x21\x9c\x2b\xbd\x1d\xb0\x86\x88"
  "\x22\x29\x21\x9c\x2b\xbe\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\xbf"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0"
  "\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c"
  "\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x86\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21"
  "\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x22"
  "\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x1d\x82\x22"
  "\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\xc2\x1c\x82\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x80\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x07\x0d\x1c\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x1b"
  "\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x81\x83\x82\x1b\x84\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x1b"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x80\x1b\x82\x84\x81\x1b\x83\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80\x1b\x82\x84\x81"
  "\x1b\x83\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x80\x1b\x82\x84\x81\x1b\x83\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80\x1b\x82"
  "\x84\x81\x1b\x83\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x83\x81\x1b\x80\x1b\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x0d\x1b\x28\x0d\x1c\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x84\x83"
  "\x1b\x81\x0d\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x84\x1b\x82\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x82\x84\x81\x1b\x83\x1b\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x84"
  "\x81\x1b\x83\x1d\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x81"
  "\x1b\x83\x80\x1b\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x81"
  "\x0d\x1c\x1b\x80\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x0d\x1c\x26\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x1c\xc1\x1c\xc1\x1c\x08"
  "\x1b\x1d\x1b\x07\x80\x84\x83\x81\x1b\x82\x1b\x28\x0d\x1c\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0c\x1c\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x81\x0c\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x28\x1b\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b\x1b\x1d\x1b\x81"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x1b"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x1b\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x82\x1b\x0d\x1c\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07"
  "\x1b\x1b\x82\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x1b\x1b\x82\x0d"
  "\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x1b\x81\x0d\x1c\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x85\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x84\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x86\x1b\x81\x0d"
  "\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x1b\x81\x0d\x1c\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x02\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x02\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x1b\x81\x0d"
  "\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b\x1b\x0d\x1c\x02"
  "\x1b\x81\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b\x1b\x0d\x1c\x02\x1b\x81\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x1b\x1b\x1b\x1b\x0d\x1c\x02\x1b\x81\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x1b\x1b\x1b\x1b\x0d\x1c\x02\x1b\x81\x28\x1b\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x1b"
  "\x1b\x0d\x1c\x02\x1b\x81\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x82\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x1b\x82\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x1b"
  "\x82\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x1b\x82"
  "\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02"
  "\x1b\x81\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x82\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x1b\x82\x0d\x1c\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x84\x1b\x82\x0d\x1c\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x82\x1b\x81\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x1b"
  "\x82\x0d\xb8\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1d\x84\x83\x81\x06\x1b\x1b\x82\x0d\x0d\x0d\x1b\xb0\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x1b"
  "\x0d\x1c\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b"
  "\x0d\x0d\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x17\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x85\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\x0d\x0d\x0d\x9a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x9a\x07\x1b\x80\x0d\x1c\x1b\x0c\x0d\x0d\x08\x89\x1b"
  "\x2a\x08\x1b\x2a\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x17\x0c\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x08\x14\xc3\x0d\x1c\xb1\x2a\xb2"
  "\x2a\xb3\x2a\xb4\x2a\xb5\x2a\xb6\x2a\xb7\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x28\x0d\x28"
  "\x0d\x28\x0d\x26\x1b\x1b\x0d\x0d\x1c\x24\x28\x0d\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x02\x47\x2f\x55\x73\x65\x72\x73\x2f"
  "\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
  "\x39\x2e\x30\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
  "\x2d\x63\x2d\x39\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
  "\x74\x69\x6d\x65\x2f\x77\x74\x74\x72\x65\x65\x2e\x69\x6e\x66\x15"
  "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
  "\x6f\x6f\x74\x5d\x02\xd4\x03\x04\x82\x02\x03\x02\xd5\x03\x04\x82"
  "\x02\x03\x02\xd6\x03\x04\x82\x02\x03\x02\xd7\x03\x04\x82\x02\x03"
  "\x02\xd8\x03\x04\x82\x02\x03\x02\xd9\x03\x04\x82\x02\x03\x02\x08"
  "\xda\x03\x04\x82\x02\x03\x02\x09\xdb\x03\x04\x82\x02\x03\x09\x02"
  "\x0a\xdc\x03\x04\x82\x02\x03\x0a\x02\x0b\xdd\x03\x04\x82\x02\x03"
  "\x0b\x02\x0c\xde\x03\x04\x82\x02\x03\x0c\x02\x0d\xdf\x03\x04\x82"
  "\x02\x03\x0d\x02\x0e\xe0\x03\x04\x82\x02\x03\x0e\x02\x0f\xe1\x03"
  "\x04\x82\x02\x03\x0f\x02\x10\xe2\x03\x04\x82\x02\x03\x10\x02\x11"
  "\xe3\x03\x04\x82\x02\x03\x11\x02\x12\x0c\x25\x72\x65\x63\x6f\x72"
  "\x64\x2d\x72\x65\x66\x12\xe4\x03\x04\x83\x04\x03\x13\x02\x13\x12"
  "\xe5\x03\x04\x83\x04\x03\x14\x02\x14\x12\xe6\x03\x04\x83\x04\x03"
  "\x15\x02\x15\x12\xe7\x03\x04\x83\x04\x03\x16\x02\x16\x12\xe8\x03"
  "\x04\x83\x04\x03\x17\x02\x17\x12\xe9\x03\x04\x83\x04\x03\x18\x02"
  "\x18\x12\x08\xea\x03\x04\x83\x04\x03\x19\x02\x19\x12\x09\xeb\x03"
  "\x04\x83\x04\x03\x1a\x02\x1a\x12\x0a\xec\x03\x04\x83\x04\x03\x1b"
  "\x02\x1b\x12\x0b\xed\x03\x04\x83\x04\x03\x1c\x02\x1c\x12\x0c\xee"
  "\x03\x04\x83\x04\x03\x1d\x02\x1d\x12\x0d\xef\x03\x04\x83\x04\x03"
  "\x1e\x02\x1e\x12\x0e\xf0\x03\x04\x83\x04\x03\x1f\x02\x1f\x12\x0f"
  "\xf1\x03\x04\x83\x04\x03\x20\x02\x20\x12\x10\xf2\x03\x04\x83\x04"
  "\x03\x21\x02\x21\x12\x11\xf3\x03\x04\x83\x04\x03\x22\x02\x22\xf4"
  "\x03\x04\x82\x02\x03\x23\x02\x23\xf5\x03\x04\x82\x02\x03\x24\x02"
  "\x24\x12\xf6\x03\x04\x83\x04\x03\x25\x02\x25\x12\xf7\x03\x04\x83"
  "\x04\x03\x26\x02\x26\x0d\x25\x72\x65\x63\x6f\x72\x64\x2d\x73\x65"
  "\x74\x21\x27\x02\xf8\x03\x04\x84\x06\x03\x28\x02\x27\xf9\x03\x04"
  "\x87\x0c\x03\x29\x02\x28\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65"
  "\x66\x2a\xfa\x03\x04\x83\x04\x03\x2b\x02\x29\x2a\xfb\x03\x04\x83"
  "\x04\x03\x2c\x02\x2a\x2a\xfc\x03\x04\x83\x04\x03\x2d\x02\x2b\x2a"
  "\xfd\x03\x04\x83\x04\x03\x2e\x02\x2c\x2a\xfe\x03\x04\x83\x04\x03"
  "\x2f\x02\x2d\x06\x65\x6d\x70\x74\x79\x30\xff\x03\x04\x83\x04\x03"
  "\x31\x02\x2e\x2a\x30\x80\x04\x04\x83\x04\x03\x32\x02\x2f\x30\x81"
  "\x04\x04\x84\x06\x03\x33\x02\x30\x2a\x86\x04\x0c\x81\x8b\x02\x85"
  "\x04\x0a\x81\x8b\x02\x84\x04\x08\x81\x87\x02\x83\x04\x06\x81\x85"
  "\x02\x82\x04\x04\x84\x06\x0b\x13\x34\x02\x31\x2a\x30\x8b\x04\x0c"
  "\x81\x8d\x02\x8a\x04\x0a\x81\x8b\x02\x89\x04\x08\x86\x0a\x88\x04"
  "\x06\x81\x89\x02\x87\x04\x04\x81\x8b\x02\x0b\x11\x35\x02\x32\x30"
  "\x2a\x98\x04\x1c\x81\x8d\x02\x97\x04\x1a\x81\x8b\x02\x96\x04\x18"
  "\x81\x9d\x02\x95\x04\x16\x81\x9b\x02\x94\x04\x14\x81\x8f\x02\x93"
  "\x04\x12\x81\x8d\x02\x92\x04\x10\x81\x8b\x02\x91\x04\x0e\x81\x89"
  "\x02\x90\x04\x0c\x86\x0a\x8f\x04\x0a\x81\x99\x02\x8e\x04\x08\x81"
  "\x9b\x02\x8d\x04\x06\x81\x89\x02\x8c\x04\x04\x81\x8b\x02\x1b\x25"
  "\x36\x02\x33\x30\x2a\xad\x04\x2c\x81\x8d\x02\xac\x04\x2a\x81\x8b"
  "\x02\xab\x04\x28\x81\xa5\x02\xaa\x04\x26\x81\xa3\x02\xa9\x04\x24"
  "\x81\xa5\x02\xa8\x04\x22\x81\xa3\x02\xa7\x04\x20\x81\x97\x02\xa6"
  "\x04\x1e\x81\x95\x02\xa5\x04\x1c\x81\x93\x02\xa4\x04\x1a\x81\x91"
  "\x02\xa3\x04\x18\x81\x8f\x02\xa2\x04\x16\x81\x8d\x02\xa1\x04\x14"
  "\x81\x8b\x02\xa0\x04\x12\x81\x89\x02\x9f\x04\x10\x86\x0a\x9e\x04"
  "\x0e\x81\xa1\x02\x9d\x04\x0c\x81\xa3\x02\x9c\x04\x0a\x81\xa1\x02"
  "\x9b\x04\x08\x81\xa3\x02\x9a\x04\x06\x81\x89\x02\x99\x04\x04\x81"
  "\x8b\x02\x2b\x35\x37\x02\x34\x30\x2a\xba\x04\x1c\x81\x8d\x02\xb9"
  "\x04\x1a\x81\x8b\x02\xb8\x04\x18\x81\x9d\x02\xb7\x04\x16\x81\x9b"
  "\x02\xb6\x04\x14\x81\x8f\x02\xb5\x04\x12\x81\x8d\x02\xb4\x04\x10"
  "\x81\x8b\x02\xb3\x04\x0e\x81\x89\x02\xb2\x04\x0c\x86\x0a\xb1\x04"
  "\x0a\x81\x99\x02\xb0\x04\x08\x81\x9b\x02\xaf\x04\x06\x81\x89\x02"
  "\xae\x04\x04\x81\x8b\x02\x1b\x25\x38\x02\x35\x30\x2a\xcf\x04\x2c"
  "\x81\x8d\x02\xce\x04\x2a\x81\x8b\x02\xcd\x04\x28\x81\xa5\x02\xcc"
  "\x04\x26\x81\xa3\x02\xcb\x04\x24\x81\xa5\x02\xca\x04\x22\x81\xa3"
  "\x02\xc9\x04\x20\x81\x97\x02\xc8\x04\x1e\x81\x95\x02\xc7\x04\x1c"
  "\x81\x93\x02\xc6\x04\x1a\x81\x91\x02\xc5\x04\x18\x81\x8f\x02\xc4"
  "\x04\x16\x81\x8d\x02\xc3\x04\x14\x81\x8b\x02\xc2\x04\x12\x81\x89"
  "\x02\xc1\x04\x10\x86\x0a\xc0\x04\x0e\x81\xa1\x02\xbf\x04\x0c\x81"
  "\xa3\x02\xbe\x04\x0a\x81\xa1\x02\xbd\x04\x08\x81\xa3\x02\xbc\x04"
  "\x06\x81\x89\x02\xbb\x04\x04\x81\x8b\x02\x2b\x35\x39\x02\x36\x2a"
  "\x30\x06\x09\x73\x69\x6e\x67\x6c\x65\x2d\x6c\x3a\x06\x09\x64\x6f"
  "\x75\x62\x6c\x65\x2d\x6c\x3b\x06\x09\x73\x69\x6e\x67\x6c\x65\x2d"
  "\x72\x3c\x06\x09\x64\x6f\x75\x62\x6c\x65\x2d\x72\x3d\x05\xe9\x04"
  "\x36\x81\x8d\x02\xe8\x04\x34\x81\x8b\x02\xe7\x04\x32\x81\x89\x02"
  "\xe6\x04\x30\x81\x89\x02\xe5\x04\x2e\x81\x8b\x02\xe4\x04\x2c\x81"
  "\x8f\x02\xe3\x04\x2a\x81\x8f\x02\xe2\x04\x28\x81\x8f\x02\xe1\x04"
  "\x26\x81\x8f\x02\xe0\x04\x24\x81\x8f\x02\xdf\x04\x22\x81\x8f\x02"
  "\xde\x04\x20\x81\x8f\x02\xdd\x04\x1e\x81\x8f\x02\xdc\x04\x1c\x81"
  "\x8f\x02\xdb\x04\x1a\x81\x8f\x02\xda\x04\x18\x81\x8f\x02\xd9\x04"
  "\x16\x81\x8f\x02\xd8\x04\x14\x81\x8d\x02\xd7\x04\x12\x81\x8b\x02"
  "\xd6\x04\x10\x86\x0a\xd5\x04\x0e\x81\x89\x02\xd4\x04\x0c\x81\x8b"
  "\x02\xd3\x04\x0a\x81\x8d\x02\xd2\x04\x08\x81\x8d\x02\xd1\x04\x06"
  "\x81\x8d\x02\xd0\x04\x04\x81\x8d\x02\x35\x46\x3e\x02\x37\x2a\x04"
  "\x6d\x69\x6e\x30\x03\x0c\x65\x72\x72\x6f\x72\x3a\x65\x6d\x70\x74"
  "\x79\x3f\x03\x09\x6e\x6f\x64\x65\x2f\x6d\x69\x6e\x40\x03\xec\x04"
  "\x08\x81\x83\x02\xeb\x04\x06\x81\x83\x02\xea\x04\x04\x83\x04\x07"
  "\x13\x41\x02\x38\x2a\x07\x64\x65\x6c\x6d\x69\x6e\x30\x03\x3f\x03"
  "\x0c\x6e\x6f\x64\x65\x2f\x64\x65\x6c\x6d\x69\x6e\x42\x06\x07\x74"
  "\x2d\x6a\x6f\x69\x6e\x43\x04\xf3\x04\x10\x81\x89\x02\xf2\x04\x0e"
  "\x81\x87\x02\xf1\x04\x0c\x81\x85\x02\xf0\x04\x0a\x81\x83\x02\xef"
  "\x04\x08\x81\x85\x02\xee\x04\x06\x81\x83\x02\xed\x04\x04\x83\x04"
  "\x0f\x20\x44\x02\x39\x2a\x30\x03\x40\x03\x42\x06\x43\x04\xf8\x04"
  "\x0c\x81\x89\x02\xf7\x04\x0a\x81\x89\x02\xf6\x04\x08\x81\x87\x02"
  "\xf5\x04\x06\x81\x85\x02\xf4\x04\x04\x84\x06\x0b\x19\x45\x02\x3a"
  "\x2a\x30\x80\x05\x12\xfd\xff\x03\xff\x04\x10\xfd\xff\x03\xfe\x04"
  "\x0e\xfd\xff\x03\xfd\x04\x0c\xfd\xff\x03\xfc\x04\x0a\xfd\xff\x03"
  "\xfb\x04\x08\xfd\xff\x03\xfa\x04\x06\xff\xff\x03\xf9\x04\x04\x85"
  "\x08\x11\x1a\x46\x02\x3b\x2a\x02\x30\x04\x0e\x6e\x6f\x64\x65\x2f"
  "\x66\x6f\x72\x2d\x65\x61\x63\x68\x47\x02\x87\x05\x10\x81\x8d\x02"
  "\x86\x05\x0e\x81\x8d\x02\x85\x05\x0c\x81\x8b\x02\x84\x05\x0a\x81"
  "\x89\x02\x83\x05\x08\x81\x87\x02\x82\x05\x06\x81\x85\x02\x81\x05"
  "\x04\x84\x06\x0f\x1c\x48\x02\x3c\x2a\x30\x03\x0c\x6e\x6f\x64\x65"
  "\x2f\x68\x65\x69\x67\x68\x74\x49\x04\x04\x6d\x61\x78\x03\x8d\x05"
  "\x0e\x81\x87\x02\x8c\x05\x0c\x81\x89\x02\x8b\x05\x0a\x81\x85\x02"
  "\x8a\x05\x08\x81\x83\x02\x89\x05\x06\x81\x87\x02\x88\x05\x04\x83"
  "\x04\x0d\x1a\x4a\x02\x3d\x0b\x6e\x6f\x64\x65\x2f\x69\x6e\x64\x65"
  "\x78\x4b\x2a\x30\x04\x19\x65\x72\x72\x6f\x72\x3a\x62\x61\x64\x2d"
  "\x72\x61\x6e\x67\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x02\x99"
  "\x05\x1a\x81\x87\x02\x98\x05\x18\x81\x87\x02\x97\x05\x16\x81\x87"
  "\x02\x96\x05\x14\x81\x87\x02\x95\x05\x12\x81\x87\x02\x94\x05\x10"
  "\x81\x85\x02\x93\x05\x0e\x81\x85\x02\x92\x05\x0c\x81\x87\x02\x91"
  "\x05\x0a\x81\x87\x02\x90\x05\x08\x81\x87\x02\x8f\x05\x06\x84\x06"
  "\x8e\x05\x04\x81\x85\x02\x19\x25\x4c\x02\x3e\x23\x4f\x70\x65\x72"
  "\x61\x74\x69\x6f\x6e\x20\x72\x65\x71\x75\x69\x72\x65\x73\x20\x6e"
  "\x6f\x6e\x2d\x65\x6d\x70\x74\x79\x20\x74\x72\x65\x65\x3a\x04\x06"
  "\x65\x72\x72\x6f\x72\x4d\x02\x9a\x05\x04\x83\x04\x03\x0a\x4e\x02"
  "\x3f\x0c\x61\x6c\x69\x73\x74\x2d\x3e\x74\x72\x65\x65\x4f\x06\x61"
  "\x6c\x69\x73\x74\x50\x04\x63\x64\x72\x51\x04\x63\x61\x72\x52\x27"
  "\x02\x12\x2a\x30\x12\x10\x25\x6d\x61\x6b\x65\x2d\x74\x72\x65\x65"
  "\x2d\x74\x79\x70\x65\x53\x03\x40\x03\x42\x06\x43\x04\x0e\x25\x6d"
  "\x61\x6b\x65\x2d\x77\x74\x2d\x74\x72\x65\x65\x54\x05\x1a\x65\x72"
  "\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61"
  "\x72\x67\x75\x6d\x65\x6e\x74\x55\x04\x0d\x6e\x6f\x64\x65\x2f\x63"
  "\x6f\x6e\x63\x61\x74\x32\x56\x08\xf3\x06\xb4\x03\xfd\xff\x03\xf2"
  "\x06\xb2\x03\xfd\xff\x03\xf1\x06\xb0\x03\xfd\xff\x03\xf0\x06\xae"
  "\x03\xfd\xff\x03\xef\x06\xac\x03\xfd\xff\x03\xee\x06\xaa\x03\xfd"
  "\xff\x03\xed\x06\xa8\x03\xfd\xff\x03\xec\x06\xa6\x03\xfd\xff\x03"
  "\xeb\x06\xa4\x03\xfd\xff\x03\xea\x06\xa2\x03\xfd\xff\x03\xe9\x06"
  "\xa0\x03\xfd\xff\x03\xe8\x06\x9e\x03\xfd\xff\x03\xe7\x06\x9c\x03"
  "\xfd\xff\x03\xe6\x06\x9a\x03\xfd\xff\x03\xe5\x06\x98\x03\xfd\xff"
  "\x03\xe4\x06\x96\x03\xfd\xff\x03\xe3\x06\x94\x03\xfd\xff\x03\xe2"
  "\x06\x92\x03\xfd\xff\x03\xe1\x06\x90\x03\xfd\xff\x03\xe0\x06\x8e"
  "\x03\x81\x8d\x02\xdf\x06\x8c\x03\x81\x8d\x02\xde\x06\x8a\x03\x81"
  "\x8b\x02\xdd\x06\x88\x03\x81\x8b\x02\xdc\x06\x86\x03\x81\x8b\x02"
  "\xdb\x06\x84\x03\x81\x8b\x02\xda\x06\x82\x03\xfd\xff\x03\xd9\x06"
  "\x80\x03\xfd\xff\x03\xd8\x06\xfe\x02\x81\x85\x02\xd7\x06\xfc\x02"
  "\x81\x85\x02\xd6\x06\xfa\x02\xfd\xff\x03\xd5\x06\xf8\x02\xfd\xff"
  "\x03\xd4\x06\xf6\x02\xfd\xff\x03\xd3\x06\xf4\x02\xfd\xff\x03\xd2"
  "\x06\xf2\x02\xfd\xff\x03\xd1\x06\xf0\x02\xfd\xff\x03\xd0\x06\xee"
  "\x02\xfd\xff\x03\xcf\x06\xec\x02\xfd\xff\x03\xce\x06\xea\x02\x81"
  "\x8f\x02\xcd\x06\xe8\x02\x81\x87\x02\xcc\x06\xe6\x02\x81\x87\x02"
  "\xcb\x06\xe4\x02\x81\x8f\x02\xca\x06\xe2\x02\x81\x87\x02\xc9\x06"
  "\xe0\x02\x81\x87\x02\xc8\x06\xde\x02\x81\x8b\x02\xc7\x06\xdc\x02"
  "\x81\x8b\x02\xc6\x06\xda\x02\x81\x8b\x02\xc5\x06\xd8\x02\xfd\xff"
  "\x03\xc4\x06\xd6\x02\xfd\xff\x03\xc3\x06\xd4\x02\x81\x8d\x02\xc2"
  "\x06\xd2\x02\x81\x8b\x02\xc1\x06\xd0\x02\xfd\xff\x03\xc0\x06\xce"
  "\x02\x81\x89\x02\xbf\x06\xcc\x02\x81\x8b\x02\xbe\x06\xca\x02\xfd"
  "\xff\x03\xbd\x06\xc8\x02\x81\x89\x02\xbc\x06\xc6\x02\x81\x8b\x02"
  "\xbb\x06\xc4\x02\x81\x8b\x02\xba\x06\xc2\x02\x81\x8b\x02\xb9\x06"
  "\xc0\x02\x81\x8b\x02\xb8\x06\xbe\x02\x81\x8b\x02\xb7\x06\xbc\x02"
  "\x81\x8b\x02\xb6\x06\xba\x02\x81\x89\x02\xb5\x06\xb8\x02\x81\x89"
  "\x02\xb4\x06\xb6\x02\x81\x89\x02\xb3\x06\xb4\x02\x81\x89\x02\xb2"
  "\x06\xb2\x02\x81\x8b\x02\xb1\x06\xb0\x02\x81\x8b\x02\xb0\x06\xae"
  "\x02\x81\x8b\x02\xaf\x06\xac\x02\x81\x87\x02\xae\x06\xaa\x02\x81"
  "\x89\x02\xad\x06\xa8\x02\x81\x85\x02\xac\x06\xa6\x02\x81\x89\x02"
  "\xab\x06\xa4\x02\x81\x89\x02\xaa\x06\xa2\x02\x81\x87\x02\xa9\x06"
  "\xa0\x02\x81\x87\x02\xa8\x06\x9e\x02\x81\x85\x02\xa7\x06\x9c\x02"
  "\x81\x87\x02\xa6\x06\x9a\x02\x81\x87\x02\xa5\x06\x98\x02\x81\x87"
  "\x02\xa4\x06\x96\x02\x81\x87\x02\xa3\x06\x94\x02\x81\x89\x02\xa2"
  "\x06\x92\x02\x81\x89\x02\xa1\x06\x90\x02\x81\x87\x02\xa0\x06\x8e"
  "\x02\x81\x87\x02\x9f\x06\x8c\x02\x81\x87\x02\x9e\x06\x8a\x02\x81"
  "\x87\x02\x9d\x06\x88\x02\x81\x87\x02\x9c\x06\x86\x02\x81\x87\x02"
  "\x9b\x06\x84\x02\x81\x87\x02\x9a\x06\x82\x02\x81\x87\x02\x99\x06"
  "\x80\x02\x81\x87\x02\x98\x06\xfe\x01\x81\x89\x02\x97\x06\xfc\x01"
  "\x81\x89\x02\x96\x06\xfa\x01\x81\x89\x02\x95\x06\xf8\x01\xfd\xff"
  "\x03\x94\x06\xf6\x01\xfd\xff\x03\x93\x06\xf4\x01\xfd\xff\x03\x92"
  "\x06\xf2\x01\xfd\xff\x03\x91\x06\xf0\x01\xfd\xff\x03\x90\x06\xee"
  "\x01\xfd\xff\x03\x8f\x06\xec\x01\xfd\xff\x03\x8e\x06\xea\x01\x81"
  "\x87\x02\x8d\x06\xe8\x01\x81\x89\x02\x8c\x06\xe6\x01\x81\x87\x02"
  "\x8b\x06\xe4\x01\x81\x87\x02\x8a\x06\xe2\x01\x81\x8b\x02\x89\x06"
  "\xe0\x01\x81\x87\x02\x88\x06\xde\x01\xfd\xff\x03\x87\x06\xdc\x01"
  "\xfd\xff\x03\x86\x06\xda\x01\x81\x87\x02\x85\x06\xd8\x01\xfd\xff"
  "\x03\x84\x06\xd6\x01\xfd\xff\x03\x83\x06\xd4\x01\x81\x89\x02\x82"
  "\x06\xd2\x01\x81\x8d\x02\x81\x06\xd0\x01\x81\x89\x02\x80\x06\xce"
  "\x01\x81\x8d\x02\xff\x05\xcc\x01\x81\x8d\x02\xfe\x05\xca\x01\x81"
  "\x8b\x02\xfd\x05\xc8\x01\x81\x89\x02\xfc\x05\xc6\x01\x81\x87\x02"
  "\xfb\x05\xc4\x01\x81\x89\x02\xfa\x05\xc2\x01\x81\x87\x02\xf9\x05"
  "\xc0\x01\x81\x8b\x02\xf8\x05\xbe\x01\x81\x89\x02\xf7\x05\xbc\x01"
  "\x81\x85\x02\xf6\x05\xba\x01\x81\x87\x02\xf5\x05\xb8\x01\x81\x87"
  "\x02\xf4\x05\xb6\x01\x81\x87\x02\xf3\x05\xb4\x01\x81\x8b\x02\xf2"
  "\x05\xb2\x01\x81\x89\x02\xf1\x05\xb0\x01\x81\x87\x02\xf0\x05\xae"
  "\x01\x81\x8b\x02\xef\x05\xac\x01\x81\x89\x02\xee\x05\xaa\x01\x81"
  "\x87\x02\xed\x05\xa8\x01\x81\x8f\x02\xec\x05\xa6\x01\x81\x8d\x02"
  "\xeb\x05\xa4\x01\x81\x89\x02\xea\x05\xa2\x01\x81\x8b\x02\xe9\x05"
  "\xa0\x01\x81\x89\x02\xe8\x05\x9e\x01\x81\x87\x02\xe7\x05\x9c\x01"
  "\x81\x8b\x02\xe6\x05\x9a\x01\x81\x87\x02\xe5\x05\x98\x01\x81\x8b"
  "\x02\xe4\x05\x96\x01\x81\x87\x02\xe3\x05\x94\x01\x81\x89\x02\xe2"
  "\x05\x92\x01\x81\x87\x02\xe1\x05\x90\x01\x81\x89\x02\xe0\x05\x8e"
  "\x01\x81\x87\x02\xdf\x05\x8c\x01\x81\x8f\x02\xde\x05\x8a\x01\x81"
  "\x89\x02\xdd\x05\x88\x01\x81\x8f\x02\xdc\x05\x86\x01\x81\x89\x02"
  "\xdb\x05\x84\x01\xfd\xff\x03\xda\x05\x82\x01\x81\x8b\x02\xd9\x05"
  "\x80\x01\x81\x89\x02\xd8\x05\x7e\x81\x87\x02\xd7\x05\x7c\x81\x8b"
  "\x02\xd6\x05\x7a\x81\x89\x02\xd5\x05\x78\x81\x87\x02\xd4\x05\x76"
  "\x81\x87\x02\xd3\x05\x74\x81\x89\x02\xd2\x05\x72\x81\x8d\x02\xd1"
  "\x05\x70\x81\x8b\x02\xd0\x05\x6e\x81\x89\x02\xcf\x05\x6c\x81\x87"
  "\x02\xce\x05\x6a\x81\x87\x02\xcd\x05\x68\x81\x8b\x02\xcc\x05\x66"
  "\x81\x89\x02\xcb\x05\x64\x81\x87\x02\xca\x05\x62\x81\x87\x02\xc9"
  "\x05\x60\x81\x8f\x02\xc8\x05\x5e\x81\x8d\x02\xc7\x05\x5c\x81\x8b"
  "\x02\xc6\x05\x5a\x81\x89\x02\xc5\x05\x58\x81\x89\x02\xc4\x05\x56"
  "\x81\x8d\x02\xc3\x05\x54\x81\x8b\x02\xc2\x05\x52\x81\x89\x02\xc1"
  "\x05\x50\x81\x87\x02\xc0\x05\x4e\x81\x87\x02\xbf\x05\x4c\x81\x8b"
  "\x02\xbe\x05\x4a\x81\x87\x02\xbd\x05\x48\x81\x89\x02\xbc\x05\x46"
  "\x81\x87\x02\xbb\x05\x44\x81\x8d\x02\xba\x05\x42\x81\x8b\x02\xb9"
  "\x05\x40\xfd\xff\x03\xb8\x05\x3e\xfd\xff\x03\xb7\x05\x3c\xfd\xff"
  "\x03\xb6\x05\x3a\xfd\xff\x03\xb5\x05\x38\xfd\xff\x03\xb4\x05\x36"
  "\xfd\xff\x03\xb3\x05\x34\xfd\xff\x03\xb2\x05\x32\xfd\xff\x03\xb1"
  "\x05\x30\x81\x8f\x02\xb0\x05\x2e\x81\x8d\x02\xaf\x05\x2c\x81\x8b"
  "\x02\xae\x05\x2a\x81\x8b\x02\xad\x05\x28\x81\x8d\x02\xac\x05\x26"
  "\x81\x89\x02\xab\x05\x24\x81\x8b\x02\xaa\x05\x22\x81\x87\x02\xa9"
  "\x05\x20\x81\x8d\x02\xa8\x05\x1e\x81\x8b\x02\xa7\x05\x1c\x81\x89"
  "\x02\xa6\x05\x1a\x81\x87\x02\xa5\x05\x18\x81\x87\x02\xa4\x05\x16"
  "\x81\x8f\x02\xa3\x05\x14\x81\x8d\x02\xa2\x05\x12\x81\x8b\x02\xa1"
  "\x05\x10\x81\x89\x02\xa0\x05\x0e\x81\x89\x02\x9f\x05\x0c\x81\x8b"
  "\x02\x9e\x05\x0a\x81\x89\x02\x9d\x05\x08\x81\x87\x02\x9c\x05\x06"
  "\x81\xbd\x02\x9b\x05\x04\x83\x04\xb3\x03\xd5\x03\x57\x02\x40\x15"
  "\x77\x65\x69\x67\x68\x74\x2d\x62\x61\x6c\x61\x6e\x63\x65\x64\x20"
  "\x74\x72\x65\x65\x05\x55\x02\xf4\x06\x04\x84\x06\x03\x0a\x58\x02"
  "\x41\x02\x03\x09\x77\x74\x2d\x74\x72\x65\x65\x3f\x59\x04\x16\x67"
  "\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x74\x72\x65\x65\x2f\x72\x65"
  "\x70\x6f\x72\x74\x5a\x03\xf6\x06\x06\x81\x85\x02\xf5\x06\x04\x84"
  "\x06\x05\x0e\x5b\x02\x42\x02\x1a\x77\x65\x69\x67\x68\x74\x2d\x62"
  "\x61\x6c\x61\x6e\x63\x65\x64\x20\x74\x72\x65\x65\x20\x74\x79\x70"
  "\x65\x5c\x03\x0b\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x3f\x5d\x05"
  "\x55\x03\xf8\x06\x06\x81\x85\x02\xf7\x06\x04\x84\x06\x05\x0f\x5e"
  "\x02\x43\x12\x0a\x54\x68\x65\x20\x74\x72\x65\x65\x73\x5f\x04\x61"
  "\x6e\x64\x60\x05\x68\x61\x76\x65\x61\x0d\x69\x6e\x63\x6f\x6d\x70"
  "\x61\x74\x69\x62\x6c\x65\x62\x06\x74\x79\x70\x65\x73\x63\x03\x59"
  "\x04\x5a\x0c\x4d\x04\xff\x06\x10\x81\x95\x02\xfe\x06\x0e\x81\x95"
  "\x02\xfd\x06\x0c\x81\x87\x02\xfc\x06\x0a\x81\x87\x02\xfb\x06\x08"
  "\x81\x87\x02\xfa\x06\x06\x81\x87\x02\xf9\x06\x04\x85\x08\x0f\x20"
  "\x64\x02\x44\x5f\x60\x61\x62\x63\x02\x12\x03\x59\x04\x5a\x0c\x4d"
  "\x04\x96\x07\x30\x81\x95\x02\x95\x07\x2e\x81\x95\x02\x94\x07\x2c"
  "\x81\x87\x02\x93\x07\x2a\x81\x87\x02\x92\x07\x28\x81\x95\x02\x91"
  "\x07\x26\x81\x95\x02\x90\x07\x24\x81\x87\x02\x8f\x07\x22\x81\x87"
  "\x02\x8e\x07\x20\x81\x95\x02\x8d\x07\x1e\x81\x95\x02\x8c\x07\x1c"
  "\x81\x87\x02\x8b\x07\x1a\x81\x87\x02\x8a\x07\x18\x81\x87\x02\x89"
  "\x07\x16\x81\x87\x02\x88\x07\x14\x81\x87\x02\x87\x07\x12\x81\x87"
  "\x02\x86\x07\x10\x81\x87\x02\x85\x07\x0e\x81\x87\x02\x84\x07\x0c"
  "\x81\x89\x02\x83\x07\x0a\x81\x87\x02\x82\x07\x08\x81\x87\x02\x81"
  "\x07\x06\x81\x87\x02\x80\x07\x04\x85\x08\x2f\x41\x65\x02\x45\x30"
  "\x04\x54\x02\x97\x07\x04\x83\x04\x03\x0a\x66\x02\x46\x30\x5c\x12"
  "\x73\x69\x6e\x67\x6c\x65\x74\x6f\x6e\x2d\x77\x74\x2d\x74\x72\x65"
  "\x65\x67\x03\x5d\x05\x55\x04\x54\x04\x9a\x07\x08\x81\x87\x02\x99"
  "\x07\x06\x81\x87\x02\x98\x07\x04\x85\x08\x07\x15\x68\x02\x47\x12"
  "\x5c\x0f\x61\x6c\x69\x73\x74\x2d\x3e\x77\x74\x2d\x74\x72\x65\x65"
  "\x5c\x03\x5d\x05\x55\x03\x9e\x07\x0a\x81\x85\x02\x9d\x07\x08\x81"
  "\x85\x02\x9c\x07\x06\x81\x85\x02\x9b\x07\x04\x84\x06\x09\x15\x69"
  "\x02\x48\x30\x12\x0f\x77\x74\x2d\x74\x72\x65\x65\x2f\x65\x6d\x70"
  "\x74\x79\x3f\x6a\x03\x59\x04\x5a\x03\xa2\x07\x0a\x81\x83\x02\xa1"
  "\x07\x08\x81\x83\x02\xa0\x07\x06\x81\x83\x02\x9f\x07\x04\x83\x04"
  "\x09\x16\x6b\x02\x49\x2a\x30\x12\x0d\x77\x74\x2d\x74\x72\x65\x65"
  "\x2f\x73\x69\x7a\x65\x6c\x03\x59\x04\x5a\x03\xa7\x07\x0c\x81\x83"
  "\x02\xa6\x07\x0a\x81\x83\x02\xa5\x07\x08\x81\x83\x02\xa4\x07\x06"
  "\x81\x83\x02\xa3\x07\x04\x83\x04\x0b\x19\x6d\x02\x4a\x12\x0c\x77"
  "\x74\x2d\x74\x72\x65\x65\x2f\x61\x64\x64\x6e\x03\x59\x04\x5a\x03"
  "\xac\x07\x0c\x81\x87\x02\xab\x07\x0a\x81\x87\x02\xaa\x07\x08\x81"
  "\x87\x02\xa9\x07\x06\x81\x87\x02\xa8\x07\x04\x85\x08\x0b\x17\x6f"
  "\x02\x4b\x12\x0f\x77\x74\x2d\x74\x72\x65\x65\x2f\x64\x65\x6c\x65"
  "\x74\x65\x70\x03\x59\x04\x5a\x03\xb1\x07\x0c\x81\x85\x02\xb0\x07"
  "\x0a\x81\x85\x02\xaf\x07\x08\x81\x85\x02\xae\x07\x06\x81\x85\x02"
  "\xad\x07\x04\x84\x06\x0b\x17\x71\x02\x4c\x12\x0d\x77\x74\x2d\x74"
  "\x72\x65\x65\x2f\x61\x64\x64\x21\x72\x03\x59\x04\x5a\x03\xb6\x07"
  "\x0c\x81\x87\x02\xb5\x07\x0a\x81\x87\x02\xb4\x07\x08\x81\x87\x02"
  "\xb3\x07\x06\x81\x87\x02\xb2\x07\x04\x85\x08\x0b\x17\x73\x02\x4d"
  "\x12\x10\x77\x74\x2d\x74\x72\x65\x65\x2f\x64\x65\x6c\x65\x74\x65"
  "\x21\x74\x03\x59\x04\x5a\x03\xbb\x07\x0c\x81\x85\x02\xba\x07\x0a"
  "\x81\x85\x02\xb9\x07\x08\x81\x85\x02\xb8\x07\x06\x81\x85\x02\xb7"
  "\x07\x04\x84\x06\x0b\x17\x75\x02\x4e\x08\x12\x10\x77\x74\x2d\x74"
  "\x72\x65\x65\x2f\x6d\x65\x6d\x62\x65\x72\x3f\x76\x03\x59\x04\x5a"
  "\x03\xc0\x07\x0c\x81\x85\x02\xbf\x07\x0a\x81\x85\x02\xbe\x07\x08"
  "\x81\x85\x02\xbd\x07\x06\x81\x85\x02\xbc\x07\x04\x84\x06\x0b\x17"
  "\x77\x02\x4f\x09\x12\x0f\x77\x74\x2d\x74\x72\x65\x65\x2f\x6c\x6f"
  "\x6f\x6b\x75\x70\x78\x03\x59\x04\x5a\x03\xc5\x07\x0c\x81\x87\x02"
  "\xc4\x07\x0a\x81\x87\x02\xc3\x07\x08\x81\x87\x02\xc2\x07\x06\x81"
  "\x87\x02\xc1\x07\x04\x85\x08\x0b\x17\x79\x02\x50\x0a\x12\x0f\x77"
  "\x74\x2d\x74\x72\x65\x65\x2f\x73\x70\x6c\x69\x74\x3c\x7a\x03\x59"
  "\x04\x5a\x03\xca\x07\x0c\x81\x85\x02\xc9\x07\x0a\x81\x85\x02\xc8"
  "\x07\x08\x81\x85\x02\xc7\x07\x06\x81\x85\x02\xc6\x07\x04\x84\x06"
  "\x0b\x17\x7b\x02\x51\x0b\x12\x0f\x77\x74\x2d\x74\x72\x65\x65\x2f"
  "\x73\x70\x6c\x69\x74\x3e\x7c\x03\x59\x04\x5a\x03\xcf\x07\x0c\x81"
  "\x85\x02\xce\x07\x0a\x81\x85\x02\xcd\x07\x08\x81\x85\x02\xcc\x07"
  "\x06\x81\x85\x02\xcb\x07\x04\x84\x06\x0b\x17\x7d\x02\x52\x5f\x61"
  "\x62\x63\x60\x0e\x77\x74\x2d\x74\x72\x65\x65\x2f\x75\x6e\x69\x6f"
  "\x6e\x7e\x0c\x12\x03\x59\x04\x5a\x0c\x4d\x04\xe9\x07\x36\x81\x8b"
  "\x02\xe8\x07\x34\x81\x87\x02\xe7\x07\x32\x81\x85\x02\xe6\x07\x30"
  "\x81\x85\x02\xe5\x07\x2e\x81\x8b\x02\xe4\x07\x2c\x81\x87\x02\xe3"
  "\x07\x2a\x81\x85\x02\xe2\x07\x28\x81\x85\x02\xe1\x07\x26\x81\x8b"
  "\x02\xe0\x07\x24\x81\x87\x02\xdf\x07\x22\x81\x85\x02\xde\x07\x20"
  "\x81\x85\x02\xdd\x07\x1e\x81\x85\x02\xdc\x07\x1c\x81\x85\x02\xdb"
  "\x07\x1a\x81\x85\x02\xda\x07\x18\x81\x85\x02\xd9\x07\x16\x81\x85"
  "\x02\xd8\x07\x14\x81\x85\x02\xd7\x07\x12\x81\x85\x02\xd6\x07\x10"
  "\x81\x85\x02\xd5\x07\x0e\x81\x87\x02\xd4\x07\x0c\x81\x85\x02\xd3"
  "\x07\x0a\x81\x85\x02\xd2\x07\x08\x81\x85\x02\xd1\x07\x06\x81\x85"
  "\x02\xd0\x07\x04\x84\x06\x35\x48\x7f\x02\x53\x5f\x61\x62\x63\x60"
  "\x14\x77\x74\x2d\x74\x72\x65\x65\x2f\x75\x6e\x69\x6f\x6e\x2d\x6d"
  "\x65\x72\x67\x65\x80\x01\x0d\x12\x03\x59\x04\x5a\x0c\x4d\x04\x83"
  "\x08\x36\x81\x8d\x02\x82\x08\x34\x81\x89\x02\x81\x08\x32\x81\x87"
  "\x02\x80\x08\x30\x81\x87\x02\xff\x07\x2e\x81\x8d\x02\xfe\x07\x2c"
  "\x81\x89\x02\xfd\x07\x2a\x81\x87\x02\xfc\x07\x28\x81\x87\x02\xfb"
  "\x07\x26\x81\x8d\x02\xfa\x07\x24\x81\x89\x02\xf9\x07\x22\x81\x87"
  "\x02\xf8\x07\x20\x81\x87\x02\xf7\x07\x1e\x81\x87\x02\xf6\x07\x1c"
  "\x81\x87\x02\xf5\x07\x1a\x81\x87\x02\xf4\x07\x18\x81\x87\x02\xf3"
  "\x07\x16\x81\x87\x02\xf2\x07\x14\x81\x87\x02\xf1\x07\x12\x81\x87"
  "\x02\xf0\x07\x10\x81\x87\x02\xef\x07\x0e\x81\x89\x02\xee\x07\x0c"
  "\x81\x87\x02\xed\x07\x0a\x81\x87\x02\xec\x07\x08\x81\x87\x02\xeb"
  "\x07\x06\x81\x87\x02\xea\x07\x04\x85\x08\x35\x48\x81\x01\x02\x54"
  "\x5f\x61\x62\x63\x60\x15\x77\x74\x2d\x74\x72\x65\x65\x2f\x69\x6e"
  "\x74\x65\x72\x73\x65\x63\x74\x69\x6f\x6e\x82\x01\x0e\x12\x03\x59"
  "\x04\x5a\x0c\x4d\x04\x9d\x08\x36\x81\x8b\x02\x9c\x08\x34\x81\x87"
  "\x02\x9b\x08\x32\x81\x85\x02\x9a\x08\x30\x81\x85\x02\x99\x08\x2e"
  "\x81\x8b\x02\x98\x08\x2c\x81\x87\x02\x97\x08\x2a\x81\x85\x02\x96"
  "\x08\x28\x81\x85\x02\x95\x08\x26\x81\x8b\x02\x94\x08\x24\x81\x87"
  "\x02\x93\x08\x22\x81\x85\x02\x92\x08\x20\x81\x85\x02\x91\x08\x1e"
  "\x81\x85\x02\x90\x08\x1c\x81\x85\x02\x8f\x08\x1a\x81\x85\x02\x8e"
  "\x08\x18\x81\x85\x02\x8d\x08\x16\x81\x85\x02\x8c\x08\x14\x81\x85"
  "\x02\x8b\x08\x12\x81\x85\x02\x8a\x08\x10\x81\x85\x02\x89\x08\x0e"
  "\x81\x87\x02\x88\x08\x0c\x81\x85\x02\x87\x08\x0a\x81\x85\x02\x86"
  "\x08\x08\x81\x85\x02\x85\x08\x06\x81\x85\x02\x84\x08\x04\x84\x06"
  "\x35\x48\x83\x01\x02\x55\x5f\x61\x62\x63\x60\x13\x77\x74\x2d\x74"
  "\x72\x65\x65\x2f\x64\x69\x66\x66\x65\x72\x65\x6e\x63\x65\x84\x01"
  "\x0f\x12\x03\x59\x04\x5a\x0c\x4d\x04\xb7\x08\x36\x81\x8b\x02\xb6"
  "\x08\x34\x81\x87\x02\xb5\x08\x32\x81\x85\x02\xb4\x08\x30\x81\x85"
  "\x02\xb3\x08\x2e\x81\x8b\x02\xb2\x08\x2c\x81\x87\x02\xb1\x08\x2a"
  "\x81\x85\x02\xb0\x08\x28\x81\x85\x02\xaf\x08\x26\x81\x8b\x02\xae"
  "\x08\x24\x81\x87\x02\xad\x08\x22\x81\x85\x02\xac\x08\x20\x81\x85"
  "\x02\xab\x08\x1e\x81\x85\x02\xaa\x08\x1c\x81\x85\x02\xa9\x08\x1a"
  "\x81\x85\x02\xa8\x08\x18\x81\x85\x02\xa7\x08\x16\x81\x85\x02\xa6"
  "\x08\x14\x81\x85\x02\xa5\x08\x12\x81\x85\x02\xa4\x08\x10\x81\x85"
  "\x02\xa3\x08\x0e\x81\x87\x02\xa2\x08\x0c\x81\x85\x02\xa1\x08\x0a"
  "\x81\x85\x02\xa0\x08\x08\x81\x85\x02\x9f\x08\x06\x81\x85\x02\x9e"
  "\x08\x04\x84\x06\x35\x48\x85\x01\x02\x56\x5f\x61\x62\x63\x60\x10"
  "\x77\x74\x2d\x74\x72\x65\x65\x2f\x73\x75\x62\x73\x65\x74\x3f\x63"
  "\x10\x12\x03\x59\x04\x5a\x0c\x4d\x04\xd1\x08\x36\x81\x8b\x02\xd0"
  "\x08\x34\x81\x87\x02\xcf\x08\x32\x81\x85\x02\xce\x08\x30\x81\x85"
  "\x02\xcd\x08\x2e\x81\x8b\x02\xcc\x08\x2c\x81\x87\x02\xcb\x08\x2a"
  "\x81\x85\x02\xca\x08\x28\x81\x85\x02\xc9\x08\x26\x81\x8b\x02\xc8"
  "\x08\x24\x81\x87\x02\xc7\x08\x22\x81\x85\x02\xc6\x08\x20\x81\x85"
  "\x02\xc5\x08\x1e\x81\x85\x02\xc4\x08\x1c\x81\x85\x02\xc3\x08\x1a"
  "\x81\x85\x02\xc2\x08\x18\x81\x85\x02\xc1\x08\x16\x81\x85\x02\xc0"
  "\x08\x14\x81\x85\x02\xbf\x08\x12\x81\x85\x02\xbe\x08\x10\x81\x85"
  "\x02\xbd\x08\x0e\x81\x87\x02\xbc\x08\x0c\x81\x85\x02\xbb\x08\x0a"
  "\x81\x85\x02\xba\x08\x08\x81\x85\x02\xb9\x08\x06\x81\x85\x02\xb8"
  "\x08\x04\x84\x06\x35\x48\x62\x02\x57\x04\x63\x02\xd3\x08\x06\x81"
  "\x85\x02\xd2\x08\x04\x84\x06\x05\x0b\x61\x02\x58\x12\x0d\x77\x74"
  "\x2d\x74\x72\x65\x65\x2f\x66\x6f\x6c\x64\x60\x03\x59\x04\x5a\x05"
  "\x12\x6e\x6f\x64\x65\x2f\x69\x6e\x6f\x72\x64\x65\x72\x2d\x66\x6f"
  "\x6c\x64\x5f\x04\xd7\x08\x0a\x81\x87\x02\xd6\x08\x08\x81\x87\x02"
  "\xd5\x08\x06\x81\x87\x02\xd4\x08\x04\x85\x08\x09\x16\x4d\x02\x59"
  "\x12\x11\x77\x74\x2d\x74\x72\x65\x65\x2f\x66\x6f\x72\x2d\x65\x61"
  "\x63\x68\x86\x01\x03\x59\x04\x5a\x04\x47\x04\xdb\x08\x0a\x81\x85"
  "\x02\xda\x08\x08\x81\x85\x02\xd9\x08\x06\x81\x85\x02\xd8\x08\x04"
  "\x84\x06\x09\x16\x87\x01\x02\x5a\x2a\x12\x0e\x77\x74\x2d\x74\x72"
  "\x65\x65\x2f\x69\x6e\x64\x65\x78\x88\x01\x03\x59\x04\x5a\x04\x4b"
  "\x04\xe0\x08\x0c\x81\x85\x02\xdf\x08\x0a\x81\x89\x02\xde\x08\x08"
  "\x81\x85\x02\xdd\x08\x06\x81\x85\x02\xdc\x08\x04\x84\x06\x0b\x19"
  "\x89\x01\x02\x5b\x2a\x12\x14\x77\x74\x2d\x74\x72\x65\x65\x2f\x69"
  "\x6e\x64\x65\x78\x2d\x64\x61\x74\x75\x6d\x8a\x01\x03\x59\x04\x5a"
  "\x04\x4b\x04\xe5\x08\x0c\x81\x85\x02\xe4\x08\x0a\x81\x89\x02\xe3"
  "\x08\x08\x81\x85\x02\xe2\x08\x06\x81\x85\x02\xe1\x08\x04\x84\x06"
  "\x0b\x1a\x8b\x01\x02\x5c\x2a\x12\x13\x77\x74\x2d\x74\x72\x65\x65"
  "\x2f\x69\x6e\x64\x65\x78\x2d\x70\x61\x69\x72\x8c\x01\x03\x59\x04"
  "\x5a\x04\x4b\x04\xec\x08\x10\x81\x85\x02\xeb\x08\x0e\x81\x83\x02"
  "\xea\x08\x0c\x81\x85\x02\xe9\x08\x0a\x81\x89\x02\xe8\x08\x08\x81"
  "\x85\x02\xe7\x08\x06\x81\x85\x02\xe6\x08\x04\x84\x06\x0f\x1e\x8d"
  "\x01\x02\x5d\x11\x12\x0d\x77\x74\x2d\x74\x72\x65\x65\x2f\x72\x61"
  "\x6e\x6b\x8e\x01\x03\x59\x04\x5a\x03\xf1\x08\x0c\x81\x85\x02\xf0"
  "\x08\x0a\x81\x85\x02\xef\x08\x08\x81\x85\x02\xee\x08\x06\x81\x85"
  "\x02\xed\x08\x04\x84\x06\x0b\x17\x8f\x01\x02\x5e\x2a\x12\x0c\x77"
  "\x74\x2d\x74\x72\x65\x65\x2f\x6d\x69\x6e\x90\x01\x03\x59\x04\x5a"
  "\x03\x40\x04\xf6\x08\x0c\x81\x83\x02\xf5\x08\x0a\x81\x85\x02\xf4"
  "\x08\x08\x81\x83\x02\xf3\x08\x06\x81\x83\x02\xf2\x08\x04\x83\x04"
  "\x0b\x19\x91\x01\x02\x5f\x2a\x12\x12\x77\x74\x2d\x74\x72\x65\x65"
  "\x2f\x6d\x69\x6e\x2d\x64\x61\x74\x75\x6d\x92\x01\x03\x59\x04\x5a"
  "\x03\x40\x04\xfb\x08\x0c\x81\x83\x02\xfa\x08\x0a\x81\x85\x02\xf9"
  "\x08\x08\x81\x83\x02\xf8\x08\x06\x81\x83\x02\xf7\x08\x04\x83\x04"
  "\x0b\x1a\x93\x01\x02\x60\x2a\x12\x11\x77\x74\x2d\x74\x72\x65\x65"
  "\x2f\x6d\x69\x6e\x2d\x70\x61\x69\x72\x94\x01\x03\x59\x04\x5a\x03"
  "\x40\x04\x82\x09\x10\x81\x85\x02\x81\x09\x0e\x81\x83\x02\x80\x09"
  "\x0c\x81\x83\x02\xff\x08\x0a\x81\x85\x02\xfe\x08\x08\x81\x83\x02"
  "\xfd\x08\x06\x81\x83\x02\xfc\x08\x04\x83\x04\x0f\x1e\x95\x01\x02"
  "\x61\x12\x13\x77\x74\x2d\x74\x72\x65\x65\x2f\x64\x65\x6c\x65\x74"
  "\x65\x2d\x6d\x69\x6e\x96\x01\x03\x59\x04\x5a\x03\x42\x04\x54\x05"
  "\x88\x09\x0e\x81\x85\x02\x87\x09\x0c\x81\x87\x02\x86\x09\x0a\x81"
  "\x83\x02\x85\x09\x08\x81\x83\x02\x84\x09\x06\x81\x83\x02\x83\x09"
  "\x04\x83\x04\x0d\x1d\x97\x01\x02\x62\x27\x02\x12\x14\x77\x74\x2d"
  "\x74\x72\x65\x65\x2f\x64\x65\x6c\x65\x74\x65\x2d\x6d\x69\x6e\x21"
  "\x03\x59\x04\x5a\x03\x42\x04\x8d\x09\x0c\x81\x87\x02\x8c\x09\x0a"
  "\x81\x89\x02\x8b\x09\x08\x81\x83\x02\x8a\x09\x06\x81\x83\x02\x89"
  "\x09\x04\x83\x04\x0b\x1a\x98\x01\x62\x99\x01\x99\x01\x4f\x50\x51"
  "\x52\x27\x02\x2a\x30\x0f\x6e\x75\x6d\x62\x65\x72\x2d\x77\x74\x2d"
  "\x74\x79\x70\x65\x0f\x73\x74\x72\x69\x6e\x67\x2d\x77\x74\x2d\x74"
  "\x79\x70\x65\x06\x74\x74\x79\x70\x65\x59\x96\x01\x94\x01\x92\x01"
  "\x90\x01\x8e\x01\x8c\x01\x8a\x01\x88\x01\x86\x01\x60\x13\x77\x74"
  "\x2d\x74\x72\x65\x65\x2f\x73\x65\x74\x2d\x65\x71\x75\x61\x6c\x3f"
  "\x63\x84\x01\x82\x01\x80\x01\x7e\x7c\x7a\x78\x76\x74\x72\x70\x6e"
  "\x6c\x6a\x5c\x67\x0d\x6d\x61\x6b\x65\x2d\x77\x74\x2d\x74\x72\x65"
  "\x65\x1b\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x63\x6f\x6d\x70"
  "\x61\x74\x69\x62\x6c\x65\x2d\x74\x72\x65\x65\x73\x22\x67\x75\x61"
  "\x72\x61\x6e\x74\x65\x65\x2d\x63\x6f\x6d\x70\x61\x74\x69\x62\x6c"
  "\x65\x2d\x74\x72\x65\x65\x73\x2f\x72\x65\x70\x6f\x72\x74\x14\x67"
  "\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x74\x72\x65\x65\x2d\x74\x79"
  "\x70\x65\x0f\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x74\x72\x65"
  "\x65\x5a\x12\x6d\x61\x6b\x65\x2d\x77\x74\x2d\x74\x72\x65\x65\x2d"
  "\x74\x79\x70\x65\x99\x01\x3f\x4b\x49\x47\x5f\x56\x42\x40\x43\x0e"
  "\x77\x74\x2d\x74\x72\x65\x65\x2d\x72\x61\x74\x69\x6f\x3d\x3c\x3b"
  "\x3a\x07\x6e\x2d\x6a\x6f\x69\x6e\x0c\x77\x69\x74\x68\x2d\x6e\x2d"
  "\x6e\x6f\x64\x65\x0f\x6e\x6f\x64\x65\x2f\x73\x69\x6e\x67\x6c\x65"
  "\x74\x6f\x6e\x0a\x6e\x6f\x64\x65\x2f\x73\x69\x7a\x65\x07\x65\x6d"
  "\x70\x74\x79\x3f\x30\x07\x6e\x6f\x64\x65\x2f\x77\x07\x6e\x6f\x64"
  "\x65\x2f\x72\x07\x6e\x6f\x64\x65\x2f\x6c\x07\x6e\x6f\x64\x65\x2f"
  "\x76\x07\x6e\x6f\x64\x65\x2f\x6b\x0a\x6d\x61\x6b\x65\x2d\x6e\x6f"
  "\x64\x65\x3f\x98\x01\x04\x97\x01\x04\x95\x01\x04\x93\x01\x04\x91"
  "\x01\x04\x8f\x01\x04\x8d\x01\x04\x8b\x01\x04\x89\x01\x04\x87\x01"
  "\x04\x4d\x04\x61\x04\x62\x04\x85\x01\x04\x83\x01\x04\x81\x01\x04"
  "\x7f\x04\x7d\x04\x7b\x04\x79\x04\x77\x04\x75\x04\x73\x04\x71\x04"
  "\x6f\x04\x6d\x04\x6b\x04\x69\x04\x68\x04\x66\x04\x65\x04\x64\x04"
  "\x5e\x04\x5b\x04\x58\x04\x57\x04\x4e\x04\x4c\x06\x4a\x04\x48\x04"
  "\x46\x04\x45\x04\x44\x04\x41\x04\x3e\x10\x39\x10\x38\x0c\x37\x10"
  "\x36\x0c\x35\x08\x34\x04\x33\x04\x32\x04\x31\x04\x30\x2f\x04\x2e"
  "\x04\x2d\x04\x2c\x04\x2b\x04\x29\x04\x3f\x54\x0f\x73\x65\x74\x2d"
  "\x74\x72\x65\x65\x2f\x72\x6f\x6f\x74\x21\x0a\x74\x72\x65\x65\x2f"
  "\x72\x6f\x6f\x74\x0a\x74\x72\x65\x65\x2f\x74\x79\x70\x65\x28\x04"
  "\x26\x04\x25\x04\x12\x0c\x72\x74\x64\x3a\x77\x74\x2d\x74\x72\x65"
  "\x65\x98\x01\x5d\x08\x77\x74\x2d\x74\x72\x65\x65\x05\x74\x79\x70"
  "\x65\x05\x72\x6f\x6f\x74\x23\x04\x24\x04\x53\x0f\x74\x72\x65\x65"
  "\x2d\x74\x79\x70\x65\x2f\x72\x61\x6e\x6b\x12\x74\x72\x65\x65\x2d"
  "\x74\x79\x70\x65\x2f\x73\x75\x62\x73\x65\x74\x3f\x15\x74\x72\x65"
  "\x65\x2d\x74\x79\x70\x65\x2f\x64\x69\x66\x66\x65\x72\x65\x6e\x63"
  "\x65\x17\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x69\x6e\x74\x65"
  "\x72\x73\x65\x63\x74\x69\x6f\x6e\x16\x74\x72\x65\x65\x2d\x74\x79"
  "\x70\x65\x2f\x75\x6e\x69\x6f\x6e\x2d\x6d\x65\x72\x67\x65\x10\x74"
  "\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x75\x6e\x69\x6f\x6e\x13\x74"
  "\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x73\x70\x6c\x69\x74\x2d\x67"
  "\x74\x13\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x73\x70\x6c\x69"
  "\x74\x2d\x6c\x74\x11\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x6c"
  "\x6f\x6f\x6b\x75\x70\x12\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x2f"
  "\x6d\x65\x6d\x62\x65\x72\x3f\x12\x74\x72\x65\x65\x2d\x74\x79\x70"
  "\x65\x2f\x64\x65\x6c\x65\x74\x65\x21\x11\x74\x72\x65\x65\x2d\x74"
  "\x79\x70\x65\x2f\x64\x65\x6c\x65\x74\x65\x12\x74\x72\x65\x65\x2d"
  "\x74\x79\x70\x65\x2f\x69\x6e\x73\x65\x72\x74\x21\x0e\x74\x72\x65"
  "\x65\x2d\x74\x79\x70\x65\x2f\x61\x64\x64\x16\x74\x72\x65\x65\x2d"
  "\x74\x79\x70\x65\x2f\x61\x6c\x69\x73\x74\x2d\x3e\x74\x72\x65\x65"
  "\x10\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x2f\x6b\x65\x79\x3c\x3f"
  "\x11\x22\x04\x21\x04\x20\x04\x1f\x04\x1e\x04\x1d\x04\x1c\x04\x1b"
  "\x04\x1a\x04\x19\x04\x18\x04\x17\x04\x16\x04\x15\x04\x14\x04\x13"
  "\x04\x11\x0a\x74\x72\x65\x65\x2d\x74\x79\x70\x65\x06\x6b\x65\x79"
  "\x3c\x3f\x4f\x04\x61\x64\x64\x08\x69\x6e\x73\x65\x72\x74\x21\x07"
  "\x64\x65\x6c\x65\x74\x65\x08\x64\x65\x6c\x65\x74\x65\x21\x08\x6d"
  "\x65\x6d\x62\x65\x72\x3f\x07\x6c\x6f\x6f\x6b\x75\x70\x09\x73\x70"
  "\x6c\x69\x74\x2d\x6c\x74\x09\x73\x70\x6c\x69\x74\x2d\x67\x74\x06"
  "\x75\x6e\x69\x6f\x6e\x0c\x75\x6e\x69\x6f\x6e\x2d\x6d\x65\x72\x67"
  "\x65\x0d\x69\x6e\x74\x65\x72\x73\x65\x63\x74\x69\x6f\x6e\x0b\x64"
  "\x69\x66\x66\x65\x72\x65\x6e\x63\x65\x08\x73\x75\x62\x73\x65\x74"
  "\x3f\x05\x72\x61\x6e\x6b\x10\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73"
  "\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0e\x72\x74\x64\x3a\x74\x72\x65"
  "\x65\x2d\x74\x79\x70\x65\x97\x01\x04\x04\x04\x04\x04\x04\x04\x09"
  "\x04\x0a\x04\x0b\x04\x0c\x04\x0d\x04\x0e\x04\x0f\x04\x10\x04\x11"
  "\x04\x03\x19\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x64"
  "\x69\x73\x70\x61\x74\x63\x68\x2d\x74\x61\x67\x06\x11\x6d\x61\x6b"
  "\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x05\x10\x64"
  "\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x04\x97"
  "\x01\x98\x01\x02\x3c\x09\x73\x74\x72\x69\x6e\x67\x3c\x3f\x98\x01"
  "\x05\x12\x05\x6c\x69\x73\x74\x03\x99\x01\x12\x53\x04\x54\x04\x56"
  "\x05\x55\x04\x98\x01\x06\x43\x03\x40\x03\x42\x0b\xd3\x03\xa8\x07"
  "\x80\x80\x04\xd2\x03\xa6\x07\x81\x81\x02\xd1\x03\xa4\x07\x81\x81"
  "\x02\xd0\x03\xa2\x07\x81\x89\x02\xcf\x03\xa0\x07\x81\x89\x02\xce"
  "\x03\x9e\x07\x81\x89\x02\xcd\x03\x9c\x07\x81\x87\x02\xcc\x03\x9a"
  "\x07\x81\x85\x02\xcb\x03\x98\x07\x81\x89\x02\xca\x03\x96\x07\x81"
  "\x87\x02\xc9\x03\x94\x07\x81\x85\x02\xc8\x03\x92\x07\xfd\xff\x03"
  "\xc7\x03\x90\x07\xfd\xff\x03\xc6\x03\x8e\x07\xfd\xff\x03\xc5\x03"
  "\x8c\x07\xfd\xff\x03\xc4\x03\x8a\x07\xfd\xff\x03\xc3\x03\x88\x07"
  "\x81\x85\x02\xc2\x03\x86\x07\xfd\xff\x03\xc1\x03\x84\x07\xfd\xff"
  "\x03\xc0\x03\x82\x07\xfd\xff\x03\xbf\x03\x80\x07\x81\x85\x02\xbe"
  "\x03\xfe\x06\x81\x8d\x02\xbd\x03\xfc\x06\x81\x8b\x02\xbc\x03\xfa"
  "\x06\xfd\xff\x03\xbb\x03\xf8\x06\xfd\xff\x03\xba\x03\xf6\x06\xfd"
  "\xff\x03\xb9\x03\xf4\x06\xfd\xff\x03\xb8\x03\xf2\x06\xfd\xff\x03"
  "\xb7\x03\xf0\x06\xfd\xff\x03\xb6\x03\xee\x06\xfd\xff\x03\xb5\x03"
  "\xec\x06\xfd\xff\x03\xb4\x03\xea\x06\x81\x8d\x02\xb3\x03\xe8\x06"
  "\x81\x8b\x02\xb2\x03\xe6\x06\x81\x89\x02\xb1\x03\xe4\x06\x81\x89"
  "\x02\xb0\x03\xe2\x06\x81\x8b\x02\xaf\x03\xe0\x06\x81\x89\x02\xae"
  "\x03\xde\x06\x81\x8b\x02\xad\x03\xdc\x06\xfd\xff\x03\xac\x03\xda"
  "\x06\xfd\xff\x03\xab\x03\xd8\x06\xfd\xff\x03\xaa\x03\xd6\x06\xfd"
  "\xff\x03\xa9\x03\xd4\x06\xfd\xff\x03\xa8\x03\xd2\x06\xfd\xff\x03"
  "\xa7\x03\xd0\x06\xfd\xff\x03\xa6\x03\xce\x06\xfd\xff\x03\xa5\x03"
  "\xcc\x06\xfd\xff\x03\xa4\x03\xca\x06\xfd\xff\x03\xa3\x03\xc8\x06"
  "\xfd\xff\x03\xa2\x03\xc6\x06\xfd\xff\x03\xa1\x03\xc4\x06\xfd\xff"
  "\x03\xa0\x03\xc2\x06\x81\x89\x02\x9f\x03\xc0\x06\x81\x89\x02\x9e"
  "\x03\xbe\x06\x81\x8b\x02\x9d\x03\xbc\x06\xfd\xff\x03\x9c\x03\xba"
  "\x06\xfd\xff\x03\x9b\x03\xb8\x06\xfd\xff\x03\x9a\x03\xb6\x06\xfd"
  "\xff\x03\x99\x03\xb4\x06\xfd\xff\x03\x98\x03\xb2\x06\xfd\xff\x03"
  "\x97\x03\xb0\x06\xfd\xff\x03\x96\x03\xae\x06\xfd\xff\x03\x95\x03"
  "\xac\x06\xfd\xff\x03\x94\x03\xaa\x06\xfd\xff\x03\x93\x03\xa8\x06"
  "\xfd\xff\x03\x92\x03\xa6\x06\xfd\xff\x03\x91\x03\xa4\x06\xfd\xff"
  "\x03\x90\x03\xa2\x06\xfd\xff\x03\x8f\x03\xa0\x06\xfd\xff\x03\x8e"
  "\x03\x9e\x06\xfd\xff\x03\x8d\x03\x9c\x06\xfd\xff\x03\x8c\x03\x9a"
  "\x06\xfd\xff\x03\x8b\x03\x98\x06\x81\x8d\x02\x8a\x03\x96\x06\x81"
  "\x8b\x02\x89\x03\x94\x06\xfd\xff\x03\x88\x03\x92\x06\x81\x89\x02"
  "\x87\x03\x90\x06\x81\x8b\x02\x86\x03\x8e\x06\xfd\xff\x03\x85\x03"
  "\x8c\x06\xfd\xff\x03\x84\x03\x8a\x06\xfd\xff\x03\x83\x03\x88\x06"
  "\x81\x87\x02\x82\x03\x86\x06\x81\x89\x02\x81\x03\x84\x06\x81\x89"
  "\x02\x80\x03\x82\x06\x81\x89\x02\xff\x02\x80\x06\x81\x8d\x02\xfe"
  "\x02\xfe\x05\x81\x87\x02\xfd\x02\xfc\x05\x81\x85\x02\xfc\x02\xfa"
  "\x05\x81\x85\x02\xfb\x02\xf8\x05\x81\x8f\x02\xfa\x02\xf6\x05\x81"
  "\x89\x02\xf9\x02\xf4\x05\x81\x87\x02\xf8\x02\xf2\x05\x81\x85\x02"
  "\xf7\x02\xf0\x05\x81\x85\x02\xf6\x02\xee\x05\xfd\xff\x03\xf5\x02"
  "\xec\x05\xfd\xff\x03\xf4\x02\xea\x05\xfd\xff\x03\xf3\x02\xe8\x05"
  "\xfd\xff\x03\xf2\x02\xe6\x05\xfd\xff\x03\xf1\x02\xe4\x05\xfd\xff"
  "\x03\xf0\x02\xe2\x05\xfd\xff\x03\xef\x02\xe0\x05\xfd\xff\x03\xee"
  "\x02\xde\x05\x81\x87\x02\xed\x02\xdc\x05\x81\x89\x02\xec\x02\xda"
  "\x05\x81\x89\x02\xeb\x02\xd8\x05\x81\x89\x02\xea\x02\xd6\x05\x81"
  "\x89\x02\xe9\x02\xd4\x05\x81\x89\x02\xe8\x02\xd2\x05\x81\x89\x02"
  "\xe7\x02\xd0\x05\x81\x87\x02\xe6\x02\xce\x05\x81\x87\x02\xe5\x02"
  "\xcc\x05\x81\x87\x02\xe4\x02\xca\x05\x81\x8d\x02\xe3\x02\xc8\x05"
  "\x81\x8b\x02\xe2\x02\xc6\x05\xfd\xff\x03\xe1\x02\xc4\x05\xfd\xff"
  "\x03\xe0\x02\xc2\x05\xfd\xff\x03\xdf\x02\xc0\x05\xfd\xff\x03\xde"
  "\x02\xbe\x05\xfd\xff\x03\xdd\x02\xbc\x05\xfd\xff\x03\xdc\x02\xba"
  "\x05\xfd\xff\x03\xdb\x02\xb8\x05\xfd\xff\x03\xda\x02\xb6\x05\x81"
  "\x8d\x02\xd9\x02\xb4\x05\x81\x8b\x02\xd8\x02\xb2\x05\x81\x89\x02"
  "\xd7\x02\xb0\x05\x81\x89\x02\xd6\x02\xae\x05\x81\x8b\x02\xd5\x02"
  "\xac\x05\x81\x89\x02\xd4\x02\xaa\x05\x81\x8b\x02\xd3\x02\xa8\x05"
  "\xfd\xff\x03\xd2\x02\xa6\x05\xfd\xff\x03\xd1\x02\xa4\x05\xfd\xff"
  "\x03\xd0\x02\xa2\x05\xfd\xff\x03\xcf\x02\xa0\x05\xfd\xff\x03\xce"
  "\x02\x9e\x05\xfd\xff\x03\xcd\x02\x9c\x05\x81\x85\x02\xcc\x02\x9a"
  "\x05\x81\x85\x02\xcb\x02\x98\x05\xfd\xff\x03\xca\x02\x96\x05\xfd"
  "\xff\x03\xc9\x02\x94\x05\x81\x8b\x02\xc8\x02\x92\x05\x81\x8b\x02"
  "\xc7\x02\x90\x05\x81\x89\x02\xc6\x02\x8e\x05\x81\x85\x02\xc5\x02"
  "\x8c\x05\x81\x89\x02\xc4\x02\x8a\x05\x81\x85\x02\xc3\x02\x88\x05"
  "\x81\x85\x02\xc2\x02\x86\x05\x81\x87\x02\xc1\x02\x84\x05\x81\x85"
  "\x02\xc0\x02\x82\x05\xfd\xff\x03\xbf\x02\x80\x05\xfd\xff\x03\xbe"
  "\x02\xfe\x04\xfd\xff\x03\xbd\x02\xfc\x04\xfd\xff\x03\xbc\x02\xfa"
  "\x04\xfd\xff\x03\xbb\x02\xf8\x04\xfd\xff\x03\xba\x02\xf6\x04\xfd"
  "\xff\x03\xb9\x02\xf4\x04\x81\x87\x02\xb8\x02\xf2\x04\x81\x8b\x02"
  "\xb7\x02\xf0\x04\x81\x87\x02\xb6\x02\xee\x04\x81\x85\x02\xb5\x02"
  "\xec\x04\x81\x85\x02\xb4\x02\xea\x04\xfd\xff\x03\xb3\x02\xe8\x04"
  "\xfd\xff\x03\xb2\x02\xe6\x04\xfd\xff\x03\xb1\x02\xe4\x04\xfd\xff"
  "\x03\xb0\x02\xe2\x04\x81\x89\x02\xaf\x02\xe0\x04\x81\x89\x02\xae"
  "\x02\xde\x04\x81\x8b\x02\xad\x02\xdc\x04\x81\x8b\x02\xac\x02\xda"
  "\x04\x81\x89\x02\xab\x02\xd8\x04\x81\x89\x02\xaa\x02\xd6\x04\x81"
  "\x87\x02\xa9\x02\xd4\x04\x81\x89\x02\xa8\x02\xd2\x04\x81\x89\x02"
  "\xa7\x02\xd0\x04\x81\x8b\x02\xa6\x02\xce\x04\xfd\xff\x03\xa5\x02"
  "\xcc\x04\xfd\xff\x03\xa4\x02\xca\x04\xfd\xff\x03\xa3\x02\xc8\x04"
  "\xfd\xff\x03\xa2\x02\xc6\x04\xfd\xff\x03\xa1\x02\xc4\x04\xfd\xff"
  "\x03\xa0\x02\xc2\x04\xfd\xff\x03\x9f\x02\xc0\x04\xfd\xff\x03\x9e"
  "\x02\xbe\x04\x81\x85\x02\x9d\x02\xbc\x04\x81\x89\x02\x9c\x02\xba"
  "\x04\x81\x89\x02\x9b\x02\xb8\x04\x81\x87\x02\x9a\x02\xb6\x04\x81"
  "\x87\x02\x99\x02\xb4\x04\x81\x85\x02\x98\x02\xb2\x04\x81\x87\x02"
  "\x97\x02\xb0\x04\x81\x87\x02\x96\x02\xae\x04\x81\x8d\x02\x95\x02"
  "\xac\x04\x81\x8b\x02\x94\x02\xaa\x04\x81\x89\x02\x93\x02\xa8\x04"
  "\x81\x87\x02\x92\x02\xa6\x04\x81\x87\x02\x91\x02\xa4\x04\x81\x87"
  "\x02\x90\x02\xa2\x04\x81\x85\x02\x8f\x02\xa0\x04\x81\x85\x02\x8e"
  "\x02\x9e\x04\x81\x8b\x02\x8d\x02\x9c\x04\x81\x89\x02\x8c\x02\x9a"
  "\x04\x81\x87\x02\x8b\x02\x98\x04\x81\x85\x02\x8a\x02\x96\x04\x81"
  "\x85\x02\x89\x02\x94\x04\x81\x87\x02\x88\x02\x92\x04\x81\x85\x02"
  "\x87\x02\x90\x04\x81\x85\x02\x86\x02\x8e\x04\x81\x87\x02\x85\x02"
  "\x8c\x04\x81\x87\x02\x84\x02\x8a\x04\x81\x85\x02\x83\x02\x88\x04"
  "\x81\x85\x02\x82\x02\x86\x04\x81\x85\x02\x81\x02\x84\x04\x81\x89"
  "\x02\x80\x02\x82\x04\x81\x85\x02\xff\x01\x80\x04\x81\x85\x02\xfe"
  "\x01\xfe\x03\x81\x85\x02\xfd\x01\xfc\x03\x81\x8b\x02\xfc\x01\xfa"
  "\x03\x81\x89\x02\xfb\x01\xf8\x03\x81\x87\x02\xfa\x01\xf6\x03\x81"
  "\x85\x02\xf9\x01\xf4\x03\x81\x85\x02\xf8\x01\xf2\x03\x81\x85\x02"
  "\xf7\x01\xf0\x03\x81\x85\x02\xf6\x01\xee\x03\x81\x8d\x02\xf5\x01"
  "\xec\x03\x81\x8b\x02\xf4\x01\xea\x03\x81\x89\x02\xf3\x01\xe8\x03"
  "\x81\x87\x02\xf2\x01\xe6\x03\x81\x87\x02\xf1\x01\xe4\x03\x81\x87"
  "\x02\xf0\x01\xe2\x03\x81\x87\x02\xef\x01\xe0\x03\x81\x8b\x02\xee"
  "\x01\xde\x03\x81\x89\x02\xed\x01\xdc\x03\x81\x87\x02\xec\x01\xda"
  "\x03\x81\x85\x02\xeb\x01\xd8\x03\x81\x85\x02\xea\x01\xd6\x03\x81"
  "\x85\x02\xe9\x01\xd4\x03\x81\x85\x02\xe8\x01\xd2\x03\x81\x89\x02"
  "\xe7\x01\xd0\x03\x81\x87\x02\xe6\x01\xce\x03\x81\x85\x02\xe5\x01"
  "\xcc\x03\x81\x85\x02\xe4\x01\xca\x03\x81\x85\x02\xe3\x01\xc8\x03"
  "\x81\x85\x02\xe2\x01\xc6\x03\xfd\xff\x03\xe1\x01\xc4\x03\x81\x89"
  "\x02\xe0\x01\xc2\x03\x81\x87\x02\xdf\x01\xc0\x03\x81\x85\x02\xde"
  "\x01\xbe\x03\x81\x89\x02\xdd\x01\xbc\x03\x81\x87\x02\xdc\x01\xba"
  "\x03\x81\x85\x02\xdb\x01\xb8\x03\x81\x85\x02\xda\x01\xb6\x03\x81"
  "\x87\x02\xd9\x01\xb4\x03\x81\x89\x02\xd8\x01\xb2\x03\x81\x87\x02"
  "\xd7\x01\xb0\x03\x81\x85\x02\xd6\x01\xae\x03\x81\x89\x02\xd5\x01"
  "\xac\x03\x81\x89\x02\xd4\x01\xaa\x03\x81\x87\x02\xd3\x01\xa8\x03"
  "\x81\x87\x02\xd2\x01\xa6\x03\x81\x85\x02\xd1\x01\xa4\x03\x81\x87"
  "\x02\xd0\x01\xa2\x03\x81\x87\x02\xcf\x01\xa0\x03\x81\x8d\x02\xce"
  "\x01\x9e\x03\x81\x8b\x02\xcd\x01\x9c\x03\x81\x8d\x02\xcc\x01\x9a"
  "\x03\x81\x8b\x02\xcb\x01\x98\x03\x81\x89\x02\xca\x01\x96\x03\x81"
  "\x87\x02\xc9\x01\x94\x03\x81\x87\x02\xc8\x01\x92\x03\xfd\xff\x03"
  "\xc7\x01\x90\x03\xfd\xff\x03\xc6\x01\x8e\x03\x81\x89\x02\xc5\x01"
  "\x8c\x03\x81\x8b\x02\xc4\x01\x8a\x03\x81\x87\x02\xc3\x01\x88\x03"
  "\x81\x85\x02\xc2\x01\x86\x03\x81\x85\x02\xc1\x01\x84\x03\x81\x8b"
  "\x02\xc0\x01\x82\x03\x81\x89\x02\xbf\x01\x80\x03\x81\x87\x02\xbe"
  "\x01\xfe\x02\x81\x85\x02\xbd\x01\xfc\x02\x81\x85\x02\xbc\x01\xfa"
  "\x02\xfd\xff\x03\xbb\x01\xf8\x02\xfd\xff\x03\xba\x01\xf6\x02\x81"
  "\x87\x02\xb9\x01\xf4\x02\x81\x85\x02\xb8\x01\xf2\x02\x81\x85\x02"
  "\xb7\x01\xf0\x02\x81\x87\x02\xb6\x01\xee\x02\x81\x85\x02\xb5\x01"
  "\xec\x02\x81\x8d\x02\xb4\x01\xea\x02\x81\x87\x02\xb3\x01\xe8\x02"
  "\x81\x85\x02\xb2\x01\xe6\x02\x81\x89\x02\xb1\x01\xe4\x02\x81\x87"
  "\x02\xb0\x01\xe2\x02\x81\x85\x02\xaf\x01\xe0\x02\x81\x85\x02\xae"
  "\x01\xde\x02\x81\x85\x02\xad\x01\xdc\x02\x81\x85\x02\xac\x01\xda"
  "\x02\x81\x85\x02\xab\x01\xd8\x02\x81\x85\x02\xaa\x01\xd6\x02\x81"
  "\x8f\x02\xa9\x01\xd4\x02\x81\x89\x02\xa8\x01\xd2\x02\x81\x87\x02"
  "\xa7\x01\xd0\x02\x81\x85\x02\xa6\x01\xce\x02\x81\x87\x02\xa5\x01"
  "\xcc\x02\x81\x89\x02\xa4\x01\xca\x02\x81\x85\x02\xa3\x01\xc8\x02"
  "\x81\x85\x02\xa2\x01\xc6\x02\x81\x85\x02\xa1\x01\xc4\x02\x81\x85"
  "\x02\xa0\x01\xc2\x02\x81\x85\x02\x9f\x01\xc0\x02\x81\x8b\x02\x9e"
  "\x01\xbe\x02\x81\x89\x02\x9d\x01\xbc\x02\x81\x87\x02\x9c\x01\xba"
  "\x02\x81\x85\x02\x9b\x01\xb8\x02\x81\x85\x02\x9a\x01\xb6\x02\x81"
  "\x85\x02\x99\x01\xb4\x02\x81\x85\x02\x98\x01\xb2\x02\x81\x8d\x02"
  "\x97\x01\xb0\x02\x81\x8b\x02\x96\x01\xae\x02\x81\x89\x02\x95\x01"
  "\xac\x02\x81\x87\x02\x94\x01\xaa\x02\x81\x87\x02\x93\x01\xa8\x02"
  "\x81\x87\x02\x92\x01\xa6\x02\x81\x87\x02\x91\x01\xa4\x02\x81\x8b"
  "\x02\x90\x01\xa2\x02\x81\x89\x02\x8f\x01\xa0\x02\x81\x87\x02\x8e"
  "\x01\x9e\x02\x81\x85\x02\x8d\x01\x9c\x02\x81\x85\x02\x8c\x01\x9a"
  "\x02\x81\x85\x02\x8b\x01\x98\x02\x81\x85\x02\x8a\x01\x96\x02\x81"
  "\x89\x02\x89\x01\x94\x02\x81\x87\x02\x88\x01\x92\x02\x81\x85\x02"
  "\x87\x01\x90\x02\x81\x85\x02\x86\x01\x8e\x02\x81\x85\x02\x85\x01"
  "\x8c\x02\x81\x85\x02\x84\x01\x8a\x02\xfd\xff\x03\x83\x01\x88\x02"
  "\xfd\xff\x03\x82\x01\x86\x02\xfd\xff\x03\x81\x01\x84\x02\xfd\xff"
  "\x03\x80\x01\x82\x02\xfd\xff\x03\x7f\x80\x02\x81\x89\x02\x7e\xfe"
  "\x01\x81\x87\x02\x7d\xfc\x01\x81\x85\x02\x7c\xfa\x01\x81\x89\x02"
  "\x7b\xf8\x01\x81\x87\x02\x7a\xf6\x01\x81\x85\x02\x79\xf4\x01\x81"
  "\x85\x02\x78\xf2\x01\x81\x87\x02\x77\xf0\x01\xfd\xff\x03\x76\xee"
  "\x01\xfd\xff\x03\x75\xec\x01\x81\x87\x02\x74\xea\x01\x81\x87\x02"
  "\x73\xe8\x01\x81\x89\x02\x72\xe6\x01\x81\x89\x02\x71\xe4\x01\x81"
  "\x89\x02\x70\xe2\x01\x81\x89\x02\x6f\xe0\x01\x81\x89\x02\x6e\xde"
  "\x01\x81\x89\x02\x6d\xdc\x01\x81\x8b\x02\x6c\xda\x01\x81\x89\x02"
  "\x6b\xd8\x01\x81\x87\x02\x6a\xd6\x01\x81\x87\x02\x69\xd4\x01\x81"
  "\x87\x02\x68\xd2\x01\x81\x87\x02\x67\xd0\x01\x81\x87\x02\x66\xce"
  "\x01\x81\x85\x02\x65\xcc\x01\x81\x8d\x02\x64\xca\x01\x85\x08\x63"
  "\xc8\x01\x81\x8d\x02\x62\xc6\x01\x85\x08\x61\xc4\x01\x81\x87\x02"
  "\x60\xc2\x01\x84\x06\x5f\xc0\x01\x81\x89\x02\x5e\xbe\x01\x84\x06"
  "\x5d\xbc\x01\x81\x87\x02\x5c\xba\x01\x84\x06\x5b\xb8\x01\x81\x89"
  "\x02\x5a\xb6\x01\x85\x08\x59\xb4\x01\x81\x89\x02\x58\xb2\x01\x84"
  "\x06\x57\xb0\x01\x81\x89\x02\x56\xae\x01\x84\x06\x55\xac\x01\x81"
  "\x89\x02\x54\xaa\x01\x81\x87\x02\x53\xa8\x01\x84\x06\x52\xa6\x01"
  "\x81\x8d\x02\x51\xa4\x01\x81\x8b\x02\x50\xa2\x01\x85\x08\x4f\xa0"
  "\x01\x81\x89\x02\x4e\x9e\x01\x81\x87\x02\x4d\x9c\x01\x84\x06\x4c"
  "\x9a\x01\x81\x89\x02\x4b\x98\x01\x81\x87\x02\x4a\x96\x01\x84\x06"
  "\x49\x94\x01\x81\x85\x02\x48\x92\x01\x81\x85\x02\x47\x90\x01\x84"
  "\x06\x46\x8e\x01\x81\x87\x02\x45\x8c\x01\x84\x06\x44\x8a\x01\x81"
  "\x8b\x02\x43\x88\x01\x81\x85\x02\x42\x86\x01\x84\x06\x41\x84\x01"
  "\x81\x8d\x02\x40\x82\x01\x85\x08\x3f\x80\x01\x81\x8d\x02\x3e\x7e"
  "\x85\x08\x3d\x7c\x81\x87\x02\x3c\x7a\x84\x06\x3b\x78\x81\x89\x02"
  "\x3a\x76\x84\x06\x39\x74\x81\x87\x02\x38\x72\x84\x06\x37\x70\x81"
  "\x89\x02\x36\x6e\x85\x08\x35\x6c\x81\x89\x02\x34\x6a\x84\x06\x33"
  "\x68\x81\x89\x02\x32\x66\x84\x06\x31\x64\x81\x89\x02\x30\x62\x81"
  "\x87\x02\x2f\x60\x84\x06\x2e\x5e\x81\x8d\x02\x2d\x5c\x81\x8b\x02"
  "\x2c\x5a\x85\x08\x2b\x58\x81\x89\x02\x2a\x56\x81\x87\x02\x29\x54"
  "\x84\x06\x28\x52\x81\x89\x02\x27\x50\x81\x87\x02\x26\x4e\x84\x06"
  "\x25\x4c\x81\x85\x02\x24\x4a\x81\x85\x02\x23\x48\x84\x06\x22\x46"
  "\x81\x87\x02\x21\x44\x84\x06\x20\x42\x81\x89\x02\x1f\x40\x81\xab"
  "\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x85\x02\x1c\x3a\x81\x83\x02"
  "\x1b\x38\x81\x85\x02\x1a\x36\x81\x85\x02\x19\x34\x81\x87\x02\x18"
  "\x32\x81\x83\x02\x17\x30\x81\x85\x02\x16\x2e\x81\x83\x02\x15\x2c"
  "\x81\x87\x02\x14\x2a\x81\x87\x02\x13\x28\x81\x83\x02\x12\x26\x81"
  "\x85\x02\x11\x24\x81\x83\x02\x10\x22\x81\x85\x02\x0f\x20\x81\x85"
  "\x02\x0e\x1e\x81\x85\x02\x0d\x1c\x81\x87\x02\x0c\x1a\x81\x83\x02"
  "\x0b\x18\x81\x85\x02\x0a\x16\x81\x83\x02\x09\x14\x81\xa3\x02\x08"
  "\x12\x81\x87\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x85\x02\x05\x0c"
  "\x81\x83\x02\x04\x0a\x81\x89\x02\x03\x08\x81\x85\x02\x02\x06\x81"
  "\x87\x02\x01\x04\x81\x83\x02\xa7\x07\x84\x08";

SCHEME_OBJECT *
wttree_so_data_4251645db0305c5b (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_wttree_so_data_4251645db0305c5b [0]))), (sizeof (prog_wttree_so_data_4251645db0305c5b)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_489]));
}

DECLARE_COMPILED_DATA_NS ("wttree.so", wttree_so_data_4251645db0305c5b)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("wttree.so", "f3b664f1b6dc3eff")
